@@ -43,7 +43,7 @@
 #include <k3dsdk/iuser_interface.h>
 #include <k3dsdk/iuser_interface_plugin.h>
 #include <k3dsdk/log.h>
-#include <k3dsdk/logbufs.h>
+#include <k3dsdk/log_control.h>
 #include <k3dsdk/nodes.h>
 #include <k3dsdk/options_policy.h>
 #include <k3dsdk/property.h>
@@ -58,10 +58,6 @@
 #include <k3dsdk/version.h>
 #include <k3dsdk/xml.h>
 
-#include <boost/filesystem/convenience.hpp>
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/path.hpp>
-
 #include <iomanip>
 #include <iterator>
 
@@ -102,32 +98,30 @@ typedef std::vector<std::string> string_array;
 /////////////////////////////////////////////////////////////////////////////
 // User options specified on the command line
 
-typedef std::vector<std::streambuf*> logbufs_t;
-
 bool g_show_timestamps = false;
 bool g_show_process = false;
 bool g_syslog = false;
 bool g_color_level = false;
-k3d::log_level_t g_minimum_log_level = k3d::WARNING;
+k3d::log_level_t g_minimum_log_level = k3d::K3D_LOG_LEVEL_WARNING;
 
 k3d::iuser_interface_plugin* g_user_interface = 0;
 
-boost::filesystem::path g_options_path;
+k3d::filesystem::path g_options_path;
 std::string g_plugin_paths;
-boost::filesystem::path g_shader_cache_path;
-boost::filesystem::path g_share_path;
-boost::filesystem::path g_user_interface_path;
-boost::filesystem::path g_null_user_interface_path;
+k3d::filesystem::path g_shader_cache_path;
+k3d::filesystem::path g_share_path;
+k3d::filesystem::path g_user_interface_path;
+k3d::filesystem::path g_null_user_interface_path;
 
 /////////////////////////////////////////////////////////////////////////////
 // handle_error
 
 void handle_error(const std::string& Message, bool& Quit, bool& Error)
 {
-	k3d::log() << error << Message << std::endl;
-
 	Quit = true;
 	Error = true;
+
+	throw std::runtime_error(Message);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -162,18 +156,22 @@ void set_default_options(bool& Quit, bool& Error)
 {
 #ifdef K3D_PLATFORM_WIN32
 
-	std::string module(256, '\0');
-	GetModuleFileName(0, const_cast<char*>(module.data()), module.size());
-	module.resize(strlen(module.c_str()));
-	const boost::filesystem::path module_path = boost::filesystem::path(module, boost::filesystem::native).branch_path();
+	// Get the path where this module is executing ...
+	std::string executable(256, '\0');
+	GetModuleFileName(0, const_cast<char*>(executable.data()), executable.size());
+	executable.resize(strlen(executable.c_str()));
+	const k3d::filesystem::path executable_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(executable)).branch_path();
 
-	const boost::filesystem::path data_path = k3d::system::get_home_directory() / boost::filesystem::path(".k3d", boost::filesystem::native);
-	g_options_path = data_path / "options.k3d";
-	g_plugin_paths = (module_path / "plugins").native_file_string();
-	g_shader_cache_path = data_path / "shadercache";
-	g_share_path = module_path / "share";
-	g_user_interface_path = module_path / "libk3dngui.dll";
-	g_null_user_interface_path = module_path / "libk3dnui.dll";
+	const k3d::filesystem::path data_path = k3d::system::get_home_directory() / k3d::filesystem::native_path(k3d::ustring::from_utf8(".k3d"));
+	g_options_path = data_path / k3d::filesystem::generic_path("options.k3d");
+	g_plugin_paths = (executable_path / k3d::filesystem::generic_path("plugins")).native_utf8_string().raw();
+	g_shader_cache_path = data_path / k3d::filesystem::generic_path("shadercache");
+	g_share_path = executable_path / k3d::filesystem::generic_path("share");
+	g_user_interface_path = executable_path / k3d::filesystem::generic_path("libk3dngui.dll");
+	g_null_user_interface_path = executable_path / k3d::filesystem::generic_path("libk3dnui.dll");
+
+	// Add the executable path to PATH
+	_putenv(("PATH=" + executable_path.native_filesystem_string() + ";" + k3d::system::get_env("PATH")).c_str());
 
 #endif // K3D_PLATFORM_WIN32
 }
@@ -182,7 +180,7 @@ void set_default_options(bool& Quit, bool& Error)
 // parse_logging_options
 
 /// Looks for command-line arguments that apply to logging (so we can set them up right away)
-string_array parse_command_line_logging_options(const std::string& ProcessName, logbufs_t& LogBufs, const string_array Options, bool& Quit, bool& Error)
+string_array parse_command_line_logging_options(const std::string& ProcessName, const string_array Options, bool& Quit, bool& Error)
 {
 	// Keep track of "unused" options ...
 	string_array unused;
@@ -215,11 +213,11 @@ string_array parse_command_line_logging_options(const std::string& ProcessName,
 			}
 
 			if((*option) == "warning")
-				g_minimum_log_level = k3d::WARNING;
+				g_minimum_log_level = k3d::K3D_LOG_LEVEL_WARNING;
 			else if((*option) == "information")
-				g_minimum_log_level = k3d::INFO;
+				g_minimum_log_level = k3d::K3D_LOG_LEVEL_INFO;
 			else if((*option) == "debug")
-				g_minimum_log_level = k3d::DEBUG;
+				g_minimum_log_level = k3d::K3D_LOG_LEVEL_DEBUG;
 			else
 			{
 				handle_error("Valid values for the --log-level option are \"warning\", \"information\", or \"debug\"", Quit, Error);
@@ -232,38 +230,12 @@ string_array parse_command_line_logging_options(const std::string& ProcessName,
 		}
 	}
 
-	LogBufs.push_back(new k3d::reset_level_buf(k3d::log()));
-
-#ifdef K3D_PLATFORM_WIN32
-
-	LogBufs.push_back(new k3d::output_debug_string_buf(k3d::log()));
-
-#endif // K3D_PLATFORM_WIN32
-
-	if(g_show_timestamps)
-		LogBufs.push_back(new k3d::timestamp_buf(k3d::log()));
-
-	if(g_show_process)
-		LogBufs.push_back(new k3d::tag_buf("[" + boost::filesystem::path(ProcessName, boost::filesystem::native).leaf() + "]", k3d::log()));
-
-	if(g_color_level)
-	{
-#ifdef K3D_PLATFORM_WIN32
-		LogBufs.push_back(new k3d::ansi_to_win32_buf(k3d::log()));
-#endif // K3D_PLATFORM_WIN32
-		LogBufs.push_back(new k3d::color_level_buf(k3d::log()));
-	}
-
-	LogBufs.push_back(new k3d::show_level_buf(k3d::log()));
-
-#ifndef	K3D_PLATFORM_WIN32
-
-	if(g_syslog)
-		LogBufs.push_back(new k3d::syslog_buf(k3d::log()));
-
-#endif	// !K3D_PLATFORM_WIN32
-
-	LogBufs.push_back(new k3d::filter_by_level_buf(g_minimum_log_level, k3d::log()));
+	k3d::log_show_timestamps(g_show_timestamps);
+	k3d::log_set_tag(g_show_process ? "[" + ProcessName + "]" : std::string());
+	k3d::log_color_level(g_color_level);
+	k3d::log_show_level(true);
+	k3d::log_syslog(g_syslog);
+	k3d::log_minimum_level(g_minimum_log_level);
 
 	return unused;
 }
@@ -292,7 +264,7 @@ string_array parse_command_line_2(const string_array Options, bool& Quit, bool&
 			if(*option == "none")
 				g_user_interface_path = g_null_user_interface_path;
 			else
-				g_user_interface_path = boost::filesystem::path(*option, boost::filesystem::native);
+				g_user_interface_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(*option));
 		}
 		else if((*option) == "--plugins")
 		{
@@ -314,7 +286,7 @@ string_array parse_command_line_2(const string_array Options, bool& Quit, bool&
 				return string_array();
 			}
 
-			g_shader_cache_path = boost::filesystem::path(*option, boost::filesystem::native);
+			g_shader_cache_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(*option));
 		}
 		else if((*option) == "--share")
 		{
@@ -325,7 +297,7 @@ string_array parse_command_line_2(const string_array Options, bool& Quit, bool&
 				return string_array();
 			}
 
-			g_share_path = boost::filesystem::path(*option, boost::filesystem::native);
+			g_share_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(*option));
 		}
 		else if((*option) == "--options")
 		{
@@ -336,7 +308,7 @@ string_array parse_command_line_2(const string_array Options, bool& Quit, bool&
 				return string_array();
 			}
 
-			g_options_path = boost::filesystem::path(*option, boost::filesystem::native);
+			g_options_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(*option));
 		}
 		else
 		{
@@ -367,15 +339,15 @@ void check_dependencies(bool& Quit, bool& Error)
 	k3d::log() << warning "xml parser: unknown" << std::endl;
 #endif
 
-	k3d::log() << info << "options file: " << g_options_path.native_file_string() << std::endl;
+	k3d::log() << info << "options file: " << g_options_path.native_console_string() << std::endl;
 #ifndef K3D_STATIC_BUILD
 	k3d::log() << info << "plugin path(s): " << g_plugin_paths << std::endl;
 #endif // !K3D_STATIC_BUILD
-	k3d::log() << info << "shader cache path: " << g_shader_cache_path.native_file_string() << std::endl;
-	k3d::log() << info << "share path: " << g_share_path.native_file_string() << std::endl;
-	k3d::log() << info << "user interface: " << g_user_interface_path.native_file_string() << std::endl;
-	k3d::log() << info << "home directory: " << k3d::system::get_home_directory().native_file_string() << std::endl;
-	k3d::log() << info << "temp directory: " << k3d::system::get_temp_directory().native_file_string() << std::endl;
+	k3d::log() << info << "shader cache path: " << g_shader_cache_path.native_console_string() << std::endl;
+	k3d::log() << info << "share path: " << g_share_path.native_console_string() << std::endl;
+	k3d::log() << info << "user interface: " << g_user_interface_path.native_console_string() << std::endl;
+	k3d::log() << info << "home directory: " << k3d::system::get_home_directory().native_console_string() << std::endl;
+	k3d::log() << info << "temp directory: " << k3d::system::get_temp_directory().native_console_string() << std::endl;
 
 #ifdef K3D_HAVE_NLS
 	k3d::log() << info << "locale directory: " << K3D_LOCALE << std::endl;
@@ -384,31 +356,30 @@ void check_dependencies(bool& Quit, bool& Error)
 	// The options file must be specified and must exist ...
 	if(g_options_path.empty())
 	{
-		handle_error("Options path must be specified using --options <path>.  Shutting down.", Quit, Error);
+		handle_error("Options path must be specified using --options <path>.", Quit, Error);
 		return;
 	}
 
-	boost::filesystem::create_directories(g_options_path.branch_path());
-	if(!boost::filesystem::exists(g_options_path))
+	k3d::filesystem::create_directories(g_options_path.branch_path());
+	if(!k3d::filesystem::exists(g_options_path))
 	{
 		k3d::filesystem::ofstream stream(g_options_path);
 		stream << k3d::xml::declaration() << k3d::xml::element("k3dml") << std::endl;
 	}
 
-	if(!boost::filesystem::exists(g_options_path))
+	if(!k3d::filesystem::exists(g_options_path))
 	{
-		handle_error("Options path [" + g_options_path.native_file_string() + "] does not exist and could not be created.  Shutting down.", Quit, Error);
+		handle_error("Options path [" + g_options_path.native_console_string() + "] does not exist and could not be created.", Quit, Error);
 		return;
 	}
 
 	// Every specified plugin path must exist ...
-	k3d::system::paths_t plugin_paths;
-	k3d::system::decompose_path_list(g_plugin_paths, plugin_paths);
+	const k3d::system::paths_t plugin_paths = k3d::system::decompose_path_list(g_plugin_paths);
 	for(k3d::system::paths_t::const_iterator plugin_path = plugin_paths.begin(); plugin_path != plugin_paths.end(); ++plugin_path)
 	{
-		if(!boost::filesystem::exists(*plugin_path))
+		if(!k3d::filesystem::exists(*plugin_path))
 		{
-			handle_error("Plugin path [" + plugin_path->native_file_string() + "] does not exist.  Shutting down.", Quit, Error);
+			handle_error("Plugin path [" + plugin_path->native_console_string() + "] does not exist.", Quit, Error);
 			return;
 		}
 	}
@@ -416,28 +387,28 @@ void check_dependencies(bool& Quit, bool& Error)
 	// The shader cache path must be specified, and must already exist or be successfully created ...
 	if(g_shader_cache_path.empty())
 	{
-		handle_error("Shader cache path must be specified using --shadercache <path>.  Shutting down.", Quit, Error);
+		handle_error("Shader cache path must be specified using --shadercache <path>.", Quit, Error);
 		return;
 	}
 
-	boost::filesystem::create_directories(g_shader_cache_path);
-	if(!boost::filesystem::exists(g_shader_cache_path))
+	k3d::filesystem::create_directories(g_shader_cache_path);
+	if(!k3d::filesystem::exists(g_shader_cache_path))
 	{
-		handle_error("Shader cache path [" + g_shader_cache_path.native_file_string() + "] does not exist and could not be created.  Shutting down.", Quit, Error);
+		handle_error("Shader cache path [" + g_shader_cache_path.native_console_string() + "] does not exist and could not be created.", Quit, Error);
 		return;
 	}
 
 	// The share path must exist ...
-	if(!boost::filesystem::exists(g_share_path))
+	if(!k3d::filesystem::exists(g_share_path))
 	{
-		handle_error("Share path [" + g_share_path.native_file_string() + "] does not exist.  Shutting down.", Quit, Error);
+		handle_error("Share path [" + g_share_path.native_console_string() + "] does not exist.", Quit, Error);
 		return;
 	}
 
 	// Test for an OpenGL implementation ...
 	if(!k3d::gl::exists(k3d::log()))
 	{
-		handle_error("Could not connect to an OpenGL server.  Shutting down.", Quit, Error);
+		handle_error("Could not connect to an OpenGL server.", Quit, Error);
 		return;
 	}
 }
@@ -455,8 +426,8 @@ void create_user_interface(k3d::plugin_factory_collection& Plugins, bool& Quit,
 
 #else // K3D_STATIC_BUILD
 
-	const std::string module_name = g_user_interface_path.native_file_string();
-	if(!g_user_interface_path.empty() && !boost::filesystem::exists(g_user_interface_path))
+	const std::string module_name = g_user_interface_path.native_utf8_string().raw();
+	if(!g_user_interface_path.empty() && !k3d::filesystem::exists(g_user_interface_path))
 	{
 		handle_error("UI plugin module [" + module_name + "] does not exist", Quit, Error);
 		return;
@@ -493,6 +464,7 @@ void create_user_interface(k3d::plugin_factory_collection& Plugins, bool& Quit,
 
 	if(!dynamic_cast<k3d::iuser_interface*>(ui_plugin))
 	{
+		g_user_interface = 0;
 		delete dynamic_cast<k3d::ideletable*>(ui_plugin);
 		handle_error("UI plugin module [" + module_name + "] does not implement required interfaces", Quit, Error);
 		return;
@@ -579,7 +551,7 @@ string_array parse_command_line_3(const string_array Options, bool& Quit, bool&
 				return string_array();
 			}
 
-			const boost::filesystem::path document_path(*option, boost::filesystem::native);
+			const k3d::filesystem::path document_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(*option));
 
 			if(!filter->read_file(*document, document_path))
 			{
@@ -613,7 +585,7 @@ string_array parse_command_line_3(const string_array Options, bool& Quit, bool&
 			else
 			{
 				k3d::log() << info << "Running script [" << scriptname << "]" << std::endl;
-				k3d::filesystem::igzstream file(boost::filesystem::path(scriptname, boost::filesystem::native));
+				k3d::filesystem::igzstream file(k3d::filesystem::native_path(k3d::ustring::from_utf8(scriptname)));
 				k3d::iscript_engine::context_t context;
 				k3d::script::execute(k3d::script::code(file), scriptname, context, recognized, executed);
 			}
@@ -666,7 +638,7 @@ void check_unused_options(const string_array Options, bool& Quit, bool& Error)
 
 int main(int argc, char* argv[])
 {
-	const std::string program_name = boost::filesystem::path(argv[0], boost::filesystem::native).leaf();
+	const std::string program_name = k3d::filesystem::native_path(k3d::ustring::from_utf8(argv[0])).leaf().raw();
 
 #ifdef K3D_HAVE_NLS
 
@@ -677,8 +649,6 @@ int main(int argc, char* argv[])
 
 #endif
 
-	logbufs_t logbufs;
-
 	try
 	{
 		bool quit = false;
@@ -693,7 +663,7 @@ int main(int argc, char* argv[])
 		string_array options(&argv[1], &argv[argc]);
 
 		// Setup our logging options before going any further ...
-		options = parse_command_line_logging_options(program_name, logbufs, options, quit, error);
+		options = parse_command_line_logging_options(program_name, options, quit, error);
 		if(quit)
 			return error ? 1 : 0;
 
@@ -723,17 +693,18 @@ int main(int argc, char* argv[])
 		create_user_interface(ui_plugins, quit, error);
 		if(quit)
 			return error ? 1 : 0;
+		return_val_if_fail(g_user_interface, 1);
+
+		// Register our user interface ...
+		k3d::set_user_interface(*dynamic_cast<k3d::iuser_interface*>(g_user_interface));
 
 		// Make sure the UI gets cleaned-up properly ...
 		std::auto_ptr<k3d::ideletable> user_interface_storage(dynamic_cast<k3d::ideletable*>(g_user_interface));
 
 		// Give the UI a chance to handle command-line options ...
-		if(g_user_interface)
-		{
-			options = g_user_interface->parse_command_line(options, quit, error);
-			if(quit)
-				return error ? 1 : 0;
-		}
+		options = g_user_interface->parse_command_line(options, quit, error);
+		if(quit)
+			return error ? 1 : 0;
 
 		// Load plugins ...
 		k3d::plugin_factory_collection plugins;
@@ -746,9 +717,6 @@ int main(int argc, char* argv[])
 		k3d::render_farm_implementation render_farm(g_options_path);
 		k3d::set_render_farm(render_farm);
 
-		// Register our user interface ...
-		k3d::set_user_interface(*dynamic_cast<k3d::iuser_interface*>(g_user_interface));
-
 		// Create the main application object ...
 		k3d::application_implementation application(plugins);
 
@@ -759,8 +727,8 @@ int main(int argc, char* argv[])
 		k3d::register_application(application.interface());
 
 		// Switch the UI to its "normal" (post-startup) layout ...
-		if(g_user_interface)
-			g_user_interface->display_user_interface();
+		startup_message_handler(_("Starting user interface"));
+		g_user_interface->display_user_interface();
 
 		// Parse command-line options that control program execution ...
 		options = parse_command_line_3(options, quit, error, application.interface());
@@ -773,23 +741,35 @@ int main(int argc, char* argv[])
 			return error ? 1 : 0;
 
 		// Main UI event-loop ...
-		if(g_user_interface)
-			g_user_interface->start_event_loop();
+		g_user_interface->start_event_loop();
+
+		return 0;
 	}
 	catch(std::exception& e)
 	{
-		k3d::log() << critical << "Caught exception: " << e.what() << " ... terminating" << std::endl;
-		throw;
+		std::string message = "Caught exception [";
+			message += typeid(e).name();
+			message += "] - ";
+			message += e.what();
+
+		k3d::log() << critical << message << std::endl;
+
+#ifdef K3D_PLATFORM_WIN32
+		MessageBox(0, message.c_str(), _("K-3D Fatal Error"), MB_OK | MB_ICONSTOP);
+#endif // K3D_PLATFORM_WIN32
+
+		return 1;
 	}
 	catch(...)
 	{
-		k3d::log() << critical << "Caught unknown exception ... terminating" << std::endl;
-		throw;
+		const std::string message = "Caught unknown exception.";
+
+		k3d::log() << critical << message << std::endl;
+
+#ifdef K3D_PLATFORM_WIN32
+		MessageBox(0, message.c_str(), _("K-3D Fatal Error"), MB_OK | MB_ICONSTOP);
+#endif // K3D_PLATFORM_WIN32
+
+		return 1;
 	}
-
-	/** \todo Figure out why this causes a segfault with gcc 3.4 */
-//	std::for_each(logbufs.begin(), logbufs.end(), k3d::delete_object());
-
-	return 0;
 }
-
