@@ -21,7 +21,7 @@ Hapy::First &Hapy::First::operator +=(const First &f) {
 // difference
 Hapy::First &Hapy::First::operator -=(const First &f) {
 	for (Set::const_iterator i = f.theSet.begin(); i != f.theSet.end(); ++i) {
-		const Set::const_iterator pos = theSet.find(*i);
+		const Set::iterator pos = theSet.find(*i);
 		if (pos != theSet.end())
 			theSet.erase(pos);
 	}
