@@ -2,7 +2,7 @@
 #define K3DSDK_BOUNDING_BOX_H
 
 // K-3D
-// Copyright (c) 1995-2004, Timothy M. Shead
+// Copyright (c) 1995-2006, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -25,9 +25,11 @@
 		\author Anders Dahnielson (anders@dahnielson.com)
 */
 
+#include "algebra.h"
 #include "vectors.h"
 
 #include <algorithm>
+#include <cassert>
 #include <cmath>
 #include <iosfwd>
 #include <limits>
@@ -49,7 +51,7 @@ public:
 		nz(std::numeric_limits<double>::max())
 	{
 	}
-	
+
 	bounding_box3(double PX, double NX, double PY, double NY, double PZ, double NZ) :
 		px(std::max(PX, NX)),
 		nx(std::min(PX, NX)),
@@ -61,7 +63,7 @@ public:
 	}
 
 	/// Grows the bounding box as needed to contain the given point
-	void insert(const vector3& Point)
+	void insert(const point3& Point)
 	{
 		px = std::max(px, Point[0]);
 		nx = std::min(nx, Point[0]);
@@ -83,7 +85,7 @@ public:
 	}
 
 	/// Returns true iff the bounding box contains the given point
-	bool contains(const vector3& Point) const
+	bool contains(const point3& Point) const
 	{
 		return nx <= Point[0] && Point[0] <= px && ny <= Point[1] && Point[1] <= py && nz <= Point[2] && Point[2] <= pz;
 	}
@@ -99,13 +101,13 @@ public:
 	{
 		return empty() ? 0.0 : px-nx;
 	}
-	
+
 	/// Returns the height of the bounding box, or zero if the box is empty
 	double height() const
 	{
 		return empty() ? 0.0 : py-ny;
 	}
-	
+
 	/// Returns the depth of the bounding box, or zero if the box is empty
 	double depth() const
 	{
@@ -113,12 +115,14 @@ public:
 	}
 
 	/// Returns the center of the bounding box, asserts if the box is empty
-	const vector3 center() const
+	const point3 center() const
 	{
 		assert(!empty());
-		return vector3((px + nx) / 2, (py + ny) / 2, (pz + nz) / 2);
+		return point3((px + nx) / 2, (py + ny) / 2, (pz + nz) / 2);
 	}
 
+	bounding_box3& operator*=(const matrix4 Transformation);
+
 	/// Stores the maximum x value (not necessarily positive)
 	double px;
 	/// Stores the minimum x value (not necessarily negative)
@@ -133,6 +137,8 @@ public:
 	double nz;
 };
 
+bounding_box3 operator*(const bounding_box3& BBox, const matrix4& Transformation);
+bounding_box3 operator*(const matrix4& Transformation, const bounding_box3& BBox);
 bool operator==(const bounding_box3& LHS, const bounding_box3& RHS);
 bool operator!=(const bounding_box3& LHS, const bounding_box3& RHS);
 
