@@ -2,7 +2,7 @@
 #define K3DSDK_CLASSES_H
 
 // K-3D
-// Copyright (c) 1995-2005, Timothy M. Shead
+// Copyright (c) 1995-2006, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -73,7 +73,6 @@ inline const uuid PerlEngine() { return uuid(0x00000001, 0x00000000, 0x00000000,
 inline const uuid PythonEngine() { return uuid(0x00000001, 0x00000000, 0x00000000, 0x00000076); }
 inline const uuid ScalarBezierChannel() { return uuid(0x00000001, 0x00000000, 0x00000000, 0x0000007c); }
 inline const uuid ColorBezierChannel() { return uuid(0x00000001, 0x00000000, 0x00000000, 0x0000007d); }
-inline const uuid Transform() { return uuid(0x00000001, 0x00000000, 0x00000000, 0x00000081); }
 inline const uuid TIFFWriter() { return uuid(0x00000001, 0x00000000, 0x00000000, 0x00000085); }
 inline const uuid FrozenMesh() { return uuid(0x305ceb88, 0x7cf34870, 0x8b5e673c, 0x636beab9); }
 inline const uuid MeshInstance() { return uuid(0x2c1d60a6, 0x863541a1, 0xbd649bd1, 0x1ea8ae24); }
@@ -88,7 +87,6 @@ inline const uuid RenderManVolumeShader() { return uuid(0xfd07a255, 0x9bb84841,
 inline const uuid Position() { return uuid(0xe2edd795, 0x08f9416a, 0x84139876, 0x9c25a60a); }
 inline const uuid Orientation() { return uuid(0xcf562348, 0x02624035, 0xae649a84, 0xf42e0b69); }
 inline const uuid Scale() { return uuid(0x542de0d6, 0xe1e94e4a, 0x883eb23c, 0x3612fb8a); }
-inline const uuid FrozenSelection() { return uuid(0xac9b1faf, 0x28ed4b34, 0x8ad9e556, 0xda333f81); }
 inline const uuid K3DScriptEngine() { return uuid(0x6598ab84, 0xfa0f48f2, 0xbc690f11, 0xe686e11b); }
 inline const uuid FrozenTransformation() { return uuid(0x6ea85710, 0x90da4d35, 0xacec30ee, 0xa6aacb9d); }
 inline const uuid Camera() { return uuid(0x45ce1872, 0xaf184b6d, 0xb391e136, 0x0dcfe8b5); }
@@ -96,11 +94,14 @@ inline const uuid DocumentWriter() { return uuid(0x0cbc9131, 0x172541b2, 0xb424a
 inline const uuid DocumentReader() { return uuid(0xf02e8dac, 0xa57d4d76, 0xa6170c3a, 0x9bf09d3b); }
 inline const uuid AqsisDisplacementShaderLayer() { return uuid(0x1802dce3, 0x71004329, 0x80cbdf0e, 0xbc7f142c); }
 inline const uuid AqsisSurfaceShaderLayer() { return uuid(0x261e244e, 0xd82947ba, 0x9e56a9af, 0x03d4cc0f); }
+inline const uuid Material() { return uuid(0x00000001, 0x00000002, 0x00000003, 0x00000004); }
+inline const uuid OpenGLMaterial() { return uuid(0x00000001, 0x00000002, 0x00000003, 0x00000005); }
 //@}
 
 /** \name Inactive class IDs for plugins that have been removed */
 //@{
 inline const uuid JavaScriptEngine() { return uuid(0x00000001, 0x00000000, 0x00000000, 0x00000048); }
+inline const uuid Transform() { return uuid(0x00000001, 0x00000000, 0x00000000, 0x00000081); }
 //@}
 
 } // namespace classes
@@ -109,4 +110,3 @@ inline const uuid JavaScriptEngine() { return uuid(0x00000001, 0x00000000, 0x000
 
 #endif // !K3DSDK_CLASSES_H
 
-
