@@ -39,11 +39,15 @@
 namespace k3d
 {
 
-// Forward class declarations
-
+template<typename, typename>
+class basic_alpha;
+	
 template<typename, typename>
 class basic_luma;
 
+template<typename, typename>
+class basic_luma_alpha;
+
 template<typename, typename>
 class basic_rgb;
 
@@ -334,6 +338,70 @@ public:
 	sample_type value;
 };
 
+/////////////////////////////////////////////////////////////////////////////
+// basic_alpha
+
+/// Encapsulates storage for an alpha color sample
+template<typename SampleType, typename SampleTraits = color_traits<SampleType> >
+class basic_alpha
+{
+public:
+	typedef SampleType sample_type;
+	typedef SampleTraits sample_traits;
+	typedef basic_alpha<sample_type, sample_traits> this_type;
+
+	/// Default constructor sets all samples to zero
+	basic_alpha() :
+		alpha(sample_traits::transparent())
+	{
+	}
+
+	/// Straightforward constructor that initializes samples
+	basic_alpha(const sample_type Alpha) :
+		alpha(Alpha)
+	{
+	}
+
+	template<typename ForeignType, typename ForeignTraits>
+	basic_alpha(const basic_alpha<ForeignType, ForeignTraits>& RHS) :
+		alpha(sample_traits::convert(RHS.Alpha))
+	{
+	}
+
+	template<typename ForeignType, typename ForeignTraits>
+	basic_alpha(const basic_rgb<ForeignType, ForeignTraits>& RHS) :
+		alpha(sample_traits::opaque())
+	{
+	}
+
+	template<typename ForeignType, typename ForeignTraits>
+	basic_alpha(const basic_rgba<ForeignType, ForeignTraits>& RHS) :
+		alpha(sample_traits::convert(RHS.alpha))
+	{
+	}
+
+	basic_alpha(const basic_hsv& RHS) :
+		alpha(sample_traits::opaque())
+	{
+	}
+
+	/// Serialization
+	friend std::ostream& operator << (std::ostream& Stream, const basic_alpha<sample_type, sample_traits>& RHS)
+	{
+		Stream << RHS.alpha;
+		return Stream;
+	}
+
+	/// Deserialization
+	friend std::istream& operator >> (std::istream& Stream, basic_alpha<sample_type, sample_traits>& RHS)
+	{
+		Stream >> RHS.alpha;
+		return Stream;
+	}
+
+	sample_type alpha;
+};
+
 /////////////////////////////////////////////////////////////////////////////
 // basic_luma
 
@@ -503,6 +571,14 @@ public:
 	{
 	}
 
+	template<typename ForeignType, typename ForeignTraits>
+	basic_rgb(const basic_alpha<ForeignType, ForeignTraits>& RHS) :
+		red(sample_traits::convert(RHS.alpha)),
+		green(sample_traits::convert(RHS.alpha)),
+		blue(sample_traits::convert(RHS.alpha))
+	{
+	}
+	
 	template<typename ForeignType, typename ForeignTraits>
 	basic_rgb(const basic_luma<ForeignType, ForeignTraits>& RHS) :
 		red(sample_traits::convert(RHS.luma)),
