@@ -65,7 +65,7 @@ public:
 	implementation(const std::string& Name, icommand_node* Parent);
 	virtual ~implementation();
 
-	bool execute_command(const std::string& Command, const std::string& Arguments);
+	const result execute_command(const std::string& Command, const std::string& Arguments);
 };
 
 } // namespace command_node
