@@ -42,10 +42,9 @@
 #include "iwritable_property.h"
 #include "nodes.h"
 #include "result.h"
+#include "state_change_set.h"
 #include "xml.h"
 
-#include <boost/filesystem/path.hpp>
-#include <boost/filesystem/operations.hpp>
 #include <boost/lexical_cast.hpp>
 #include <boost/static_assert.hpp>
 #include <boost/type_traits.hpp>
@@ -129,8 +128,8 @@ protected:
 /////////////////////////////////////////////////////////////////////////////
 // path_serialization
 
-void save_external_resource(xml::element& Element, const ipersistent::save_context& Context, const std::string& Name, const ipath_property::reference_t Reference, const boost::filesystem::path& Value);
-void load_external_resource(xml::element& Element, const ipersistent::load_context& Context, ipath_property::reference_t& Reference, boost::filesystem::path& Value);
+void save_external_resource(xml::element& Element, const ipersistent::save_context& Context, const std::string& Name, const ipath_property::reference_t Reference, const filesystem::path& Value);
+void load_external_resource(xml::element& Element, const ipersistent::load_context& Context, ipath_property::reference_t& Reference, filesystem::path& Value);
 
 /// Serialization policy for filesystem path data that handles external filesystem resources
 template<typename value_t, class property_policy_t>
@@ -150,7 +149,7 @@ public:
 	void load(xml::element& Element, const ipersistent::load_context& Context)
 	{
 		ipath_property::reference_t reference;
-		boost::filesystem::path value;
+		filesystem::path value;
 
 		load_external_resource(Element, Context, reference, value);
 
@@ -210,21 +209,9 @@ private:
 // property_lookup
 
 /** \brief Encapsulates the lookup process for connected properties
-	\note Breaks circular dependencies by returning the original property
+	\note In the case of circular dependencies, returns the same value as the input property
 */
-inline iproperty* property_lookup(iproperty* const Source, idag& DAG)
-{
-	iproperty* result = Source;
-	for(iproperty* dependency = DAG.dependency(*Source); dependency; dependency = DAG.dependency(*dependency))
-	{
-		result = dependency;
-
-		if(Source == dependency)
-			break;
-	}
-
-	return result;
-}
+iproperty* property_lookup(iproperty* const Source, idag& DAG);
 
 /////////////////////////////////////////////////////////////////////////////
 // no_property
@@ -648,7 +635,7 @@ public:
 	{
 		m_pattern_filters.push_back(PatternFilter);
 	}
-	
+
 protected:
 	template<typename init_t>
 	path_property(const init_t& Init) :
@@ -920,7 +907,7 @@ private:
 	const char* const m_label;
 	const char* const m_description;
 	const ienumeration_property::enumeration_values_t& m_values;
-	sigc::signal0<void> m_values_changed_signal;
+	sigc::signal<void> m_values_changed_signal;
 	deleted_signal_t m_deleted_signal;
 };
 
@@ -1209,11 +1196,6 @@ public:
 		return true;
 	}
 
-	const unsigned long property_precision()
-	{
-		return m_precision;
-	}
-
 	const double property_step_increment()
 	{
 		return m_step_increment;
@@ -1232,7 +1214,6 @@ protected:
 		m_node(Init.node()),
 		m_label(Init.label()),
 		m_description(Init.description()),
-		m_precision(Init.precision()),
 		m_step_increment(Init.step_increment()),
 		m_units(Init.units())
 	{
@@ -1249,7 +1230,6 @@ private:
 	inode* const m_node;
 	const char* const m_label;
 	const char* const m_description;
-	const unsigned long m_precision;
 	const double m_step_increment;
 	const std::type_info& m_units;
 	deleted_signal_t m_deleted_signal;
@@ -1528,11 +1508,12 @@ protected:
 	void set_value(const value_t& Value, iunknown* const Hint = 0)
 	{
 		if(ready_to_record())
-			{
-				m_changes = true;
-				m_state_recorder.current_change_set()->recording_done_signal().connect(sigc::mem_fun(*this, &this_t::on_recording_done));
-				storage_policy_t::start_recording(m_state_recorder);
-			}
+		{
+			m_changes = true;
+			/// Note ... we don't save the connection here because connections are automatically disconnected when the signal is emitted
+			m_state_recorder.connect_recording_done_signal(sigc::mem_fun(*this, &this_t::on_recording_done));
+			storage_policy_t::start_recording(m_state_recorder);
+		}
 
 		storage_policy_t::set_value(Value, Hint);
 	}
@@ -1902,13 +1883,13 @@ protected:
 /////////////////////////////////////////////////////////////////////////////
 // change_signal
 
-/// Signal policy for data containers that notify observers when their value changes
+/// Signal policy for data containers that notify observers when their value changes, including through undo/redo.
 template<typename value_t>
 class change_signal
 {
 public:
 	/// Defines a signal emitted when the underlying data changes.  The signal includes an optional "hint" that describes the nature of the change.
-	typedef sigc::signal1<void, iunknown*> changed_signal_t;
+	typedef sigc::signal<void, iunknown*> changed_signal_t;
 
 	/// Returns a reference to the signal that is emitted whenever the underlying data changes
 	changed_signal_t& changed_signal()
@@ -1933,14 +1914,61 @@ protected:
 
 	void finish_recording(istate_recorder& StateRecorder)
 	{
-		StateRecorder.current_change_set()->undo_signal().connect(sigc::bind(m_changed_signal.make_slot(), static_cast<iunknown*>(0)));
-		StateRecorder.current_change_set()->redo_signal().connect(sigc::bind(m_changed_signal.make_slot(), static_cast<iunknown*>(0)));
+		StateRecorder.current_change_set()->connect_undo_signal(sigc::bind(m_changed_signal.make_slot(), static_cast<iunknown*>(0)));
+		StateRecorder.current_change_set()->connect_redo_signal(sigc::bind(m_changed_signal.make_slot(), static_cast<iunknown*>(0)));
 	}
 
 private:
 	changed_signal_t m_changed_signal;
 };
 
+/// Signal policy for data containers that notify observers when their value changes.  Observers can choose whether to be notified every time the value changes (including undo/redo), or only when the value is changed explicitly by a caller.
+template<typename value_t>
+class explicit_change_signal
+{
+public:
+	/// Defines a signal emitted when the underlying data changes.  The signal includes an optional "hint" that describes the nature of the change.
+	typedef sigc::signal<void, k3d::iunknown*> changed_signal_t;
+
+	/// Returns a reference to the signal that is emitted whenever the underlying data changes.
+	changed_signal_t& changed_signal()
+	{
+		return m_changed_signal;
+	}
+
+	/// Connects a slot to a signal that is emitted whenever the underlying data is modified explicitly through set_value, never by undo/redo
+	const sigc::connection connect_explicit_change_signal(const sigc::slot<void, k3d::iunknown*>& Slot)
+	{
+		return m_explicit_change_signal.connect(Slot);
+	}
+
+protected:
+	template<typename init_t>
+	explicit_change_signal(const init_t& Init)
+	{
+	}
+
+	void start_recording(k3d::istate_recorder& StateRecorder)
+	{
+	}
+
+	void set_value(k3d::iunknown* const Hint)
+	{
+		m_changed_signal.emit(Hint);
+		m_explicit_change_signal.emit(Hint);
+	}
+
+	void finish_recording(k3d::istate_recorder& StateRecorder)
+	{
+		StateRecorder.current_change_set()->connect_undo_signal(sigc::bind(m_changed_signal.make_slot(), static_cast<k3d::iunknown*>(0)));
+		StateRecorder.current_change_set()->connect_redo_signal(sigc::bind(m_changed_signal.make_slot(), static_cast<k3d::iunknown*>(0)));
+	}
+
+private:
+	changed_signal_t m_changed_signal;
+	changed_signal_t m_explicit_change_signal;
+};
+
 /// Convenience macro for declaring k3d::data::container nodes
 #define k3d_data(value_type, name_policy, signal_policy, undo_policy, storage_policy, constraint_policy, property_policy, serialization_policy) \
 	k3d::data::container<value_type, serialization_policy<value_type, property_policy<value_type, name_policy<constraint_policy<value_type, undo_policy<value_type, storage_policy<value_type, signal_policy<value_type> > > > > > > >
@@ -2191,29 +2219,6 @@ inline const initializer_t<values_t<data_t> > init_values(const data_t& Values)
 	return initializer_t<values_t<data_t> >(values_t<data_t>(Values));
 }
 
-/// Helper class used to initialize measurement properties
-class precision_t
-{
-public:
-	explicit precision_t(const unsigned int Precision) :
-		m_precision(Precision)
-	{
-	}
-
-	const unsigned int precision() const
-	{
-		return m_precision;
-	}
-
-private:
-	const unsigned int m_precision;
-};
-
-inline const initializer_t<precision_t> init_precision(const unsigned int Precision)
-{
-	return initializer_t<precision_t>(precision_t(Precision));
-}
-
 /// Helper class used to initialize measurement properties
 class step_increment_t
 {
@@ -2374,16 +2379,6 @@ inline const initializer_t<slot_initializer_t<slot_t> > init_slot(const slot_t&
 	return initializer_t<slot_initializer_t<slot_t> >(slot_initializer_t<slot_t>(Slot));
 }
 
-#if BOOST_VERSION < 103200
-
-/// Defines equality for boost::filesystem::path
-inline bool operator!=(const boost::filesystem::path& LHS, const boost::filesystem::path& RHS)
-{
-	return LHS.native_file_string() != RHS.native_file_string();
-}
-
-#endif // BOOST_VERSION < 103200
-
 } // namespace data
 
 namespace detail
@@ -2438,8 +2433,8 @@ void undoable_new(object_t* const Object, idocument& Document)
 	// Create an instance container that only deletes the object if it has been undone
 	typedef detail::instance_container<object_t> container_t;
 	container_t* const container = new container_t(Object, false);
-	changeset->undo_signal().connect(sigc::bind(sigc::mem_fun(*container, &container_t::on_owned), true));
-	changeset->redo_signal().connect(sigc::bind(sigc::mem_fun(*container, &container_t::on_owned), false));
+	changeset->connect_undo_signal(sigc::bind(sigc::mem_fun(*container, &container_t::on_owned), true));
+	changeset->connect_redo_signal(sigc::bind(sigc::mem_fun(*container, &container_t::on_owned), false));
 
 	changeset->record_old_state(container);
 }
@@ -2462,8 +2457,8 @@ void undoable_delete(object_t* const Object, idocument& Document)
 	// Create an instance container that only deletes the object if it hasn't been undone
 	typedef detail::instance_container<object_t> container_t;
 	container_t* const container = new container_t(Object, true);
-	changeset->undo_signal().connect(sigc::bind(sigc::mem_fun(*container, &container_t::on_owned), false));
-	changeset->redo_signal().connect(sigc::bind(sigc::mem_fun(*container, &container_t::on_owned), true));
+	changeset->connect_undo_signal(sigc::bind(sigc::mem_fun(*container, &container_t::on_owned), false));
+	changeset->connect_redo_signal(sigc::bind(sigc::mem_fun(*container, &container_t::on_owned), true));
 
 	changeset->record_old_state(container);
 }
