@@ -27,7 +27,7 @@
 namespace k3d
 {
 
-void dependencies::register_object_dependency(iobject& Object, const bool CopyByReference)
+void dependencies::register_object_dependency(inode& Object, const bool CopyByReference)
 {
 	// Add this object to the list ...
 	m_objects.insert(std::make_pair(&Object, CopyByReference));
