@@ -56,7 +56,6 @@ using namespace k3d::xml;
 #include <sigc++/bind.h>
 
 #include "fstream.h"
-#include <boost/filesystem/path.hpp>
 
 #include <fstream>
 #include <iterator>
@@ -103,19 +102,23 @@ public:
 		delete Node;
 	}
 
-	void start_recording(std::auto_ptr<state_change_set> ChangeSet)
+	void start_recording(std::auto_ptr<state_change_set> ChangeSet, const char* const Context)
 	{
-		return_if_fail(ChangeSet.get());
-
+		if(!ChangeSet.get())
+		{
+			log() << error << "start_recording() attempt with NULL changeset.  Context: " << Context << std::endl;
+			return;
+		}
+		
 		if(m_current_recording.get())
 		{
-			log() << warning << "Starting undo/redo recording while recording is already in progress, this indicates an undo/redo leak" << std::endl;
-			std::auto_ptr<state_change_set> changeset = stop_recording();
-			commit_change_set(changeset, "Unfinished changeset");
+			log() << warning << "Forcing termination of unfinished changeset.  Context: " << m_current_context << std::endl;
+			std::auto_ptr<state_change_set> changeset = stop_recording(Context);
+			commit_change_set(changeset, "Unfinished changeset", Context);
 		}
 
-		return_if_fail(!m_current_recording.get());
 		m_current_recording = ChangeSet;
+		m_current_context = Context;
 	}
 
 	state_change_set* current_change_set()
@@ -123,29 +126,47 @@ public:
 		return m_current_recording.get();
 	}
 
-	std::auto_ptr<state_change_set> stop_recording()
+	std::auto_ptr<state_change_set> stop_recording(const char* const Context)
 	{
-		// Sanity checks ...
-		return_val_if_fail(m_current_recording.get(), m_current_recording);
-
-		// Let the world know that recording is stopping ...
-		m_current_recording->recording_done_signal().emit();
+		if(!m_current_recording.get())
+		{
+			log() << error << "stop_recording() attempt with NULL changeset.  Context: " << Context << std::endl;
+			return m_current_recording;
+		}
+		
+		// Let the world know that recording is finished ...
+		m_recording_done_signal.emit();
 
 		// Now that recording is complete, get rid of leftover connections ...
-		state_change_set::recording_done_signal_t::slot_list_type slots = m_current_recording->recording_done_signal().slots();
+		sigc::signal<void>::slot_list_type slots = m_recording_done_signal.slots();
 		slots.erase(slots.begin(), slots.end());
 
 		return m_current_recording;
 	}
 
-	void commit_change_set(std::auto_ptr<state_change_set> ChangeSet, const std::string& Label)
+	void commit_change_set(std::auto_ptr<state_change_set> ChangeSet, const std::string& Label, const char* const Context)
 	{
-		// Sanity checks ...
-		return_if_fail(ChangeSet.get());
-		return_if_fail(!Label.empty());
+		if(!ChangeSet.get())
+		{
+			log() << error << "commit_change_set() attempt with NULL changeset.  Context: " << Context << std::endl;
+			return;
+		}
+
+		if(!ChangeSet->undo_count() && !ChangeSet->redo_count())
+		{
+			log() << error << "discarding empty changeset [" << Label << "].  Context: " << Context << std::endl;
+			return;
+		}
+		
+		std::string label = Label;
+		if(label.empty())
+		{
+			log() << warning << "committing anonymous changeset.  Context: " << Context << std::endl;
+			label = "Unnamed changeset";
+		}
 
 		// Create a new node in the hierarchy, branching it from the current node if necessary ...
-		m_newest_node = new node(Label, ChangeSet.release(), m_current_node);
+		m_newest_node = new node(label, ChangeSet.release(), m_current_node);
 
 		if(m_current_node)
 			m_current_node->children.push_back(m_newest_node);
@@ -190,24 +211,31 @@ public:
 		m_current_node_changed_signal.emit();
 	}
 
-	istate_recorder::node_added_signal_t& node_added_signal()
+	sigc::connection connect_recording_done_signal(const sigc::slot<void>& Slot)
 	{
-		return m_node_added_signal;
+		return m_recording_done_signal.connect(Slot);
 	}
-
-	current_node_changed_signal_t& current_node_changed_signal()
+	
+	sigc::connection connect_node_added_signal(const sigc::slot<void, const node*>& Slot)
 	{
-		return m_current_node_changed_signal;
+		return m_node_added_signal.connect(Slot);
 	}
-
-	last_saved_node_changed_signal_t& last_saved_node_changed_signal()
+	
+	sigc::connection connect_current_node_changed_signal(const sigc::slot<void>& Slot)
 	{
-		return m_last_saved_node_changed_signal;
+		return m_current_node_changed_signal.connect(Slot);
+	}
+	
+	sigc::connection connect_last_saved_node_changed_signal(const sigc::slot<void>& Slot)
+	{
+		return m_last_saved_node_changed_signal.connect(Slot);
 	}
 
 private:
 	/// Stores the current change set
 	std::auto_ptr<state_change_set> m_current_recording;
+	/// Stores the context for the current change set
+	const char* m_current_context;
 	/// Stores the root node(s) (if any)
 	nodes_t m_root_nodes;
 	/// Stores a reference to the current node (if any)
@@ -217,9 +245,10 @@ private:
 	/// Stores a reference to the most-recently-saved node (if any)
 	node* m_last_saved_node;
 
-	node_added_signal_t m_node_added_signal;
-	current_node_changed_signal_t m_current_node_changed_signal;
-	last_saved_node_changed_signal_t m_last_saved_node_changed_signal;
+	sigc::signal<void> m_recording_done_signal;
+	sigc::signal<void, const node*> m_node_added_signal;
+	sigc::signal<void> m_current_node_changed_signal;
+	sigc::signal<void> m_last_saved_node_changed_signal;
 };
 
 /////////////////////////////////////////////////////////////////////////////
@@ -588,8 +617,8 @@ public:
 		m_state_recorder(StateRecorder),
 		m_nodes(Nodes),
 		m_dag(Dag),
-		m_path(init_owner(*this) + init_name("path") + init_label(_("Document Path")) + init_description(_("Document Path")) + init_value(boost::filesystem::path())),
-		m_title(init_owner(*this) + init_name("title") + init_label(_("Document Title")) + init_description(_("Document Title")) + init_value<std::string>(""))
+		m_path(init_owner(*this) + init_name("path") + init_label(_("Document Path")) + init_description(_("Document Path")) + init_value(filesystem::path())),
+		m_title(init_owner(*this) + init_name("title") + init_label(_("Document Title")) + init_description(_("Document Title")) + init_value(k3d::ustring()))
 	{
  		// Automatically add nodes to the unique node name collection
  		m_nodes.add_nodes_signal().connect(sigc::mem_fun(m_unique_node_names, &node_name_map::add_nodes));
@@ -664,10 +693,10 @@ private:
  	/// Stores unique node names
  	node_name_map m_unique_node_names;
 
-	/// Stores the full document filepath
-	k3d_data(boost::filesystem::path, immutable_name, change_signal, no_undo, local_storage, no_constraint, writable_property, no_serialization) m_path;
-	/// Stores the document title
-	k3d_data(std::string, immutable_name, change_signal, no_undo, local_storage, no_constraint, writable_property, no_serialization) m_title;
+	/// Stores the full document filepath (if any)
+	k3d_data(filesystem::path, immutable_name, change_signal, no_undo, local_storage, no_constraint, writable_property, no_serialization) m_path;
+	/// Stores the document title (if any)
+	k3d_data(ustring, immutable_name, change_signal, no_undo, local_storage, no_constraint, writable_property, no_serialization) m_title;
 
 	/// Stores a collection of per-plugin-type serialization handlers
 	plugin_serialization_handlers_t m_plugin_serialization_handlers;
