@@ -2,7 +2,7 @@
 #define K3DSDK_GEOMETRY_H
 
 // K-3D
-// Copyright (c) 1995-2004, Timothy M. Shead
+// Copyright (c) 1995-2006, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -27,10 +27,12 @@
 
 #include "vectors.h"
 
+#include <cassert>
+#include <vector>
+
 namespace k3d
 {
 
-// Forward declarations
 class matrix4;
 
 /////////////////////////////////////////////////////////////////////////////
@@ -41,19 +43,19 @@ class rectangle
 {
 public:
 	rectangle(const double Left, const double Right, const double Top, const double Bottom);
-	rectangle(const vector2& TopLeft, const vector2& BottomRight);
+	rectangle(const point2& TopLeft, const point2& BottomRight);
 	/// Returns the rectangle width
 	double width() const;
 	/// Returns the rectangle height
 	double height() const;
 	/// Returns the top-left corner of the rectangle
-	const vector2 top_left() const;
+	const point2 top_left() const;
 	/// Returns the bottom-right corner of the rectangle
-	const vector2 bottom_right() const;
+	const point2 bottom_right() const;
 	/// Returns the center of the rectangle
-	const vector2 center() const;
+	const point2 center() const;
 	/// Tests a point to see if it is contained within the rectangle
-	bool contains(const vector2& Point) const;
+	bool contains(const point2& Point) const;
 	/// Stores the rectangle's left edge
 	double left;
 	/// Stores the rectangle's right edge
@@ -77,13 +79,13 @@ class plane
 {
 public:
 	/// Constructs a plane from its normal and distance from the origin
-	plane(const normal3& Normal, const double Distance);
+	plane(const vector3& Normal, const double Distance);
 	/// Constructs a plane from its normal and one point located within the plane
-	plane(const normal3& Normal, const vector3& Point);
+	plane(const vector3& Normal, const point3& Point);
 	/// Constructs a plane from three points contained within the plane
-	plane(const vector3& PointA, const vector3& PointB, const vector3& PointC);
+	plane(const point3& PointA, const point3& PointB, const point3& PointC);
 
-	normal3 normal;
+	vector3 normal;
 	double distance;
 };
 
@@ -95,7 +97,7 @@ const plane operator*(const plane& Plane, const matrix4& Matrix);
 std::ostream& operator<<(std::ostream& Stream, const plane& RHS);
 std::istream& operator>>(std::istream& Stream, plane& RHS);
 
-///////////////////////////////////////////////////////////////////////////////////////////////////////
+/////////////////////////////////////////////////////////////////////////////
 // line2
 
 /// Encapsulates a 2D line
@@ -103,15 +105,15 @@ class line2
 {
 public:
 	/// Constructs a line from its direction vector and a point on the line
-	line2(const normal2& Direction, const vector2& Point);
+	line2(const vector2& Direction, const point2& Point);
 	/// Constructs a line from two points on the line
-	line2(const vector2& Point1, const vector2& Point2);
+	line2(const point2& Point1, const point2& Point2);
 
-	normal2 direction;
-	vector2 point;
+	vector2 direction;
+	point2 point;
 };
 
-///////////////////////////////////////////////////////////////////////////////////////////////////////
+/////////////////////////////////////////////////////////////////////////////
 // line3
 
 /// Encapsulates a 3D line
@@ -119,12 +121,12 @@ class line3
 {
 public:
 	/// Constructs a line from its direction vector and a point on the line
-	line3(const normal3& Direction, const vector3& Point);
+	line3(const vector3& Direction, const point3& Point);
 	/// Constructs a line from two points on the line
-	line3(const vector3& Point1, const vector3& Point2);
+	line3(const point3& Point1, const point3& Point2);
 
-	normal3 direction;
-	vector3 point;
+	vector3 direction;
+	point3 point;
 };
 
 /*
@@ -146,15 +148,15 @@ typedef enum
 	SDP_ERROR
 } line_segment_intersection_type;
 /// Determines whether two line segments intersect, and if so, how
-line_segment_intersection_type LineSegmentIntersection(const vector2& A1, const vector2& A2, const vector2& B1, const vector2& B2);
+line_segment_intersection_type LineSegmentIntersection(const point2& A1, const point2& A2, const point2& B1, const point2& B2);
 /// Calculates the intersection of two lines, specified by two contained points each
-bool LineIntersection(const vector2& A1, const vector2& A2, const vector2& B1, const vector2& B2, vector2& Result);
+bool LineIntersection(const point2& A1, const point2& A2, const point2& B1, const point2& B2, point2& Result);
 */
 
 /// Calculates the intersection of a plane with a line, returns false if the line and plane are parallel
-bool intersect(const plane& Plane, const line3& Line, vector3& Intersection);
+bool intersect(const plane& Plane, const line3& Line, point3& Intersection);
 /// Returns the (minimum) distance between a point and a line in two dimensions
-const double distance(const vector2& Point, const line2& Line);
+const double distance(const point2& Point, const line2& Line);
 
 /// Returns a Bezier / Bernstein basis for the given order, control point number, and parameter value
 double BernsteinBasis(const unsigned long Order, const unsigned long ControlPoint, const double Parameter);
@@ -166,9 +168,8 @@ Type Bezier(const std::vector<Type>& ControlPoints, const double Parameter)
 	// Sanity checks ...
 	assert(ControlPoints.size() > 1);
 
-	Type result = 0.0;
-
-	for(unsigned long i = 0; i < ControlPoints.size(); i++)
+	Type result = BernsteinBasis(ControlPoints.size(), 0, Parameter) * ControlPoints[0];
+	for(unsigned long i = 1; i < ControlPoints.size(); i++)
 		result += BernsteinBasis(ControlPoints.size(), i, Parameter) * ControlPoints[i];
 
 	return result;
@@ -183,7 +184,7 @@ Type Bezier(const std::vector<Type>& ControlPoints, const double Parameter)
 	\result Returns true iff the lines intersect, false if they are parallel
 	\note Code originally from Aqsis, http://www.aqsis.com
 */
-bool intersect_lines(const k3d::vector3& P1, const k3d::vector3& T1, const k3d::vector3& P2, const k3d::vector3& T2, k3d::vector3& Result);
+bool intersect_lines(const point3& P1, const vector3& T1, const point3& P2, const vector3& T2, point3& Result);
 
 /** Calculates a 3rd-order NURBS curve that creates a circular arc centered at the origin with unit radius
 	\param X Defines the X axis of the plane containing the arc
@@ -196,46 +197,46 @@ bool intersect_lines(const k3d::vector3& P1, const k3d::vector3& T1, const k3d::
 	\param ControlPoints Output container for the resulting arc control point positions
 */
 template<typename knots_t, typename weights_t, typename control_points_t>
-void nurbs_arc(const k3d::vector3& X, const k3d::vector3& Y, const double StartAngle, const double EndAngle, const unsigned long Segments, knots_t& Knots, weights_t& Weights, control_points_t& ControlPoints)
+void nurbs_arc(const point3& X, const point3& Y, const double StartAngle, const double EndAngle, const unsigned long Segments, knots_t& Knots, weights_t& Weights, control_points_t& ControlPoints)
 {
 	const double start_angle = std::min(StartAngle, EndAngle);
 	const double end_angle = std::max(StartAngle, EndAngle);
 	const double theta = (end_angle - start_angle) / static_cast<double>(Segments);
 	const double weight = std::cos(theta * 0.5);
-	
+
 	Knots.clear();
 	Knots.insert(Knots.end(), 3, 0);
 	for(unsigned long i = 1; i != Segments; ++i)
 		Knots.insert(Knots.end(), 2, i);
 	Knots.insert(Knots.end(), 3, Segments);
-	
+
 	Weights.clear();
 	Weights.push_back(1.0);
 	for(unsigned long i = 0; i != Segments; ++i)
-		{
-			Weights.push_back(weight);
-			Weights.push_back(1);
-		}
-		
+	{
+		Weights.push_back(weight);
+		Weights.push_back(1);
+	}
+
 	ControlPoints.clear();
 	ControlPoints.push_back(std::cos(start_angle) * X + std::sin(start_angle) * Y);
 	for(unsigned long i = 0; i != Segments; ++i)
-		{
-			const double a0 = start_angle + (theta * (i));
-			const double a2 = start_angle + (theta * (i + 1));
-			
-			const k3d::vector3 p0(std::cos(a0) * X + std::sin(a0) * Y);
-			const k3d::vector3 p2(std::cos(a2) * X + std::sin(a2) * Y);
-			
-			const k3d::vector3 t0(-std::sin(a0) * X + std::cos(a0) * Y);
-			const k3d::vector3 t2(-std::sin(a2) * X + std::cos(a2) * Y);
+	{
+		const double a0 = start_angle + (theta * (i));
+		const double a2 = start_angle + (theta * (i + 1));
 
-			k3d::vector3 p1;
-			k3d::intersect_lines(p0, t0, p2, t2, p1);
-				
-			ControlPoints.push_back(p1);
-			ControlPoints.push_back(p2);
-		}
+		const point3 p0(std::cos(a0) * X + std::sin(a0) * Y);
+		const point3 p2(std::cos(a2) * X + std::sin(a2) * Y);
+
+		const point3 t0(-std::sin(a0) * X + std::cos(a0) * Y);
+		const point3 t2(-std::sin(a2) * X + std::cos(a2) * Y);
+
+		point3 p1;
+		intersect_lines(p0, to_vector(t0), p2, to_vector(t2), p1);
+
+		ControlPoints.push_back(p1);
+		ControlPoints.push_back(p2);
+	}
 }
 
 } // namespace k3d
