@@ -36,7 +36,7 @@ class i3d_2d_mapping :
 	public virtual iunknown
 {
 public:
-	virtual const vector2 map_3d_to_2d(const vector3& Position, const bounding_box3& Bounds) = 0;
+	virtual const point2 map_3d_to_2d(const point3& Position, const bounding_box3& Bounds) = 0;
 
 protected:
 	i3d_2d_mapping() {}
