@@ -39,12 +39,26 @@ public:
 	/// Enumerates the types of commands that can be executed by a node
 	typedef enum
 	{
-		INTERACTIVE,
-		MACRO,
+		COMMAND_INTERACTIVE,
+		COMMAND_MACRO,
 	} type;
+
+	/// Enumerates the possible return values from execute_command
+	typedef enum
+	{
+		/// The command was executed without error, further execution should be halted
+		RESULT_STOP,
+		/// The command was executed without error, continue executing normally
+		RESULT_CONTINUE,
+		/// The command failed to execute
+		RESULT_ERROR,
+		/// The command was not recognized
+		RESULT_UNKNOWN_COMMAND
+		
+	} result;
 	
-	/// Executes a command, with optional return object
-	virtual bool execute_command(const std::string& Command, const std::string& Arguments) = 0;
+	/// Executes a command, returning the command result
+	virtual const result execute_command(const std::string& Command, const std::string& Arguments) = 0;
 
 protected:
 	icommand_node() {}
@@ -57,4 +71,3 @@ protected:
 
 #endif // K3DSDK_ICOMMAND_NODE_H
 
-
