@@ -33,13 +33,12 @@
 #include <map>
 #include <string>
 
-namespace boost { namespace filesystem { class path; } }
-
 namespace k3d
 {
 
 class idag;
 class inode_collection;
+class inode_name_map;
 class ipersistent;
 class iproperty;
 class istate_recorder;
@@ -50,12 +49,15 @@ class idocument :
 {
 public:
 	/// Returns the collection of K-3D objects within this document
-	virtual k3d::inode_collection& nodes() = 0;
+	virtual inode_collection& nodes() = 0;
 	/// Returns the directed acyclic graph of dependencies between object properties within this document
-	virtual k3d::idag& dag() = 0;
-	/// Returns the k3d::istate_recorder interface for this document
-	virtual k3d::istate_recorder& state_recorder() = 0;
+	virtual idag& dag() = 0;
+	/// Returns the istate_recorder interface for this document
+	virtual istate_recorder& state_recorder() = 0;
 
+	/// Returns an interface that provides a mapping of nodes to unique names
+	virtual inode_name_map& unique_node_names() = 0;
+	
 	/// Returns a property that will store the document filepath (could be empty)
 	virtual iproperty& path() = 0;
 	/// Returns a property that will store the document title (could be empty string)
@@ -67,10 +69,6 @@ public:
 	typedef std::map<uuid, ipersistent*> plugin_serialization_handlers_t;
 	virtual const plugin_serialization_handlers_t& plugin_serialization_handlers() = 0;
 
-	/// Defines a signal emitted before the document is closed - observers can return false to cancel closing (e.g. if a resource is unsaved), true otherwise
-	typedef sigc::signal0<bool, signal::cancelable> safe_to_close_signal_t;
-	virtual safe_to_close_signal_t& safe_to_close_signal() = 0;
-
 	/// Defines a signal emitted when the document closes
 	typedef sigc::signal0<void> close_signal_t;
 	virtual close_signal_t& close_signal() = 0;
@@ -86,4 +84,3 @@ protected:
 
 #endif // K3DSDK_IDOCUMENT_H
 
-
