@@ -54,8 +54,8 @@ public:
 	virtual const boost::any property_value() = 0;
 	/// Returns a reference to the object that owns the property (if any)
 	virtual inode* property_node() = 0;
-	/// Defines a signal that will be emitted anytime the property value changes
-	typedef sigc::signal0<void> changed_signal_t;
+	/// Defines a signal that will be emitted if the property value changes.  The signal includes a pointer to an optional "hint" object that may provide additional information about what changed.
+	typedef sigc::signal1<void, iunknown*> changed_signal_t;
 	virtual changed_signal_t& property_changed_signal() = 0;
 	/// Defines a signal that will be emitted when the property is destroyed
 	typedef sigc::signal0<void> deleted_signal_t;
