@@ -25,20 +25,8 @@
 		\author Tim Shead (tshead@k-3d.com)
 */
 
-#include "algebra.h"
-#include "bounding_box.h"
-#include "color.h"
 #include "iunknown.h"
-#include "vectors.h"
-
-#include <boost/any.hpp>
-#include <boost/array.hpp>
-#include <boost/cstdint.hpp>
-
-#include <list>
-#include <vector>
-
-namespace boost { namespace filesystem { class path; } }
+#include "renderman_types.h"
 
 namespace k3d
 {
@@ -49,139 +37,7 @@ class irender_frame;
 namespace ri
 {
 
-/// RenderMan integer datatype
-typedef boost::int32_t integer;
-/// RenderMan unsigned integer datatype
-typedef boost::uint32_t unsigned_integer;
-/// RenderMan real datatype
-typedef double real;
-/// RenderMan string datatype
-typedef std::string string;
-
-/** \todo Someday, we should have separate types for points, vectors, normals, colors, hpoints, etc. but in the short-term, k3d::vector will suffice */
-/// RenderMan point datatype
-struct point : public k3d::vector3
-{
-	point() {}
-	point(const k3d::vector3& RHS) : k3d::vector3(RHS) {}
-};
-
-/// RenderMan vector datatype
-struct vector : public k3d::vector3
-{
-	vector() {}
-	vector(const k3d::vector3& RHS) : k3d::vector3(RHS) {}
-};
-
-/// RenderMan normal datatype
-struct normal : public k3d::vector3
-{
-	normal() {}
-	normal(const k3d::vector3& RHS) : k3d::vector3(RHS) {}
-};
-
-/// Renderman color datatype
-typedef k3d::color color;
-
-/// Renderman hpoint datatype
-struct hpoint : public k3d::vector4
-{
-	hpoint() {}
-	hpoint(const k3d::vector4& RHS) : k3d::vector4(RHS) {}
-};
-
-/// RenderMan matrix datatype
-typedef boost::array<real, 16> matrix;
-
-/// RenderMan light handle datatype
-typedef boost::uint32_t light_handle;
-/// RenderMan object handle datatype
-typedef boost::uint32_t object_handle;
-
-/// Filesystem path datatype
-typedef boost::filesystem::path path;
-/// 3D bounding-box datatype
-typedef k3d::bounding_box3 bound;
-
-/// RenderMan integer array
-typedef std::vector<integer> integers;
-/// RenderMan unsigned integer array
-typedef std::vector<unsigned_integer> unsigned_integers;
-/// RenderMan real array
-typedef std::vector<real> reals;
-/// RenderMan string array
-typedef std::vector<string> strings;
-/// RenderMan point array
-typedef std::vector<point> points;
-/// RenderMan vector array
-typedef std::vector<vector> vectors;
-/// RenderMan normal array
-typedef std::vector<normal> normals;
-/// RenderMan color array
-typedef std::vector<color> colors;
-/// RenderMan hpoint array
-typedef std::vector<hpoint> hpoints;
-/// RenderMan matrix array
-typedef std::vector<matrix> matrices;
-
-/// Enumerates parameter storage classes defined by the RenderMan standard
-typedef enum
-{
-	CONSTANT,
-	UNIFORM,
-	VARYING,
-	VERTEX,
-	FACEVARYING
-} storage_class_t;
-
-std::ostream& operator<<(std::ostream& Stream, const storage_class_t RHS);
-
-/// Defines a name-value pair for passing RenderMan parameter lists
-/** \note Although parameter can safely hold any value type, only the
- * integer, real, string, point, vector, normal, color, hpoint and matrix
- *  types and their array counterparts are guaranteed to render */
-class parameter
-{
-public:
-	template<typename value_t>
-	parameter(const string Name, const storage_class_t StorageClass, const value_t& Value, const boost::uint32_t ArrayDimension = 1) :
-		name(Name),
-		storage_class(StorageClass),
-		value(Value),
-		array_dimension(ArrayDimension)
-	{
-	}
-
-	const string name;
-	const storage_class_t storage_class;
-	const boost::any value;
-	const boost::uint32_t array_dimension;
-};
-
-/// Defines a RenderMan parameter list (a collection of name-value pairs)
-typedef std::list<parameter> parameter_list;
-/// Convenience operator for concatenating parameter lists
-parameter_list& operator+=(parameter_list& LHS, const parameter_list& RHS);
-/// Convenience operator for concatenating parameter lists
-parameter_list operator+(const parameter_list& LHS, const parameter_list& RHS);
-
-/// Defines a collection of intra-frame sample times in the range [0, 1]
-typedef reals sample_times_t;
-
-/// Enumerates possible values for the current render context
-typedef enum
-{
-	/// We're generating a CSG solid object
-	CSG_SOLID,
-	/// We're generating an object instance
-	OBJECT_INSTANCE,
-	/// We're generating a shadow map
-	SHADOW_MAP,
-	/// We're generating an environment map
-	ENVIRONMENT_MAP,
-	/// We're generating the final output frame
-	FINAL_FRAME
-} render_context_t;
+class ishader_collection;
 
 /// Abstract binding to the Pixar RenderMan interface
 class irender_engine :
@@ -190,8 +46,8 @@ class irender_engine :
 public:
 	virtual bool set_inline_types(const bool Inline) = 0;
 
-	virtual const light_handle RiAreaLightSourceV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
-	virtual void RiAtmosphereV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual const light_handle RiAreaLightSourceV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual void RiAtmosphereV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiAttributeBegin() = 0;
 	virtual void RiAttributeEnd() = 0;
 	virtual void RiAttributeV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
@@ -211,16 +67,16 @@ public:
 	virtual void RiCurvesV(const string& Type, const unsigned_integers& VertexCounts, const string& Wrap, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiCylinderV(const real Radius, const real ZMin, const real ZMax, const real ThetaMax, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiDeclare(const string& Name, const string& Type) = 0;
-	virtual void RiDeformationV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual void RiDeformationV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiDepthOfField(const real FStop, const real FocalLength, const real FocalDistance) = 0;
 	virtual void RiDetail(const boost::array<real, 6>& Bound) = 0;
 	virtual void RiDetailRange(const real MinVis, const real LowTran, const real UpTran, const real MaxVis) = 0;
 	virtual void RiDiskV(real Height, real Radius, real ThetaMax, const parameter_list& Parameters = parameter_list()) = 0;
-	virtual void RiDisplacementV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual void RiDisplacementV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiDisplayV(const string& Name, const string& Type, const string& Mode, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiErrorHandler(const string& Style) = 0;
 	virtual void RiExposure(const real Gain, const real Gamma) = 0;
-	virtual void RiExteriorV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual void RiExteriorV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiFormat(const unsigned_integer XResolution, const unsigned_integer YResolution, const real AspectRatio) = 0;
 	virtual void RiFrameAspectRatio(const real AspectRatio) = 0;
 	virtual void RiFrameBegin(const unsigned_integer FrameNumber) = 0;
@@ -233,9 +89,9 @@ public:
 	virtual void RiHyperboloidV(const point& Point1, const point& Point2, const real ThetaMax, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiIdentity() = 0;
 	virtual void RiIlluminate(const light_handle LightHandle, const bool OnOff) = 0;
-	virtual void RiImagerV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
-	virtual void RiInteriorV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
-	virtual const light_handle RiLightSourceV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual void RiImagerV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual void RiInteriorV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual const light_handle RiLightSourceV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiMakeCubeFaceEnvironmentV(const string& px, const string& nx, const string& py, const string& ny, const string& pz, const string& nz, const string& texturename, const real fov, const string& swrap, const string& twrap, const string& filterfunc, const real swidth, const real twidth, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiMakeLatLongEnvironmentV(const string& picturename, const string& texturename, const string& filterfunc, const real swidth, const real twidth, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiMakeShadowV(const string& picturename, const string& texturename, const parameter_list& Parameters = parameter_list()) = 0;
@@ -281,7 +137,7 @@ public:
 	virtual void RiSphereV(const real Radius, const real ZMin, const real ZMax, const real ThetaMax, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiStructure(const string& Structure) = 0;
 	virtual void RiSubdivisionMeshV(const string& Scheme, const unsigned_integers& VertexCounts, const unsigned_integers& VertexIDs, const strings& Tags, const unsigned_integers& ArgCounts, const integers& IntegerArgs, const reals& FloatArgs, const parameter_list& Parameters = parameter_list()) = 0;
-	virtual void RiSurfaceV(const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual void RiSurfaceV(const path& Path, const string& Name, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiTextureCoordinates(const real S1, const real T1, const real S2, const real T2, const real S3, const real T3, const real S4, const real T4) = 0;
 	virtual void RiTorusV(const real MajorRadius, const real MinorRadius, const real PhiMin, const real PhiMax, const real ThetaMax, const parameter_list& Parameters = parameter_list()) = 0;
 	virtual void RiTransform(const matrix& Transform) = 0;
@@ -295,11 +151,11 @@ public:
 	// New Aqsis-specific calls introduced to support layered shaders
 	//
 	/** \todo Come up with a better way to handle non-standard calls */
-	virtual void RiShaderLayerV(const std::string& type, const std::string& name, const std::string& layername, const parameter_list& Parameters = parameter_list()) = 0;
+	virtual void RiShaderLayerV(const std::string& type, const path& Path, const std::string& name, const std::string& layername, const parameter_list& Parameters = parameter_list()) = 0;
 	/** \todo Come up with a better way to handle non-standard calls */
 	virtual void RiConnectShaderLayers(const std::string& type, const std::string& layer1, const std::string& variable1, const std::string& layer2, const std::string& variable2) = 0;
 
-	
+
 protected:
 	irender_engine() {}
 	irender_engine(const irender_engine& ) {}
@@ -310,9 +166,10 @@ protected:
 /// Used to pass (potentially) useful rendering state from the engine to the object being rendered
 struct render_state
 {
-	render_state(irender_frame& Frame, irender_engine& Engine, iprojection& Projection, const render_context_t RenderContext, const sample_times_t& SampleTimes, const unsigned_integer SampleIndex, const matrix4& CameraMatrix) :
+	render_state(irender_frame& Frame, irender_engine& Engine, ishader_collection& Shaders, iprojection& Projection, const render_context_t RenderContext, const sample_times_t& SampleTimes, const unsigned_integer SampleIndex, const matrix4& CameraMatrix) :
 		frame(Frame),
 		engine(Engine),
+		shaders(Shaders),
 		projection(Projection),
 		render_context(RenderContext),
 		sample_times(SampleTimes),
@@ -323,6 +180,7 @@ struct render_state
 
 	irender_frame& frame;
 	irender_engine& engine;
+	ishader_collection& shaders;
 	iprojection& projection;
 	render_context_t render_context;
 	sample_times_t sample_times;
@@ -364,6 +222,7 @@ class irenderable :
 {
 public:
 	virtual void renderman_render(const render_state& State) = 0;
+	virtual void renderman_render_complete(const render_state& State) = 0;
 
 protected:
 	irenderable() {}
@@ -377,8 +236,8 @@ class itexture :
 	public virtual iunknown
 {
 public:
-	virtual void setup_renderman_texture(irender_frame& Frame, irender_engine& Engine) = 0;
-	virtual const boost::filesystem::path renderman_texture_path(const render_state& State) = 0;
+	virtual void setup_renderman_texture(irender_frame& Frame, irender_engine& Engine, ishader_collection& Shaders) = 0;
+	virtual const filesystem::path renderman_texture_path(const render_state& State) = 0;
 
 protected:
 	itexture() {}
@@ -421,6 +280,7 @@ class ilight_shader :
 {
 public:
 	virtual void setup_renderman_light_shader(const render_state& State) = 0;
+	virtual void setup_renderman_area_light_shader(const render_state& State) = 0;
 
 protected:
 	ilight_shader() {}
@@ -562,4 +422,3 @@ inline const std::string RI_Z() { return "z"; }
 
 #endif // K3DSDK_IRENDERMAN_INTERFACE_H
 
-
