@@ -35,11 +35,20 @@
 namespace k3d
 {
 
-// Forward declarations ...
 class icommand_node;
 class iplugin_factory;
 
 /// Abstract interface implemented by objects that can execute scripts written in a specific scripting language
+/** \note: The Script arguments to can_execute() and execute() have bounced back-and-forth between
+ * string and stream representations several times.  The original rationale for making them streams was
+ * to avoid having to buffer the source code to a script in memory; the new rationale for making them strings
+ * is that in practice you always end-up having to buffer the source code anyway, for one of two reasons:
+ * first, only the k3dscript engine can use an input stream efficiently, the Python engine doesn't understand
+ * C++ streams, so we had to buffer the source before passing it to the interpreter anyway; second, calling
+ * can_execute() and execute() in sequence (the most common use-case) requires random access to the source stream,
+ * which isn't available for compressed streams or socket-based streams.
+*/
+
 class iscript_engine :
 	public virtual iunknown
 {
@@ -54,7 +63,7 @@ public:
 		\param Script The complete source code of the script to be tested
 		\return true, iff the supplied script can be executed by the engine
 	*/
-	virtual bool can_execute(std::istream& Script) = 0;
+	virtual bool can_execute(const std::string& Script) = 0;
 
 	/// Defines a collection of named objects to pass to a script that define its context (its execution environment) - how they are used is implementation-dependent (note that the names are merely suggestions, and may be changed or ignored at the whim of the implementation)
 	typedef std::map<std::string, boost::any> context_t;
@@ -65,7 +74,7 @@ public:
 		\param Context Optional collection of objects that define the context/execution environment of the script -  how they are used is implementation-dependent.  Note that the script engine may alter context objects before returning.
 		\return true, iff the script was successfully executed without errors (either syntax or runtime)
 	*/
-	virtual bool execute(const std::string& ScriptName, std::istream& Script, context_t& Context) = 0;
+	virtual bool execute(const std::string& ScriptName, const std::string& Script, context_t& Context) = 0;
 
 	/**	\brief Requests a cancellation of all running scripts.
 		\return true, iff script cancellation is supported by this engine.
@@ -102,4 +111,3 @@ protected:
 
 #endif // K3DSDK_ISCRIPT_ENGINE_H
 
-
