@@ -26,7 +26,6 @@
 
 #include "iunknown.h"
 #include "signal_system.h"
-#include "state_change_set.h"
 
 #include <memory>
 #include <string>
@@ -35,19 +34,21 @@
 namespace k3d
 {
 
+class state_change_set;
+	
 /// Abstract interface for an object that can store a hierarchical tree of state changes to the document
 class istate_recorder :
 	public virtual iunknown
 {
 public:
-	/// Called by clients to register a change set for recording subsequent state changes
-	virtual void start_recording(std::auto_ptr<state_change_set> ChangeSet) = 0;
+	/// Called by clients to register a change set for recording subsequent state changes (the recorder assumes responsibility for the lifetime of the changeset)
+	virtual void start_recording(std::auto_ptr<state_change_set> ChangeSet, const char* const DebugLabel) = 0;
 	/// Returns the current change set being recorded (if any - could return NULL)
 	virtual state_change_set* current_change_set() = 0;
-	/// Called by clients to stop recording a set of state changes
-	virtual std::auto_ptr<state_change_set> stop_recording() = 0;
+	/// Called by clients to stop recording a set of state changes (the recorder relinquishes responsibility for the lifetime of the returned changeset)
+	virtual std::auto_ptr<state_change_set> stop_recording(const char* const DebugLabel) = 0;
 	/// Called by clients once a set of changes is complete, to make them a part of the undo/redo tree (the recorder assumes responsibility for the lifetime of the change set)
-	virtual void commit_change_set(std::auto_ptr<state_change_set> ChangeSet, const std::string& Label) = 0;
+	virtual void commit_change_set(std::auto_ptr<state_change_set> ChangeSet, const std::string& Label, const char* const DebugLabel) = 0;
 
 	/// Defines a collection of "nodes" in the hierarchy of recorded state changes
 	struct node;
@@ -82,15 +83,15 @@ public:
 	/// Called to mark the current node as saved
 	virtual void mark_saved() = 0;
 
-	/// Defines a signal for notifying observers that a node has been added to the hierarchy
-	typedef sigc::signal1<void, const node*> node_added_signal_t;
-	virtual node_added_signal_t& node_added_signal() = 0;
-	/// Defines a signal for notifying observers that the current node has changed
-	typedef sigc::signal0<void> current_node_changed_signal_t;
-	virtual current_node_changed_signal_t& current_node_changed_signal() = 0;
-	/// Defines a signal for notifying observers that the last saved node has changed
-	typedef sigc::signal0<void> last_saved_node_changed_signal_t;
-	virtual last_saved_node_changed_signal_t& last_saved_node_changed_signal() = 0;
+	/// Connects a slot that will be called when recording finishes
+	virtual sigc::connection connect_recording_done_signal(const sigc::slot<void>& Slot) = 0;
+	
+	/// Connects a slot that will be called after a node is added to the hierarchy
+	virtual sigc::connection connect_node_added_signal(const sigc::slot<void, const node*>& Slot) = 0;
+	/// Connects a slot that will be called when the current node has changed
+	virtual sigc::connection connect_current_node_changed_signal(const sigc::slot<void>& Slot) = 0;
+	/// Connects a slot that will be called when the last saved node has changed
+	virtual sigc::connection connect_last_saved_node_changed_signal(const sigc::slot<void>& Slot) = 0;
 
 protected:
 	istate_recorder() {}
@@ -103,4 +104,3 @@ protected:
 
 #endif // K3DSDK_ISTATE_RECORDER_H
 
-
