@@ -36,8 +36,8 @@ class iwritable_property :
 	public virtual iunknown
 {
 public:
-	/// Sets the property value (note - could fail and return false if there's a type-mismatch or other problem with the input data)
-	virtual bool property_set_value(const boost::any Value) = 0;
+	/// Sets the property value (note - could fail and return false if there's a type-mismatch or other problem with the input data).  The optional Hint will be passed to observers and can provide additional information about what changed.
+	virtual bool property_set_value(const boost::any Value, iunknown* const Hint = 0) = 0;
 
 protected:
 	iwritable_property() {}
