@@ -23,15 +23,15 @@
 
 #include "idocument.h"
 #include "imaterial.h"
-#include "iobject.h"
-#include "objects.h"
+#include "inode.h"
+#include "nodes.h"
 
 namespace k3d
 {
 
-iobject* default_material(k3d::idocument& Document)
+inode* default_material(k3d::idocument& Document)
 {
-	const k3d::objects_t materials(k3d::find_objects<k3d::imaterial>(Document.objects()));
+	const k3d::nodes_t materials(k3d::find_nodes<k3d::imaterial>(Document.nodes()));
 
 	if(materials.size())
 		return *materials.rbegin();
