@@ -35,7 +35,7 @@ class mesh_source :
 public:
 	mesh_source(idocument& Document) :
 		base_t(Document),
-		m_output_mesh(init_owner(*this) + init_name("output_mesh") + init_label(_("Output Mesh")) + init_description("Output mesh"))
+		m_output_mesh(init_owner(*this) + init_name("output_mesh") + init_label(_("Output Mesh")) + init_description("Output mesh") + init_slot(sigc::mem_fun(*this, &mesh_source<base_t>::create_mesh)))
 	{
 	}
 
@@ -44,12 +44,40 @@ public:
 		return m_output_mesh;
 	}
 
+	sigc::slot1<void, iunknown*> make_reset_mesh_slot()
+	{
+		return m_output_mesh.make_reset_slot();
+	}
+
+	sigc::slot1<void, iunknown*> make_update_mesh_slot()
+	{
+		return sigc::mem_fun(*this, &mesh_source<base_t>::update_mesh);
+	}
+
 protected:
 	k3d_data(mesh*, data::immutable_name, data::change_signal, data::no_undo, data::demand_storage, data::no_constraint, data::read_only_property, data::no_serialization) m_output_mesh;
+
+private:
+	void create_mesh(mesh& Mesh)
+	{
+		on_create_mesh(Mesh);
+		on_update_mesh(Mesh);
+	}
+
+	void update_mesh(iunknown* const Hint)
+	{
+		if(mesh* const output_mesh = m_output_mesh.internal_value())
+		{
+			on_update_mesh(*output_mesh);
+			m_output_mesh.changed_signal().emit(Hint);
+		}
+	}
+
+	virtual void on_create_mesh(mesh& Mesh) = 0;
+	virtual void on_update_mesh(mesh& Mesh) = 0;
 };
 
 } // namespace k3d
 
 #endif // !K3DSDK_MESH_SOURCE_H
 
-
