@@ -2,7 +2,7 @@
 #define K3DSDK_MESH_TRIANGULATE_DETAIL_H
 
 // K-3D
-// Copyright (c) 1995-2005, Timothy M. Shead
+// Copyright (c) 1995-2006, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -56,25 +56,25 @@ public:
 		// Handle the main contour for the face ...
 		sgiTessBeginContour(tessellator);
 		for(split_edge* edge = Face.first_edge; edge && edge->face_clockwise; edge = edge->face_clockwise)
-			{
-				sgiTessVertex(tessellator, edge->vertex->position, edge->vertex);
-				if(edge->face_clockwise == Face.first_edge)
-					break;
-			}
+		{
+			sgiTessVertex(tessellator, edge->vertex->position.data(), edge->vertex);
+			if(edge->face_clockwise == Face.first_edge)
+				break;
+		}
 		sgiTessEndContour(tessellator);
 
 		// Handle holes ...
 		for(face::holes_t::const_iterator hole = Face.holes.begin(); hole != Face.holes.end(); ++hole)
+		{
+			sgiTessBeginContour(tessellator);
+			for(split_edge* edge = *hole; edge && edge->face_clockwise; edge = edge->face_clockwise)
 			{
-				sgiTessBeginContour(tessellator);
-				for(split_edge* edge = *hole; edge && edge->face_clockwise; edge = edge->face_clockwise)
-					{
-						sgiTessVertex(tessellator, edge->vertex->position, edge->vertex);
-						if(edge->face_clockwise == *hole)
-							break;
-					}
-				sgiTessEndContour(tessellator);
+				sgiTessVertex(tessellator, edge->vertex->position.data(), edge->vertex);
+				if(edge->face_clockwise == *hole)
+					break;
 			}
+			sgiTessEndContour(tessellator);
+		}
 
 		sgiTessEndPolygon(tessellator);
 	}
@@ -90,10 +90,10 @@ private:
 	void vertex(void* VertexData)
 	{
 		if(!v0)
-			{
-				v0 = v1;
-				v1 = v2;
-			}
+		{
+			v0 = v1;
+			v1 = v2;
+		}
 		v2 = reinterpret_cast<point*>(VertexData);
 
 		if(!v0)
@@ -101,25 +101,25 @@ private:
 
 		std::vector<split_edge*> new_edges;
 		switch(mode)
-			{
-				case GL_TRIANGLE_FAN:
-					new_edges.push_back(new split_edge(v0));
-					new_edges.push_back(new split_edge(v1));
-					new_edges.push_back(new split_edge(v2));
-					break;
-				case GL_TRIANGLE_STRIP:
-					new_edges.push_back(new split_edge(v0));
-					new_edges.push_back(new split_edge(v1));
-					new_edges.push_back(new split_edge(v2));
-					if(flip_strip)
-						std::reverse(new_edges.begin(), new_edges.end());
-					break;
-				case GL_TRIANGLES:
-					new_edges.push_back(new split_edge(v0));
-					new_edges.push_back(new split_edge(v1));
-					new_edges.push_back(new split_edge(v2));
-					break;
-			}
+		{
+			case GL_TRIANGLE_FAN:
+				new_edges.push_back(new split_edge(v0));
+				new_edges.push_back(new split_edge(v1));
+				new_edges.push_back(new split_edge(v2));
+				break;
+			case GL_TRIANGLE_STRIP:
+				new_edges.push_back(new split_edge(v0));
+				new_edges.push_back(new split_edge(v1));
+				new_edges.push_back(new split_edge(v2));
+				if(flip_strip)
+					std::reverse(new_edges.begin(), new_edges.end());
+				break;
+			case GL_TRIANGLES:
+				new_edges.push_back(new split_edge(v0));
+				new_edges.push_back(new split_edge(v1));
+				new_edges.push_back(new split_edge(v2));
+				break;
+		}
 		loop_edges(new_edges.begin(), new_edges.end());
 
 		face* const new_face = new face(*current_face);
@@ -128,24 +128,24 @@ private:
 		*output_faces++ = new_face;
 
 		switch(mode)
-			{
-				case GL_TRIANGLE_FAN:
-					v1 = v2;
-					break;
-				case GL_TRIANGLE_STRIP:
-					v0 = v1;
-					v1 = v2;
-					flip_strip = !flip_strip;
-					break;
-				case GL_TRIANGLES:
-					v0 = v1 = v2 = 0;
-					break;
-			}
+		{
+			case GL_TRIANGLE_FAN:
+				v1 = v2;
+				break;
+			case GL_TRIANGLE_STRIP:
+				v0 = v1;
+				v1 = v2;
+				flip_strip = !flip_strip;
+				break;
+			case GL_TRIANGLES:
+				v0 = v1 = v2 = 0;
+				break;
+		}
 	}
 
 	void combine(GLdouble Coords[3], void* VertexData[4], GLfloat Weight[4], void** OutputData)
 	{
-		point* const new_point = new point(vector3(Coords[0], Coords[1], Coords[2]));
+		point* const new_point = new point(point3(Coords[0], Coords[1], Coords[2]));
 		*OutputData = new_point;
 		*output_points++ = new_point;
 	}
@@ -207,4 +207,3 @@ private:
 
 #endif // K3DSDK_MESH_TRIANGULATE_DETAIL_H
 
-
