@@ -25,15 +25,13 @@
 		\author Tim Shead (tshead@k-3d.com)
 */
 
-#include <boost/filesystem/path.hpp>
-
 #include <string>
 #include <vector>
 
 namespace k3d
 {
 
-// Forward declarations
+namespace filesystem { class path; }
 namespace xml { class element; }
 
 namespace options
@@ -70,9 +68,9 @@ const std::string default_render_engine(const std::string& Type);
 void set_default_render_engine(const std::string& Type, const std::string& Name);
 
 /// Returns the default file path for the given data type (e.g. bitmap, document, script, etc)
-const boost::filesystem::path get_path(const std::string& PathType);
+const filesystem::path get_path(const std::string& PathType);
 /// Sets the default file path for the given data type (e.g. bitmap, document, script, etc)
-void set_path(const std::string& PathType, const boost::filesystem::path& Path);
+void set_path(const std::string& PathType, const filesystem::path& Path);
 
 /// Predefined path types for use with get_path() and set_path()
 namespace path
@@ -83,6 +81,7 @@ inline const std::string scripts() { return "scripts"; }
 inline const std::string documents() { return "documents"; }
 inline const std::string bitmaps() { return "bitmaps"; }
 inline const std::string tutorials() { return "tutorials"; }
+inline const std::string test_cases() { return "test_cases"; }
 inline const std::string render_frame() { return "render_frame"; }
 inline const std::string render_animation() { return "render_animation"; }
 inline const std::string fonts() { return "fonts"; }
