@@ -37,9 +37,6 @@
 #include "version.h"
 #include "xml.h"
 
-#include <boost/filesystem/path.hpp>
-#include <boost/filesystem/operations.hpp>
-
 #include <iostream>
 
 namespace k3d
@@ -55,18 +52,18 @@ namespace detail
 
 	#include <windows.h>
 
-	static void os_load_module(const boost::filesystem::path& FilePath, register_module_entry_point& RegisterModule, register_plugins_entry_point& RegisterPlugins)
+	static void os_load_module(const filesystem::path& FilePath, register_module_entry_point& RegisterModule, register_plugins_entry_point& RegisterPlugins)
 	{
-		if(file_extension(FilePath) != "dll")
+		if(filesystem::extension(FilePath).lowercase().raw() != ".dll")
 			return;
 
 		const UINT old_error_mode = SetErrorMode(SetErrorMode(SEM_FAILCRITICALERRORS)); // Disable error dialogs when loading DLLs
-		HINSTANCE module = LoadLibrary(FilePath.native_file_string().c_str());
+		HINSTANCE module = LoadLibrary(FilePath.native_filesystem_string().c_str());
 		SetErrorMode(old_error_mode);
 
 		if(!module)
 		{
-			log() << error << "Module [" << FilePath.native_file_string() << "] could not be loaded: error " << GetLastError() << std::endl;
+			log() << error << "Module [" << FilePath.native_console_string() << "] could not be loaded: error " << GetLastError() << std::endl;
 			return;
 		}
 
@@ -75,7 +72,7 @@ namespace detail
 			RegisterModule = register_module_entry_point(GetProcAddress(module, "_register_k3d_module"));
 		if(!RegisterModule)
 		{
-			log() << warning << "Module " << FilePath.leaf() << " does not contain required register_k3d_module() entry point" << std::endl;
+			log() << warning << "Module " << FilePath.leaf().raw() << " does not contain required register_k3d_module() entry point" << std::endl;
 			return;
 		}
 
@@ -84,7 +81,7 @@ namespace detail
 			RegisterPlugins = register_plugins_entry_point(GetProcAddress(module, "_register_k3d_plugins"));
 		if(!RegisterPlugins)
 		{
-			log() << error << "Module " << FilePath.leaf() << " does not contain required register_k3d_plugins() entry point" << std::endl;
+			log() << error << "Module " << FilePath.leaf().raw() << " does not contain required register_k3d_plugins() entry point" << std::endl;
 			return;
 		}
 	}
@@ -180,12 +177,12 @@ namespace detail
 		return 0;
 	}
 
-	static void os_load_module(const boost::filesystem::path& FilePath, register_module_entry_point& RegisterModule, register_plugins_entry_point& RegisterPlugins)
+	static void os_load_module(const filesystem::path& FilePath, register_module_entry_point& RegisterModule, register_plugins_entry_point& RegisterPlugins)
 	{
-		if(file_extension(FilePath) != "dylib")
+		if(filesystem::extension(FilePath).lowercase().raw() != ".dylib")
 			return;
 
-		void* module = dlopen(FilePath.native_file_string().c_str(), 0);
+		void* module = dlopen(FilePath.native_filesystem_string().c_str(), 0);
 		if(!module)
 		{
 			log() << error << "Module " << FilePath.leaf() << ": " << dlerror() << std::endl;
@@ -211,29 +208,29 @@ namespace detail
 
 	#include <dlfcn.h>
 
-	static void os_load_module(const boost::filesystem::path& FilePath, register_module_entry_point& RegisterModule, register_plugins_entry_point& RegisterPlugins)
+	static void os_load_module(const filesystem::path& FilePath, register_module_entry_point& RegisterModule, register_plugins_entry_point& RegisterPlugins)
 	{
-		if(file_extension(FilePath) != "so")
+		if(filesystem::extension(FilePath).lowercase().raw() != ".so")
 			return;
 
-		void* module = dlopen(FilePath.native_file_string().c_str(), RTLD_GLOBAL | RTLD_LAZY);
+		void* module = dlopen(FilePath.native_filesystem_string().c_str(), RTLD_GLOBAL | RTLD_LAZY);
 		if(!module)
 		{
-			log() << error << "Module " << FilePath.leaf() << ": " << dlerror() << std::endl;
+			log() << error << "Module " << FilePath.leaf().raw() << ": " << dlerror() << std::endl;
 			return;
 		}
 
 		RegisterModule = register_module_entry_point(dlsym(module, "register_k3d_module"));
 		if(!RegisterModule)
 		{
-			log() << warning << "Module " << FilePath.leaf() << " does not contain required register_k3d_module() entry point" << std::endl;
+			log() << warning << "Module " << FilePath.leaf().raw() << " does not contain required register_k3d_module() entry point" << std::endl;
 			return;
 		}
 
 		RegisterPlugins = register_plugins_entry_point(dlsym(module, "register_k3d_plugins"));
 		if(!RegisterPlugins)
 		{
-			log() << error << "Module " << FilePath.leaf() << " does not contain required register_k3d_plugins() entry point" << std::endl;
+			log() << error << "Module " << FilePath.leaf().raw() << " does not contain required register_k3d_plugins() entry point" << std::endl;
 			return;
 		}
 	}
@@ -326,7 +323,7 @@ private:
 /// Stores a mapping of plugin class id to plugin factory, so we can lookup recently-loaded factories quickly
 std::map<uuid, iplugin_factory*> proxied_factories;
 /// Stores a mapping of plugin class id to plugin module path, so we can load modules that were proxied
-std::map<uuid, boost::filesystem::path> proxied_modules;
+std::map<uuid, filesystem::path> proxied_modules;
 
 iplugin_factory* load_proxied_factory(const uuid& ClassID)
 {
@@ -343,7 +340,7 @@ iplugin_factory* load_proxied_factory(const uuid& ClassID)
 		return 0;
 
 	// It's a K-3D module, all-right - give it a chance to register its plugins
-	log() << info << "Loading plugin module " << proxied_modules[ClassID].native_file_string() << std::endl;
+	log() << info << "Loading plugin module " << proxied_modules[ClassID].native_console_string() << std::endl;
 
 	message_signal_t message_signal;
 	iplugin_factory_collection::factories_t factories;
@@ -571,9 +568,9 @@ private:
 
 struct plugin_factory_collection::implementation
 {
-	bool proxy_module(const boost::filesystem::path& Path, const boost::filesystem::path& ProxyPath)
+	bool proxy_module(const filesystem::path& Path, const filesystem::path& ProxyPath)
 	{
-		m_message_signal.emit(string_cast(boost::format(_("Proxying plugin module %1%")) % Path.native_file_string()));
+		m_message_signal.emit(string_cast(boost::format(_("Proxying plugin module %1%")) % Path.native_utf8_string().raw()));
 
 		try
 		{
@@ -663,24 +660,29 @@ struct plugin_factory_collection::implementation
 		}
 		catch(std::exception& e)
 		{
-			log() << error << "Error proxying plugin module " << ProxyPath.native_file_string() << std::endl;
+			log() << error << "Error proxying plugin module " << ProxyPath.native_console_string() << std::endl;
 			return false;
 		}
 
 		return false;
 	}
 
-	void load_module(const boost::filesystem::path& Path, const load_proxy_t LoadProxies)
+	void load_module(const filesystem::path& Path, const load_proxy_t LoadProxies)
 	{
+		if(filesystem::extension(Path).lowercase().raw() == ".proxy")
+			return;
+
 		// If the module can be proxied for fast startup, do that instead ...
-		boost::filesystem::path proxy_path = boost::filesystem::path(Path.native_file_string() + ".proxy", boost::filesystem::native);
+		filesystem::path proxy_path = Path + ".proxy";
 		if(LoadProxies == LOAD_PROXIES)
 		{
-			if(boost::filesystem::exists(proxy_path) && proxy_module(Path, proxy_path))
+			if(filesystem::exists(proxy_path) && proxy_module(Path, proxy_path))
 				return;
 		}
 
 		// OK, just load the module ...
+		m_message_signal.emit(string_cast(boost::format(_("Loading plugin module %1%")) % Path.native_utf8_string().raw()));
+
 		register_module_entry_point register_module = 0;
 		register_plugins_entry_point register_plugins = 0;
 		detail::os_load_module(Path, register_module, register_plugins);
@@ -693,14 +695,12 @@ struct plugin_factory_collection::implementation
 		register_module(module_id);
 		if(m_modules.count(module_id))
 		{
-			log() << info << "Skipping duplicate module " << Path.native_file_string() << std::endl;
+			log() << info << "Skipping duplicate module " << Path.native_console_string() << std::endl;
 			return;
 		}
 		m_modules.insert(module_id);
 
 		// It's a K-3D module, all-right - give it a chance to register its plugins
-		m_message_signal.emit(string_cast(boost::format(_("Loading plugin module %1%")) % Path.native_file_string()));
-
 		iplugin_factory_collection::factories_t new_factories;
 		detail::plugin_registry registry(m_message_signal, m_factories, new_factories);
 		register_plugins(registry);
@@ -747,19 +747,18 @@ void plugin_factory_collection::bind_module(const std::string& ModuleName, regis
 	RegisterPlugins(registry);
 }
 
-void plugin_factory_collection::load_module(const boost::filesystem::path& Path, const load_proxy_t LoadProxies)
+void plugin_factory_collection::load_module(const filesystem::path& Path, const load_proxy_t LoadProxies)
 {
 	m_implementation->load_module(Path, LoadProxies);
 }
 
-void plugin_factory_collection::load_modules(const boost::filesystem::path& Path, const bool Recursive, const load_proxy_t LoadProxies)
+void plugin_factory_collection::load_modules(const filesystem::path& Path, const bool Recursive, const load_proxy_t LoadProxies)
 {
-	m_implementation->m_message_signal.emit(
-		string_cast(boost::format(_("Searching for plugins in %1%")) % Path.native_file_string()));
+	m_implementation->m_message_signal.emit(string_cast(boost::format(_("Searching for plugins in %1%")) % Path.native_utf8_string().raw()));
 
-	for(boost::filesystem::directory_iterator path(Path); path != boost::filesystem::directory_iterator(); ++path)
+	for(k3d::filesystem::directory_iterator path(Path); path != k3d::filesystem::directory_iterator(); ++path)
 	{
-		if(boost::filesystem::is_directory(*path))
+		if(k3d::filesystem::is_directory(*path))
 		{
 			if(Recursive)
 				load_modules(*path, Recursive, LoadProxies);
@@ -773,9 +772,7 @@ void plugin_factory_collection::load_modules(const boost::filesystem::path& Path
 
 void plugin_factory_collection::load_modules(const std::string& Paths, const bool Recursive, const load_proxy_t LoadProxies)
 {
-	system::paths_t paths;
-	system::decompose_path_list(Paths, paths);
-
+	const system::paths_t paths = system::decompose_path_list(Paths);
 	for(system::paths_t::const_iterator path = paths.begin(); path != paths.end(); ++path)
 		load_modules(*path, Recursive, LoadProxies);
 }
