@@ -61,11 +61,19 @@ boost::any get_internal_value(iunknown& Object, const std::string& Name);
 	\return true, iff the value was set successfully, false otherwise (the property wasn't writable or the type didn't match)
 */
 bool set_value(iproperty& Property, const boost::any& Value);
+/** \brief Quietly sets the value of a property - doesn't log errors if the property couldn't be set
+	\return true, iff the value was set successfully, false otherwise (the property wasn't writable or the type didn't match)
+*/
+bool quiet_set_value(iproperty& Property, const boost::any& Value);
 
 /** \brief Sets the value of a named property
     \return true, iff the value was set successfully, false otherwise (couldn't find a property with a matching name, it wasn't writable, or the type didn't match)
 */
 bool set_value(iunknown& Object, const std::string Name, const boost::any& Value);
+/** \brief Quietly sets the value of a named property - doesn't log errors if the property couldn't be set
+    \return true, iff the value was set successfully, false otherwise (couldn't find a property with a matching name, it wasn't writable, or the type didn't match)
+*/
+bool quiet_set_value(iunknown& Object, const std::string Name, const boost::any& Value);
 
 } // namespace k3d
 
