@@ -23,6 +23,7 @@
 */
 
 #include "fstream.h"
+#include "log.h"
 #include "options.h"
 #include "render_farm.h"
 #include "render_farm_detail.h"
@@ -34,9 +35,6 @@
 #include "xml.h"
 using namespace k3d::xml;
 
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/path.hpp>
-
 #include <list>
 #include <iostream>
 
@@ -60,20 +58,14 @@ class render_frame_implementation :
 	public irender_frame
 {
 public:
-	render_frame_implementation(const boost::filesystem::path& JobPath, const std::string& Name) :
-		m_Path(JobPath / Name)
+	render_frame_implementation(const filesystem::path& JobPath, const std::string& Name) :
+		m_Path(JobPath / filesystem::native_path(ustring::from_utf8(Name)))
 	{
-		try
-		{
-			create_directory(m_Path);
-		}
-		catch(const std::exception&)
-		{
-			log() << error << "Error creating frame directory [" << m_Path.native_file_string() << "]" << std::endl;
-		}
+		if(!filesystem::create_directory(m_Path))
+			log() << error << "Error creating frame directory [" << m_Path.native_console_string() << "]" << std::endl;
 	}
 
-	const boost::filesystem::path add_input_file(const std::string& Name)
+	const filesystem::path add_input_file(const std::string& Name)
 	{
 		// Sanity checks ...
 		assert_warning(Name.size());
@@ -86,10 +78,10 @@ public:
 
 		m_input_files.push_back(name);
 
-		return m_Path / name;
+		return m_Path / filesystem::generic_path(name);
 	}
 
-	const boost::filesystem::path add_output_file(const std::string& Name)
+	const filesystem::path add_output_file(const std::string& Name)
 	{
 		// Sanity checks ...
 		assert_warning(Name.size());
@@ -102,10 +94,10 @@ public:
 
 		m_output_files.push_back(name);
 
-		return m_Path / name;
+		return m_Path / filesystem::generic_path(name);
 	}
 
-	void add_render_operation(const std::string& Type, const std::string& Name, const boost::filesystem::path& SourceFilePath, const bool VisibleRender)
+	void add_render_operation(const std::string& Type, const std::string& Name, const filesystem::path& SourceFilePath, const bool VisibleRender)
 	{
 		// Sanity checks ...
 		assert_warning(!Type.empty());
@@ -115,7 +107,7 @@ public:
 		m_render_operations.push_back(render_operation(Type, Name, SourceFilePath, VisibleRender));
 	}
 
-	void add_copy_operation(const boost::filesystem::path& SourceFilePath, const boost::filesystem::path& TargetFilePath)
+	void add_copy_operation(const filesystem::path& SourceFilePath, const filesystem::path& TargetFilePath)
 	{
 		// Sanity checks ...
 		assert_warning(!SourceFilePath.empty());
@@ -124,7 +116,7 @@ public:
 		m_copy_operations.push_back(copy_operation(SourceFilePath, TargetFilePath));
 	}
 
-	void add_view_operation(const boost::filesystem::path& FilePath)
+	void add_view_operation(const filesystem::path& FilePath)
 	{
 		m_view_files.push_back(FilePath);
 	}
@@ -132,7 +124,7 @@ public:
 	void write_control_file()
 	{
 		// Create the empty control file ...
-		filesystem::ofstream file(m_Path / "control.k3d");
+		filesystem::ofstream file(m_Path / filesystem::generic_path("control.k3d"));
 
 		// Create the XML document ...
 		element document("k3dml");
@@ -156,9 +148,9 @@ public:
 			frame.append(element("renderoperation",
 				attribute("type", renderop->type),
 				attribute("name", renderop->name),
-				attribute("sourcepath", renderop->source_path.native_file_string()),
-				attribute("shaderspath", shader_cache_path().native_file_string()),
-				attribute("sharepath", share_path().native_file_string()),
+				attribute("sourcepath", renderop->source_path.native_utf8_string().raw()),
+				attribute("shaderspath", shader_cache_path().native_utf8_string().raw()),
+				attribute("sharepath", share_path().native_utf8_string().raw()),
 				attribute("visiblerender", renderop->visible_render)));
 		}
 
@@ -166,13 +158,13 @@ public:
 		for(copy_operations_t::const_iterator copyop = m_copy_operations.begin(); copyop != m_copy_operations.end(); ++copyop)
 		{
 			frame.append(element("copyoperation",
-				attribute("from", copyop->from.native_file_string()),
-				attribute("to", copyop->to.native_file_string())));
+				attribute("from", copyop->from.native_utf8_string().raw()),
+				attribute("to", copyop->to.native_utf8_string().raw())));
 		}
 
 		// Specify any viewing operations to be performed after the render ...
 		for(view_files_t::const_iterator viewop = m_view_files.begin(); viewop != m_view_files.end(); ++viewop)
-			frame.append(element("viewoperation", attribute("path", viewop->native_file_string())));
+			frame.append(element("viewoperation", attribute("path", viewop->native_utf8_string().raw())));
 
 		// Write the document ...
 		file << document << std::endl;
@@ -181,7 +173,7 @@ public:
 	void mark_ready()
 	{
 		// Create the empty "ready" status file ...
-		filesystem::ofstream file(m_Path / "ready");
+		filesystem::ofstream file(m_Path / filesystem::generic_path("ready"));
 
 		// Boost::filesystem does not rename empty files
 		file << "K-3D renderfarm status file";
@@ -189,7 +181,7 @@ public:
 
 private:
 	/// Stores the filesystem path for this job
-	const boost::filesystem::path m_Path;
+	const filesystem::path m_Path;
 	/// Stores the set of input files used during rendering
 	typedef std::vector<std::string> input_files_t;
 	input_files_t m_input_files;
@@ -199,7 +191,7 @@ private:
 	/// Defines a render operation to be performed
 	struct render_operation
 	{
-		explicit render_operation(const std::string& Type, const std::string& Name, const boost::filesystem::path& SourcePath, const bool VisibleRender) :
+		explicit render_operation(const std::string& Type, const std::string& Name, const filesystem::path& SourcePath, const bool VisibleRender) :
 			type(Type),
 			name(Name),
 			source_path(SourcePath),
@@ -209,7 +201,7 @@ private:
 
 		const std::string type;
 		const std::string name;
-		const boost::filesystem::path source_path;
+		const filesystem::path source_path;
 		const bool visible_render;
 	};
 	typedef std::list<render_operation> render_operations_t;
@@ -217,19 +209,19 @@ private:
 	/// Defines a post-render copy operation
 	struct copy_operation
 	{
-		explicit copy_operation(const boost::filesystem::path& From, const boost::filesystem::path& To) :
+		explicit copy_operation(const filesystem::path& From, const filesystem::path& To) :
 			from(From),
 			to(To)
 		{
 		}
 
-		const boost::filesystem::path from;
-		const boost::filesystem::path to;
+		const filesystem::path from;
+		const filesystem::path to;
 	};
 	typedef std::list<copy_operation> copy_operations_t;
 	copy_operations_t m_copy_operations;
 	/// Stores an array of files to view once rendering is complete
-	typedef std::vector<boost::filesystem::path> view_files_t;
+	typedef std::vector<filesystem::path> view_files_t;
 	view_files_t m_view_files;
 };
 
@@ -240,8 +232,8 @@ class render_job_implementation :
 	public irender_job
 {
 public:
-	render_job_implementation(const boost::filesystem::path Path, const std::string JobName) :
-		m_Path(Path / JobName)
+	render_job_implementation(const filesystem::path Path, const std::string JobName) :
+		m_Path(Path / filesystem::generic_path(JobName))
 	{
 		try
 		{
@@ -249,7 +241,7 @@ public:
 		}
 		catch(const std::exception& ex)
 		{
-			log() << error << k3d_file_reference << ": Error creating job directory [" << m_Path.native_file_string() << "]" << std::endl;
+			log() << error << k3d_file_reference << ": Error creating job directory [" << m_Path.native_console_string() << "]" << std::endl;
 		}
 	}
 
@@ -265,7 +257,7 @@ public:
 		std::for_each(m_frames.begin(), m_frames.end(), std::mem_fun_ref(&render_frame_implementation::write_control_file));
 
 		// Create the control file ...
-		filesystem::ofstream file(m_Path / "control.k3d");
+		filesystem::ofstream file(m_Path / filesystem::generic_path("control.k3d"));
 
 		// Create the XML document ...
 		element document("k3dml");
@@ -282,7 +274,7 @@ public:
 		std::for_each(m_frames.begin(), m_frames.end(), std::mem_fun_ref(&render_frame_implementation::mark_ready));
 
 		// Create the "ready" status file ...
-		filesystem::ofstream file(m_Path / "ready");
+		filesystem::ofstream file(m_Path / filesystem::generic_path("ready"));
 
 		// Boost::filesystem does not rename empty files
 		file << "Status file." << std::ends;
@@ -292,11 +284,11 @@ public:
 
 	const std::string path()
 	{
-		return m_Path.native_file_string();
+		return m_Path.native_utf8_string().raw();
 	}
 
 private:
-	const boost::filesystem::path m_Path;
+	const filesystem::path m_Path;
 
 	typedef std::list<render_frame_implementation> frames_t;
 	frames_t m_frames;
@@ -308,7 +300,7 @@ private:
 class render_farm_implementation::implementation
 {
 public:
-	implementation(const boost::filesystem::path& OptionsPath) :
+	implementation(const filesystem::path& OptionsPath) :
 		m_options_path(OptionsPath)
 	{
 	}
@@ -319,12 +311,12 @@ public:
 		assert_warning(JobName.size());
 
 		// Render farm path ...
-		const boost::filesystem::path job_path = options::get_path(options::path::render_farm());
+		const filesystem::path job_path = options::get_path(options::path::render_farm());
 
 		// Ensure that the job gets a unique name ...
 		unsigned long index = 0;
 		std::string job_name(JobName);
-		while(boost::filesystem::exists(job_path / job_name))
+		while(filesystem::exists(job_path / filesystem::generic_path(job_name)))
 			job_name = JobName + '-' + string_cast(index++);
 
 		m_jobs.push_back(render_job_implementation(job_path, job_name));
@@ -353,16 +345,12 @@ public:
 
 		// Start the local rendering process ...
 		std::string commandline = "k3d-renderjob \"";
-		commandline += m_options_path.native_file_string();
+		commandline += m_options_path.native_filesystem_string();
 		commandline += "\" \"";
 		commandline += job->path();
 		commandline += "\"";
 
-#ifdef K3D_PLATFORM_WIN32
-		if(!system::async_run_process(commandline))
-#else // K3D_PLATFORM_WIN32
-		if(!system::run_process(commandline))
-#endif // !K3D_PLATFORM_WIN32
+		if(!system::spawn_async(commandline))
 		{
 			log() << error << "Error starting render job " << commandline << std::endl;
 			return;
@@ -370,7 +358,7 @@ public:
 	}
 
 private:
-	const boost::filesystem::path m_options_path;
+	const filesystem::path m_options_path;
 	typedef std::list<render_job_implementation> jobs_t;
 	jobs_t m_jobs;
 };
@@ -379,7 +367,7 @@ private:
 /////////////////////////////////////////////////////////////////////////////
 // render_farm_implementation
 
-render_farm_implementation::render_farm_implementation(const boost::filesystem::path& OptionsPath) :
+render_farm_implementation::render_farm_implementation(const filesystem::path& OptionsPath) :
 	m_implementation(new implementation(OptionsPath))
 {
 }
@@ -418,3 +406,4 @@ irender_farm& render_farm()
 }
 
 } // namespace k3d
+
