@@ -37,17 +37,6 @@
 #include <set>
 #include <stack>
 
-namespace boost
-{
-
-std::ostream& operator<<(std::ostream& Stream, const array<double, 16>& RHS)
-{
-	std::copy(RHS.begin(), RHS.end(), std::ostream_iterator<double>(Stream, " "));
-	return Stream;
-}
-
-} // namespace boost
-
 namespace
 {
 
@@ -124,6 +113,34 @@ private:
 	const k3d::ri::string& token;
 };
 
+/// Formats a matrix for inclusion in a RIB file; designed to be used as an inline formatting object
+class format_matrix
+{
+public:
+	explicit format_matrix(const k3d::ri::matrix& M) :
+		m(M)
+	{
+	}
+
+	friend std::ostream& operator<<(std::ostream& Stream, const format_matrix& RHS)
+	{
+		Stream << "[";
+		for(int i = 0; i != 4; ++i)
+		{
+			for(int j = 0; j != 4; ++j)
+			{
+				Stream << RHS.m[j][i] << " ";
+			}
+		}
+		Stream << "]";
+
+		return Stream;
+	}
+
+private:
+	const k3d::ri::matrix& m;
+};
+
 /// Encapsulates a RenderMan RIB parameter type
 struct predefined_type
 {
@@ -179,8 +196,10 @@ predefined_types_t& predefined_types()
 		types.insert(predefined_type(k3d::ri::VERTEX, "Pw", typeid(k3d::ri::hpoint), 1));
 		types.insert(predefined_type(k3d::ri::VERTEX, "Pw", typeid(k3d::ri::hpoints), 1));
 
+/*
 		types.insert(predefined_type(k3d::ri::VARYING, "N", typeid(k3d::ri::normal), 1));
 		types.insert(predefined_type(k3d::ri::VARYING, "N", typeid(k3d::ri::normals), 1));
+*/
 
 		types.insert(predefined_type(k3d::ri::VARYING, "Cs", typeid(k3d::ri::color), 1));
 		types.insert(predefined_type(k3d::ri::VARYING, "Cs", typeid(k3d::ri::colors), 1));
@@ -269,10 +288,12 @@ public:
 				{
 					Stream << "vector";
 				}
+/*
 				else if(typeid(k3d::ri::normal) == type || typeid(k3d::ri::normals) == type)
 				{
 					Stream << "normal";
 				}
+*/
 				else if(typeid(k3d::ri::color) == type || typeid(k3d::ri::colors) == type)
 				{
 					Stream << "color";
@@ -375,32 +396,6 @@ namespace k3d
 namespace ri
 {
 
-std::ostream& operator<<(std::ostream& Stream, const storage_class_t RHS)
-{
-	switch(RHS)
-	{
-		case k3d::ri::CONSTANT:
-			Stream << "constant";
-			break;
-		case k3d::ri::UNIFORM:
-			Stream << "uniform";
-			break;
-		case k3d::ri::VARYING:
-			Stream << "varying";
-			break;
-		case k3d::ri::VERTEX:
-			Stream << "vertex";
-			break;
-		case k3d::ri::FACEVARYING:
-			Stream << "facevarying";
-			break;
-		default:
-			assert_not_reached();
-	}
-
-	return Stream;
-}
-
 std::ostream& operator<<(std::ostream& Stream, const parameter& RHS)
 {
 	Stream << format_parameter_name(RHS) << " ";
@@ -429,10 +424,12 @@ std::ostream& operator<<(std::ostream& Stream, const parameter& RHS)
 	{
 		Stream << "[ " << boost::any_cast<vector>(RHS.value) << " ]";
 	}
+/*
 	else if(typeid(normal) == RHS.value.type())
 	{
 		Stream << "[ " << boost::any_cast<normal>(RHS.value) << " ]";
 	}
+*/
 	else if(typeid(color) == RHS.value.type())
 	{
 		Stream << "[ " << boost::any_cast<color>(RHS.value) << " ]";
@@ -470,11 +467,13 @@ std::ostream& operator<<(std::ostream& Stream, const parameter& RHS)
 		const vectors* const p = boost::any_cast<vectors>(&RHS.value);
 		Stream << format_array(p->begin(), p->end());
 	}
+/*
 	else if(typeid(normals) == RHS.value.type())
 	{
 		const normals* const p = boost::any_cast<normals>(&RHS.value);
 		Stream << format_array(p->begin(), p->end());
 	}
+*/
 	else if(typeid(colors) == RHS.value.type())
 	{
 		const colors* const p = boost::any_cast<colors>(&RHS.value);
@@ -493,7 +492,7 @@ std::ostream& operator<<(std::ostream& Stream, const parameter& RHS)
 	else
 	{
 		Stream << "[ ]";
-		log() << error << "Unknown parameter type for [" << RHS.name << "] will not be serialized" << std::endl;
+		log() << error << k3d_file_reference << "Unknown type [" << RHS.value.type().name() << "] for [" << RHS.name << "] will be ignored" << std::endl;
 	}
 
 	return Stream;
@@ -552,13 +551,7 @@ bool last_sample(const render_state& State)
 
 const matrix convert(const k3d::matrix4& Matrix)
 {
-	matrix result;
-
-	k3d::matrix4 temp(transpose(Matrix));
-	real* const m = temp;
-	std::copy(m, m+16, result.begin());
-
-	return result;
+	return Matrix;
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -566,10 +559,14 @@ const matrix convert(const k3d::matrix4& Matrix)
 
 void setup_material(iunknown* const Material, const render_state& State)
 {
-	k3d::ri::imaterial* const material = dynamic_cast<k3d::ri::imaterial*>(Material);
-	if(material)
+	k3d::ri::imaterial* ri_material = 0;
+
+	if(k3d::imaterial* const material = dynamic_cast<k3d::imaterial*>(Material))
+		ri_material = material->ri_material();
+
+	if(ri_material)
 	{
-		material->setup_renderman_material(State);
+		ri_material->setup_renderman_material(State);
 	}
 	else
 	{
@@ -579,11 +576,11 @@ void setup_material(iunknown* const Material, const render_state& State)
 
 		State.engine.RiColor(k3d::color(1, 1, 1));
 		State.engine.RiOpacity(k3d::color(1, 1, 1));
-		State.engine.RiSurfaceV("null");
-		State.engine.RiDisplacementV("null");
-		State.engine.RiAtmosphereV("null");
-		State.engine.RiInteriorV("null");
-		State.engine.RiExteriorV("null");
+		State.engine.RiSurfaceV(path(), "null");
+		State.engine.RiDisplacementV(path(), "null");
+		State.engine.RiAtmosphereV(path(), "null");
+		State.engine.RiInteriorV(path(), "null");
+		State.engine.RiExteriorV(path(), "null");
 	}
 }
 
@@ -610,7 +607,7 @@ void set_attributes(iproperty_collection& Properties, irender_engine& Engine)
 			parameter_lists[parameter_list_name].push_back(parameter(parameter_name, UNIFORM, (*property)->property_value()));
 		}
 	}
-	
+
 	for(parameter_lists_t::iterator parameter_list = parameter_lists.begin(); parameter_list != parameter_lists.end(); ++parameter_list)
 		Engine.RiAttributeV(parameter_list->first, parameter_list->second);
 }
@@ -639,9 +636,9 @@ void set_options(iproperty_collection& Properties, irender_engine& Engine)
 			parameter_lists[parameter_list_name].push_back(parameter(parameter_name, UNIFORM, (*property)->property_value()));
 		}
 	}
-	
+
 	for(parameter_lists_t::iterator parameter_list = parameter_lists.begin(); parameter_list != parameter_lists.end(); ++parameter_list)
-		Engine.RiAttributeV(parameter_list->first, parameter_list->second);
+		Engine.RiOptionV(parameter_list->first, parameter_list->second);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -675,8 +672,6 @@ public:
 	bool m_object_block;
 	/// Set to true within a motion block
 	bool m_motion_block;
-	/// Stores the set of shaders in-use
-	shaders_t m_shaders;
 };
 
 /////////////////////////////////////////////////////////////////////////////
@@ -701,11 +696,6 @@ render_engine::~render_engine()
 	delete m_implementation;
 }
 
-const render_engine::shaders_t render_engine::shaders()
-{
-	return m_implementation->m_shaders;
-}
-
 bool render_engine::set_inline_types(const bool Inline)
 {
 	return ::set_inline_types(m_implementation->m_stream, Inline);
@@ -821,9 +811,8 @@ void render_engine::RiExposure(real Gain, real Gamma)
 	m_implementation->m_stream << ::indentation << "Exposure " << Gain << " " << Gamma << "\n";
 }
 
-void render_engine::RiImagerV(const string& Name, const parameter_list& Parameters)
+void render_engine::RiImagerV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Name);
 	m_implementation->m_stream << ::indentation << "Imager " << format_string(Name) << " " << Parameters << "\n";
 }
 
@@ -891,16 +880,14 @@ void render_engine::RiTextureCoordinates(real S1, real T1, real S2, real T2, rea
 	m_implementation->m_stream << ::indentation << "TextureCoordinates " << S1 << " " << T1 << " " << S2 << " " << T2 << " " << S3 << " " << T3 << " " << S4 << " " << T4 << "\n";
 }
 
-const light_handle render_engine::RiLightSourceV(const string& Name, const parameter_list& Parameters)
+const light_handle render_engine::RiLightSourceV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Name);
 	m_implementation->m_stream << ::indentation << "LightSource " << format_string(Name) << " " << ++m_implementation->m_light_handle << " " << Parameters << "\n";
 	return m_implementation->m_light_handle;
 }
 
-const light_handle render_engine::RiAreaLightSourceV(const string& Name, const parameter_list& Parameters)
+const light_handle render_engine::RiAreaLightSourceV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Name);
 	m_implementation->m_stream << ::indentation << "AreaLightSource " << format_string(Name) << " " << ++m_implementation->m_light_handle << " " << Parameters << "\n";
 	return m_implementation->m_light_handle;
 }
@@ -910,27 +897,23 @@ void render_engine::RiIlluminate(const light_handle LightHandle, bool OnOff)
 	m_implementation->m_stream << ::indentation << "Illuminate " << LightHandle << " " << OnOff << "\n";
 }
 
-void render_engine::RiSurfaceV(const string& Name, const parameter_list& Parameters)
+void render_engine::RiSurfaceV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Name);
 	m_implementation->m_stream << ::indentation << "Surface " << format_string(Name) << " " << Parameters << "\n";
 }
 
-void render_engine::RiAtmosphereV(const string& Name, const parameter_list& Parameters)
+void render_engine::RiAtmosphereV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Name);
 	m_implementation->m_stream << ::indentation << "Atmosphere " << format_string(Name) << " " << Parameters << "\n";
 }
 
-void render_engine::RiInteriorV(const string& Name, const parameter_list& Parameters)
+void render_engine::RiInteriorV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Name);
 	m_implementation->m_stream << ::indentation << "Interior " << format_string(Name) << " " << Parameters << "\n";
 }
 
-void render_engine::RiExteriorV(const string& Name, const parameter_list& Parameters)
+void render_engine::RiExteriorV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Name);
 	m_implementation->m_stream << ::indentation << "Exterior " << format_string(Name) << " " << Parameters << "\n";
 }
 
@@ -996,12 +979,12 @@ void render_engine::RiIdentity()
 
 void render_engine::RiTransform(const matrix& Transform)
 {
-	m_implementation->m_stream << ::indentation << "Transform " << format_array(Transform.begin(), Transform.end()) << "\n";
+	m_implementation->m_stream << ::indentation << "Transform " << format_matrix(Transform) << "\n";
 }
 
 void render_engine::RiConcatTransform(const matrix& Transform)
 {
-	m_implementation->m_stream << ::indentation << "ConcatTransform " << format_array(Transform.begin(), Transform.end()) << "\n";
+	m_implementation->m_stream << ::indentation << "ConcatTransform " << format_matrix(Transform) << "\n";
 }
 
 void render_engine::RiPerspective(real FieldOfView)
@@ -1029,15 +1012,13 @@ void render_engine::RiSkew(real Angle, real DX1, real DY1, real DZ1, real DX2, r
 	m_implementation->m_stream << ::indentation << "Skew " << Angle << " " << DX1 << " " << DY1 << " " << DZ1 << " " << DX2 << " " << DY2 << " " << DZ2 << "\n";
 }
 
-void render_engine::RiDeformationV(const string& Name, const parameter_list& Parameters)
+void render_engine::RiDeformationV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Name);
 	m_implementation->m_stream << ::indentation << "Deformation " << format_string(Name) << " " << Parameters << "\n";
 }
 
-void render_engine::RiDisplacementV(const string& Name, const parameter_list& Parameters)
+void render_engine::RiDisplacementV(const path& Path, const string& Name, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(Name);
 	m_implementation->m_stream << ::indentation << "Displacement " << format_string(Name) << " " << Parameters << "\n";
 }
 
@@ -1113,7 +1094,7 @@ void render_engine::RiPointsGeneralPolygonsV(const unsigned_integers& LoopCounts
 
 void render_engine::RiBasis(const matrix& UBasis, const unsigned_integer UStep, const matrix& VBasis, const unsigned_integer VStep)
 {
-	m_implementation->m_stream << ::indentation << "Basis " << format_array(UBasis.begin(), UBasis.end()) << " " << UStep << " " << format_array(VBasis.begin(), VBasis.end()) << " " << VStep << "\n";
+	m_implementation->m_stream << ::indentation << "Basis " << format_matrix(UBasis) << " " << UStep << " " << format_matrix(VBasis) << " " << VStep << "\n";
 }
 
 void render_engine::RiBasis(const string& UBasis, const unsigned_integer UStep, const string& VBasis, const unsigned_integer VStep)
@@ -1263,12 +1244,12 @@ void render_engine::RiNewline()
 
 void render_engine::RiReadArchive(const path& Archive)
 {
-	m_implementation->m_stream << ::indentation << "ReadArchive " << format_string(Archive.native_file_string()) << "\n";
+	m_implementation->m_stream << ::indentation << "ReadArchive " << format_string(Archive.native_filesystem_string()) << "\n";
 }
 
 void render_engine::RiProcDelayedReadArchive(const path& Archive, const bound& Bound)
 {
-	m_implementation->m_stream << ::indentation << "Procedural " << format_string("DelayedReadArchive") << " [ " <<  format_string(Archive.native_file_string()) << " ] [ " << Bound.nx << " " << Bound.px << " " << Bound.ny << " " << Bound.py << " " << Bound.nz << " " << Bound.pz << " ]\n";
+	m_implementation->m_stream << ::indentation << "Procedural " << format_string("DelayedReadArchive") << " [ " <<  format_string(Archive.native_filesystem_string()) << " ] [ " << Bound.nx << " " << Bound.px << " " << Bound.ny << " " << Bound.py << " " << Bound.nz << " " << Bound.pz << " ]\n";
 }
 
 void render_engine::RiStructure(const string& Structure)
@@ -1310,9 +1291,8 @@ void render_engine::RiBlobbyV(const unsigned_integer NLeaf, const unsigned_integ
 	m_implementation->m_stream << ::indentation << "Blobby " << NLeaf << " " << format_array(Codes.begin(), Codes.end()) << " " << format_array(Floats.begin(), Floats.end()) << " " << format_array(Strings.begin(), Strings.end()) << " " << Parameters << "\n";
 }
 
-void render_engine::RiShaderLayerV(const std::string& type, const std::string& name, const std::string& layername, const parameter_list& Parameters)
+void render_engine::RiShaderLayerV(const std::string& type, const path& Path, const std::string& name, const std::string& layername, const parameter_list& Parameters)
 {
-	m_implementation->m_shaders.insert(name);
 	m_implementation->m_stream << ::indentation << "ShaderLayer " << format_string(type) << " " << format_string(name) << " " << format_string(layername) << " " << Parameters << "\n";
 }
 
@@ -1321,25 +1301,7 @@ void render_engine::RiConnectShaderLayers(const std::string& type, const std::st
 	m_implementation->m_stream << ::indentation << "ConnectShaderLayers " << format_string(type) << " " << format_string(layer1) << " " << format_string(variable1) << " " << format_string(layer2) << " " << format_string(variable2) << "\n";
 }
 
-////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-// parameter_list
-
-parameter_list& operator+=(parameter_list& LHS, const parameter_list& RHS)
-{
-	LHS.insert(LHS.end(), RHS.begin(), RHS.end());
-	return LHS;
-}
-
-parameter_list operator+(const parameter_list& LHS, const parameter_list& RHS)
-{
-	parameter_list results(LHS);
-	results += RHS;
-
-	return results;
-}
-
 } // namespace ri
 
 } // namespace k3d
 
-
