@@ -22,7 +22,6 @@
 		\author Tim Shead (tshead@k-3d.com)
 */
 
-#include "application.h"
 #include "create_plugins.h"
 #include "iapplication_plugin_factory.h"
 #include "ideletable.h"
@@ -39,6 +38,9 @@
 namespace k3d
 {
 
+namespace script
+{
+
 namespace detail
 {
 
@@ -53,17 +55,17 @@ const factories_t& script_engine_factories()
 }
 
 /// Executes a script using the given plugin factory to create the script engine
-bool execute_script(std::istream& Script, const std::string& ScriptName, iscript_engine::context_t& Context, iplugin_factory& Language)
+bool execute_script(const code& Script, const std::string& ScriptName, iscript_engine::context_t& Context, const language& Language)
 {
-	// Sanity checks ...
 	return_val_if_fail(ScriptName.size(), false);
+	return_val_if_fail(Language.factory(), false);
 
 	// Get the requested scripting engine ...
-	iscript_engine* const engine = dynamic_cast<iscript_engine*>(create_plugin(Language));
+	iscript_engine* const engine = dynamic_cast<iscript_engine*>(create_plugin(*Language.factory()));
 	return_val_if_fail(engine, false);
 
 	// Run that bad-boy ...
-	const bool result = engine->execute(ScriptName, Script, Context);
+	const bool result = engine->execute(ScriptName, Script.source(), Context);
 
 	// Done with the engine ...
 	delete dynamic_cast<ideletable*>(engine);
@@ -73,7 +75,42 @@ bool execute_script(std::istream& Script, const std::string& ScriptName, iscript
 
 } // namespace detail
 
-iplugin_factory* recognize_script_language(std::istream& Script)
+/////////////////////////////////////////////////////////////////////////////////
+// code
+
+code::code(const std::string& Source) :
+	m_buffer(Source)
+{
+}
+
+code::code(std::istream& Source)
+{
+	std::stringstream temp;
+	temp << Source.rdbuf();
+
+	m_buffer = temp.str();
+}
+
+code::code(std::istringstream& Source) :
+	m_buffer(Source.str())
+{
+}
+
+code::code(std::stringstream& Source) :
+	m_buffer(Source.str())
+{
+}
+
+const std::string& code::source() const
+{
+	return m_buffer;
+}
+
+///////////////////////////////////////////////////////////////////////////////
+// language
+
+language::language(const code& Script) :
+	m_factory(0)
 {
 	// Get the set of all script engine factories ...
 	const factories_t& factories(detail::script_engine_factories());
@@ -85,45 +122,68 @@ iplugin_factory* recognize_script_language(std::istream& Script)
 		if(!script_engine)
 			continue;
 
-		const bool can_execute = script_engine->can_execute(Script);
+		const bool can_execute = script_engine->can_execute(Script.source());
 		delete dynamic_cast<ideletable*>(script_engine);
 	
 		if(can_execute)
-			return *factory;
+		{
+			m_factory = *factory;
+			break;
+		}
 	}
-
-	// Couldn't find anything ...
-	return 0;
 }
 
-bool execute_script(std::istream& Script, const std::string& ScriptName, iscript_engine::context_t& Context, const uuid& Language)
+language::language(const uuid& Language) :
+	m_factory(0)
 {
-	// Lookup the engine ...
-	iplugin_factory* const language = plugin(Language);
-	return_val_if_fail(language, false);
+	// Get the set of all script engine factories ...
+	const factories_t& factories(detail::script_engine_factories());
 
-	// Make it happen ...
-	return detail::execute_script(Script, ScriptName, Context, *language);
+	// Look for a factory that matches ...
+	for(factories_t::const_iterator factory = factories.begin(); factory != factories.end(); ++factory)
+	{
+		if((*factory)->class_id() != Language)
+			continue;
+
+		m_factory = *factory;
+		break;
+	}
 }
 
-void execute_script(std::istream& Script, const std::string& ScriptName, iscript_engine::context_t& Context, bool& Recognized, bool& Executed)
+language::language(iplugin_factory* Language) :
+	m_factory(Language)
+{
+}
+
+iplugin_factory* language::factory() const
+{
+	return m_factory;
+}
+
+bool execute(const code& Script, const std::string& ScriptName, iscript_engine::context_t& Context, const language& Language)
+{
+	return detail::execute_script(Script, ScriptName, Context, Language);
+}
+
+void execute(const code& Script, const std::string& ScriptName, iscript_engine::context_t& Context, bool& Recognized, bool& Executed)
 {
 	// Starting state ...
 	Recognized = false;
 	Executed = false;
 
 	// See which language it's written in ...
-	iplugin_factory* const language = recognize_script_language(Script);
+	language detected_language(Script);
 
 	// If the language wasn't recognized, we're done ...
-	Recognized = language ? true : false;
+	Recognized = detected_language.factory() ? true : false;
 	if(!Recognized)
 		return;
 
 	// Execute that puppy ...
-	Executed = detail::execute_script(Script, ScriptName, Context, *language);
+	Executed = detail::execute_script(Script, ScriptName, Context, detected_language);
 }
 
+} // namespace script
+
 } // namespace k3d
 
-
