@@ -31,21 +31,10 @@ class selectable :
 {
 public:
 	selectable() :
-		visible_selection(false),
-		selection_weight(1.0)
+		selection_weight(0.0)
 	{
 	}
 
-	bool get_visible_selection()
-	{
-		return visible_selection;
-	}
-
-	void set_visible_selection(const bool Visible)
-	{
-		visible_selection = Visible;
-	}
-
 	double get_selection_weight()
 	{
 		return selection_weight;
@@ -56,7 +45,6 @@ public:
 		selection_weight = Weight;
 	}
 
-	bool visible_selection;
 	double selection_weight;
 };
 
