@@ -582,10 +582,7 @@ nupatch* get_nupatch(mesh& Mesh, const record& Record)
 void select(inode* Node)
 {
 	if(iselectable* const selectable = dynamic_cast<iselectable*>(Node))
-	{
-		selectable->set_visible_selection(true);
 		selectable->set_selection_weight(1.0);
-	}
 }
 
 ///////////////////////////////////////////////////////////////////////////////////
@@ -594,10 +591,7 @@ void select(inode* Node)
 void deselect(inode* Node)
 {
 	if(iselectable* const selectable = dynamic_cast<iselectable*>(Node))
-	{
-		selectable->set_visible_selection(false);
 		selectable->set_selection_weight(0.0);
-	}
 }
 
 } // namespace selection
