@@ -42,8 +42,8 @@
 #include "property.h"
 #include "result.h"
 #include "serialization.h"
-#include "shader_collection.h"
 #include "share.h"
+#include "sl.h"
 #include "string_cast.h"
 #include "types.h"
 #include "xml.h"
@@ -1005,198 +1005,6 @@ struct same_name
 	const std::string name;
 };
 
-/// Returns a collection of "old-fashioned cached shader metadata"
-const sl::shaders_t& shader_cache()
-{
-	static shader_collection cache;
-	if(cache.shaders().empty())
-	{
-		cache.load_shaders((share_path() / "shaders/displacement").native_file_string());
-		cache.load_shaders((share_path() / "shaders/imager").native_file_string());
-		cache.load_shaders((share_path() / "shaders/light").native_file_string());
-		cache.load_shaders((share_path() / "shaders/surface").native_file_string());
-		cache.load_shaders((share_path() / "shaders/volume").native_file_string());
-	}
-
-	return cache.shaders();
-}
-
-/// Upgrades RenderMan shaders so that their arguments are user properties
-void upgrade_renderman_shader_arguments(element& XMLDocument)
-{
-	element* const xml_nodes = find_element(XMLDocument, "nodes");
-	if(!xml_nodes)
-		return;
-
-	for(element::elements_t::iterator xml_node = xml_nodes->children.begin(); xml_node != xml_nodes->children.end(); ++xml_node)
-	{
-		if(xml_node->name != "node")
-			continue;
-
-		const uuid node_class_id = attribute_value<uuid>(*xml_node, "class", uuid::null());
-		if(
-			node_class_id != classes::RenderManDisplacementShader() &&
-			node_class_id != classes::RenderManImagerShader() &&
-			node_class_id != classes::RenderManLightShader() &&
-			node_class_id != classes::RenderManSurfaceShader() &&
-			node_class_id != classes::RenderManVolumeShader())
-			continue;
-
-		element* const xml_properties = find_element(*xml_node, "properties");
-		if(!xml_properties)
-			continue;
-
-		std::string xml_shader_name;
-		for(element::elements_t::iterator xml_property = xml_properties->children.begin(); xml_property != xml_properties->children.end(); ++xml_property)
-		{
-			if(xml_property->name != "property")
-				continue;
-
-			if(attribute_text(*xml_property, "name") != "shader_name")
-				continue;
-
-			xml_shader_name = xml_property->text;
-		}
-
-		if(xml_shader_name.empty())
-			continue;
-
-		const sl::shaders_t& shaders = shader_cache();
-		const sl::shaders_t::const_iterator shader = std::find_if(shaders.begin(), shaders.end(), same_name(xml_shader_name));
-		if(shader == shaders.end())
-		{
-			log() << error << "unknown shader [" << xml_shader_name << "]" << std::endl;
-			continue;
-		}
-
-		for(element::elements_t::iterator xml_property = xml_properties->children.begin(); xml_property != xml_properties->children.end(); ++xml_property)
-		{
-			if(xml_property->name != "property")
-				continue;
-
-			const std::string xml_property_name = attribute_text(*xml_property, "name");
-			if(xml_property_name == "shader_name")
-				continue;
-
-			if(!find_attribute(*xml_property, "label"))
-				xml_property->append(attribute("label", ""));
-
-			if(!find_attribute(*xml_property, "description"))
-				xml_property->append(attribute("description", ""));
-
-			if(!find_attribute(*xml_property, "type"))
-			{
-				// Try looking-up the property type
-				for(sl::shader::arguments_t::const_iterator argument = shader->arguments.begin(); argument != shader->arguments.end(); ++argument)
-				{
-					if(argument->name != xml_property_name)
-						continue;
-
-					switch(argument->extended_type)
-					{
-						case sl::argument::EX_FLOAT:
-						case sl::argument::EX_TIME:
-						case sl::argument::EX_ANGLE:
-						case sl::argument::EX_DISTANCE:
-						case sl::argument::EX_AREA:
-						case sl::argument::EX_VOLUME:
-						case sl::argument::EX_MASS:
-						case sl::argument::EX_FORCE:
-						case sl::argument::EX_PRESSURE:
-							xml_property->append(attribute("type", type_string<k3d::ri::real>()));
-							break;
-						case sl::argument::EX_STRING:
-						case sl::argument::EX_SPACE:
-							xml_property->append(attribute("type", type_string<k3d::ri::string>()));
-							break;
-						case sl::argument::EX_TEXTURE:
-							break;
-						case sl::argument::EX_POINT:
-							xml_property->append(attribute("type", type_string<k3d::ri::point>()));
-							break;
-						case sl::argument::EX_VECTOR:
-							xml_property->append(attribute("type", type_string<k3d::ri::vector>()));
-							break;
-						case sl::argument::EX_NORMAL:
-							xml_property->append(attribute("type", type_string<k3d::ri::normal>()));
-							break;
-						case sl::argument::EX_HPOINT:
-							xml_property->append(attribute("type", type_string<k3d::ri::hpoint>()));
-							break;
-						case sl::argument::EX_MATRIX:
-							xml_property->append(attribute("type", type_string<k3d::ri::matrix>()));
-							break;
-						case sl::argument::EX_COLOR:
-							xml_property->append(attribute("type", type_string<k3d::ri::color>()));
-							break;
-					}
-				}
-			}
-
-			if(!find_attribute(*xml_property, "user_property"))
-				xml_property->append(attribute("user_property", "vanilla"));
-		}
-	}
-}
-
-/// Upgrades RenderMan shaders to use shader paths instead of shader names
-void upgrade_renderman_shader_names(element& XMLDocument)
-{
-	element* const xml_nodes = find_element(XMLDocument, "nodes");
-	if(!xml_nodes)
-		return;
-
-	for(element::elements_t::iterator xml_node = xml_nodes->children.begin(); xml_node != xml_nodes->children.end(); ++xml_node)
-	{
-		if(xml_node->name != "node")
-			continue;
-
-		const uuid node_class_id = attribute_value<uuid>(*xml_node, "class", uuid::null());
-		if(
-			node_class_id != classes::AqsisDisplacementShaderLayer() &&
-			node_class_id != classes::AqsisSurfaceShaderLayer() &&
-			node_class_id != classes::RenderManDisplacementShader() &&
-			node_class_id != classes::RenderManImagerShader() &&
-			node_class_id != classes::RenderManLightShader() &&
-			node_class_id != classes::RenderManSurfaceShader() &&
-			node_class_id != classes::RenderManVolumeShader())
-			continue;
-
-		element* const xml_properties = find_element(*xml_node, "properties");
-		if(!xml_properties)
-			continue;
-
-		std::string xml_shader_name;
-		for(element::elements_t::iterator xml_property = xml_properties->children.begin(); xml_property != xml_properties->children.end(); ++xml_property)
-		{
-			if(xml_property->name != "property")
-				continue;
-
-			if(attribute_text(*xml_property, "name") != "shader_name")
-				continue;
-
-			xml_shader_name = xml_property->text;
-		}
-
-		if(xml_shader_name.empty())
-			continue;
-
-		const sl::shaders_t& shaders = shader_cache();
-		const sl::shaders_t::const_iterator shader = std::find_if(shaders.begin(), shaders.end(), same_name(xml_shader_name));
-		if(shader == shaders.end())
-		{
-			log() << error << "unknown shader [" << xml_shader_name << "]" << std::endl;
-			continue;
-		}
-
-		xml_properties->append(
-			xml::element("property",
-				xml::attribute("name", "shader_path"),
-				xml::attribute("reference", "absolute"),
-				xml::attribute("absolute_path", shader->file_path)));
-	}
-}
-
 } // namespace detail
 
 /////////////////////////////////////////////////////////////////////////////
@@ -1219,8 +1027,6 @@ void upgrade_document(element& XMLDocument)
 	detail::upgrade_poly_terrain_hfbm_nodes(XMLDocument);
 	detail::upgrade_poly_text_nodes(XMLDocument);
 	detail::upgrade_transformable_nodes(XMLDocument);
-	detail::upgrade_renderman_shader_arguments(XMLDocument);
-	detail::upgrade_renderman_shader_names(XMLDocument);
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -1914,12 +1720,12 @@ void load_mesh(mesh& Mesh, element& XML, const ipersistent::load_context& Contex
 	}
 }
 
-bool import_file(idocument& Document, idocument_read_format& FormatFilter, const boost::filesystem::path& File)
+bool import_file(idocument& Document, idocument_read_format& FormatFilter, const filesystem::path& File)
 {
 	return FormatFilter.read_file(Document, File);
 }
 
-bool export_file(idocument& Document, idocument_write_format& FormatFilter, const boost::filesystem::path& File)
+bool export_file(idocument& Document, idocument_write_format& FormatFilter, const filesystem::path& File)
 {
 	return FormatFilter.write_file(Document, File);
 }
