@@ -28,14 +28,11 @@
 #include "sl.h"
 #include <memory>
 
-// Forward declarations
-namespace boost { namespace filesystem { class path; } }
-
 namespace k3d
 {
 
 /// Recompiles a shader from source iff it's out-of-date
-bool compile_shader(const boost::filesystem::path& SourceFile, const std::string& RenderEngineType, const std::string& RenderEngine);
+bool compile_shader(const filesystem::path& SourceFile, const std::string& RenderEngineType, const std::string& RenderEngine);
 
 } // namespace k3d
 
