@@ -23,6 +23,8 @@
 namespace k3d
 {
 
+class iunknown;
+
 namespace signal
 {
 
@@ -35,17 +37,27 @@ public:
 		emitting(false)
 	{
 	}
-	
+
 	void operator()()
 	{
 		if(emitting)
 			return;
-		
+
 		emitting = true;
 		signal.emit();
 		emitting = false;
 	}
 
+	void operator()(iunknown* const Hint)
+	{
+		if(emitting)
+			return;
+
+		emitting = true;
+		signal.emit(Hint);
+		emitting = false;
+	}
+
 private:
 	SignalT& signal;
 	bool emitting;
@@ -56,9 +68,9 @@ loop_safe_slot<SignalT> make_loop_safe_slot(SignalT& Signal)
 {
 	return loop_safe_slot<SignalT>(Signal);
 }
-	
+
 } // namespace signal
-	
+
 } // namespace k3d
 
 #endif // !K3DSDK_SIGNAL_SLOTS_H
