@@ -25,9 +25,11 @@
 		\author Tim Shead (tshead@k-3d.com)
 */
 
+#include "path.h"
+
 #include <iosfwd>
-#include <list>
 #include <string>
+#include <vector>
 
 namespace k3d
 {
@@ -83,28 +85,28 @@ public:
 	} extended_type_t;
 
 	/// Stores the argument name
-	const std::string name;
+	std::string name;
 	/// Stores the argument label (human-readable string)
-	const std::string label;
+	std::string label;
 	/// Stores the argument description (human-readable string)
-	const std::string description;
+	std::string description;
 	/// Stores the Shading Language storage class
-	const storage_class_t storage_class;
+	storage_class_t storage_class;
 	/// Stores the Shading Language data type
-	const type_t type;
+	type_t type;
 	/// Stores the extended data type
-	const extended_type_t extended_type;
+	extended_type_t extended_type;
 	/// Stores the number of array elements for this argument
-	const unsigned long array_count;
+	unsigned long array_count;
 	/// Stores the coordinate system that this argument is declared within
-	const std::string space;
+	std::string space;
 	/// Stores true iff this argument is an output (message passing) argument
-	const bool output;
+	bool output;
 	/// Stores the argument's default value as a string
-	const std::string default_value;
+	std::string default_value;
 
 	// Enforce strict initialization
-	explicit argument(const std::string& Name, const std::string& Label, const std::string& Description, const storage_class_t StorageClass, const type_t Type, const extended_type_t ExtendedType, const unsigned long ArrayCount, const std::string& Space, const bool Output, const std::string& DefaultValue);
+	argument(const std::string& Name, const std::string& Label, const std::string& Description, const storage_class_t StorageClass, const type_t Type, const extended_type_t ExtendedType, const unsigned long ArrayCount, const std::string& Space, const bool Output, const std::string& DefaultValue);
 };
 
 /// Encapsulates a Pixar RenderMan Shading Language shader
@@ -123,39 +125,31 @@ public:
 	} type_t;
 
 	/// Stores the shader file
-	const std::string file_path;
-	/// Stores the shader name
-	const std::string name;
-	/// Stores the shader author(s)
-	const std::string authors;
-	/// Stores the shader copyright
-	const std::string copyright;
-	/// Stores a brief description of the shader
-	const std::string description;
+	filesystem::path file_path;
 	/// Stores the shader type
 	type_t type;
+	/// Stores the shader name
+	std::string name;
+	/// Stores the shader author(s)
+	std::string authors;
+	/// Stores the shader copyright
+	std::string copyright;
+	/// Stores a brief description of the shader
+	std::string description;
 	/// Stores the shader arguments
-	typedef std::list<argument> arguments_t;
-	const arguments_t arguments;
+	typedef std::vector<argument> arguments_t;
+	arguments_t arguments;
 
-	// Enforce strict initialization
-	explicit shader(const std::string& FilePath, const std::string& Name, const std::string& Authors, const std::string& Copyright, const std::string& Description, const type_t Type, const arguments_t Arguments);
-
-	/// Establish equivalency based on name-only
-	friend bool operator==(const shader& LHS, const shader& RHS)
-	{
-		return LHS.name == RHS.name;
-	}
-
-	/// Establish order based on name-only
-	friend bool operator<(const shader& LHS, const shader& RHS)
-	{
-		return LHS.name < RHS.name;
-	}
+	shader(const type_t Type);
+	shader(const filesystem::path& FilePath, const type_t Type, const std::string& Name, const std::string& Authors, const std::string& Copyright, const std::string& Description, const arguments_t Arguments);
 };
 
 /// A collection of shaders
-typedef std::list<shader> shaders_t;
+typedef std::vector<shader> shaders_t;
+
+bool operator==(const shader& LHS, const shader& RHS);
+bool operator!=(const shader& LHS, const shader& RHS);
+bool operator<(const shader& LHS, const shader& RHS);
 
 // Serialization
 std::ostream& operator<<(std::ostream& Stream, const argument::storage_class_t&);
@@ -168,9 +162,9 @@ std::ostream& operator<<(std::ostream& Stream, const shader::type_t& Value);
 std::istream& operator>>(std::istream& Stream, shader::type_t& Value);
 
 /// Parses preprocessed RenderMan shading language source-code, returning shader data (note: could return an empty collection, SourcePath is for informational messages only)
-shaders_t parse_source(std::istream& Stream, const std::string& SourcePath);
+shaders_t parse_source(std::istream& Stream, const filesystem::path& SourcePath);
 /// Parses a shader metafile, returning shader data (note: could return an empty collection, SourcePath and MetafilePath are for informational messages only)
-shaders_t parse_metafile(std::istream& Stream, const std::string& SourcePath, const std::string& MetafilePath);
+shaders_t parse_metafile(std::istream& Stream, const filesystem::path& SourcePath, const filesystem::path& MetafilePath);
 /// Generates a shader metafile from a collection of shaders
 void generate_metafile(std::ostream& Stream, const shaders_t Shaders);
 
