@@ -36,77 +36,91 @@
 namespace k3d
 {
 
+/////////////////////////////////////////////////////////////////////////////
+// state_change_set::implementation
+
+class state_change_set::implementation
+{
+public:
+	implementation()
+	{
+	}
+
+	~implementation()
+	{
+		std::for_each(m_old_states.begin(), m_old_states.end(), delete_object());
+		std::for_each(m_new_states.begin(), m_new_states.end(), delete_object());
+	}
+
+	typedef std::vector<istate_container*> state_collection_t;
+	state_collection_t m_old_states;
+	state_collection_t m_new_states;
+
+	sigc::signal<void> m_undo_signal;
+	sigc::signal<void> m_redo_signal;
+};
+	
 /////////////////////////////////////////////////////////////////////////////
 // state_change_set
 
 state_change_set::state_change_set() :
-	m_recording_done(false)
+	m_implementation(new implementation())
 {
-	m_recording_done_signal.connect(sigc::mem_fun(*this, &state_change_set::on_recording_done));
 }
 
 state_change_set::~state_change_set()
 {
-	std::for_each(m_old_states.begin(), m_old_states.end(), delete_object());
-	std::for_each(m_new_states.begin(), m_new_states.end(), delete_object());
-}
-
-void state_change_set::on_recording_done()
-{
-	if(m_recording_done)
-		k3d::log() << warning << "state change set already finalized" << std::endl;
-
-	if(m_old_states.empty())
-		k3d::log() << warning << "state change set missing undo data" << std::endl;
-	
-	m_recording_done = true;
+	delete m_implementation;
 }
 
 void state_change_set::record_old_state(istate_container* const OldState)
 {
-	// Sanity checks ...
 	return_if_fail(OldState);
-	m_old_states.push_back(OldState);
+	m_implementation->m_old_states.push_back(OldState);
 }
 
 void state_change_set::record_new_state(istate_container* const NewState)
 {
-	// Sanity checks ...
 	return_if_fail(NewState);
-	m_new_states.push_back(NewState);
+	m_implementation->m_new_states.push_back(NewState);
 }
 
-state_change_set::recording_done_signal_t& state_change_set::recording_done_signal()
+sigc::connection state_change_set::connect_undo_signal(const sigc::slot<void>& Slot)
 {
-	return m_recording_done_signal;
+	return m_implementation->m_undo_signal.connect(Slot);
 }
 
-state_change_set::undo_signal_t& state_change_set::undo_signal()
+sigc::connection state_change_set::connect_redo_signal(const sigc::slot<void>& Slot)
 {
-	return m_undo_signal;
-}
-
-state_change_set::redo_signal_t& state_change_set::redo_signal()
-{
-	return m_redo_signal;
+	return m_implementation->m_redo_signal.connect(Slot);
 }
 
 void state_change_set::undo()
 {
-	std::for_each(m_old_states.rbegin(), m_old_states.rend(), std::mem_fun(&istate_container::restore_state));
-	m_undo_signal.emit();
+	std::for_each(m_implementation->m_old_states.rbegin(), m_implementation->m_old_states.rend(), std::mem_fun(&istate_container::restore_state));
+	m_implementation->m_undo_signal.emit();
 }
 
 void state_change_set::redo()
 {
-	std::for_each(m_new_states.begin(), m_new_states.end(), std::mem_fun(&istate_container::restore_state));
-	m_redo_signal.emit();
+	std::for_each(m_implementation->m_new_states.begin(), m_implementation->m_new_states.end(), std::mem_fun(&istate_container::restore_state));
+	m_implementation->m_redo_signal.emit();
+}
+
+const size_t state_change_set::undo_count() const
+{
+	return m_implementation->m_old_states.size();
+}
+
+const size_t state_change_set::redo_count() const
+{
+	return m_implementation->m_new_states.size();
 }
 
 /////////////////////////////////////////////////////////////////////////////
 // create_state_change_set
 
-std::auto_ptr<state_change_set> create_state_change_set()
+std::auto_ptr<state_change_set> create_state_change_set(const char* const Context)
 {
 	return std::auto_ptr<state_change_set>(new state_change_set());
 }
@@ -114,18 +128,18 @@ std::auto_ptr<state_change_set> create_state_change_set()
 /////////////////////////////////////////////////////////////////////////////
 // start_state_change_set
 
-void  start_state_change_set(idocument& Document)
+void start_state_change_set(idocument& Document, const char* const Context)
 {
-	Document.state_recorder().start_recording(create_state_change_set());
+	Document.state_recorder().start_recording(create_state_change_set(Context), Context);
 }
 
 /////////////////////////////////////////////////////////////////////////////
 // cancel_state_change_set
 
-void cancel_state_change_set(idocument& Document)
+void cancel_state_change_set(idocument& Document, const char* const Context)
 {
 	// Tell the document to stop recording ...
-	const std::auto_ptr<state_change_set> changeset(Document.state_recorder().stop_recording());
+	const std::auto_ptr<state_change_set> changeset(Document.state_recorder().stop_recording(Context));
 
 	// Undo any changes up to this point, and let the leftover data get destroyed ...
 	return_if_fail(changeset.get());
@@ -135,29 +149,29 @@ void cancel_state_change_set(idocument& Document)
 /////////////////////////////////////////////////////////////////////////////
 // finish_state_change_set
 
-void finish_state_change_set(idocument& Document, const std::string& Label)
+void finish_state_change_set(idocument& Document, const std::string& Label, const char* const Context)
 {
-	Document.state_recorder().commit_change_set(Document.state_recorder().stop_recording(), Label);
+	Document.state_recorder().commit_change_set(Document.state_recorder().stop_recording(Context), Label, Context);
 }
 
 /////////////////////////////////////////////////////////////////////////////
 // record_state_change_set
 
-record_state_change_set::record_state_change_set(idocument& Document, const std::string& Label) :
+record_state_change_set::record_state_change_set(idocument& Document, const std::string& Label, const char* const Context) :
 	m_document(Document),
-	m_label(Label)
+	m_label(Label),
+	m_context(Context)
 {
 	// Sanity checks ...
 	assert_warning(m_label.size());
 
-	start_state_change_set(m_document);
+	start_state_change_set(m_document, m_context);
 }
 
 record_state_change_set::~record_state_change_set()
 {
-	finish_state_change_set(m_document, m_label);
+	finish_state_change_set(m_document, m_label, m_context);
 }
 
 } //namespace k3d
 
-
