@@ -4,10 +4,10 @@
 int main()
 {
 	const k3d::matrix4 a(
-		k3d::vector4(1, 2, 3, 4),
-		k3d::vector4(5, 6, 7, 8),
-		k3d::vector4(9, 10, 11, 12),
-		k3d::vector4(13, 14, 15, 16));
+		k3d::point4(1, 2, 3, 4),
+		k3d::point4(5, 6, 7, 8),
+		k3d::point4(9, 10, 11, 12),
+		k3d::point4(13, 14, 15, 16));
 
 	const k3d::matrix4 b = k3d::transpose(a);
 
