@@ -42,6 +42,7 @@
 #include "imaterial.h"
 #include "imesh_sink.h"
 #include "imesh_source.h"
+#include "imesh_storage.h"
 #include "ipreview_render_engine.h"
 #include "irenderman.h"
 #include "irenderman.h"
@@ -65,6 +66,21 @@
 
 #include <map>
 
+#if defined(__GNUC__) &&  __GNUC__ >= 3
+
+	#define K3D_HAVE_GCC_DEMANGLE
+
+	// http://lists.debian.org/debian-gcc/2003/09/msg00055.html notes
+	// that, in cxxabi.h of gcc-3.x for x < 4, this type is used before it
+	// is declared.
+
+	#if __GNUC__ == 3 && __GNUC_MINOR__ < 4
+		class __class_type_info;
+	#endif
+
+	#include <cxxabi.h>
+#endif
+
 namespace k3d
 {
 
@@ -104,7 +120,7 @@ void register_type(const std::type_info& Info, const std::string& Name)
 		k3d::log() << error << k3d_file_reference << ": attempt to register [" << Name << "] twice" << std::endl;
 		return;
 	}
-	
+
 	type_to_name_map.insert(std::make_pair(type_info(Info), Name));
 	name_to_type_map.insert(std::make_pair(Name, type_info(Info)));
 }
@@ -126,6 +142,7 @@ void initialize_types()
 	register_type(typeid(k3d::bitmap*), "k3d::bitmap*");
 	register_type(typeid(k3d::bounding_box3), "k3d::bounding_box3");
 	register_type(typeid(k3d::color), "k3d::color");
+	register_type(typeid(k3d::filesystem::path), "k3d::filesystem::path");
 	register_type(typeid(k3d::gl::ilight), "k3d::gl::ilight");
 	register_type(typeid(k3d::gl::imaterial), "k3d::gl::imaterial");
 	register_type(typeid(k3d::i3d_2d_mapping), "k3d::i3d_2d_mapping");
@@ -145,6 +162,7 @@ void initialize_types()
 	register_type(typeid(k3d::imaterial), "k3d::imaterial");
 	register_type(typeid(k3d::imesh_sink), "k3d::imesh_sink");
 	register_type(typeid(k3d::imesh_source), "k3d::imesh_source");
+	register_type(typeid(k3d::imesh_storage), "k3d::imesh_storage");
 	register_type(typeid(k3d::inode), "k3d::inode");
 	register_type(typeid(k3d::inode*), "k3d::inode*");
 	register_type(typeid(k3d::ipreview_render_engine), "k3d::ipreview_render_engine");
@@ -186,11 +204,27 @@ void initialize_types()
 	/** \todo Come up with a more explicit type for the tweaks filter */
 	register_type(typeid(std::vector<k3d::point3>), "std::vector<k3d::point3>");
 
-	register_type(typeid(boost::filesystem::path), "boost::filesystem::path");
-
 	initialized = true;
 }
 
+const std::string demangle(const std::string& Type)
+{
+	std::string result = Type;
+
+#ifdef K3D_HAVE_GCC_DEMANGLE
+
+	int status = 0;
+	char* const temp = ::abi::__cxa_demangle(Type.c_str(), 0, 0, &status);
+	if(temp && (status == 0))
+		result = temp;
+	if(temp)
+		::free(temp);
+
+#endif // K3D_HAVE_GCC_DEMANGLE
+
+	return result;
+}
+
 } // namespace detail
 
 void register_type(const std::type_info& Info, const std::string& Name)
@@ -233,5 +267,15 @@ const std::type_info* type_id(const std::string& Name)
 	return 0;
 }
 
+const std::type_info& type_id_k3d_bitmap_ptr()
+{
+    return typeid(k3d::bitmap*);
+}
+
+const std::string demangle(const std::type_info& Type)
+{
+	return detail::demangle(Type.name());
+}
+
 } // namespace k3d
 
