@@ -31,12 +31,11 @@
 #include <k3dsdk/module.h>
 #include <k3dsdk/node.h>
 #include <k3dsdk/options.h>
+#include <k3dsdk/path.h>
 #include <k3dsdk/persistent.h>
 
 using namespace k3d::xml;
 
-#include <boost/filesystem/operations.hpp>
-
 #include <iterator>
 
 namespace libk3dbitmap
@@ -53,31 +52,25 @@ class bitmap_file_in :
 public:
 	bitmap_file_in(k3d::idocument& Document) :
 		base(Document),
-		m_file(init_owner(*this) + init_name("file") + init_label(_("File")) + init_description(_("Browse for an input bitmap")) + init_value(boost::filesystem::path()) + init_path_mode(k3d::ipath_property::READ) + init_path_type(k3d::options::path::bitmaps()))
+		m_file(init_owner(*this) + init_name("file") + init_label(_("File")) + init_description(_("Browse for an input bitmap")) + init_value(k3d::filesystem::path()) + init_path_mode(k3d::ipath_property::READ) + init_path_type(k3d::options::path::bitmaps()))
 	{
-		m_file.changed_signal().connect(sigc::mem_fun(*this, &bitmap_file_in::on_reset_bitmap));
-		m_output.need_data_signal().connect(sigc::mem_fun(*this, &bitmap_file_in::on_create_bitmap));
+		m_file.changed_signal().connect(make_reset_bitmap_slot());
 	}
 
-	void on_reset_bitmap()
+	void on_create_bitmap(k3d::bitmap& Bitmap)
 	{
-		m_output.reset();
-	}
-
-	k3d::bitmap* on_create_bitmap()
-	{
-		std::auto_ptr<k3d::bitmap> bitmap(new k3d::bitmap());
-
-		const boost::filesystem::path file = m_file.value();
-		if(!boost::filesystem::exists(file))
-			return 0;
+		const k3d::filesystem::path file = m_file.value();
+		if(!k3d::filesystem::exists(file))
+			return;
 
 		k3d::auto_ptr<k3d::ibitmap_read_format> filter(k3d::auto_file_filter<k3d::ibitmap_read_format>(file));
-		return_val_if_fail(filter.get(), 0);
+		return_if_fail(filter.get());
 
-		return_val_if_fail(filter->read_file(file, *bitmap), 0);
+		filter->read_file(file, Bitmap);
+	}
 
-		return bitmap.release();
+	void on_update_bitmap(k3d::bitmap& Bitmap)
+	{
 	}
 
 	k3d::iplugin_factory& factory()
@@ -100,7 +93,7 @@ public:
 	}
 
 private:
-	k3d_data(boost::filesystem::path, immutable_name, change_signal, with_undo, local_storage, no_constraint, path_property, path_serialization) m_file;
+	k3d_data(k3d::filesystem::path, immutable_name, change_signal, with_undo, local_storage, no_constraint, path_property, path_serialization) m_file;
 };
 
 /////////////////////////////////////////////////////////////////////////////
@@ -113,4 +106,3 @@ k3d::iplugin_factory& bitmap_file_in_factory()
 
 } // namespace libk3dbitmap
 
-
