@@ -43,14 +43,14 @@ public:
 	{
 	}
 
-	void on_value_change() {}
+	void on_value_change(k3d::iunknown*) {}
 
 	void on_composite(const k3d::pixel& A, const k3d::pixel& B, k3d::pixel& O)
 	{
 		O.red   = std::min(A.red,   B.red);
 		O.green = std::min(A.green, B.green);
 		O.blue  = std::min(A.blue,  B.blue);
-		O.alpha = std::min(A.alpha, B.alpha);		
+		O.alpha = std::min(A.alpha, B.alpha);
 	}
 
 	k3d::iplugin_factory& factory()
