@@ -45,11 +45,10 @@ public:
 		m_value.changed_signal().connect(sigc::mem_fun(*this, &bitmap_image_mix::on_value_change));
 	}
 
-	void on_value_change()
+	void on_value_change(k3d::iunknown* const Hint)
 	{
 		m_value_cache = m_value.value();
-
-		on_reset_bitmap();
+		on_reset_bitmap(Hint);
 	}
 
 	void on_composite(const k3d::pixel& A, const k3d::pixel& B, k3d::pixel& O)
