@@ -43,7 +43,7 @@ public:
 	{
 	}
 
-	void on_value_change() {}
+	void on_value_change(k3d::iunknown*) {}
 
 	void on_composite(const k3d::pixel& A, const k3d::pixel& B, k3d::pixel& O)
 	{
