@@ -43,13 +43,13 @@ public:
 	{
 	}
 
-	void on_value_change() {}
+	void on_value_change(k3d::iunknown*) {}
 
 	void on_composite(const k3d::pixel& A, const k3d::pixel& B, k3d::pixel& O)
 	{
 		double Ainvmat = k3d::pixel::sample_traits::invert(A.alpha);
 		double Binvmat = k3d::pixel::sample_traits::invert(B.alpha);
-		
+
 		O.red   = A.red   * Binvmat + B.red   * Ainvmat;
 		O.green = A.green * Binvmat + B.green * Ainvmat;
 		O.blue  = A.blue  * Binvmat + B.blue  * Ainvmat;
