@@ -18,13 +18,12 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 /** \file
-		\author Anders Dahnielson (anders@dahnielson.com)
+	\author Anders Dahnielson (anders@dahnielson.com)
 */
 
 #include <k3dsdk/i18n.h>
 #include <k3dsdk/auto_ptr.h>
 #include <k3dsdk/bitmap_source.h>
-#include <k3dsdk/frames.h>
 #include <k3dsdk/file_filter.h>
 #include <k3dsdk/ibitmap_read_format.h>
 #include <k3dsdk/itime_sink.h>
@@ -37,8 +36,6 @@
 #include <k3dsdk/time_source.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/path.hpp>
 
 #include <fstream>
 #include <iomanip>
@@ -59,12 +56,11 @@ class bitmap_sequence_in :
 public:
 	bitmap_sequence_in(k3d::idocument& Document) :
 		base(Document),
-		m_file(init_owner(*this) + init_name("file_path") + init_label(_("File path")) + init_description(_("Path for bitmap sequence")) + init_value(boost::filesystem::path()) + init_path_mode(k3d::ipath_property::READ) + init_path_type(k3d::options::path::bitmaps())),
+		m_file(init_owner(*this) + init_name("file_path") + init_label(_("File path")) + init_description(_("Path for bitmap sequence")) + init_value(k3d::filesystem::path()) + init_path_mode(k3d::ipath_property::READ) + init_path_type(k3d::options::path::bitmaps())),
 		m_time(init_owner(*this) + init_name("time") + init_label(_("Input time")) + init_description(_("Bitmap change delay")) + init_value(0.0))
 	{
-		m_file.changed_signal().connect(sigc::mem_fun(*this, &bitmap_sequence_in::on_reset_bitmap));
-		m_time.changed_signal().connect(sigc::mem_fun(*this, &bitmap_sequence_in::on_reset_bitmap));
-		m_output.need_data_signal().connect(sigc::mem_fun(*this, &bitmap_sequence_in::on_create_bitmap));
+		m_file.changed_signal().connect(make_reset_bitmap_slot());
+		m_time.changed_signal().connect(make_reset_bitmap_slot());
 	}
 
 	k3d::iproperty& time_sink_input()
@@ -72,55 +68,50 @@ public:
 		return m_time;
 	}
 
-	void on_reset_bitmap()
+	void on_create_bitmap(k3d::bitmap& Bitmap)
 	{
-		m_output.reset();
-	}
-
-	k3d::bitmap* on_create_bitmap()
-	{
-		const boost::filesystem::path file = m_file.value();
+		const k3d::filesystem::path file = m_file.value();
 
 		// Check that the document has animation capabilities ...
-		k3d::iproperty* const frame_rate_property = k3d::get_frame_rate(document());
-		if(frame_rate_property)
-			{
-				// Solve frame number and filename ...
-				const double frame_rate = boost::any_cast<double>(k3d::get_value(document().dag(), *frame_rate_property));
-				const long view_frame = static_cast<long>(k3d::round(frame_rate * m_time.value()));
+		if(k3d::iproperty* const frame_rate_property = k3d::get_frame_rate(document()))
+		{
+assert_not_implemented();
+/*
+			// Solve frame number and filename ...
+			const double frame_rate = boost::any_cast<double>(k3d::get_value(document().dag(), *frame_rate_property));
+			const long view_frame = static_cast<long>(k3d::round(frame_rate * m_time.value()));
 
-				k3d::frames frames(file);
-				boost::filesystem::path destination;
-				frames.frame(view_frame, destination);
+			k3d::frames frames(file);
+			k3d::filesystem::path destination;
+			frames.frame(view_frame, destination);
 
-				// Read file ...
-				if(!boost::filesystem::exists(destination))
-					return 0;
+			// Read file ...
+			if(!k3d::filesystem::exists(destination))
+				return;
 
-				std::auto_ptr<k3d::bitmap> bitmap(new k3d::bitmap());
-				k3d::auto_ptr<k3d::ibitmap_read_format> filter(k3d::auto_file_filter<k3d::ibitmap_read_format>(destination));
+			k3d::auto_ptr<k3d::ibitmap_read_format> filter(k3d::auto_file_filter<k3d::ibitmap_read_format>(destination));
 
-				return_val_if_fail(filter.get(), 0);
-				return_val_if_fail(filter->read_file(destination, *bitmap), 0);
-
-				return bitmap.release();
-			}
+			return_if_fail(filter.get());
+			filter->read_file(destination, Bitmap);
+*/
+		}
 		else
 		{
 			// Read file ...
-			if (!boost::filesystem::exists(file))
-				return 0;
+			if (!k3d::filesystem::exists(file))
+				return;
 
-			std::auto_ptr<k3d::bitmap> bitmap(new k3d::bitmap());
 			k3d::auto_ptr<k3d::ibitmap_read_format> filter(k3d::auto_file_filter<k3d::ibitmap_read_format>(file));
 
-			return_val_if_fail(filter.get(), 0);
-			return_val_if_fail(filter->read_file(file, *bitmap), 0);
-
-			return bitmap.release();
+			return_if_fail(filter.get());
+			filter->read_file(file, Bitmap);
 		}
 	}
 
+	void on_update_bitmap(k3d::bitmap& Bitmap)
+	{
+	}
+
 	k3d::iplugin_factory& factory()
 	{
 		return get_factory();
@@ -142,7 +133,7 @@ public:
 	}
 
 private:
-	k3d_data(boost::filesystem::path, immutable_name, change_signal, with_undo, local_storage, no_constraint, path_property, path_serialization) m_file;
+	k3d_data(k3d::filesystem::path, immutable_name, change_signal, with_undo, local_storage, no_constraint, path_property, path_serialization) m_file;
 	k3d_data(double, immutable_name, change_signal, with_undo, local_storage, no_constraint, writable_property, with_serialization) m_time;
 };
 
@@ -156,4 +147,3 @@ k3d::iplugin_factory& bitmap_sequence_in_factory()
 
 } // namespace libk3dbitmap
 
-
