@@ -18,15 +18,14 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 /** \file
-		\author Anders Dahnielson (anders@dahnielson.com)
+	\author Anders Dahnielson (anders@dahnielson.com)
 */
 
-#include <k3dsdk/i18n.h>
 #include "bitmap_functions.h"
 
 #include <k3dsdk/bitmap.h>
-#include <k3dsdk/frames.h>
 #include <k3dsdk/file_filter.h>
+#include <k3dsdk/i18n.h>
 #include <k3dsdk/ibitmap_sink.h>
 #include <k3dsdk/ibitmap_write_format.h>
 #include <k3dsdk/irender_farm.h>
@@ -37,10 +36,6 @@
 #include <k3dsdk/property.h>
 #include <k3dsdk/time_source.h>
 
-#include <k3dsdk/fstream.h>
-#include <boost/filesystem/path.hpp>
-
-#include <fstream>
 #include <iomanip>
 #include <iterator>
 
@@ -60,8 +55,8 @@ public:
 	bitmap_sequence_out(k3d::idocument& Document) :
 		base(Document),
 		m_input(init_owner(*this) + init_name("input") + init_label(_("Input Bitmap")) + init_description(_("Input bitmap")) + init_value<k3d::bitmap*>(0)),
-		m_width(init_owner(*this) + init_name("pixel_width") + init_label(_("Output Pixel Width")) + init_description(_("Output pixel width")) + init_value(320) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_height(init_owner(*this) + init_name("pixel_height") + init_label(_("Output Pixel Height")) + init_description(_("Output pixel height")) + init_value(240) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)))
+		m_width(init_owner(*this) + init_name("pixel_width") + init_label(_("Output Pixel Width")) + init_description(_("Output pixel width")) + init_value(320) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_height(init_owner(*this) + init_name("pixel_height") + init_label(_("Output Pixel Height")) + init_description(_("Output pixel height")) + init_value(240) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)))
 	{
 	}
 
@@ -71,6 +66,8 @@ public:
 	}
 
 /*
+assert_not_implemented();
+
 	bool render_preview()
 	{
 		// Start a new render job ...
@@ -80,7 +77,7 @@ public:
 		k3d::irender_frame& frame = job.create_frame("frame");
 
 		// Create an output image path ...
-		const boost::filesystem::path outputimagepath = frame.add_output_file("outputimage.tiff");
+		const k3d::filesystem::path outputimagepath = frame.add_output_file("outputimage.tiff");
 		return_val_if_fail(!outputimagepath.empty(), false);
 
 		// Look up file format ...
@@ -99,7 +96,7 @@ public:
 		return true;
 	}
 
-	bool render_frame(const boost::filesystem::path& OutputImage, const bool ViewImage)
+	bool render_frame(const k3d::filesystem::path& OutputImage, const bool ViewImage)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!OutputImage.empty(), false);
@@ -127,7 +124,7 @@ public:
 		return true;
 	}
 
-	bool render_animation(const boost::filesystem::path& OutputImages, const bool ViewCompletedImages)
+	bool render_animation(const k3d::filesystem::path& OutputImages, const bool ViewCompletedImages)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!OutputImages.empty(), false);
@@ -165,7 +162,7 @@ public:
 			k3d::irender_frame& frame = job.create_frame(buffer.str());
 
 			// Create an output image path ...
-			boost::filesystem::path destination;
+			k3d::filesystem::path destination;
 			frames.frame(view_frame, destination);
 			
 			// Look up file format ...
@@ -211,7 +208,7 @@ private:
 	k3d_data(long, immutable_name, change_signal, with_undo, local_storage, with_constraint, measurement_property, with_serialization) m_width;
 	k3d_data(long, immutable_name, change_signal, with_undo, local_storage, with_constraint, measurement_property, with_serialization) m_height;
 
-	bool render(k3d::ibitmap_write_format* const FileFormat, k3d::irender_frame& Frame, const boost::filesystem::path& OutputImagePath, const bool VisibleRender)
+	bool render(k3d::ibitmap_write_format* const FileFormat, k3d::irender_frame& Frame, const k3d::filesystem::path& OutputImagePath, const bool VisibleRender)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!OutputImagePath.empty(), false);
