@@ -49,7 +49,6 @@ extern k3d::iplugin_factory& bitmap_image_sub_abs_factory();
 extern k3d::iplugin_factory& bitmap_image_sub_factory();
 extern k3d::iplugin_factory& bitmap_image_under_factory();
 extern k3d::iplugin_factory& bitmap_image_xor_factory();
-extern k3d::iplugin_factory& bitmap_instance_factory();
 extern k3d::iplugin_factory& bitmap_invert_factory();
 extern k3d::iplugin_factory& bitmap_matte_colordiff_factory();
 extern k3d::iplugin_factory& bitmap_matte_invert_factory();
@@ -85,7 +84,6 @@ K3D_MODULE_START(libk3dbitmap, k3d::uuid(0x996e0d12, 0xa51c4762, 0x9434e1fd, 0x2
 	Registry.register_factory(libk3dbitmap::bitmap_image_sub_factory());
 	Registry.register_factory(libk3dbitmap::bitmap_image_under_factory());
 	Registry.register_factory(libk3dbitmap::bitmap_image_xor_factory());
-	Registry.register_factory(libk3dbitmap::bitmap_instance_factory());
 	Registry.register_factory(libk3dbitmap::bitmap_invert_factory());
 	Registry.register_factory(libk3dbitmap::bitmap_matte_colordiff_factory());
 	Registry.register_factory(libk3dbitmap::bitmap_matte_invert_factory());
@@ -99,4 +97,3 @@ K3D_MODULE_START(libk3dbitmap, k3d::uuid(0x996e0d12, 0xa51c4762, 0x9434e1fd, 0x2
 	Registry.register_factory(libk3dbitmap::bitmap_threshold_factory());
 K3D_MODULE_END
 
-
