@@ -125,7 +125,7 @@ class edges_to_blobby_implementation :
 public:
 	edges_to_blobby_implementation(k3d::idocument& Document) :
 		base(Document),
-		m_radius(init_owner(*this) + init_name("radius") + init_label(_("Radius")) + init_description(_("Segments radius")) + init_value(1.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::scalar))),
+		m_radius(init_owner(*this) + init_name("radius") + init_label(_("Radius")) + init_description(_("Segments radius")) + init_value(1.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::scalar))),
 		m_type(init_owner(*this) + init_name("type") + init_label(_("Operator type")) + init_description(_("Addition, multiplication, minimum or maximum")) + init_enumeration(operation_values()) + init_value(MAX))
 	{
 		m_radius.changed_signal().connect(make_reset_mesh_slot());
