@@ -41,8 +41,8 @@ public:
 		m_input2(init_owner(*this) + init_name("input2") + init_label(_("Input 2")) + init_description(_("Second input float")) + init_value(1.0)),
 		m_output(init_owner(*this) + init_name("output") + init_label(_("Output")) + init_description(_("Product of inputs")) + init_slot(sigc::mem_fun(*this, &scalar_multiply::get_value)))
 	{
-		m_input1.changed_signal().connect(m_output.changed_signal().make_slot());
-		m_input2.changed_signal().connect(m_output.changed_signal().make_slot());
+		m_input1.changed_signal().connect(m_output.make_reset_slot());
+		m_input2.changed_signal().connect(m_output.make_reset_slot());
 	}
 
 	double get_value()
