@@ -42,7 +42,7 @@ public:
 		m_input(init_owner(*this) + init_name("input") + init_label(_("Input value")) + init_description(_("Input value")) + init_value(0.0)),
 		m_output(init_owner(*this) + init_name("output") + init_label(_("Output value")) + init_description(_("Sine wave function applied on input")) + init_slot(sigc::mem_fun(*this, &scalar_sine::get_value)))
 	{
-		m_input.changed_signal().connect(m_output.changed_signal().make_slot());
+		m_input.changed_signal().connect(m_output.make_reset_slot());
 	}
 
 	double get_value()
