@@ -53,61 +53,24 @@ public:
 		m_center_y(init_owner(*this) + init_name("center_y") + init_label(_("Center Y")) + init_description(_("Center Y components around origin")) + init_value(true)),
 		m_center_z(init_owner(*this) + init_name("center_z") + init_label(_("Center Z")) + init_description(_("Center Z components around origin")) + init_value(true))
 	{
-		m_input_mesh.changed_signal().connect(sigc::mem_fun(*this, &center_points::on_reset_geometry));
-		m_mesh_selection.changed_signal().connect(sigc::mem_fun(*this, &center_points::on_reset_geometry));
+		m_mesh_selection.changed_signal().connect(make_reset_mesh_slot());
 
-		m_center_x.changed_signal().connect(sigc::mem_fun(*this, &center_points::on_reshape_geometry));
-		m_center_y.changed_signal().connect(sigc::mem_fun(*this, &center_points::on_reshape_geometry));
-		m_center_z.changed_signal().connect(sigc::mem_fun(*this, &center_points::on_reshape_geometry));
-
-		m_output_mesh.need_data_signal().connect(sigc::mem_fun(*this, &center_points::on_create_geometry));
+		m_center_x.changed_signal().connect(make_update_mesh_slot());
+		m_center_y.changed_signal().connect(make_update_mesh_slot());
+		m_center_z.changed_signal().connect(make_update_mesh_slot());
 	}
 
-	void on_reset_geometry()
+	void on_create_mesh(const k3d::mesh& InputMesh, k3d::mesh& Mesh)
 	{
-		m_output_mesh.reset();
+		k3d::deep_copy(InputMesh, Mesh);
+		k3d::replace_selection(m_mesh_selection.value(), Mesh);
 	}
 
-	void on_reshape_geometry()
+	void on_update_mesh(const k3d::mesh& InputMesh, k3d::mesh& Mesh)
 	{
-		if(m_output_mesh.empty())
-			return;
+		return_if_fail(InputMesh.points.size() == Mesh.points.size());
 
-		const k3d::mesh* const input = m_input_mesh.value();
-		if(!input)
-			return;
-
-		k3d::mesh* const output = const_cast<k3d::mesh*>(m_output_mesh.internal_value());
-		if(!output)
-			return;
-
-		reshape_geometry(*input, *output);
-
-		m_output_mesh.changed_signal().emit();
-	}
-
-	k3d::mesh* on_create_geometry()
-	{
-		// If we don't have any input mesh, we're done ...
-		const k3d::mesh* const input = m_input_mesh.value();
-		if(!input)
-			return 0;
-
-		// Otherwise, we make a copy of the input mesh and modify the copy ...
-		k3d::mesh* const output = new k3d::mesh();
-		k3d::deep_copy(*input, *output);
-		k3d::replace_selection(m_mesh_selection.value(), *output);
-		reshape_geometry(*input, *output);
-
-		return output;
-	}
-
-	void reshape_geometry(const k3d::mesh& Source, k3d::mesh& Target)
-	{
-		// Sanity checks ...
-		assert(Source.points.size() == Target.points.size());
-
-		const k3d::bounding_box3 bounds = k3d::bounds(Source);
+		const k3d::bounding_box3 bounds = k3d::bounds(InputMesh);
 		if(bounds.empty())
 			return;
 
@@ -115,13 +78,13 @@ public:
 		const bool center_y = m_center_y.value();
 		const bool center_z = m_center_z.value();
 
-		const k3d::vector3 offset(
+		const k3d::point3 offset(
 			center_x ? -0.5 * (bounds.px + bounds.nx) : 0,
 			center_y ? -0.5 * (bounds.py + bounds.ny) : 0,
 			center_z ? -0.5 * (bounds.pz + bounds.nz) : 0);
 
-		for(unsigned long i = 0; i != Target.points.size(); ++i)
-			Target.points[i]->position = k3d::mix(Source.points[i]->position, Source.points[i]->position + offset, Target.points[i]->selection_weight);
+		for(unsigned long i = 0; i != Mesh.points.size(); ++i)
+			Mesh.points[i]->position = k3d::mix(InputMesh.points[i]->position, InputMesh.points[i]->position + offset, Mesh.points[i]->selection_weight);
 	}
 
 	k3d::iplugin_factory& factory()
