@@ -1,5 +1,5 @@
 // K-3D
-// Copyright (c) 1995-2005, Timothy M. Shead
+// Copyright (c) 1995-2006, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -31,7 +31,6 @@ extern k3d::iplugin_factory& bend_points_factory();
 extern k3d::iplugin_factory& bulge_points_factory();
 extern k3d::iplugin_factory& center_points_factory();
 extern k3d::iplugin_factory& cylindrical_wave_points_factory();
-extern k3d::iplugin_factory& deformation_bone_factory();
 extern k3d::iplugin_factory& linear_point_noise_factory();
 extern k3d::iplugin_factory& linear_wave_points_factory();
 extern k3d::iplugin_factory& rotate_points_factory();
@@ -40,6 +39,7 @@ extern k3d::iplugin_factory& shear_points_factory();
 extern k3d::iplugin_factory& smooth_points_factory();
 extern k3d::iplugin_factory& sphereize_points_factory();
 extern k3d::iplugin_factory& taper_points_factory();
+extern k3d::iplugin_factory& transform_points_factory();
 extern k3d::iplugin_factory& translate_points_factory();
 extern k3d::iplugin_factory& tweak_points_factory();
 extern k3d::iplugin_factory& twist_points_factory();
@@ -51,7 +51,6 @@ K3D_MODULE_START(libk3ddeformation, k3d::uuid(0xd848f9e0, 0x6ab349a4, 0xb3554581
 	Registry.register_factory(libk3ddeformation::bulge_points_factory());
 	Registry.register_factory(libk3ddeformation::center_points_factory());
 	Registry.register_factory(libk3ddeformation::cylindrical_wave_points_factory());
-	Registry.register_factory(libk3ddeformation::deformation_bone_factory());
 	Registry.register_factory(libk3ddeformation::linear_point_noise_factory());
 	Registry.register_factory(libk3ddeformation::linear_wave_points_factory());
 	Registry.register_factory(libk3ddeformation::rotate_points_factory());
@@ -60,6 +59,7 @@ K3D_MODULE_START(libk3ddeformation, k3d::uuid(0xd848f9e0, 0x6ab349a4, 0xb3554581
 	Registry.register_factory(libk3ddeformation::smooth_points_factory());
 	Registry.register_factory(libk3ddeformation::sphereize_points_factory());
 	Registry.register_factory(libk3ddeformation::taper_points_factory());
+	Registry.register_factory(libk3ddeformation::transform_points_factory());
 	Registry.register_factory(libk3ddeformation::translate_points_factory());
 	Registry.register_factory(libk3ddeformation::tweak_points_factory());
 	Registry.register_factory(libk3ddeformation::twist_points_factory());
