@@ -49,11 +49,11 @@ class taper_points :
 public:
 	taper_points(k3d::idocument& Document) :
 		base(Document),
-		m_axis(init_owner(*this) + init_name("axis") + init_label(_("Axis")) + init_description(_("Taper along this axis")) + init_value(k3d::Z) + init_enumeration(k3d::axis_values())),
-		m_taper_factor(init_owner(*this) + init_name("taper_fator") + init_label(_("Taper fator")) + init_description(_("Taper factor")) + init_value(0.0) + init_precision(2) + init_step_increment(k3d::radians(1.0)) + init_units(typeid(k3d::measurement::scalar))),
-		m_displace_x(init_owner(*this) + init_name("displace_x") + init_label(_("Displace X")) + init_description(_("Displacement on X axis")) + init_value(true)),
-		m_displace_y(init_owner(*this) + init_name("displace_y") + init_label(_("Displace Y")) + init_description(_("Displacement on Y axis")) + init_value(true)),
-		m_displace_z(init_owner(*this) + init_name("displace_z") + init_label(_("Displace Z")) + init_description(_("Displacement on Z axis")) + init_value(false))
+		m_axis(init_owner(*this) + init_name("axis") + init_label(_("Axis")) + init_description(_("Taper points along this axis.")) + init_value(k3d::Z) + init_enumeration(k3d::axis_values())),
+		m_taper_factor(init_owner(*this) + init_name("taper_factor") + init_label(_("Taper Factor")) + init_description(_("Controls the amount of taper, 0 = no taper, 1 = taper to a point.")) + init_value(0.0) + init_step_increment(k3d::radians(1.0)) + init_units(typeid(k3d::measurement::scalar))),
+		m_displace_x(init_owner(*this) + init_name("displace_x") + init_label(_("Displace X")) + init_description(_("Enable point displacement along the X axis.")) + init_value(true)),
+		m_displace_y(init_owner(*this) + init_name("displace_y") + init_label(_("Displace Y")) + init_description(_("Enable point displacement along the Y axis.")) + init_value(true)),
+		m_displace_z(init_owner(*this) + init_name("displace_z") + init_label(_("Displace Z")) + init_description(_("Enable point displacement along the Z axis.")) + init_value(false))
 	{
 		m_mesh_selection.changed_signal().connect(make_reset_mesh_slot());
 
