@@ -26,7 +26,6 @@
 #include "helpers.h"
 
 #include <k3dsdk/i18n.h>
-#include <k3dsdk/iapplication.h>
 #include <k3dsdk/ideletable.h>
 #include <k3dsdk/idocument.h>
 #include <k3dsdk/ifile_format.h>
@@ -45,7 +44,6 @@
 #include <k3dsdk/vectors.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/path.hpp>
 
 #include <map>
 #include <set>
@@ -185,7 +183,7 @@ void write_gts_mesh(k3d::mesh& Mesh, k3d::inode& Object, std::ostream& Stream)
 	for(PointCollection::iterator point = points.begin(); point != points.end(); ++point)
 		{
 			// Transform coords back to GTS convention
-			const k3d::vector3 coords = (*point)->position;
+			const k3d::point3 coords = (*point)->position;
 			Stream << -coords[0] << " " << -coords[2] << " " << coords[1] << std::endl;
 		}
 
@@ -218,12 +216,12 @@ public:
 		return 128;
 	}
 
-	bool query_can_handle(const boost::filesystem::path& FilePath)
+	bool query_can_handle(const k3d::filesystem::path& FilePath)
 	{
-		return "gts" == k3d::file_extension(FilePath);
+		return k3d::filesystem::extension(FilePath).lowercase().raw() == ".gts";
 	}
 
-	bool write_file(k3d::idocument& Document, const boost::filesystem::path& FilePath);
+	bool write_file(k3d::idocument& Document, const k3d::filesystem::path& FilePath);
 
 	k3d::iplugin_factory& factory()
 	{
@@ -242,9 +240,9 @@ public:
 	}
 };
 
-bool gts_writer_implementation::write_file(k3d::idocument& Document, const boost::filesystem::path& FilePath)
+bool gts_writer_implementation::write_file(k3d::idocument& Document, const k3d::filesystem::path& FilePath)
 {
-	k3d::log() << info << "Writing " << FilePath.native_file_string() << " with " << factory().name() << std::endl;
+	k3d::log() << info << "Writing " << FilePath.native_console_string() << " with " << factory().name() << std::endl;
 
 	// (GTS format is not a real one : it has been designed to store surfaces
 	// as sets of points, edges and triangles, only;
@@ -274,4 +272,3 @@ k3d::iplugin_factory& gts_writer_factory()
 
 } // namespace libk3dgeometry
 
-
