@@ -1,7 +1,7 @@
 // K-3D
-// Copyright (c) 1995-2005, Timothy M. Shead
+// Copyright (c) 2004-2006, Romain Behar
 //
-// Contact: tshead@k-3d.com
+// Contact: romainbehar@yahoo.com
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public
@@ -80,58 +80,66 @@ k3d::mesh* create_mesh(k3d::idocument& Document, const std::string Name, k3d::in
 
 void get_mesh_instances(k3d::idocument& Document, mesh_instances_t& MeshInstances)
 {
-	k3d::nodes_t mesh_instances(k3d::find_nodes(Document.nodes(), k3d::classes::MeshInstance()));
+	const k3d::inode_collection::nodes_t& nodes = Document.nodes().collection();
+	for(k3d::inode_collection::nodes_t::const_iterator node = nodes.begin(); node != nodes.end(); ++node)
+	{
+		if(!dynamic_cast<k3d::gl::idrawable*>(*node))
+			continue;
 
-	for(k3d::nodes_t::iterator object = mesh_instances.begin(); object != mesh_instances.end(); ++object)
+		k3d::imesh_source* const mesh_source = dynamic_cast<k3d::imesh_source*>(*node);
+		if(!mesh_source)
+			continue;
+
+		// Check for transformed output mesh
+		k3d::mesh* mesh = 0;
+		if(k3d::iproperty* property = k3d::get_property(**node, "transformed_output_mesh"))
 		{
-			k3d::imesh_source* const mesh_source = dynamic_cast<k3d::imesh_source*>(*object);
-			if(!mesh_source)
-				{
-					assert_not_reached();
-					continue;
-				}
-
-			k3d::mesh* const mesh = boost::any_cast<k3d::mesh*>(k3d::get_value(Document.dag(), mesh_source->mesh_source_output()));
-			if(!mesh)
-				{
-					assert_not_reached();
-					continue;
-				}
-
-			MeshInstances.insert(std::make_pair(mesh, *object));
+			mesh = boost::any_cast<k3d::mesh*>(property->property_value());
 		}
+		else
+		{
+			// Fall back to mesh source
+			k3d::iproperty& property = mesh_source->mesh_source_output();
+			mesh = boost::any_cast<k3d::mesh*>(property.property_value());
+		}
+
+		if(!mesh)
+			continue;
+
+		MeshInstances.insert(std::make_pair(mesh, *node));
+	}
 }
 
 bool triangle_test(const k3d::mesh& Mesh)
 {
 	k3d::mesh::polyhedra_t::const_iterator polyhedron;
 	for(polyhedron = Mesh.polyhedra.begin(); polyhedron != Mesh.polyhedra.end(); polyhedron++)
+	{
+		k3d::polyhedron::faces_t::const_iterator face;
+		for(face = (*polyhedron)->faces.begin(); face != (*polyhedron)->faces.end(); face++)
 		{
-			k3d::polyhedron::faces_t::const_iterator face;
-			for(face = (*polyhedron)->faces.begin(); face != (*polyhedron)->faces.end(); face++)
-				{
-					k3d::split_edge* first = (*face)->first_edge;
-					// Skip empty faces
-					if(!first)
-						continue;
+			k3d::split_edge* first = (*face)->first_edge;
+			// Skip empty faces
+			if(!first)
+				continue;
 
-					k3d::split_edge* current_edge = first->face_clockwise;
-					// Skip one-edged faces
-					if(!current_edge)
-						continue;
+			k3d::split_edge* current_edge = first->face_clockwise;
+			// Skip one-edged faces
+			if(!current_edge)
+				continue;
 
-					unsigned long edge_number = 1;
+			unsigned long edge_number = 1;
 
-					while(current_edge != first)
-						{
-							edge_number++;
-							current_edge = current_edge->face_clockwise;
-						}
+			while(current_edge != first)
+			{
+				edge_number++;
+				current_edge = current_edge->face_clockwise;
+			}
 
-					if(edge_number != 3)
-						return false;
-				}
+			if(edge_number != 3)
+				return false;
 		}
+	}
 
 	return true;
 }
@@ -140,4 +148,3 @@ bool triangle_test(const k3d::mesh& Mesh)
 
 } // namespace libk3dgeometry
 
-
