@@ -47,14 +47,13 @@
 #include <k3dsdk/vectors.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/path.hpp>
 
 #include <iostream>
 
 namespace
 {
 
-k3dIPoint* CreatePoint(k3dIMesh* const Mesh, const k3d::vector3 Coords)
+k3dIPoint* CreatePoint(k3dIMesh* const Mesh, const k3d::point3 Coords)
 {
 	// Sanity checks ...
 	assert_warning(Mesh);
@@ -92,13 +91,13 @@ public:
 		return 128;
 	}
 
-	bool query_can_handle(const boost::filesystem::path& FilePath)
+	bool query_can_handle(const k3d::filesystem::path& FilePath)
 	{
 		const std::string ext = k3d::file_extension(FilePath);
 		return "lwo" == ext || "lw" == ext;
 	}
 
-	bool read_file(k3d::idocument& Document, const boost::filesystem::path& FilePath);
+	bool read_file(k3d::idocument& Document, const k3d::filesystem::path& FilePath);
 
 	k3d::iplugin_factory& factory()
 	{
@@ -123,7 +122,7 @@ private:
 	std::string GetString();
 	unsigned long GetVariableLengthIndex();
 	k3d::color GetColor();
-	k3d::vector3 GetVector();
+	k3d::point3 GetVector();
 
 	const std::string GetChunkId();
 	bool GetChunkInfo();
@@ -164,9 +163,9 @@ private:
 	std::vector<k3dIPoint*> m_CurrentPointList;
 };
 
-bool lwo2_reader_implementation::read_file(k3d::idocument& Document, const boost::filesystem::path& FilePath)
+bool lwo2_reader_implementation::read_file(k3d::idocument& Document, const k3d::filesystem::path& FilePath)
 {
-	k3d::log() << info << "Reading " << FilePath.native_file_string() << " with " << factory().name() << std::endl;
+	k3d::log() << info << "Reading " << FilePath.native_string() << " with " << factory().name() << std::endl;
 	
 	// Allocate a buffer and load file
 	k3d::filesystem::ifstream file(FilePath, std::ios::in | std::ios::binary);
@@ -413,13 +412,13 @@ k3d::color lwo2_reader_implementation::GetColor()
 	return k3d::color(red, green, blue);
 }
 
-k3d::vector3 lwo2_reader_implementation::GetVector()
+k3d::point3 lwo2_reader_implementation::GetVector()
 {
 	double x = GetFloat();
 	double y = GetFloat();
 	double z = GetFloat();
 
-	return k3d::vector3(x, y, z);
+	return k3d::point3(x, y, z);
 }
 
 bool lwo2_reader_implementation::ReadPNTS()
@@ -431,7 +430,7 @@ bool lwo2_reader_implementation::ReadPNTS()
 
 	for(unsigned long i = 0; i < numv; i++)
 	{
-		k3d::vector3 coords;
+		k3d::point3 coords;
 		coords[0] = GetFloat();
 		coords[1] = GetFloat();
 		coords[2] = GetFloat();
@@ -640,7 +639,7 @@ bool lwo2_reader_implementation::ReadLayer()
 {
 	unsigned short number = GetShort();
 	unsigned short flags = GetShort();
-	k3d::vector3 pivot = GetVector();
+	k3d::point3 pivot = GetVector();
 	std::string name = GetString();
 
 	k3d::log() << debug << "Layer : " << name << std::endl;
