@@ -40,8 +40,6 @@
 #include <k3dsdk/string_cast.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/path.hpp>
 
 namespace libk3dgeometry
 {
@@ -52,7 +50,7 @@ namespace detail
 // Declarations
 typedef std::map<std::string, k3d::imaterial*> obj_materials_t;
 const std::string default_material_name = "default";
-bool load_mtl(k3d::idocument& Document, const boost::filesystem::path Path, obj_materials_t& Materials);
+bool load_mtl(k3d::idocument& Document, const k3d::filesystem::path& Path, obj_materials_t& Materials);
 
 typedef std::vector<k3d::point4> positions_t;
 bool load_bspline(k3d::idocument& Document, const bool rational, k3d::filesystem::ifstream& file, unsigned long& LineCount, k3d::mesh& Mesh, k3d::imaterial* Material, positions_t& Positions, const unsigned long CurrentSize);
@@ -77,17 +75,17 @@ unsigned long lookup(const long Index, const unsigned long PointsSize, const uns
 	return CurrentSize - offset;
 }
 
-bool load_obj_file(k3d::mesh& Mesh, k3d::idocument& Document, const boost::filesystem::path& Path, const std::string& TextureU, const std::string& TextureV, const std::string& TextureW)
+bool load_obj_file(k3d::mesh& Mesh, k3d::idocument& Document, const k3d::filesystem::path& Path, const std::string& TextureU, const std::string& TextureV, const std::string& TextureW)
 {
 	if(Path.empty())
 		return false;
 
-	k3d::log() << info << "Loading .obj file: " << Path.native_file_string() << std::endl;
+	k3d::log() << info << "Loading .obj file: " << Path.native_console_string() << std::endl;
 
 	k3d::filesystem::ifstream file(Path);
 	if(!file)
 	{
-		k3d::log() << error << k3d_file_reference << ": error opening [" << Path.native_file_string() << "]" << std::endl;
+		k3d::log() << error << k3d_file_reference << ": error opening [" << Path.native_console_string() << "]" << std::endl;
 		return false;
 	}
 
@@ -153,8 +151,8 @@ bool load_obj_file(k3d::mesh& Mesh, k3d::idocument& Document, const boost::files
 				// Append parent .obj path (.mtl file name may contain a path too)
 				try
 				{
-					boost::filesystem::path mtl_path(mtl_name, boost::filesystem::native);
-					load_mtl(Document, Path.branch_path() / mtl_path.leaf(), materials);
+					k3d::filesystem::path mtl_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(mtl_name));
+					load_mtl(Document, Path.branch_path() / k3d::filesystem::native_path(mtl_path.leaf()), materials);
 				}
 				catch(std::exception& e)
 				{
@@ -356,7 +354,7 @@ bool load_obj_file(k3d::mesh& Mesh, k3d::idocument& Document, const boost::files
 		else
 		{
 			// Not gonna handle this baby ...
-			k3d::log() << warning << Path.native_file_string() << " line " << line_count << ": unsupported keyword will be ignored: " << line_buffer << std::endl;
+			k3d::log() << warning << Path.native_console_string() << " line " << line_count << ": unsupported keyword will be ignored: " << line_buffer << std::endl;
 		}
 	}
 
@@ -366,18 +364,18 @@ bool load_obj_file(k3d::mesh& Mesh, k3d::idocument& Document, const boost::files
 	return true;
 }
 
-bool load_mtl(k3d::idocument& Document, const boost::filesystem::path Path, obj_materials_t& Materials)
+bool load_mtl(k3d::idocument& Document, const k3d::filesystem::path& Path, obj_materials_t& Materials)
 {
 	// Open mtl file ...
 	k3d::filesystem::ifstream file(Path);
 	if(!file)
 	{
-		k3d::log() << error << k3d_file_reference << ": error opening material [" << Path.native_file_string() << "]" << std::endl;
+		k3d::log() << error << k3d_file_reference << ": error opening material [" << Path.native_console_string() << "]" << std::endl;
 		return false;
 	}
 
 	// For tests
-	k3d::log() << debug << "Loading MTL file : " << Path.native_file_string() << std::endl;
+	k3d::log() << info << "Loading MTL file : " << Path.native_console_string() << std::endl;
 
 	// Current processed material
 	std::string material_name;
@@ -408,7 +406,7 @@ bool load_mtl(k3d::idocument& Document, const boost::filesystem::path Path, obj_
 			if(!material_name.size())
 			{
 				material_name = default_material_name;
-				k3d::log() << debug << "empty material name in file " << Path.native_file_string() << " - using default material" << std::endl;
+				k3d::log() << debug << "empty material name in file " << Path.native_console_string() << " - using default material" << std::endl;
 			}
 
 			if(Materials.find(material_name) == Materials.end())
@@ -419,7 +417,7 @@ bool load_mtl(k3d::idocument& Document, const boost::filesystem::path Path, obj_
 				current_shader = k3d::create_plugin<k3d::inode>(k3d::classes::RenderManSurfaceShader(), Document, material_name + " shader");
 				return_val_if_fail(current_shader, false);
 
-				assert_warning(k3d::set_value(*current_shader, "shader_path", k3d::share_path() / "shaders/k3d_plastic.sl"));
+				assert_warning(k3d::set_value(*current_shader, "shader_path", k3d::share_path() / k3d::filesystem::generic_path("shaders/k3d_plastic.sl")));
 				assert_warning(k3d::set_value(*current_material, "surface_shader", current_shader));
 
 				k3d::imaterial* mtl_material = dynamic_cast<k3d::imaterial*>(current_material);
@@ -448,7 +446,8 @@ bool load_mtl(k3d::idocument& Document, const boost::filesystem::path Path, obj_
 			k3d::color color;
 			line_stream >> color;
 
-			assert_warning(k3d::set_value(*current_shader, "specularcolor", color));
+			if(current_shader)
+				assert_warning(k3d::set_value(*current_shader, "specularcolor", color));
 		}
 		else if(keyword == "Ns")
 		{
@@ -588,4 +587,3 @@ bool load_bspline(k3d::idocument& Document, const bool rational, k3d::filesystem
 
 } // namespace libk3dgeometry
 
-
