@@ -23,7 +23,6 @@
 */
 
 #include <k3dsdk/file_helpers.h>
-#include <k3dsdk/iapplication.h>
 #include <k3dsdk/ideletable.h>
 #include <k3dsdk/idocument.h>
 #include <k3dsdk/ifile_format.h>
@@ -41,7 +40,6 @@
 #include "helpers.h"
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/path.hpp>
 
 namespace libk3dgeometry
 {
@@ -83,12 +81,12 @@ public:
 		return 128;
 	}
 
-	bool query_can_handle(const boost::filesystem::path& FilePath)
+	bool query_can_handle(const k3d::filesystem::path& FilePath)
 	{
-		return "off" == k3d::file_extension(FilePath);
+		return k3d::filesystem::extension(FilePath).lowercase().raw() == ".off";
 	}
 
-	bool read_file(k3d::idocument& Document, const boost::filesystem::path& FilePath);
+	bool read_file(k3d::idocument& Document, const k3d::filesystem::path& FilePath);
 
 	k3d::iplugin_factory& factory()
 	{
@@ -107,15 +105,15 @@ public:
 	}
 };
 
-bool off_reader_implementation::read_file(k3d::idocument& Document, const boost::filesystem::path& FilePath)
+bool off_reader_implementation::read_file(k3d::idocument& Document, const k3d::filesystem::path& FilePath)
 {
-	k3d::log() << info << "Reading " << FilePath.native_file_string() << " with " << factory().name() << std::endl;
+	k3d::log() << info << "Reading " << FilePath.native_console_string() << " with " << factory().name() << std::endl;
 
 	// Try to open the input file ...
 	k3d::filesystem::ifstream file(FilePath);
 	if(!file.good())
 		{
-			k3d::log() << error << k3d_file_reference << "error opening [" << FilePath.native_file_string() << "]" << std::endl;
+			k3d::log() << error << k3d_file_reference << "error opening [" << FilePath.native_console_string() << "]" << std::endl;
 			return_val_if_fail(0, false);
 		}
 
@@ -170,14 +168,14 @@ bool off_reader_implementation::read_file(k3d::idocument& Document, const boost:
 					// Get next data line
 					if(!off_line(file, linebuffer))
 						{
-							k3d::log() << "ERROR: Unexpected end of input file (file \"" << FilePath.native_file_string() << "\", point #" << n << "." << std::endl;
+							k3d::log() << "ERROR: Unexpected end of input file (file \"" << FilePath.native_console_string() << "\", point #" << n << "." << std::endl;
 							return false;
 						}
 
 					// Extract a record type ...
 					std::istringstream stream(linebuffer);
 
-					k3d::vector3 coords;
+					k3d::point3 coords;
 					stream >> coords;
 
 					k3d::point* const point = new k3d::point(coords);
@@ -193,7 +191,7 @@ bool off_reader_implementation::read_file(k3d::idocument& Document, const boost:
 					// Get next data line
 					if(!off_line(file, linebuffer))
 						{
-							k3d::log() << warning << "ERROR: Unexpected end of input file (file \"" << FilePath.native_file_string() << "\", triangle #" << n << "." << std::endl;
+							k3d::log() << warning << "ERROR: Unexpected end of input file (file \"" << FilePath.native_console_string() << "\", triangle #" << n << "." << std::endl;
 							return false;
 						}
 
@@ -260,4 +258,3 @@ k3d::iplugin_factory& off_reader_factory()
 
 } // namespace libk3dgeometry
 
-
