@@ -1,5 +1,5 @@
 // K-3D
-// Copyright (c) 2004-2005, Timothy M. Shead
+// Copyright (c) 2004-2006, Romain Behar
 //
 // Contact: romainbehar@yahoo.com
 //
@@ -22,33 +22,23 @@
 		\author Romain Behar (romainbehar@yahoo.com)
 */
 
-#include <k3dsdk/i18n.h>
 #include <k3dsdk/algebra.h>
 #include <k3dsdk/classes.h>
-#include <k3dsdk/color.h>
 #include <k3dsdk/create_plugins.h>
 #include <k3dsdk/file_helpers.h>
-#include <k3dsdk/idag.h>
 #include <k3dsdk/ideletable.h>
-#include <k3dsdk/idocument.h>
 #include <k3dsdk/idocument_plugin_factory.h>
-#include <k3dsdk/ifile_format.h>
 #include <k3dsdk/idocument_read_format.h>
+#include <k3dsdk/ifile_format.h>
 #include <k3dsdk/imaterial.h>
-#include <k3dsdk/inode.h>
-#include <k3dsdk/inode_collection.h>
 #include <k3dsdk/irenderman.h>
 #include <k3dsdk/itransform_sink.h>
 #include <k3dsdk/itransform_source.h>
 #include <k3dsdk/material.h>
-#include <k3dsdk/mesh.h>
 #include <k3dsdk/module.h>
 #include <k3dsdk/property.h>
-#include <k3dsdk/result.h>
-#include <k3dsdk/string_cast.h>
 #include <k3dsdk/string_modifiers.h>
-#include <k3dsdk/utility.h>
-#include <k3dsdk/vectors.h>
+#include <k3dsdk/transform.h>
 
 #include "helpers.h"
 
@@ -56,7 +46,6 @@
 #include <Hapy/Rules.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/path.hpp>
 
 #include <iostream>
 #include <map>
@@ -308,34 +297,34 @@ const std::string no_quotes(const std::string& s)
 	return s;
 }
 
-k3d::vector3 mult_scales(const k3d::vector3& v1, const k3d::vector3& v2)
-{
-	return k3d::vector3(v1[0] * v2[0], v1[1] * v2[1], v1[2] * v2[2]);
-}
-
-typedef std::vector<k3d::vector3> coordinates_t;
+typedef std::vector<k3d::point3> coordinates_t;
 
 /////////////////////////////////////////////////////////////////////////////
-// rib_reader_implementation
+// rib_reader
 
-class rib_reader_implementation :
+class rib_reader :
 	public k3d::ifile_format,
 	public k3d::idocument_read_format,
 	public k3d::ideletable
 {
 public:
-	rib_reader_implementation()
+	rib_reader()
 	{
-		m_inside_world = false;
-
+		// Variable initializations
 		m_current_mesh = 0;
+		m_current_mesh_object = 0;
+		m_current_mesh_instance = 0;
+
 		m_current_polyhedron = 0;
 		m_current_linear_curve_group = 0;
+		m_current_bilinear_patch = 0;
+		m_current_nupatch = 0;
+
+		m_current_material = 0;
+		m_current_shader = 0;
 
 		m_is_solid = false;
 
-		m_transform_number = 0;
-
 		// Init parser ...
 		create_parser();
 		file.trim(*Hapy::space_r);
@@ -347,12 +336,12 @@ public:
 		return 128;
 	}
 
-	bool query_can_handle(const boost::filesystem::path& FilePath)
+	bool query_can_handle(const k3d::filesystem::path& FilePath)
 	{
-		return "rib" == k3d::file_extension(FilePath);
+		return k3d::filesystem::extension(FilePath).lowercase().raw() == ".rib";
 	}
 
-	bool read_file(k3d::idocument& Document, const boost::filesystem::path& FilePath);
+	bool read_file(k3d::idocument& Document, const k3d::filesystem::path& FilePath);
 
 	k3d::iplugin_factory& factory()
 	{
@@ -361,7 +350,7 @@ public:
 
 	static k3d::iplugin_factory& get_factory()
 	{
-		static k3d::plugin_factory<k3d::application_plugin<rib_reader_implementation>, k3d::interface_list<k3d::idocument_read_format> > factory(
+		static k3d::plugin_factory<k3d::application_plugin<rib_reader>, k3d::interface_list<k3d::idocument_read_format> > factory(
 			k3d::uuid(0x9a392c01, 0x50234b23, 0xa61245ff, 0x9345ce15),
 			"RIBReader",
 			_("RenderMan ( .rib )"),
@@ -382,34 +371,25 @@ private:
 	k3d::color m_current_opacity;
 	k3d::ri::integer m_current_matte;
 
-	// Frame parameters
-	bool m_inside_world;
-	k3d::matrix4 frame_transformation;
-	k3d::vector3 frame_translation;
-	k3d::matrix4 frame_rotation;
-	k3d::vector3 frame_scaling;
-
-	// Transformation stacks
-	unsigned long m_transform_number;
+	// Transformation stack
 	std::stack<std::string> begin_end_stack;
-	std::vector<k3d::matrix4> m_transformations;
-	std::vector<k3d::vector3> m_translations;
-	std::vector<k3d::matrix4> m_rotations;
-	std::vector<k3d::vector3> m_scalings;
+	std::vector<k3d::matrix4> m_transformation_stack;
 
 	bool m_is_solid;
 	std::string m_solid_type;
 
-	// Mesh variables and functions
-	std::stack<k3d::inode*> m_transform_objects;
-	k3d::mesh* m_current_mesh;
 	std::string m_current_name;
+
+	// Mesh variables and functions
+	k3d::mesh* m_current_mesh;
 	k3d::inode* m_current_mesh_object;
 	k3d::inode* m_current_mesh_instance;
+
+	k3d::polyhedron* m_current_polyhedron;
 	k3d::nupatch* m_current_nupatch;
 	k3d::bilinear_patch* m_current_bilinear_patch;
-	k3d::polyhedron* m_current_polyhedron;
 	k3d::linear_curve_group* m_current_linear_curve_group;
+
 	k3d::inode* m_current_material;
 	k3d::inode* m_current_shader;
 
@@ -490,13 +470,13 @@ private:
 		std::vector<k3d::split_edge*> edges;
 		coordinates_t::const_iterator point = points.begin();
 		for(; point != points.end(); point++)
-			{
-				k3d::point* new_point = new k3d::point(*point);
-				return_val_if_fail(new_point, false);
+		{
+			k3d::point* new_point = new k3d::point(*point);
+			return_val_if_fail(new_point, false);
 
-				mesh->points.push_back(new_point);
-				edges.push_back(new k3d::split_edge(new_point));
-			}
+			mesh->points.push_back(new_point);
+			edges.push_back(new k3d::split_edge(new_point));
+		}
 
 		k3d::loop_edges(edges.begin(), edges.end());
 
@@ -513,45 +493,14 @@ private:
 		return true;
 	}
 
-	bool create_transform(k3d::idocument& Document)
-	{
-		k3d::inode* const transform = k3d::create_plugin<k3d::inode>(k3d::classes::Transform(), Document);
-		return_val_if_fail(transform, false);
-
-		transform->set_name("Transform " + k3d::string_cast(++m_transform_number));
-		connect_transforms(transform, Document);
-		m_transform_objects.push(transform);
-
-		return true;
-	}
-
-	bool connect_transforms(k3d::inode* Object, k3d::idocument& Document)
-	{
-		if(m_transform_objects.empty())
-			return false;
-
-		k3d::inode* const last_transform = m_transform_objects.top();
-		k3d::itransform_source* const transform_source = dynamic_cast<k3d::itransform_source*>(last_transform);
-		return_val_if_fail(transform_source, false);
-
-		k3d::itransform_sink* const transform_sink = dynamic_cast<k3d::itransform_sink*>(Object);
-		return_val_if_fail(transform_sink, false);
-
-		k3d::idag::dependencies_t dependencies;
-		dependencies.insert(std::make_pair(&transform_sink->transform_sink_input(), &transform_source->transform_source_output()));
-		Document.dag().set_dependencies(dependencies);
-
-		return true;
-	}
-
 	k3d::imaterial* assign_current_material(k3d::idocument& Document)
 	{
 		if(m_current_material)
-			{
-				k3d::imaterial* current = dynamic_cast<k3d::imaterial*>(m_current_material);
-				if(current)
-					return current;
-			}
+		{
+			k3d::imaterial* current = dynamic_cast<k3d::imaterial*>(m_current_material);
+			if(current)
+				return current;
+		}
 
 		k3d::imaterial* default_material = dynamic_cast<k3d::imaterial*>(k3d::default_material(Document));
 		return default_material;
@@ -600,17 +549,17 @@ private:
 				continue;
 
 			for(Hapy::Pree::const_iterator i = (*node).begin(); i != (*node).end(); i++)
-				{
-					double value = k3d::from_string<double>(i->image(), 0);
-					if(n == 0)
-						x = value;
-					else if(n == 1)
-						y = value;
-					else
-						Points.push_back(k3d::vector3(x, y, value));
+			{
+				double value = k3d::from_string<double>(i->image(), 0);
+				if(n == 0)
+					x = value;
+				else if(n == 1)
+					y = value;
+				else
+					Points.push_back(k3d::point3(x, y, value));
 
-					n = (n + 1) % 3;
-				}
+				n = (n + 1) % 3;
+			}
 		}
 
 		assert_warning(n == 0);
@@ -622,57 +571,36 @@ private:
 		get_rtfloat_array(FloatArray, v);
 
 		Matrix = k3d::matrix4(
-			k3d::vector4(v[0], v[1], v[2], v[3]),
-			k3d::vector4(v[4], v[5], v[6], v[7]),
-			k3d::vector4(v[8], v[9], v[10], v[11]),
-			k3d::vector4(v[12], v[13], v[14], v[15]));
+			k3d::point4(v[0], v[1], v[2], v[3]),
+			k3d::point4(v[4], v[5], v[6], v[7]),
+			k3d::point4(v[8], v[9], v[10], v[11]),
+			k3d::point4(v[12], v[13], v[14], v[15]));
 
 		Matrix = k3d::transpose(Matrix);
 	}
 
-	void set_current_transformations(k3d::inode* Object)
-	{
-		assert_warning(k3d::set_value(*Object, "position", k3d::vector3(*m_translations.rbegin() + extract_translation(*m_transformations.rbegin()))));
-		assert_warning(k3d::set_value(*Object, "orientation", k3d::angle_axis(k3d::rotation3D(*m_rotations.rbegin() * *m_transformations.rbegin()))));
-		assert_warning(k3d::set_value(*Object, "scale", k3d::vector3(mult_scales(*m_scalings.rbegin(), k3d::deprecated_extract_scaling(*m_transformations.rbegin())))));
-	}
-
 	void rib_stack_push(const std::string& name, k3d::idocument& Document)
 	{
 		// Save object type and stack a generic object ...
 		begin_end_stack.push(name);
 
-		if(name == "Frame")
-			{
-				frame_translation = k3d::vector3(0, 0, 0);
-				frame_rotation = k3d::identity3D();
-				frame_scaling = k3d::vector3(1, 1, 1);
-				m_inside_world = false;
-			}
-		else if(name == "World")
-			{
-				m_inside_world = true;
+		if("World" == name)
+		{
+			// World starts, the world-to-camera transformation is set to the current transformation
+			// and the current transformation is reinitialized to Identity
+			m_transformation_stack.push_back(k3d::identity3D());
+		}
+		else if("Frame" == name || "Transform" == name || "Attribute" == name)
+		{
+			// Save (push) current transformation
+			if(m_transformation_stack.empty())
+				m_transformation_stack.push_back(k3d::identity3D());
+			else
+				m_transformation_stack.push_back(m_transformation_stack.back());
 
-				m_transformations.push_back(k3d::identity3D());
-				m_translations.push_back(k3d::vector3(0, 0, 0));
-				m_rotations.push_back(k3d::identity3D());
-				m_scalings.push_back(k3d::vector3(1, 1, 1));
-			}
-
-		if(m_inside_world)
-			{
-				// Save current transformation ...
-				if(m_transform_objects.size())
-					set_current_transformations(m_transform_objects.top());
-
-				// Push new transformation ...
-				create_transform(Document);
-
-				m_transformations.push_back(k3d::identity3D());
-				m_translations.push_back(k3d::vector3(0, 0, 0));
-				m_rotations.push_back(k3d::identity3D());
-				m_scalings.push_back(k3d::vector3(1, 1, 1));
-			}
+			// AttributeBegin should save attributes
+			// FrameBegin should save rendering options
+		}
 	}
 
 	void rib_stack_pop(const std::string& name)
@@ -680,41 +608,36 @@ private:
 		assert_warning(begin_end_stack.top() == name);
 		begin_end_stack.pop();
 
-		if(m_inside_world)
-			{
-				m_transformations.pop_back();
-				m_translations.pop_back();
-				m_rotations.pop_back();
-				m_scalings.pop_back();
-
-				m_transform_objects.pop();
-			}
-
-		if(name == "World")
-			m_inside_world = false;
+		m_transformation_stack.pop_back();
 	}
 
-	void set_object_properties(k3d::inode* Object, const std::string& Name, k3d::idocument& Document)
+	void set_object_properties(k3d::inode* Node, const std::string& Name, k3d::idocument& Document)
 	{
-		assert_warning(Object);
+		return_if_fail(Node);
 
-		// Set name, parent transformer and current transformations
-		Object->set_name(m_current_name + "  " + Name);
-		connect_transforms(Object, Document);
-		set_current_transformations(Object);
+		// Set name
+		Node->set_name(m_current_name + "  " + Name);
+
+		// Set transformation
+		if(!m_transformation_stack.empty())
+		{
+			k3d::matrix4 transformation = m_transformation_stack.back();
+			if(transformation != k3d::identity3D())
+				k3d::set_matrix(*Node, transformation);
+		}
 	}
 
 	k3d::matrix4 get_blobby_matrix(std::vector<double>::iterator First)
 	{
 		k3d::matrix4 m;
 
-		m[0] = k3d::vector4(First[0], First[1], First[2], First[3]);
+		m[0] = k3d::point4(First[0], First[1], First[2], First[3]);
 		First += 4;
-		m[1] = k3d::vector4(First[0], First[1], First[2], First[3]);
+		m[1] = k3d::point4(First[0], First[1], First[2], First[3]);
 		First += 4;
-		m[2] = k3d::vector4(First[0], First[1], First[2], First[3]);
+		m[2] = k3d::point4(First[0], First[1], First[2], First[3]);
 		First += 4;
-		m[3] = k3d::vector4(First[0], First[1], First[2], First[3]);
+		m[3] = k3d::point4(First[0], First[1], First[2], First[3]);
 
 		return k3d::transpose(m);
 	}
@@ -727,7 +650,7 @@ private:
 	}
 };
 
-void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocument& Document)
+void rib_reader::parse_subpree(const Hapy::Pree& Node, k3d::idocument& Document)
 {
 	if(Node.begin() == Node.end())
 		return;
@@ -1055,16 +978,16 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 				const Hapy::Pree& string = *value.begin();
 				std::string parameter_name = no_quotes(string.image());
 				if(parameter_name == "P")
-					{
-						return_if_fail(create_mesh(Document));
+				{
+					return_if_fail(create_mesh(Document));
 
-						const Hapy::Pree& float_array = *(value.begin() + 1);
-						coordinates_t points;
-						get_rtfloat_array(float_array, points);
+					const Hapy::Pree& float_array = *(value.begin() + 1);
+					coordinates_t points;
+					get_rtfloat_array(float_array, points);
 
-						create_polygon(points, m_current_mesh, Document);
-						set_object_properties(m_current_mesh_instance, "Polygon", Document);
-					}
+					create_polygon(points, m_current_mesh, Document);
+					set_object_properties(m_current_mesh_instance, "Polygon", Document);
+				}
 				//else
 					// Find "P"
 			}
@@ -1129,32 +1052,32 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 						k3d::face* face = 0;
 
 						for(unsigned long vs = 0; vs < n_vertices; vs++)
+						{
+							k3d::point* const point = geometric_points[*current_vertex_id++];
+							return_if_fail(point);
+
+							k3d::split_edge* edge = new k3d::split_edge(point);
+							return_if_fail(edge);
+
+							if(!face)
 							{
-								k3d::point* const point = geometric_points[*current_vertex_id++];
-								return_if_fail(point);
-
-								k3d::split_edge* edge = new k3d::split_edge(point);
-								return_if_fail(edge);
-
-								if(!face)
-									{
-										face = new k3d::face(edge, assign_current_material(Document));
-										return_if_fail(face);
-										m_current_polyhedron->faces.push_back(face);
-									}
-								else
-									{
-										previous_edge->face_clockwise = edge;
-									}
-
-								previous_edge = edge;
+								face = new k3d::face(edge, assign_current_material(Document));
+								return_if_fail(face);
+								m_current_polyhedron->faces.push_back(face);
 							}
+							else
+							{
+								previous_edge->face_clockwise = edge;
+							}
+
+							previous_edge = edge;
+						}
 
 						// Close loop
 						if(face)
-							{
-								previous_edge->face_clockwise = face->first_edge;
-							}
+						{
+							previous_edge->face_clockwise = face->first_edge;
+						}
 					}
 				}
 
@@ -1164,7 +1087,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 			else if("Cone" == (*pir).image())
 			{
 				k3d::inode* const cone = k3d::create_plugin<k3d::inode>(k3d::classes::Cone(), Document);
-				assert_warning(cone);
+				return_if_fail(cone);
 
 				k3d::set_value(*cone, "height", k3d::from_string<double>((++pir)->image(), 0));
 				k3d::set_value(*cone, "radius", k3d::from_string<double>((++pir)->image(), 0));
@@ -1176,7 +1099,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 			else if("Cylinder" == (*pir).image())
 			{
 				k3d::inode* const cylinder = k3d::create_plugin<k3d::inode>(k3d::classes::Cylinder(), Document);
-				assert_warning(cylinder);
+				return_if_fail(cylinder);
 
 				k3d::set_value(*cylinder, "radius", k3d::from_string<double>((++pir)->image(), 0));
 				k3d::set_value(*cylinder, "zmin", k3d::from_string<double>((++pir)->image(), 0));
@@ -1189,7 +1112,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 			else if("Disk" == (*pir).image())
 			{
 				k3d::inode* const disk = k3d::create_plugin<k3d::inode>(k3d::classes::Disk(), Document);
-				assert_warning(disk);
+				return_if_fail(disk);
 
 				k3d::set_value(*disk, "height", k3d::from_string<double>((++pir)->image(), 0));
 				k3d::set_value(*disk, "radius", k3d::from_string<double>((++pir)->image(), 0));
@@ -1201,7 +1124,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 			else if("Hyperboloid" == (*pir).image())
 			{
 				k3d::inode* const hyperboloid = k3d::create_plugin<k3d::inode>(k3d::classes::Hyperboloid(), Document);
-				assert_warning(hyperboloid);
+				return_if_fail(hyperboloid);
 
 				k3d::set_value(*hyperboloid, "p1x", k3d::from_string<double>((++pir)->image(), 0));
 				k3d::set_value(*hyperboloid, "p1y", k3d::from_string<double>((++pir)->image(), 0));
@@ -1217,7 +1140,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 			else if("Paraboloid" == (*pir).image())
 			{
 				k3d::inode* const paraboloid = k3d::create_plugin<k3d::inode>(k3d::classes::Paraboloid(), Document);
-				assert_warning(paraboloid);
+				return_if_fail(paraboloid);
 
 				k3d::set_value(*paraboloid, "radius", k3d::from_string<double>((++pir)->image(), 0));
 				k3d::set_value(*paraboloid, "zmin", k3d::from_string<double>((++pir)->image(), 0));
@@ -1230,7 +1153,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 			else if("Sphere" == (*pir).image())
 			{
 				k3d::inode* const sphere = k3d::create_plugin<k3d::inode>(k3d::classes::Sphere(), Document);
-				assert_warning(sphere);
+				return_if_fail(sphere);
 
 				k3d::set_value(*sphere, "radius", k3d::from_string<double>((++pir)->image(), 0));
 				k3d::set_value(*sphere, "zmin", k3d::from_string<double>((++pir)->image(), 0));
@@ -1243,7 +1166,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 			else if("Torus" == (*pir).image())
 			{
 				k3d::inode* const torus = k3d::create_plugin<k3d::inode>(k3d::classes::Torus(), Document);
-				assert_warning(torus);
+				return_if_fail(torus);
 
 				k3d::set_value(*torus, "majorradius", k3d::from_string<double>((++pir)->image(), 0));
 				k3d::set_value(*torus, "minorradius", k3d::from_string<double>((++pir)->image(), 0));
@@ -1415,13 +1338,12 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 	else
 	if(Node[0].rid() == transformation.id())
 	{
+		return_if_fail(!m_transformation_stack.empty());
+
 		Hapy::Pree::const_iterator transf_item = (Node[0]).begin();
 		if(transf_item->image() == "Identity")
 		{
-			if(!m_inside_world)
-				frame_transformation = k3d::identity3D();
-			else
-				*m_transformations.rbegin() = k3d::identity3D();
+			*m_transformation_stack.rbegin() = k3d::identity3D();
 		}
 		else if(transf_item->image() == "TransformPoints")
 		{
@@ -1438,10 +1360,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 				k3d::matrix4 m;
 				get_rtfloat_matrix(matrix, m);
 
-				if(!m_inside_world)
-					frame_transformation = k3d::identity3D();
-				else
-					*m_transformations.rbegin() = *m_transformations.rbegin() * m;
+				*m_transformation_stack.rbegin() = m_transformation_stack.back() * m;
 			}
 			else if("Transform" == (*transf_item).image())
 			{
@@ -1451,10 +1370,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 				k3d::matrix4 m;
 				get_rtfloat_matrix(matrix, m);
 
-				if(!m_inside_world)
-					frame_transformation = k3d::identity3D();
-				else
-					*m_transformations.rbegin() = m;
+				*m_transformation_stack.rbegin() = m;
 			}
 			else if("Translate" == (*transf_item).image())
 			{
@@ -1462,10 +1378,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 				double t2 = k3d::from_string<double>((++transf_item)->image(), 0);
 				double t3 = k3d::from_string<double>((++transf_item)->image(), 0);
 
-				if(!m_inside_world)
-					frame_translation += k3d::vector3(t1, t2, t3);
-				else
-					*m_translations.rbegin() += k3d::vector3(t1, t2, t3);
+				*m_transformation_stack.rbegin() = m_transformation_stack.back() * k3d::translation3D(k3d::point3(t1, t2, t3));
 			}
 			else if("Rotate" == (*transf_item).image())
 			{
@@ -1475,10 +1388,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 				double axis3 = k3d::from_string<double>((++transf_item)->image(), 0);
 				k3d::matrix4 r_matrix = k3d::rotation3D(k3d::radians(angle), k3d::vector3(axis1, axis2, axis3));
 
-				if(!m_inside_world)
-					frame_rotation = frame_rotation * r_matrix;
-				else
-					*m_rotations.rbegin() = *m_rotations.rbegin() * r_matrix;
+				*m_transformation_stack.rbegin() = m_transformation_stack.back() * r_matrix;
 			}
 			else if("Scale" == (*transf_item).image())
 			{
@@ -1486,10 +1396,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 				double s2 = k3d::from_string<double>((++transf_item)->image(), 0);
 				double s3 = k3d::from_string<double>((++transf_item)->image(), 0);
 
-				if(!m_inside_world)
-					frame_scaling = mult_scales(frame_scaling, k3d::vector3(s1, s2, s3));
-				else
-					*m_scalings.rbegin() = mult_scales(*m_scalings.rbegin(), k3d::vector3(s1, s2, s3));
+				*m_transformation_stack.rbegin() = m_transformation_stack.back() * k3d::scaling3D(k3d::point3(s1, s2, s3));
 			}
 		}
 	}
@@ -1537,7 +1444,7 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 					if(m_declarations[variable] == "point")
 					{
 						const Hapy::Pree& float_vals = *(value.begin() + 1);
-						k3d::set_value(*m_current_shader, variable, k3d::from_string<k3d::vector3>(float_vals.image(), k3d::vector3(0.0, 0.0, 0.0)));
+						k3d::set_value(*m_current_shader, variable, k3d::from_string<k3d::point3>(float_vals.image(), k3d::point3(0.0, 0.0, 0.0)));
 					}
 					else
 						k3d::log() << debug << "Variable type not declared for " << variable << " : " << m_declarations[variable] << std::endl;
@@ -1596,25 +1503,25 @@ void rib_reader_implementation::parse_subpree(const Hapy::Pree& Node, k3d::idocu
 	return;
 }
 
-bool rib_reader_implementation::read_file(k3d::idocument& Document, const boost::filesystem::path& FilePath)
+bool rib_reader::read_file(k3d::idocument& Document, const k3d::filesystem::path& FilePath)
 {
-	k3d::log() << info << "Reading " << FilePath.native_file_string() << " with " << factory().name() << std::endl;
+	k3d::log() << info << "Reading " << FilePath.native_console_string() << " with " << factory().name() << std::endl;
 
 	// Try to open the input file ...
 	k3d::filesystem::ifstream rib_file(FilePath);
 	if(!rib_file.good())
-		{
-			k3d::log() << error << k3d_file_reference << ": error opening [" << FilePath.native_file_string() << "]" << std::endl;
-			return false;
-		}
+	{
+		k3d::log() << error << k3d_file_reference << ": error opening [" << FilePath.native_console_string() << "]" << std::endl;
+		return false;
+	}
 
 	std::string buffer("");
 	while(!rib_file.eof())
-		{
-			std::string linebuffer;
-			k3d::getline(rib_file, linebuffer);
-			buffer += linebuffer + "\n";
-		}
+	{
+		std::string linebuffer;
+		k3d::getline(rib_file, linebuffer);
+		buffer += linebuffer + "\n";
+	}
 
 	if(!parser.parse(buffer))
 	{
@@ -1637,9 +1544,8 @@ bool rib_reader_implementation::read_file(k3d::idocument& Document, const boost:
 
 k3d::iplugin_factory& rib_reader_factory()
 {
-	return rib_reader_implementation::get_factory();
+	return rib_reader::get_factory();
 }
 
 } // namespace libk3dgeometry
 
-
