@@ -21,19 +21,17 @@
 		\author Tim Shead <tshead@k-3d.com>
 */
 
+#include <k3dsdk/fstream.h>
 #include <k3dsdk/i18n.h>
-#include <k3dsdk/ipreview_depict_engine.h>
+#include <k3dsdk/ipreview_render_engine.h>
 #include <k3dsdk/irender_farm.h>
-#include <k3dsdk/istill_depict_engine.h>
+#include <k3dsdk/istill_render_engine.h>
 #include <k3dsdk/module.h>
 #include <k3dsdk/node.h>
 #include <k3dsdk/options.h>
 #include <k3dsdk/persistent.h>
+#include <k3dsdk/render_farm.h>
 
-#include <k3dsdk/fstream.h>
-#include <boost/filesystem/path.hpp>
-
-#include <fstream>
 #include <iomanip>
 #include <iterator>
 
@@ -45,8 +43,8 @@ namespace libk3dgraphviz
 
 class render_engine :
 	public k3d::persistent<k3d::node>,
-	public k3d::ipreview_depict_engine,
-	public k3d::istill_depict_engine
+	public k3d::ipreview_render_engine,
+	public k3d::istill_render_engine
 {
 	typedef k3d::persistent<k3d::node> base;
 
@@ -57,16 +55,16 @@ public:
 	{
 	}
 
-	bool depict_preview()
+	bool render_preview()
 	{
 		// Start a new render job ...
-		k3d::irender_job& job = k3d::application().render_farm().create_job("k3d-preview");
+		k3d::irender_job& job = k3d::render_farm().create_job("k3d-preview");
 
 		// Add a single render frame to the job ...
 		k3d::irender_frame& frame = job.create_frame("frame");
 
 		// Create an output image path ...
-		const boost::filesystem::path outputimagepath = frame.add_output_file("world.ps");
+		const k3d::filesystem::path outputimagepath = frame.add_output_file("world.ps");
 		return_val_if_fail(!outputimagepath.empty(), false);
 
 		// View the output image when it's done ...
@@ -76,24 +74,24 @@ public:
 		return_val_if_fail(render(frame, outputimagepath), false);
 
 		// Start the job running ...
-		k3d::application().render_farm().start_job(job);
+		k3d::render_farm().start_job(job);
 
 		return true;
 	}
 
-	bool depict_frame(const boost::filesystem::path& OutputImage, const bool ViewImage)
+	bool render_frame(const k3d::filesystem::path& OutputImage, const bool ViewImage)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!OutputImage.empty(), false);
 
 		// Start a new render job ...
-		k3d::irender_job& job = k3d::application().render_farm().create_job("k3d-render-frame");
+		k3d::irender_job& job = k3d::render_farm().create_job("k3d-render-frame");
 
 		// Add a single render frame to the job ...
 		k3d::irender_frame& frame = job.create_frame("frame");
 
 		// Create an output image path ...
-		const boost::filesystem::path outputimagepath = frame.add_output_file("world.ps");
+		const k3d::filesystem::path outputimagepath = frame.add_output_file("world.ps");
 		return_val_if_fail(!outputimagepath.empty(), false);
 
 		// Copy the output image to its requested destination ...
@@ -107,7 +105,7 @@ public:
 		return_val_if_fail(render(frame, outputimagepath), false);
 
 		// Start the job running ...
-		k3d::application().render_farm().start_job(job);
+		k3d::render_farm().start_job(job);
 
 		return true;
 	}
@@ -120,8 +118,8 @@ public:
 	static k3d::iplugin_factory& get_factory()
 	{
 		static k3d::plugin_factory<k3d::document_plugin<render_engine>,
-			k3d::interface_list<k3d::istill_depict_engine,
-			k3d::interface_list<k3d::ipreview_depict_engine> > > factory(
+			k3d::interface_list<k3d::istill_render_engine,
+			k3d::interface_list<k3d::ipreview_render_engine> > > factory(
 				k3d::uuid(0xbe72cb50, 0x011f41d8, 0x90449ae0, 0x4c24ace5),
 				"GraphVizEngine",
 				_("GraphViz Render Engine"),
@@ -151,13 +149,13 @@ private:
 		return result;
 	}
 
-	bool render(k3d::irender_frame& Frame, const boost::filesystem::path& OutputImagePath)
+	bool render(k3d::irender_frame& Frame, const k3d::filesystem::path& OutputImagePath)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!OutputImagePath.empty(), false);
 
 		// Start our GraphViz DOT file ...
-		const boost::filesystem::path filepath = Frame.add_input_file("world.dot");
+		const k3d::filesystem::path filepath = Frame.add_input_file("world.dot");
 		return_val_if_fail(!filepath.empty(), false);
 
 		// Open the DOT file stream ...
@@ -167,7 +165,7 @@ private:
 		// Setup the frame for GraphViz rendering ...
 		Frame.add_render_operation("graphviz", m_render_engine.value(), filepath, false);
 
-		stream << "digraph \"" << boost::any_cast<std::string>(document().title().property_value()) << "\"\n";
+		stream << "digraph \"" << boost::any_cast<k3d::ustring>(document().title().property_value()).raw() << "\"\n";
 		stream << "{\n\n";
 
 		stream << "rankdir=TD\n\n";
@@ -180,42 +178,42 @@ private:
 		// Create nodes for every document object ...
 		const k3d::nodes_t objects = document().nodes().collection();
 		for(k3d::nodes_t::const_iterator object = objects.begin(); object != objects.end(); ++object)
+		{
+			stream << to_integer(*object) << " [label=\"" << escaped_string((*object)->name()) << "\"]\n";
+
+			k3d::iproperty_collection* const property_collection = dynamic_cast<k3d::iproperty_collection*>(*object);
+			if(property_collection)
 			{
-				stream << to_integer(*object) << " [label=\"" << escaped_string((*object)->name()) << "\"]\n";
+				const k3d::iproperty_collection::properties_t properties = property_collection->properties();
+				for(k3d::iproperty_collection::properties_t::const_iterator property = properties.begin(); property != properties.end(); ++property)
+				{
+					object_map.insert(std::make_pair(*property, *object));
 
-				k3d::iproperty_collection* const property_collection = dynamic_cast<k3d::iproperty_collection*>(*object);
-				if(property_collection)
+					// Show references between objects ...
+					if(typeid(k3d::inode*) == (*property)->property_type())
 					{
-						const k3d::iproperty_collection::properties_t properties = property_collection->properties();
-						for(k3d::iproperty_collection::properties_t::const_iterator property = properties.begin(); property != properties.end(); ++property)
-							{
-								object_map.insert(std::make_pair(*property, *object));
-
-								// Show references between objects ...
-								if(typeid(k3d::inode*) == (*property)->property_type())
-									{
-										k3d::inode* const referenced_object = boost::any_cast<k3d::inode*>((*property)->property_value());
-										if(referenced_object)
-											{
-												stream << to_integer(*object) << " -> " << to_integer(referenced_object);
-												stream << " [style=dotted,label=\"" << escaped_string((*property)->property_name()) << "\"]\n";
-											}
-									}
-							}
+						k3d::inode* const referenced_object = boost::any_cast<k3d::inode*>((*property)->property_value());
+						if(referenced_object)
+						{
+							stream << to_integer(referenced_object) << " -> " << to_integer(*object);
+							stream << " [style=dotted,label=\"" << escaped_string((*property)->property_name()) << "\"]\n";
+						}
 					}
+				}
 			}
+		}
 
 		// Show property dependencies ...
 		stream << "\n";
 		const k3d::idag::dependencies_t dependencies = document().dag().dependencies();
 		for(k3d::idag::dependencies_t::const_iterator dependency = dependencies.begin(); dependency != dependencies.end(); ++dependency)
+		{
+			if(dependency->first && dependency->second)
 			{
-				if(dependency->first && dependency->second)
-					{
-						stream << to_integer(object_map[dependency->second]) << " -> " << to_integer(object_map[dependency->first]);
-						stream << " [headlabel=\"" << escaped_string(dependency->first->property_name()) << "\" taillabel=\"" << escaped_string(dependency->second->property_name()) << "\"]\n";
-					}
+				stream << to_integer(object_map[dependency->second]) << " -> " << to_integer(object_map[dependency->first]);
+				stream << " [headlabel=\"" << escaped_string(dependency->first->property_name()) << "\" taillabel=\"" << escaped_string(dependency->second->property_name()) << "\"]\n";
 			}
+		}
 
 		stream << "\n}\n";
 
@@ -228,23 +226,21 @@ private:
 	{
 		static k3d::ilist_property<std::string>::values_t values;
 		if(values.empty())
+		{
+			const k3d::options::render_engines_t engines = k3d::options::render_engines();
+			for(k3d::options::render_engines_t::const_iterator engine = engines.begin(); engine != engines.end(); ++engine)
 			{
-				const k3d::options::render_engines_t engines = k3d::options::render_engines();
-				for(k3d::options::render_engines_t::const_iterator engine = engines.begin(); engine != engines.end(); ++engine)
-					{
-						if(engine->type == "graphviz")
-							values.push_back(engine->name);
-					}
+				if(engine->type == "graphviz")
+					values.push_back(engine->name);
 			}
+		}
 		return values;
 	}
 };
 
 } // namespace libk3dgraphviz
 
-
 K3D_MODULE_START(libk3dgraphviz, k3d::uuid(0x11643e3b, 0xf8ca4564, 0xba9a7358, 0x096291c1), Registry)
 	Registry.register_factory(libk3dgraphviz::render_engine::get_factory());
 K3D_MODULE_END
 
-
