@@ -38,8 +38,6 @@
 #include <k3dsdk/string_modifiers.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/path.hpp>
-#include <boost/filesystem/operations.hpp>
 
 #include <cmath>
 #include <fstream>
@@ -422,13 +420,13 @@ bool ls_line(std::istream& file, std::string& linebuffer)
 	return false;
 }
 
-bool load_configuration_values(const boost::filesystem::path& file_path, double& recursion, double& basic_angle, double& thickness)
+bool load_configuration_values(const k3d::filesystem::path& file_path, double& recursion, double& basic_angle, double& thickness)
 {
 	// Open configuration file
 	k3d::filesystem::ifstream file(file_path);
 	if(!file.good())
 	{
-		k3d::log() << error << k3d_file_reference << ": error opening [" << file_path.native_file_string() << "]" << std::endl;
+		k3d::log() << error << k3d_file_reference << ": error opening [" << file_path.native_console_string() << "]" << std::endl;
 		return 0.0;
 	}
 
@@ -452,13 +450,13 @@ bool load_configuration_values(const boost::filesystem::path& file_path, double&
 }
 
 // Process a ls file and setup rules
-bool load_configuration_rules(const double recursion, const double basic_angle, const double thickness, const boost::filesystem::path& file_path)
+bool load_configuration_rules(const double recursion, const double basic_angle, const double thickness, const k3d::filesystem::path& file_path)
 {
 	// Open grammar file
 	k3d::filesystem::ifstream file(file_path);
 	if(!file.good())
 	{
-		k3d::log() << error << k3d_file_reference << ": error opening [" << file_path.native_file_string() << "]" << std::endl;
+		k3d::log() << error << k3d_file_reference << ": error opening [" << file_path.native_console_string() << "]" << std::endl;
 		return false;
 	}
 
@@ -1506,16 +1504,16 @@ class l_parser :
 public:
 	l_parser(k3d::idocument& Document) :
 		base(Document),
-		m_file_path(init_owner(*this) + init_name("file") + init_label(_("File")) + init_description(_("File path for lsystem description")) + init_value(boost::filesystem::path(k3d::share_path() / "lsystem/abop-nested-polygon-leaves.ls")) + init_path_mode(k3d::ipath_property::READ) + init_path_type("lsystems")),
-		m_recursion(init_owner(*this) + init_name("growth") + init_label(_("Growth")) + init_description(_("Growth value")) + init_value(5.0) + init_precision(2) + init_step_increment(0.1) + init_constraint(constraint::minimum(1.0)) + init_units(typeid(k3d::measurement::scalar))),
-		m_basic_angle(init_owner(*this) + init_name("basic_angle") + init_label(_("Basic angle")) + init_description(_("Basic angle")) + init_value(10.0) + init_precision(2) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
-		m_thickness(init_owner(*this) + init_name("thickness") + init_label(_("Thickness")) + init_description(_("Thickness")) + init_value(50.0) + init_precision(2) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
-		m_random_seed(init_owner(*this) + init_name("random_seed") + init_label(_("Random seed")) + init_description(_("Random seed")) + init_value(0) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_size(init_owner(*this) + init_name("size") + init_label(_("Size")) + init_description(_("Size")) + init_value(5.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::scalar))),
+		m_file_path(init_owner(*this) + init_name("file") + init_label(_("File")) + init_description(_("File path for lsystem description")) + init_value(k3d::filesystem::path(k3d::share_path() / k3d::filesystem::generic_path("lsystem/abop-nested-polygon-leaves.ls"))) + init_path_mode(k3d::ipath_property::READ) + init_path_type("lsystems")),
+		m_recursion(init_owner(*this) + init_name("growth") + init_label(_("Growth")) + init_description(_("Growth value")) + init_value(5.0) + init_step_increment(0.1) + init_constraint(constraint::minimum(1.0)) + init_units(typeid(k3d::measurement::scalar))),
+		m_basic_angle(init_owner(*this) + init_name("basic_angle") + init_label(_("Basic angle")) + init_description(_("Basic angle")) + init_value(10.0) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
+		m_thickness(init_owner(*this) + init_name("thickness") + init_label(_("Thickness")) + init_description(_("Thickness")) + init_value(50.0) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
+		m_random_seed(init_owner(*this) + init_name("random_seed") + init_label(_("Random seed")) + init_description(_("Random seed")) + init_value(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_size(init_owner(*this) + init_name("size") + init_label(_("Size")) + init_description(_("Size")) + init_value(5.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::scalar))),
 		m_closed_form(init_owner(*this) + init_name("closed_form") + init_label(_("Closed form")) + init_description(_("Closed form")) + init_value(true)),
-		m_mutations(init_owner(*this) + init_name("mutations") + init_label(_("Mutations")) + init_description(_("Mutations")) + init_value(0) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_mutation_seed(init_owner(*this) + init_name("mutation_seed") + init_label(_("Mutation seed")) + init_description(_("Mutation seed")) + init_value(0) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_max_stack_size(init_owner(*this) + init_name("max_stack_size") + init_label(_("Max stack size")) + init_description(_("Max stack size")) + init_value(1000) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_mutations(init_owner(*this) + init_name("mutations") + init_label(_("Mutations")) + init_description(_("Mutations")) + init_value(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_mutation_seed(init_owner(*this) + init_name("mutation_seed") + init_label(_("Mutation seed")) + init_description(_("Mutation seed")) + init_value(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_max_stack_size(init_owner(*this) + init_name("max_stack_size") + init_label(_("Max stack size")) + init_description(_("Max stack size")) + init_value(1000) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
 		m_orientation(init_owner(*this) + init_name("orientation") + init_label(_("Orientation")) + init_description(_("Orientation type (forward or backward along X, Y or Z axis)")) + init_value(k3d::PZ) + init_enumeration(k3d::signed_axis_values())),
 		m_flip_normals(init_owner(*this) + init_name("flip_normals") + init_label(_("Flip normals")) + init_description(_("Flip normals in case the faces are reversed")) + init_value(false))
 	{
@@ -1541,7 +1539,7 @@ public:
 	void init_lsystem()
 	{
 		// Load configuration file
-		const boost::filesystem::path file_path = m_file_path.value();
+		const k3d::filesystem::path file_path = m_file_path.value();
 		double recursion, basic_angle, thickness;
 		if(!lparser::load_configuration_values(file_path, recursion, basic_angle, thickness))
 			return;
@@ -1576,7 +1574,7 @@ public:
 		k3d::imaterial* const material = m_material.value();
 
 		// Load configuration file
-		const boost::filesystem::path file_path = m_file_path.value();
+		const k3d::filesystem::path file_path = m_file_path.value();
 		if(!lparser::load_configuration_rules(recursion, basic_angle, thickness, file_path))
 			return;
 
@@ -1627,7 +1625,7 @@ public:
 	}
 
 private:
-	k3d_data(boost::filesystem::path, immutable_name, change_signal, with_undo, local_storage, no_constraint, path_property, path_serialization) m_file_path;
+	k3d_data(k3d::filesystem::path, immutable_name, change_signal, with_undo, local_storage, no_constraint, path_property, path_serialization) m_file_path;
 	k3d_data(double, immutable_name, change_signal, with_undo, local_storage, with_constraint, measurement_property, with_serialization) m_recursion;
 	k3d_data(double, immutable_name, change_signal, with_undo, local_storage, no_constraint, measurement_property, with_serialization) m_basic_angle;
 	k3d_data(double, immutable_name, change_signal, with_undo, local_storage, no_constraint, measurement_property, with_serialization) m_thickness;
