@@ -47,9 +47,9 @@ public:
 	array_3d_implementation(k3d::idocument& Document) :
 		base(Document),
 		m_layout(init_owner(*this) + init_name("layout") + init_label(_("Layout")) + init_description(_("Layout")) + init_value<k3d::itransform_array_3d*>(0)),
-		m_count1(init_owner(*this) + init_name("count1") + init_label(_("Count 1")) + init_description(_("Number of mesh copies")) + init_value(5) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
-		m_count2(init_owner(*this) + init_name("count2") + init_label(_("Count 2")) + init_description(_("Number of mesh copies")) + init_value(5) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
-		m_count3(init_owner(*this) + init_name("count3") + init_label(_("Count 3")) + init_description(_("Number of mesh copies")) + init_value(5) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L)))
+		m_count1(init_owner(*this) + init_name("count1") + init_label(_("Count 1")) + init_description(_("Number of mesh copies")) + init_value(5) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
+		m_count2(init_owner(*this) + init_name("count2") + init_label(_("Count 2")) + init_description(_("Number of mesh copies")) + init_value(5) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
+		m_count3(init_owner(*this) + init_name("count3") + init_label(_("Count 3")) + init_description(_("Number of mesh copies")) + init_value(5) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L)))
 	{
 		m_layout.changed_signal().connect(make_reset_mesh_slot());
 		m_count1.changed_signal().connect(make_reset_mesh_slot());
@@ -110,7 +110,7 @@ public:
 				k3d::uuid(0x29bb292a, 0x421647be, 0x99236f5c, 0x3407fe41),
 				"MeshArray3D",
 				_("Makes copies of a mesh along three dimensions"),
-				"Mesh Instancing",
+				"Mesh Array",
 				k3d::iplugin_factory::STABLE);
 
 		return factory;
