@@ -52,7 +52,7 @@ public:
 	catmull_clark_subdivider(k3d::idocument& Document) :
 		base(Document),
 		m_material(dynamic_cast<k3d::imaterial*>(k3d::default_material(Document))),
-		m_level(init_owner(*this) + init_name("level") + init_label(_("Level")) + init_description(_("Subdivision level")) + init_constraint(constraint::minimum(1L)) + init_value(1) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)))
+		m_level(init_owner(*this) + init_name("level") + init_label(_("Level")) + init_description(_("Subdivision level")) + init_constraint(constraint::minimum(1L)) + init_value(1) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)))
 	{
 		m_mesh_selection.changed_signal().connect(make_reset_mesh_slot());
 		m_level.changed_signal().connect(make_reset_mesh_slot());
