@@ -436,7 +436,7 @@ public:
 					k3d::uuid(0xa5252071, 0xa3484315, 0x9c9daf1c, 0x786042a3),
 					"CollapseEdges",
 					"For each selected edge, collapses its two vertices into one",
-					"Objects",
+					"Mesh",
 					k3d::iplugin_factory::STABLE);
 
 		return factory;
@@ -484,7 +484,7 @@ private:
 		return Stream;
 	}
 
-	const k3d::ienumeration_property::enumeration_values_t& operator_values()
+	static const k3d::ienumeration_property::enumeration_values_t& operator_values()
 	{
 		static k3d::ienumeration_property::enumeration_values_t values;
 		if(values.empty())
@@ -721,7 +721,7 @@ public:
 				k3d::uuid(0x13f8a224, 0x5e284ac4, 0xb5b58ebd, 0x10f65bb6),
 				"CollapseFaces",
 				"For each selected face, collapses its vertices to the centroid",
-				"Objects",
+				"Mesh",
 				k3d::iplugin_factory::STABLE);
 
 		return factory;
