@@ -791,9 +791,9 @@ class extrude_faces :
 public:
 	extrude_faces(k3d::idocument& Document) :
 		base(Document),
-		m_distance(init_owner(*this) + init_name("distance") + init_label(_("Distance")) + init_description(_("Distance between original and new faces")) + init_value(1.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
-		m_segments(init_owner(*this) + init_name("segments") + init_label(_("Segments")) + init_description(_("Segment number between original and new faces")) + init_value(1) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_inset(init_owner(*this) + init_name("inset") + init_label(_("Inset")) + init_description(_("Inset value for the new faces")) + init_value(0.0) + init_precision(2) + init_step_increment(0.02) + init_units(typeid(k3d::measurement::distance))),
+		m_distance(init_owner(*this) + init_name("distance") + init_label(_("Distance")) + init_description(_("Distance between original and new faces")) + init_value(1.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
+		m_segments(init_owner(*this) + init_name("segments") + init_label(_("Segments")) + init_description(_("Segment number between original and new faces")) + init_value(1) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_inset(init_owner(*this) + init_name("inset") + init_label(_("Inset")) + init_description(_("Inset value for the new faces")) + init_value(0.0) + init_step_increment(0.02) + init_units(typeid(k3d::measurement::distance))),
 		m_direction(init_owner(*this) + init_name("direction") + init_label(_("Direction")) + init_description(_("Extrusion direction : inside / outside")) + init_value(INSIDE) + init_enumeration(direction_values())),
 		m_region(init_owner(*this) + init_name("region") + init_label(_("Region")) + init_description(_("Extrude neighbour faces as a single one (named a region)")) + init_value(true)),
 		m_group_normals(init_owner(*this) + init_name("group_normals") + init_label(_("Group normals")) + init_description(_("For region extrusion use the average normal; else each face is extrude along its own normal")) + init_value(false)),
@@ -935,7 +935,7 @@ private:
 		return Stream;
 	}
 
-	const k3d::ienumeration_property::enumeration_values_t& direction_values()
+	static const k3d::ienumeration_property::enumeration_values_t& direction_values()
 	{
 		static k3d::ienumeration_property::enumeration_values_t values;
 		if(values.empty())
