@@ -321,7 +321,7 @@ public:
 				k3d::uuid(0x34524730, 0x7ba14abf, 0xb1922641, 0xf64c68ce),
 				"FillSelectedHoles",
 				"Fills holes by creating polygons containing selected border edges",
-				"Objects",
+				"Mesh",
 				k3d::iplugin_factory::DEPRECATED);
 
 		return factory;
