@@ -49,42 +49,28 @@ public:
 		base(Document),
 		m_interpolateboundary(init_owner(*this) + init_name("interpolateboundary") + init_label(_("Interpolate boundary")) + init_description(_("Render sharp boundaries on the resulting subdivision surface")) + init_value(true))
 	{
-		m_input_mesh.changed_signal().connect(sigc::mem_fun(*this, &make_sds_implementation::on_reset_geometry));
-		m_interpolateboundary.changed_signal().connect(sigc::mem_fun(*this, &make_sds_implementation::on_reset_geometry));
-
-		m_output_mesh.need_data_signal().connect(sigc::mem_fun(*this, &make_sds_implementation::on_create_geometry));
+		m_interpolateboundary.changed_signal().connect(make_reset_mesh_slot());
 	}
 
-	void on_reset_geometry()
+	k3d::iunknown* on_rewrite_hint(iunknown* const Hint)
 	{
-		m_output_mesh.reset();
+		// Force all updates to re-allocate our mesh, for the sake of the SDS code in MeshInstance
+		return 0;
 	}
 
-	k3d::mesh* on_create_geometry()
+	void on_create_mesh(const k3d::mesh& InputMesh, k3d::mesh& Mesh)
 	{
-		// If we don't have any input mesh, we're done ...
-		const k3d::mesh* const input = m_input_mesh.value();
-		if(!input)
-			return 0;
-
-		// Otherwise, we make a copy of the input mesh and modify the copy ...
-		k3d::mesh* const output = new k3d::mesh();
-		k3d::deep_copy(*input, *output);
-		reshape_geometry(*input, *output);
-
-		return output;
+		k3d::deep_copy(InputMesh, Mesh);
 	}
 
-	void reshape_geometry(const k3d::mesh& Source, k3d::mesh& Target)
+	void on_update_mesh(const k3d::mesh& InputMesh, k3d::mesh& Mesh)
 	{
 		const bool interpolateboundary = m_interpolateboundary.value();
-
-		for(k3d::mesh::polyhedra_t::iterator polyhedron = Target.polyhedra.begin(); polyhedron != Target.polyhedra.end(); ++polyhedron)
-			{
-				(*polyhedron)->type = k3d::polyhedron::CATMULL_CLARK_SUBDIVISION_MESH;
-				(*polyhedron)->tags["interpolateboundary"] = static_cast<bool>(interpolateboundary);
-			}
-
+		for(k3d::mesh::polyhedra_t::iterator polyhedron = Mesh.polyhedra.begin(); polyhedron != Mesh.polyhedra.end(); ++polyhedron)
+		{
+			(*polyhedron)->type = k3d::polyhedron::CATMULL_CLARK_SUBDIVISION_MESH;
+			(*polyhedron)->tags["interpolateboundary"] = interpolateboundary;
+		}
 	}
 
 	k3d::iplugin_factory& factory()
