@@ -1,5 +1,5 @@
 // K-3D
-// Copyright (c) 1995-2005, Timothy M. Shead
+// Copyright (c) 1995-2006, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -19,16 +19,16 @@
 
 /** \file
 		\author Timothy M. Shead (tshead@k-3d.com)
+		\author Romain Behar (romainbehar@yahoo.com)
 */
 
 #include <k3dsdk/i18n.h>
-#include <k3dsdk/node.h>
-#include <k3dsdk/persistent.h>
 #include <k3dsdk/measurement.h>
 #include <k3dsdk/mesh_source.h>
 #include <k3dsdk/module.h>
+#include <k3dsdk/node.h>
+#include <k3dsdk/persistent.h>
 
-#include <boost/multi_array.hpp>
 #include <iterator>
 
 namespace libk3dmesh
@@ -46,34 +46,49 @@ public:
 	merge_mesh_implementation(k3d::idocument& Document) :
 		base(Document),
 		m_input_mesh1(init_owner(*this) + init_name("input_mesh1") + init_label(_("Input mesh 1")) + init_description(_("First mesh to merge")) + init_value<k3d::mesh*>(0)),
-		m_input_mesh2(init_owner(*this) + init_name("input_mesh2") + init_label(_("Input mesh 2")) + init_description(_("Second mesh to merge")) + init_value<k3d::mesh*>(0))
+		m_input_mesh2(init_owner(*this) + init_name("input_mesh2") + init_label(_("Input mesh 2")) + init_description(_("Second mesh to merge")) + init_value<k3d::mesh*>(0)),
+		m_same_polyhedron(init_owner(*this) + init_name("same_polyhedron") + init_label(_("Same polyhedron")) + init_description(_("Merge meshes in a single polyhedron")) + init_value(true))
 	{
-		m_input_mesh1.changed_signal().connect(sigc::mem_fun(*this, &merge_mesh_implementation::on_reset_geometry));
-		m_input_mesh2.changed_signal().connect(sigc::mem_fun(*this, &merge_mesh_implementation::on_reset_geometry));
-
-		m_output_mesh.need_data_signal().connect(sigc::mem_fun(*this, &merge_mesh_implementation::on_create_geometry));
+		m_input_mesh1.changed_signal().connect(make_reset_mesh_slot());
+		m_input_mesh2.changed_signal().connect(make_reset_mesh_slot());
+		m_same_polyhedron.changed_signal().connect(make_reset_mesh_slot());
 	}
 
-	void on_reset_geometry()
+	/** \todo Improve the implementation so we don't have to do this */
+	k3d::iunknown* on_rewrite_hint(iunknown* const Hint)
 	{
-		m_output_mesh.reset();
+		// Force updates to re-allocate our mesh, for simplicity
+		return 0;
 	}
 
-	k3d::mesh* on_create_geometry()
+	void on_create_mesh(k3d::mesh& Mesh)
 	{
 		// Get the input geometry ...
 		const k3d::mesh* const input_mesh1 = m_input_mesh1.value();
 		const k3d::mesh* const input_mesh2 = m_input_mesh2.value();
 
 		// Create output geometry ...
-		k3d::mesh* const output = new k3d::mesh();
 		if(input_mesh1)
-			k3d::deep_copy(*input_mesh1, *output);
+			k3d::deep_copy(*input_mesh1, Mesh);
 
 		if(input_mesh2)
-			k3d::deep_copy(*input_mesh2, *output);
+			k3d::deep_copy(*input_mesh2, Mesh);
 
-		return output;
+		while(m_same_polyhedron.value() && Mesh.polyhedra.size() > 1)
+		{
+			// Merge two first polyhedra
+			k3d::polyhedron* polyhedron1 = Mesh.polyhedra[0];
+			k3d::polyhedron* polyhedron2 = Mesh.polyhedra[1];
+
+			polyhedron1->faces.insert(polyhedron1->faces.end(), polyhedron2->faces.begin(), polyhedron2->faces.end());
+			Mesh.polyhedra.erase(std::find(Mesh.polyhedra.begin(), Mesh.polyhedra.end(), polyhedron2));
+			polyhedron2->faces.clear();
+			delete polyhedron2;
+		}
+	}
+
+	void on_update_mesh(k3d::mesh& Mesh)
+	{
 	}
 
 	k3d::iplugin_factory& factory()
@@ -96,6 +111,7 @@ public:
 private:
 	k3d_data(k3d::mesh*, immutable_name, change_signal, no_undo, local_storage, no_constraint, read_only_property, no_serialization) m_input_mesh1;
 	k3d_data(k3d::mesh*, immutable_name, change_signal, no_undo, local_storage, no_constraint, read_only_property, no_serialization) m_input_mesh2;
+	k3d_data(bool, immutable_name, change_signal, with_undo, local_storage, no_constraint, writable_property, with_serialization) m_same_polyhedron;
 };
 
 /////////////////////////////////////////////////////////////////////////////
@@ -108,4 +124,3 @@ k3d::iplugin_factory& merge_mesh_factory()
 
 } // namespace libk3dmesh
 
-
