@@ -33,25 +33,25 @@ namespace libk3dmesh
 {
 
 /////////////////////////////////////////////////////////////////////////////
-// planar_map_implementation
+// planar_map
 
-class planar_map_implementation :
+class planar_map :
 	public k3d::persistent<k3d::node>,
 	public k3d::i3d_2d_mapping
 {
 	typedef k3d::persistent<k3d::node> base;
 
 public:
-	planar_map_implementation(k3d::idocument& Document) :
+	planar_map(k3d::idocument& Document) :
 		base(Document)
 	{
 	}
 
-	const k3d::vector2 map_3d_to_2d(const k3d::vector3& Position, const k3d::bounding_box3& Bounds)
+	const k3d::point2 map_3d_to_2d(const k3d::point3& Position, const k3d::bounding_box3& Bounds)
 	{
-		return_val_if_fail(Bounds.width() && Bounds.height() && Bounds.depth(), k3d::vector2(0, 0));
+		return_val_if_fail(Bounds.width() && Bounds.height() && Bounds.depth(), k3d::point2(0, 0));
 
-		return k3d::vector2(
+		return k3d::point2(
 			(Position[0] - Bounds.nx) / (Bounds.width()),
 			(Bounds.py - Position[1]) / (Bounds.height()));
 	}
@@ -64,7 +64,7 @@ public:
 	static k3d::iplugin_factory& get_factory()
 	{
 		static k3d::plugin_factory<
-			k3d::document_plugin<planar_map_implementation>,
+			k3d::document_plugin<planar_map>,
 			k3d::interface_list<k3d::i3d_2d_mapping> > factory(
 				k3d::uuid(0xd9148b60, 0x7f2a49f0, 0xa28e505a, 0xa3f4d4df),
 				"PlanarMap",
@@ -81,7 +81,7 @@ public:
 
 k3d::iplugin_factory& planar_map_factory()
 {
-	return planar_map_implementation::get_factory();
+	return planar_map::get_factory();
 }
 
 } // namespace libk3dmesh
