@@ -50,63 +50,34 @@ public:
 		base(Document),
 		m_sharpness(init_owner(*this) + init_name("sharpness") + init_label(_("Sharpness")) + init_description(_("Controls the sharpness of subdivision surface corners")) + init_value(0.0))
 	{
-		m_input_mesh.changed_signal().connect(sigc::mem_fun(*this, &sds_corner_implementation::on_reset_geometry));
-		m_mesh_selection.changed_signal().connect(sigc::mem_fun(*this, &sds_corner_implementation::on_reset_geometry));
-		m_output_mesh.need_data_signal().connect(sigc::mem_fun(*this, &sds_corner_implementation::on_create_geometry));
-
-		m_sharpness.changed_signal().connect(sigc::mem_fun(*this, &sds_corner_implementation::on_reshape_geometry));
+		m_mesh_selection.changed_signal().connect(make_reset_mesh_slot());
+		m_sharpness.changed_signal().connect(make_update_mesh_slot());
 	}
 
-	void on_reset_geometry()
+	/** \todo Improve the implementation so we don't have to do this */
+	k3d::iunknown* on_rewrite_hint(iunknown* const Hint)
 	{
-		m_output_mesh.reset();
+		// Force updates to re-allocate our mesh, for simplicity
+		return 0;
 	}
 
-	void on_reshape_geometry()
+	void on_create_mesh(const k3d::mesh& InputMesh, k3d::mesh& Mesh)
 	{
-		if(m_output_mesh.empty())
-			return;
-
-		const k3d::mesh* const input = m_input_mesh.value();
-		if(!input)
-			return;
-
-		k3d::mesh* const output = const_cast<k3d::mesh*>(m_output_mesh.internal_value());
-		if(!output)
-			return;
-
-		reshape_geometry(*input, *output);
-
-		m_output_mesh.changed_signal().emit();
+		k3d::deep_copy(InputMesh, Mesh);
+		k3d::replace_selection(m_mesh_selection.value(), Mesh);
 	}
 
-	k3d::mesh* on_create_geometry()
-	{
-		// If we don't have any input mesh, we're done ...
-		const k3d::mesh* const input = m_input_mesh.value();
-		if(!input)
-			return 0;
-
-		// Otherwise, we make a copy of the input mesh and modify the copy ...
-		k3d::mesh* const output = new k3d::mesh();
-		k3d::deep_copy(*input, *output);
-		k3d::replace_selection(m_mesh_selection.value(), *output);
-		reshape_geometry(*input, *output);
-
-		return output;
-	}
-
-	void reshape_geometry(const k3d::mesh& Source, k3d::mesh& Target)
+	void on_update_mesh(const k3d::mesh& Source, k3d::mesh& Target)
 	{
 		return_if_fail(Source.points.size() == Target.points.size());
 
 		const k3d::ri::real sharpness = m_sharpness.value();
 
 		for(unsigned long i = 0; i != Target.points.size(); ++i)
-			{
-				if(Source.points[i]->selection_weight)
-					Target.points[i]->tags["corner"] = sharpness;
-			}
+		{
+			if(Source.points[i]->selection_weight)
+				Target.points[i]->tags["corner"] = sharpness;
+		}
 	}
 
 	k3d::iplugin_factory& factory()
