@@ -50,33 +50,21 @@ public:
 	set_material_implementation(k3d::idocument& Document) :
 		base(Document)
 	{
-		m_input_mesh.changed_signal().connect(sigc::mem_fun(*this, &set_material_implementation::on_reset_geometry));
-		m_mesh_selection.changed_signal().connect(sigc::mem_fun(*this, &set_material_implementation::on_reset_geometry));
-		m_material.changed_signal().connect(sigc::mem_fun(*this, &set_material_implementation::on_reset_geometry));
-		m_output_mesh.need_data_signal().connect(sigc::mem_fun(*this, &set_material_implementation::on_create_geometry));
+		m_mesh_selection.changed_signal().connect(make_update_mesh_slot());
+		m_material.changed_signal().connect(make_update_mesh_slot());
+	}
+
+	void on_create_mesh(const k3d::mesh& InputMesh, k3d::mesh& Mesh)
+	{
+		k3d::deep_copy(InputMesh, Mesh);
+		k3d::replace_selection(m_mesh_selection.value(), Mesh);
+	}
+
+	void on_update_mesh(const k3d::mesh& InputMesh, k3d::mesh& Mesh)
+	{
+		k3d::for_each_component(Mesh, set_material(m_material.value()));
 	}
 	
-	void on_reset_geometry()
-	{
-		m_output_mesh.reset();
-	}
-	
-	k3d::mesh* on_create_geometry()
-	{
-		// If we don't have any input mesh, we're done ...
-		const k3d::mesh* const input = m_input_mesh.value();
-		if(!input)
-			return 0;
-
-		// Otherwise, we make a copy of the input mesh and modify the copy ...
-		k3d::mesh* const output = new k3d::mesh();
-		k3d::deep_copy(*input, *output);
-		k3d::replace_selection(m_mesh_selection.value(), *output);
-		reshape_geometry(*input, *output);
-
-		return output;
-	}
-
 	class set_material
 	{
 	public:
@@ -104,12 +92,6 @@ public:
 		k3d::imaterial* const m_material;
 	};
 
-	void reshape_geometry(const k3d::mesh& Source, k3d::mesh& Target)
-	{
-		k3d::for_each_component(Target, set_material(m_material.value()));
-
-	}
-	
 	k3d::iplugin_factory& factory()
 	{
 		return get_factory();
