@@ -57,44 +57,105 @@ public:
 		m_tag_bilinear_patches(init_owner(*this) + init_name("tag_bilinear_patches") + init_label(_("Tag bilinear patches")) + init_description(_("Tag Bilinear Patches")) + init_value(false)),
 		m_tag_bicubic_patches(init_owner(*this) + init_name("tag_bicubic_patches") + init_label(_("Tag bicubic patches")) + init_description(_("Tag Bicubic Patches")) + init_value(false))
 	{
-		m_input_mesh.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_mesh_selection.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_new_color.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_default_color.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_tag_points.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_tag_point_groups.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_tag_edges.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_tag_faces.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_tag_polyhedra.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_tag_linear_curve_groups.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_tag_cubic_curve_groups.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_tag_bilinear_patches.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
-		m_tag_bicubic_patches.changed_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_reset_geometry));
+		m_mesh_selection.changed_signal().connect(make_reset_mesh_slot());
 
-		m_output_mesh.need_data_signal().connect(sigc::mem_fun(*this, &tag_color_implementation::on_create_geometry));
+		m_new_color.changed_signal().connect(make_update_mesh_slot());
+		m_default_color.changed_signal().connect(make_update_mesh_slot());
+		m_tag_points.changed_signal().connect(make_update_mesh_slot());
+		m_tag_point_groups.changed_signal().connect(make_update_mesh_slot());
+		m_tag_edges.changed_signal().connect(make_update_mesh_slot());
+		m_tag_faces.changed_signal().connect(make_update_mesh_slot());
+		m_tag_polyhedra.changed_signal().connect(make_update_mesh_slot());
+		m_tag_linear_curve_groups.changed_signal().connect(make_update_mesh_slot());
+		m_tag_cubic_curve_groups.changed_signal().connect(make_update_mesh_slot());
+		m_tag_bilinear_patches.changed_signal().connect(make_update_mesh_slot());
+		m_tag_bicubic_patches.changed_signal().connect(make_update_mesh_slot());
+	}
+
+	/** \todo Improve the implementation so we don't have to do this */
+	k3d::iunknown* on_rewrite_hint(iunknown* const Hint)
+	{
+		// Force updates to re-allocate our mesh, for simplicity
+		return 0;
+	}
+
+	void on_create_mesh(const k3d::mesh& InputMesh, k3d::mesh& Mesh)
+	{
+		k3d::deep_copy(InputMesh, Mesh);
+		k3d::replace_selection(m_mesh_selection.value(), Mesh);
+	}
+
+	void on_update_mesh(const k3d::mesh& Source, k3d::mesh& Target)
+	{
+		const k3d::color new_color = m_new_color.value();
+		const k3d::color default_color = m_default_color.value();
+
+		if(m_tag_points.value())
+		{
+			for(k3d::mesh::points_t::iterator point = Target.points.begin(); point != Target.points.end(); ++point)
+				set_color(**point, new_color, default_color, (*point)->vertex_data);
+		}
+
+		if(m_tag_point_groups.value())
+		{
+			for(k3d::mesh::point_groups_t::iterator group = Target.point_groups.begin(); group != Target.point_groups.end(); ++group)
+				set_color(**group, new_color, default_color, (*group)->constant_data);
+		}
+
+		if(m_tag_linear_curve_groups.value())
+		{
+			for(k3d::mesh::linear_curve_groups_t::iterator group = Target.linear_curve_groups.begin(); group != Target.linear_curve_groups.end(); ++group)
+				set_color(**group, new_color, default_color, (*group)->constant_data);
+		}
+
+		if(m_tag_cubic_curve_groups.value())
+		{
+			for(k3d::mesh::cubic_curve_groups_t::iterator group = Target.cubic_curve_groups.begin(); group != Target.cubic_curve_groups.end(); ++group)
+				set_color(**group, new_color, default_color, (*group)->constant_data);
+		}
+
+		if(m_tag_bilinear_patches.value())
+		{
+			for(k3d::mesh::bilinear_patches_t::iterator patch = Target.bilinear_patches.begin(); patch != Target.bilinear_patches.end(); ++patch)
+				set_color(**patch, new_color, default_color, (*patch)->uniform_data);
+		}
+
+		if(m_tag_bicubic_patches.value())
+		{
+			for(k3d::mesh::bicubic_patches_t::iterator patch = Target.bicubic_patches.begin(); patch != Target.bicubic_patches.end(); ++patch)
+				set_color(**patch, new_color, default_color, (*patch)->uniform_data);
+		}
+
+		for(k3d::mesh::polyhedra_t::iterator polyhedron = Target.polyhedra.begin(); polyhedron != Target.polyhedra.end(); ++polyhedron)
+		{
+			if(m_tag_polyhedra.value())
+			{
+				set_color(**polyhedron, new_color, default_color, (*polyhedron)->constant_data);
+			}
+
+			if(m_tag_edges.value())
+			{
+				for(k3d::polyhedron::faces_t::const_iterator face = (*polyhedron)->faces.begin(); face != (*polyhedron)->faces.end(); ++face)
+				{
+					k3d::split_edge* edge = (*face)->first_edge;
+					do
+					{
+						set_color(*edge, new_color, default_color, edge->facevarying_data);
+
+						edge = edge->face_clockwise;
+					}
+					while(edge != (*face)->first_edge);
+				}
+			}
+
+			if(m_tag_faces.value())
+			{
+				for(k3d::polyhedron::faces_t::const_iterator face = (*polyhedron)->faces.begin(); face != (*polyhedron)->faces.end(); ++face)
+					set_color(**face, new_color, default_color, (*face)->uniform_data);
+			}
+		}
 	}
 	
-	void on_reset_geometry()
-	{
-		m_output_mesh.reset();
-	}
-	
-	k3d::mesh* on_create_geometry()
-	{
-		// If we don't have any input mesh, we're done ...
-		const k3d::mesh* const input = m_input_mesh.value();
-		if(!input)
-			return 0;
-
-		// Otherwise, we make a copy of the input mesh and modify the copy ...
-		k3d::mesh* const output = new k3d::mesh();
-		k3d::deep_copy(*input, *output);
-		k3d::replace_selection(m_mesh_selection.value(), *output);
-		modify_geometry(*input, *output);
-
-		return output;
-	}
-
 	template<typename T>
 	void set_color(T& Object, const k3d::color& NewColor, const k3d::color& DefaultColor, k3d::parameters_t& Parameters)
 	{
@@ -104,77 +165,6 @@ public:
 			Parameters["Cs"] = DefaultColor;
 	}
 
-	void modify_geometry(const k3d::mesh& Source, k3d::mesh& Target)
-	{
-		const k3d::color new_color = m_new_color.value();
-		const k3d::color default_color = m_default_color.value();
-
-		if(m_tag_points.value())
-			{
-				for(k3d::mesh::points_t::iterator point = Target.points.begin(); point != Target.points.end(); ++point)
-					set_color(**point, new_color, default_color, (*point)->vertex_data);
-			}
-
-		if(m_tag_point_groups.value())
-			{
-				for(k3d::mesh::point_groups_t::iterator group = Target.point_groups.begin(); group != Target.point_groups.end(); ++group)
-					set_color(**group, new_color, default_color, (*group)->constant_data);
-			}
-
-		if(m_tag_linear_curve_groups.value())
-			{
-				for(k3d::mesh::linear_curve_groups_t::iterator group = Target.linear_curve_groups.begin(); group != Target.linear_curve_groups.end(); ++group)
-					set_color(**group, new_color, default_color, (*group)->constant_data);
-			}
-
-		if(m_tag_cubic_curve_groups.value())
-			{
-				for(k3d::mesh::cubic_curve_groups_t::iterator group = Target.cubic_curve_groups.begin(); group != Target.cubic_curve_groups.end(); ++group)
-					set_color(**group, new_color, default_color, (*group)->constant_data);
-			}
-
-		if(m_tag_bilinear_patches.value())
-			{
-				for(k3d::mesh::bilinear_patches_t::iterator patch = Target.bilinear_patches.begin(); patch != Target.bilinear_patches.end(); ++patch)
-					set_color(**patch, new_color, default_color, (*patch)->uniform_data);
-			}
-
-		if(m_tag_bicubic_patches.value())
-			{
-				for(k3d::mesh::bicubic_patches_t::iterator patch = Target.bicubic_patches.begin(); patch != Target.bicubic_patches.end(); ++patch)
-					set_color(**patch, new_color, default_color, (*patch)->uniform_data);
-			}
-
-		for(k3d::mesh::polyhedra_t::iterator polyhedron = Target.polyhedra.begin(); polyhedron != Target.polyhedra.end(); ++polyhedron)
-			{
-				if(m_tag_polyhedra.value())
-					{
-						set_color(**polyhedron, new_color, default_color, (*polyhedron)->constant_data);
-					}
-
-				if(m_tag_edges.value())
-					{
-						for(k3d::polyhedron::faces_t::const_iterator face = (*polyhedron)->faces.begin(); face != (*polyhedron)->faces.end(); ++face)
-							{
-								k3d::split_edge* edge = (*face)->first_edge;
-								do
-									{
-										set_color(*edge, new_color, default_color, edge->facevarying_data);
-
-										edge = edge->face_clockwise;
-									}
-								while(edge != (*face)->first_edge);
-							}
-					}
-
-				if(m_tag_faces.value())
-					{
-						for(k3d::polyhedron::faces_t::const_iterator face = (*polyhedron)->faces.begin(); face != (*polyhedron)->faces.end(); ++face)
-							set_color(**face, new_color, default_color, (*face)->uniform_data);
-					}
-			}
-	}
-	
 	k3d::iplugin_factory& factory()
 	{
 		return get_factory();
