@@ -27,10 +27,9 @@
 #include <k3dsdk/ideletable.h>
 #include <k3dsdk/ifile_format.h>
 #include <k3dsdk/module.h>
+#include <k3dsdk/path.h>
 #include <k3dsdk/string_modifiers.h>
 
-#include <boost/filesystem/path.hpp>
-
 #include <ImfOutputFile.h>
 #include <ImfChannelList.h>
 
@@ -55,18 +54,14 @@ public:
 		return 128;
 	}
 
-	bool query_can_handle(const boost::filesystem::path& File)
+	bool query_can_handle(const k3d::filesystem::path& File)
 	{
-		return_val_if_fail(!File.empty(), false);
-		return "exr" == k3d::file_extension(File);
+		return k3d::filesystem::extension(File).lowercase().raw() == ".exr";
 	}
 
-	bool write_file(const boost::filesystem::path& File, const k3d::bitmap& Bitmap)
+	bool write_file(const k3d::filesystem::path& File, const k3d::bitmap& Bitmap)
 	{
-		// Sanity checks ...
-		return_val_if_fail(!File.empty(), false);
-
-		k3d::log() << info << "Write " << File.native_file_string() << " using OpenEXRWriter" << std::endl;
+		k3d::log() << info << "Write " << File.native_console_string() << " using OpenEXRWriter" << std::endl;
 
 		try
 		{
@@ -76,7 +71,7 @@ public:
 			header.channels().insert("B", Imf::Channel(Imf::HALF));
 			header.channels().insert("A", Imf::Channel(Imf::HALF));
 
-			Imf::OutputFile file(File.native_file_string().c_str(), header);
+			Imf::OutputFile file(File.native_filesystem_string().c_str(), header);
 			
 			const Imath::Box2i dw = file.header().dataWindow();
 			const int width  = dw.max.x - dw.min.x + 1;
