@@ -33,7 +33,7 @@ extern k3d::iplugin_factory& exr_writer_factory();
 
 } // namespace libk3dopenexr
 
-K3D_MODULE_START(k3d::uuid(0x32567543, 0x3ddc4113, 0xaf186fa6, 0xe050f4fc), Registry)
+K3D_MODULE_START(libk3dopenexr, k3d::uuid(0x32567543, 0x3ddc4113, 0xaf186fa6, 0xe050f4fc), Registry)
 	Registry.register_factory(libk3dopenexr::exr_reader_factory());
 	Registry.register_factory(libk3dopenexr::exr_writer_factory());
 K3D_MODULE_END
