@@ -45,16 +45,16 @@ namespace
 {
 
 /////////////////////////////////////////////////////////////////////////////
-// background_plane_implementation
+// background_plane
 
-class background_plane_implementation :
+class background_plane :
 	public k3d::material_client<k3d::persistent<k3d::node> >,
 	public k3d::ri::irenderable
 {
 	typedef k3d::material_client<k3d::persistent<k3d::node> > base;
 
 public:
-	background_plane_implementation(k3d::idocument& Document) :
+	background_plane(k3d::idocument& Document) :
 		base(Document),
 		m_distance(init_owner(*this) + init_name("distance") + init_label(_("distance")) + init_description(_("Distance")) + init_value(1.0) + init_constraint(k3d::data::constraint::minimum(0.0, k3d::data::constraint::maximum(1.0))))
 	{
@@ -72,36 +72,36 @@ public:
 		k3d::iperspective* const perspective = dynamic_cast<k3d::iperspective*>(&State.projection);
 		k3d::iorthographic* const orthographic = dynamic_cast<k3d::iorthographic*>(&State.projection);
 		if(!perspective && !orthographic)
-			{
-				k3d::log() << error << k3d_file_reference << ": unknown projection type" << std::endl;
-				return;
-			}
+		{
+			k3d::log() << error << k3d_file_reference << ": unknown projection type" << std::endl;
+			return;
+		}
 	
 		double left, right, top, bottom, plane;
 		if(perspective)
-			{
-				const double near = boost::any_cast<double>(k3d::get_value(document().dag(), perspective->near()));
-				const double far = boost::any_cast<double>(k3d::get_value(document().dag(), perspective->far()));
-				plane = k3d::mix(near, far, m_distance.value());
-				left = plane * boost::any_cast<double>(k3d::get_value(document().dag(), perspective->left()));
-				right = plane * boost::any_cast<double>(k3d::get_value(document().dag(), perspective->right()));
-				top = plane * boost::any_cast<double>(k3d::get_value(document().dag(), perspective->top()));
-				bottom = plane * boost::any_cast<double>(k3d::get_value(document().dag(), perspective->bottom()));
-			}
+		{
+			const double near = boost::any_cast<double>(k3d::get_value(document().dag(), perspective->near()));
+			const double far = boost::any_cast<double>(k3d::get_value(document().dag(), perspective->far()));
+			plane = k3d::mix(near, far, m_distance.value());
+			left = plane * boost::any_cast<double>(k3d::get_value(document().dag(), perspective->left()));
+			right = plane * boost::any_cast<double>(k3d::get_value(document().dag(), perspective->right()));
+			top = plane * boost::any_cast<double>(k3d::get_value(document().dag(), perspective->top()));
+			bottom = plane * boost::any_cast<double>(k3d::get_value(document().dag(), perspective->bottom()));
+		}
 
 		if(orthographic)
-			{
-				const double near = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->near()));
-				const double far = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->far()));
-				plane = k3d::mix(near, far, m_distance.value());
-				left = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->left()));
-				right = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->right()));
-				top = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->top()));
-				bottom = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->bottom()));
-			}
+		{
+			const double near = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->near()));
+			const double far = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->far()));
+			plane = k3d::mix(near, far, m_distance.value());
+			left = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->left()));
+			right = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->right()));
+			top = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->top()));
+			bottom = boost::any_cast<double>(k3d::get_value(document().dag(), orthographic->bottom()));
+		}
 		
 		State.engine.RiAttributeBegin();
-		State.engine.RiAttributeV("identifier", k3d::ri::parameter_list(1, k3d::ri::parameter("name", k3d::ri::UNIFORM, name())));
+		State.engine.RiAttributeV("identifier", k3d::ri::parameter_list(1, k3d::ri::parameter("name", k3d::ri::UNIFORM, k3d::ri::string(name()))));
 		State.engine.RiIdentity();
 		State.engine.RiCoordSysTransform(k3d::ri::RI_CAMERA());
 		
@@ -109,15 +109,19 @@ public:
 
 		// Draw a plane ...
 		k3d::ri::points points;
-		points.push_back(k3d::ri::point(k3d::vector3(left, top, plane)));
-		points.push_back(k3d::ri::point(k3d::vector3(right, top, plane)));
-		points.push_back(k3d::ri::point(k3d::vector3(left, bottom, plane)));
-		points.push_back(k3d::ri::point(k3d::vector3(right, bottom, plane)));
+		points.push_back(k3d::ri::point(k3d::point3(left, top, plane)));
+		points.push_back(k3d::ri::point(k3d::point3(right, top, plane)));
+		points.push_back(k3d::ri::point(k3d::point3(left, bottom, plane)));
+		points.push_back(k3d::ri::point(k3d::point3(right, bottom, plane)));
 		State.engine.RiPatchV("bilinear", k3d::ri::parameter_list(1, k3d::ri::parameter(k3d::ri::RI_P(), k3d::ri::VERTEX, points)));
 
 		State.engine.RiAttributeEnd();
 	}
 
+	void renderman_render_complete(const k3d::ri::render_state& State)
+	{
+	}
+
 	k3d::iplugin_factory& factory()
 	{
 		return get_factory();
@@ -125,7 +129,7 @@ public:
 
 	static k3d::iplugin_factory& get_factory()
 	{
-		static k3d::plugin_factory<k3d::document_plugin<background_plane_implementation> >factory(
+		static k3d::plugin_factory<k3d::document_plugin<background_plane> >factory(
 			k3d::uuid(0x80e1c8eb, 0x001d4342, 0xb401551d, 0xd5c45a3d),
 			"RenderManBackgroundPlane",
 			_("Places a shader on a bilinear patch, aligned with the farplane"),
@@ -146,7 +150,7 @@ namespace libk3drenderman
 
 k3d::iplugin_factory& background_plane_factory()
 {
-	return background_plane_implementation::get_factory();
+	return background_plane::get_factory();
 }
 
 } // namespace libk3drenderman
