@@ -25,7 +25,6 @@
 #include <k3dsdk/classes.h>
 #include <k3dsdk/gl.h>
 #include <k3dsdk/i18n.h>
-#include <k3dsdk/iapplication.h>
 #include <k3dsdk/module.h>
 #include <k3dsdk/node.h>
 #include <k3dsdk/persistent.h>
@@ -39,9 +38,9 @@ namespace libk3drenderman
 {
 
 /////////////////////////////////////////////////////////////////////////////
-// light_implementation
+// light
 
-class light_implementation :
+class light :
 	public k3d::gl::drawable<k3d::transformable<k3d::persistent<k3d::node> > >,
 	public k3d::gl::ilight,
 	public k3d::ri::ilight
@@ -49,10 +48,12 @@ class light_implementation :
 	typedef k3d::gl::drawable<k3d::transformable<k3d::persistent<k3d::node> > > base;
 
 public:
-	light_implementation(k3d::idocument& Document) :
+	light(k3d::idocument& Document) :
 		base(Document),
 		m_shader(init_owner(*this) + init_name("shader") + init_label(_("Shader")) + init_description(_("Light shader")) + init_value<k3d::ri::ilight_shader*>(0))
 	{
+		m_selection_weight.changed_signal().connect(make_async_redraw_slot());
+		m_input_matrix.changed_signal().connect(make_async_redraw_slot());
 	}
 
 	void on_gl_draw(const k3d::gl::render_state& State)
@@ -61,7 +62,7 @@ public:
 		glDisable(GL_TEXTURE_1D);
 		glDisable(GL_TEXTURE_2D);
 
-		k3d::gl::color3d(get_visible_selection() ? k3d::color(1, 1, 1) : k3d::color(1, 1, 0));
+		k3d::gl::color3d(get_selection_weight() ? k3d::color(1, 1, 1) : k3d::color(1, 1, 0));
 		glLineWidth(1.0f);
 		glDisable(GL_LINE_STIPPLE);
 
@@ -79,7 +80,7 @@ public:
 	{
 		glBegin(GL_LINES);
 
-		k3d::vector3 coords(0, 0, 0);
+		k3d::point3 coords(0, 0, 0);
 
 		glVertex3d(coords[0] + 1.0, coords[1], coords[2]);
 		glVertex3d(coords[0] - 1.0, coords[1], coords[2]);
@@ -120,7 +121,7 @@ public:
 		glLightf(light, GL_QUADRATIC_ATTENUATION, GLfloat(intensity));
 
 		// Setup color ...
-		k3d::vector3 color(1.0, 1.0, 1.0);
+		k3d::point3 color(1.0, 1.0, 1.0);
 
 		GLfloat glcolor[4];
 		glcolor[0] = (GLfloat)color[0];
@@ -175,7 +176,7 @@ public:
 	static k3d::iplugin_factory& get_factory()
 	{
 		static k3d::plugin_factory<
-			k3d::document_plugin<light_implementation>,
+			k3d::document_plugin<light>,
 			k3d::interface_list<k3d::gl::ilight,
 			k3d::interface_list<k3d::ri::ilight,
 			k3d::interface_list<k3d::itransform_source,
@@ -198,9 +199,8 @@ private:
 
 k3d::iplugin_factory& light_factory()
 {
-	return light_implementation::get_factory();
+	return light::get_factory();
 }
 
 } // namespace libk3drenderman
 
-
