@@ -1,5 +1,5 @@
 // K-3D
-// Copyright (c) 1995-2006, Timothy M. Shead
+// Copyright (c) 1995-2007, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -18,11 +18,11 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 /** \file
-		\author Tim Shead <tshead@k-3d.com>
+	\author Tim Shead <tshead@k-3d.com>
 */
 
 #include <k3dsdk/classes.h>
-#include <k3dsdk/frames.h>
+#include <k3dsdk/file_range.h>
 #include <k3dsdk/fstream.h>
 #include <k3dsdk/gl.h>
 #include <k3dsdk/i18n.h>
@@ -46,6 +46,7 @@
 #include <k3dsdk/renderman.h>
 #include <k3dsdk/resolutions.h>
 #include <k3dsdk/shader_cache.h>
+#include <k3dsdk/shader_collection_ri.h>
 #include <k3dsdk/shaders.h>
 #include <k3dsdk/string_cast.h>
 #include <k3dsdk/time_source.h>
@@ -73,59 +74,76 @@ class setup_light
 {
 public:
 	explicit setup_light(const k3d::ri::render_state& State) :
-		m_state(State)
+		state(State)
 	{
 	}
 
-	void operator()(k3d::inode* const Object)
+	void operator()(k3d::inode* const Node)
 	{
-		k3d::ri::ilight* const light = dynamic_cast<k3d::ri::ilight*>(Object);
-		if(light)
-			light->setup_renderman_light(m_state);
+		if(k3d::ri::ilight* const light = dynamic_cast<k3d::ri::ilight*>(Node))
+			light->setup_renderman_light(state);
 	}
 
 private:
-	const k3d::ri::render_state& m_state;
+	const k3d::ri::render_state& state;
 };
 
 class setup_texture
 {
 public:
-	explicit setup_texture(k3d::irender_frame& Frame, k3d::ri::irender_engine& Engine) :
-		m_frame(Frame),
-		m_engine(Engine)
+	explicit setup_texture(k3d::irender_frame& Frame, k3d::ri::irender_engine& Engine, k3d::ri::ishader_collection& Shaders) :
+		frame(Frame),
+		engine(Engine),
+		shaders(Shaders)
 	{
 	}
 
-	void operator()(k3d::inode* const Object)
+	void operator()(k3d::inode* const Node)
 	{
-		k3d::ri::itexture* const texture = dynamic_cast<k3d::ri::itexture*>(Object);
-		if(texture)
-			texture->setup_renderman_texture(m_frame, m_engine);
+		if(k3d::ri::itexture* const texture = dynamic_cast<k3d::ri::itexture*>(Node))
+			texture->setup_renderman_texture(frame, engine, shaders);
 	}
 
 private:
-	k3d::irender_frame& m_frame;
-	k3d::ri::irender_engine& m_engine;
+	k3d::irender_frame& frame;
+	k3d::ri::irender_engine& engine;
+	k3d::ri::ishader_collection& shaders;
 };
 
 class render
 {
 public:
 	explicit render(const k3d::ri::render_state& State) :
-		m_state(State)
+		state(State)
 	{
 	}
 
-	void operator()(k3d::inode* const Object)
+	void operator()(k3d::inode* const Node)
 	{
-		k3d::ri::irenderable* const renderable = dynamic_cast<k3d::ri::irenderable*>(Object);
-		if(renderable)
-			renderable->renderman_render(m_state);
+		if(k3d::ri::irenderable* const renderable = dynamic_cast<k3d::ri::irenderable*>(Node))
+			renderable->renderman_render(state);
 	}
 
 private:
-	const k3d::ri::render_state& m_state;
+	const k3d::ri::render_state& state;
+};
+
+class render_complete
+{
+public:
+	explicit render_complete(const k3d::ri::render_state& State) :
+		state(State)
+	{
+	}
+
+	void operator()(k3d::inode* const Node)
+	{
+		if(k3d::ri::irenderable* const renderable = dynamic_cast<k3d::ri::irenderable*>(Node))
+			renderable->renderman_render_complete(state);
+	}
+
+private:
+	const k3d::ri::render_state& state;
 };
 
 } // namespace detail
@@ -147,31 +165,32 @@ public:
 		base(Document),
 		m_resolution(init_owner(*this) + init_name("resolution") + init_label(_("Resolution")) + init_description(_("Choose a predefined image resolution")) + init_enumeration(k3d::resolution_values()) + init_value(std::string(""))),
 		m_render_engine(init_owner(*this) + init_name("render_engine") + init_label(_("Render Engine")) + init_description(_("Render Engine")) + init_value(k3d::options::default_render_engine("ri")) + init_values(render_engine_values())),
-		m_pixel_width(init_owner(*this) + init_name("pixel_width") + init_label(_("Pixel Width")) + init_description(_("Output pixel width")) + init_value(320) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_pixel_height(init_owner(*this) + init_name("pixel_height") + init_label(_("Pixel Height")) + init_description(_("Output pixel height")) + init_value(240) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_pixel_aspect_ratio(init_owner(*this) + init_name("pixel_aspect_ratio") + init_label(_("Pixel Aspect Ratio")) + init_description(_("Output pixel aspect ratio")) + init_value(1.0) + init_constraint(constraint::minimum(std::numeric_limits<double>::epsilon())) + init_precision(2) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::scalar))),
+		m_hider(init_owner(*this) + init_name("hider") + init_label(_("Hider")) + init_description(_("Hider Algorithm")) + init_value(std::string())),
+		m_pixel_width(init_owner(*this) + init_name("pixel_width") + init_label(_("Pixel Width")) + init_description(_("Output pixel width")) + init_value(320) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_pixel_height(init_owner(*this) + init_name("pixel_height") + init_label(_("Pixel Height")) + init_description(_("Output pixel height")) + init_value(240) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_pixel_aspect_ratio(init_owner(*this) + init_name("pixel_aspect_ratio") + init_label(_("Pixel Aspect Ratio")) + init_description(_("Output pixel aspect ratio")) + init_value(1.0) + init_constraint(constraint::minimum(std::numeric_limits<double>::epsilon())) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::scalar))),
 		m_default_atmosphere_shader(init_owner(*this) + init_name("default_atmosphere_shader") + init_label(_("Default Atmosphere Shader")) + init_description(_("Default atmosphere shader")) + init_value<k3d::ri::ivolume_shader*>(0)),
 		m_default_interior_shader(init_owner(*this) + init_name("default_interior_shader") + init_label(_("Default Interior Shader")) + init_description(_("Default interior shader")) + init_value<k3d::ri::ivolume_shader*>(0)),
 		m_default_exterior_shader(init_owner(*this) + init_name("default_exterior_shader") + init_label(_("Default Exterior Shader")) + init_description(_("Default exterior shader")) + init_value<k3d::ri::ivolume_shader*>(0)),
 		m_imager_shader(init_owner(*this) + init_name("imager_shader") + init_label(_("Imager Shader")) + init_description(_("Imager shader")) + init_value<k3d::ri::iimager_shader*>(0)),
-		m_bucket_width(init_owner(*this) + init_name("bucket_width") + init_label(_("Bucket Width")) + init_description(_("Bucket Width")) + init_value(16) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_bucket_height(init_owner(*this) + init_name("bucket_height") + init_label(_("Bucket Height")) + init_description(_("Bucket Height")) + init_value(16) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_grid_size(init_owner(*this) + init_name("grid_size") + init_label(_("Grid Size")) + init_description(_("Grid Size")) + init_value(256) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_eye_splits(init_owner(*this) + init_name("eye_splits") + init_label(_("Eye Splits")) + init_description(_("Eye Splits")) + init_value(10) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
-		m_texture_memory(init_owner(*this) + init_name("texture_memory") + init_label(_("Texture Memory")) + init_description(_("Texture Memory")) + init_value(1024) + init_constraint(constraint::minimum(1L)) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_bucket_width(init_owner(*this) + init_name("bucket_width") + init_label(_("Bucket Width")) + init_description(_("Bucket Width")) + init_value(16) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_bucket_height(init_owner(*this) + init_name("bucket_height") + init_label(_("Bucket Height")) + init_description(_("Bucket Height")) + init_value(16) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_grid_size(init_owner(*this) + init_name("grid_size") + init_label(_("Grid Size")) + init_description(_("Grid Size")) + init_value(256) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_eye_splits(init_owner(*this) + init_name("eye_splits") + init_label(_("Eye Splits")) + init_description(_("Eye Splits")) + init_value(10) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
+		m_texture_memory(init_owner(*this) + init_name("texture_memory") + init_label(_("Texture Memory")) + init_description(_("Texture Memory")) + init_value(1024) + init_constraint(constraint::minimum(1L)) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar))),
 		m_render_alpha(init_owner(*this) + init_name("render_alpha") + init_label(_("Render Alpha")) + init_description(_("Render Alpha")) + init_value(false)),
-		m_pixel_xsamples(init_owner(*this) + init_name("pixel_xsamples") + init_label(_("Pixel X Samples")) + init_description(_("The smaller the faster, the higher the better (anti-aliasing)")) + init_value(3.0) + init_constraint(constraint::minimum(1.0)) + init_precision(2) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
-		m_pixel_ysamples(init_owner(*this) + init_name("pixel_ysamples") + init_label(_("Pixel Y Samples")) + init_description(_("The smaller the faster, the higher the better (anti-aliasing)")) + init_value(3.0) + init_constraint(constraint::minimum(1.0)) + init_precision(2) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
+		m_pixel_xsamples(init_owner(*this) + init_name("pixel_xsamples") + init_label(_("Pixel X Samples")) + init_description(_("The smaller the faster, the higher the better (anti-aliasing)")) + init_value(3.0) + init_constraint(constraint::minimum(1.0)) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
+		m_pixel_ysamples(init_owner(*this) + init_name("pixel_ysamples") + init_label(_("Pixel Y Samples")) + init_description(_("The smaller the faster, the higher the better (anti-aliasing)")) + init_value(3.0) + init_constraint(constraint::minimum(1.0)) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
 		m_pixel_filter(init_owner(*this) + init_name("pixel_filter") + init_label(_("Pixel Filter")) + init_description(_("Anti-aliasing type")) + init_value(k3d::ri::RI_GAUSSIAN()) + init_values(pixel_filter_values())),
-		m_pixel_filter_width(init_owner(*this) + init_name("pixel_filter_width") + init_label(_("Pixel Filter Width")) + init_description(_("Filter width in X")) + init_value(2.0) + init_constraint(constraint::minimum(std::numeric_limits<double>::epsilon())) + init_precision(2) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
-		m_pixel_filter_height(init_owner(*this) + init_name("pixel_filter_height") + init_label(_("Pixel Filter Height")) + init_description(_("Filter width in Y")) + init_value(2.0) + init_constraint(constraint::minimum(std::numeric_limits<double>::epsilon())) + init_precision(2) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
-		m_exposure(init_owner(*this) + init_name("exposure") + init_label(_("Exposure")) + init_description(_("Exposure")) + init_value(1.0) + init_precision(2) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::scalar))),
-		m_gamma(init_owner(*this) + init_name("gamma") + init_label(_("Gamma")) + init_description(_("Gamma")) + init_value(1.0) + init_precision(2) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::scalar))),
+		m_pixel_filter_width(init_owner(*this) + init_name("pixel_filter_width") + init_label(_("Pixel Filter Width")) + init_description(_("Filter width in X")) + init_value(2.0) + init_constraint(constraint::minimum(std::numeric_limits<double>::epsilon())) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
+		m_pixel_filter_height(init_owner(*this) + init_name("pixel_filter_height") + init_label(_("Pixel Filter Height")) + init_description(_("Filter width in Y")) + init_value(2.0) + init_constraint(constraint::minimum(std::numeric_limits<double>::epsilon())) + init_step_increment(1.0) + init_units(typeid(k3d::measurement::scalar))),
+		m_exposure(init_owner(*this) + init_name("exposure") + init_label(_("Exposure")) + init_description(_("Exposure")) + init_value(1.0) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::scalar))),
+		m_gamma(init_owner(*this) + init_name("gamma") + init_label(_("Gamma")) + init_description(_("Gamma")) + init_value(1.0) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::scalar))),
 		m_dof(init_owner(*this) + init_name("dof") + init_label(_("DOF")) + init_description(_("Depth of Field")) + init_value(false)),
-		m_fstop(init_owner(*this) + init_name("fstop") + init_label(_("f-Stop")) + init_description(_("f-Stop")) + init_value(0.3) + init_precision(2) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::scalar))),
-		m_focal_length(init_owner(*this) + init_name("focal_length") + init_label(_("Focal Length")) + init_description(_("Focal Length")) + init_value(1.6) + init_precision(2) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::distance))),
-		m_focus_plane(init_owner(*this) + init_name("focus_plane") + init_label(_("Focus Plane")) + init_description(_("Focus Plane")) + init_value(30.0) + init_precision(2) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::distance))),
-		m_shading_rate(init_owner(*this) + init_name("shading_rate") + init_label(_("Shading Rate")) + init_description(_("Shading Rate")) + init_value(1.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::scalar))),
+		m_fstop(init_owner(*this) + init_name("fstop") + init_label(_("f-Stop")) + init_description(_("f-Stop")) + init_value(0.3) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::scalar))),
+		m_focal_length(init_owner(*this) + init_name("focal_length") + init_label(_("Focal Length")) + init_description(_("Focal Length")) + init_value(1.6) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::distance))),
+		m_focus_plane(init_owner(*this) + init_name("focus_plane") + init_label(_("Focus Plane")) + init_description(_("Focus Plane")) + init_value(30.0) + init_step_increment(0.01) + init_units(typeid(k3d::measurement::distance))),
+		m_shading_rate(init_owner(*this) + init_name("shading_rate") + init_label(_("Shading Rate")) + init_description(_("Shading Rate")) + init_value(1.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::scalar))),
 		m_shading_interpolation(init_owner(*this) + init_name("shading_interpolation") + init_label(_("Shading Interpolation")) + init_description(_("Shading Interpolation")) + init_value(k3d::ri::RI_CONSTANT()) + init_values(shading_interpolation_values())),
 		m_two_sided(init_owner(*this) + init_name("two_sided") + init_label(_("Two-Sided")) + init_description(_("Two Sided")) + init_value(true)),
 		m_motion_blur(init_owner(*this) + init_name("motion_blur") + init_label(_("Motion Blur")) + init_description(_("Motion Blur")) + init_value(false)),
@@ -180,6 +199,7 @@ public:
 		k3d::iproperty_group_collection::group output_group("Output");
 		output_group.properties.push_back(&static_cast<k3d::iproperty&>(m_resolution));
 		output_group.properties.push_back(&static_cast<k3d::iproperty&>(m_render_engine));
+		output_group.properties.push_back(&static_cast<k3d::iproperty&>(m_hider));
 		output_group.properties.push_back(&static_cast<k3d::iproperty&>(m_pixel_width));
 		output_group.properties.push_back(&static_cast<k3d::iproperty&>(m_pixel_height));
 		output_group.properties.push_back(&static_cast<k3d::iproperty&>(m_pixel_aspect_ratio));
@@ -238,9 +258,6 @@ public:
 
 	bool render_camera_preview(k3d::icamera& Camera)
 	{
-		// Keep track of compiled shaders ...
-		k3d::ri::render_engine::shaders_t shaders;
-
 		// Start a new render job ...
 		k3d::irender_job& job = k3d::render_farm().create_job("k3d-preview");
 
@@ -248,26 +265,29 @@ public:
 		k3d::irender_frame& frame = job.create_frame("frame");
 
 		// Create an output image path ...
-		const boost::filesystem::path outputimagepath = frame.add_output_file("outputimage");
+		const k3d::filesystem::path outputimagepath = frame.add_output_file("outputimage");
 		return_val_if_fail(!outputimagepath.empty(), false);
 
-		// Render it (visible rendering) ...
+		// Keep track of shaders used during the preview ...
+		k3d::ri::shader_collection shaders;
+
+		// Create the preview (visible rendering) ...
 		return_val_if_fail(render(Camera, frame, outputimagepath, true, shaders), false);
 
+		// Ensure shaders are up-to-date ...
+		synchronize_shaders(shaders);
+
 		// Start the job running ...
 		k3d::render_farm().start_job(job);
 
 		return true;
 	}
 
-	bool render_camera_frame(k3d::icamera& Camera, const boost::filesystem::path& OutputImage, const bool ViewImage)
+	bool render_camera_frame(k3d::icamera& Camera, const k3d::filesystem::path& OutputImage, const bool ViewImage)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!OutputImage.empty(), false);
 
-		// Keep track of compiled shaders ...
-		k3d::ri::render_engine::shaders_t shaders;
-
 		// Start a new render job ...
 		k3d::irender_job& job = k3d::render_farm().create_job("k3d-render-frame");
 
@@ -275,7 +295,7 @@ public:
 		k3d::irender_frame& frame = job.create_frame("frame");
 
 		// Create an output image path ...
-		const boost::filesystem::path outputimagepath = frame.add_output_file("outputimage");
+		const k3d::filesystem::path outputimagepath = frame.add_output_file("outputimage");
 		return_val_if_fail(!outputimagepath.empty(), false);
 
 		// Copy the output image to its requested destination ...
@@ -285,20 +305,23 @@ public:
 		if(ViewImage)
 			frame.add_view_operation(OutputImage);
 
-		// Render it (hidden rendering) ...
+		// Keep track of shaders used during the render ...
+		k3d::ri::shader_collection shaders;
+
+		// Create the render (hidden rendering) ...
 		return_val_if_fail(render(Camera, frame, outputimagepath, false, shaders), false);
 
+		// Ensure shaders are up-to-date ...
+		synchronize_shaders(shaders);
+
 		// Start the job running ...
 		k3d::render_farm().start_job(job);
 
 		return true;
 	}
 
-	bool render_camera_animation(k3d::icamera& Camera, const boost::filesystem::path& OutputImages, const bool ViewCompletedImages)
+	bool render_camera_animation(k3d::icamera& Camera, const k3d::file_range& Files, const bool ViewCompletedImages)
 	{
-		// Sanity checks ...
-		return_val_if_fail(!OutputImages.empty(), false);
-
 		// Ensure that the document has animation capabilities, first ...
 		k3d::iproperty* const start_time_property = k3d::get_start_time(document());
 		k3d::iproperty* const end_time_property = k3d::get_end_time(document());
@@ -311,20 +334,19 @@ public:
 		const double end_time = boost::any_cast<double>(k3d::get_value(document().dag(), *end_time_property));
 		const double frame_rate = boost::any_cast<double>(k3d::get_value(document().dag(), *frame_rate_property));
 
-		const long start_frame = static_cast<long>(k3d::round(frame_rate * start_time));
-		const long end_frame = static_cast<long>(k3d::round(frame_rate * end_time));
+		const size_t start_frame = static_cast<size_t>(k3d::round(frame_rate * start_time));
+		const size_t end_frame = static_cast<size_t>(k3d::round(frame_rate * end_time));
 
-		k3d::frames frames(OutputImages, start_frame, end_frame);
-		return_val_if_fail(frames.max_frame() >= end_frame, false);
-
-		// Keep track of compiled shaders ...
-		k3d::ri::render_engine::shaders_t shaders;
+		return_val_if_fail(Files.max_file_count() > end_frame, false);
 
 		// Start a new render job ...
 		k3d::irender_job& job = k3d::render_farm().create_job("k3d-render-animation");
 
+		// Keep track of shaders used over the course of the animation ...
+		k3d::ri::shader_collection shaders;
+
 		// For each frame to be rendered ...
-		for(long view_frame = start_frame; view_frame < end_frame; ++view_frame)
+		for(size_t view_frame = start_frame; view_frame < end_frame; ++view_frame)
 		{
 			// Set the frame time ...
 			time_property->property_set_value(view_frame / frame_rate);
@@ -334,16 +356,15 @@ public:
 
 			// Add a render frame to the job ...
 			std::stringstream buffer;
-			buffer << "frame-" << std::setw(frames.frame_digits()) << std::setfill('0') << view_frame;
+			buffer << "frame-" << std::setw(Files.digits) << std::setfill('0') << view_frame;
 			k3d::irender_frame& frame = job.create_frame(buffer.str());
 
 			// Create an output image path ...
-			const boost::filesystem::path outputimagepath = frame.add_output_file("outputimage");
+			const k3d::filesystem::path outputimagepath = frame.add_output_file("outputimage");
 			return_val_if_fail(!outputimagepath.empty(), false);
 
 			// Copy the output image to its requested destination ...
-			boost::filesystem::path destination;
-			frames.frame(view_frame, destination);
+			const k3d::filesystem::path destination = Files.file(view_frame);
 			frame.add_copy_operation(outputimagepath, destination);
 
 			// View the output image when it's done ...
@@ -354,6 +375,9 @@ public:
 			return_val_if_fail(render(Camera, frame, outputimagepath, false, shaders), false);
 		}
 
+		// Ensure shaders are up-to-date ...
+		synchronize_shaders(shaders);
+
 		// Start the job running ...
 		k3d::render_farm().start_job(job);
 
@@ -382,7 +406,7 @@ public:
 	}
 
 private:
-	bool render(k3d::icamera& Camera, k3d::irender_frame& Frame, const boost::filesystem::path& OutputImagePath, const bool VisibleRender, k3d::ri::render_engine::shaders_t& Shaders)
+	bool render(k3d::icamera& Camera, k3d::irender_frame& Frame, const k3d::filesystem::path& OutputImagePath, const bool VisibleRender, k3d::ri::shader_collection& Shaders)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!OutputImagePath.empty(), false);
@@ -398,7 +422,7 @@ private:
 
 		// Start our RIB file ...
 		const std::string ribfilename("world.rib");
-		const boost::filesystem::path ribfilepath = Frame.add_input_file(ribfilename);
+		const k3d::filesystem::path ribfilepath = Frame.add_input_file(ribfilename);
 		return_val_if_fail(!ribfilepath.empty(), false);
 
 		// Open the RIB file stream ...
@@ -406,7 +430,7 @@ private:
 		return_val_if_fail(ribfile.good(), false);
 
 		// Setup the frame for RI rendering with the user's preferred engine ...
-		Frame.add_render_operation("ri", m_render_engine.value(), boost::filesystem::path(ribfilename, boost::filesystem::native), VisibleRender);
+		Frame.add_render_operation("ri", m_render_engine.value(), k3d::filesystem::native_path(k3d::ustring::from_utf8(ribfilename)), VisibleRender);
 
 		// Create the Ri render engine object ...
 		k3d::ri::render_engine engine(ribfile);
@@ -424,16 +448,20 @@ private:
 			k3d::ri::parameter(
 				"shader",
 				k3d::ri::UNIFORM,
-				k3d::ri::string(k3d::shader_cache_path().native_file_string() + ":&")));
+				k3d::ri::string(k3d::shader_cache_path().native_filesystem_string() + ":&")));
 		engine.RiOptionV("searchpath", searchpath_options);
 
 		// Perform frame-start operations for textures
-		std::for_each(document().nodes().collection().begin(), document().nodes().collection().end(), detail::setup_texture(Frame, engine));
+		std::for_each(document().nodes().collection().begin(), document().nodes().collection().end(), detail::setup_texture(Frame, engine, Shaders));
 
 		// Start the (final output) frame ...
 		engine.RiNewline();
 		engine.RiFrameBegin(1);
 
+        const std::string hider = m_hider.value();
+        if(!hider.empty())
+            engine.RiHiderV(hider);
+
 		// Set limits options
 		engine.RiNewline();
 		engine.RiComment("Setup options");
@@ -458,16 +486,16 @@ private:
 		engine.RiNewline();
 		engine.RiComment("Setup Display");
 
-		boost::filesystem::path outputimage(OutputImagePath);
+		k3d::filesystem::path outputimage(OutputImagePath);
 
 		if(VisibleRender)
-			engine.RiDisplayV(outputimage.leaf(), k3d::ri::RI_FRAMEBUFFER(), k3d::ri::RI_RGB());
+			engine.RiDisplayV(outputimage.leaf().raw(), k3d::ri::RI_FRAMEBUFFER(), k3d::ri::RI_RGB());
 		else
 		{
 			if(m_render_alpha.value())
-				engine.RiDisplayV(outputimage.leaf(), k3d::ri::RI_FILE(), k3d::ri::RI_RGBA());
+				engine.RiDisplayV(outputimage.leaf().raw(), k3d::ri::RI_FILE(), k3d::ri::RI_RGBA());
 			else
-				engine.RiDisplayV(outputimage.leaf(), k3d::ri::RI_FILE(), k3d::ri::RI_RGB());
+				engine.RiDisplayV(outputimage.leaf().raw(), k3d::ri::RI_FILE(), k3d::ri::RI_RGB());
 		}
 
 		const k3d::ri::unsigned_integer pixel_width = m_pixel_width.value();
@@ -509,7 +537,7 @@ private:
 		const double crop_bottom = boost::any_cast<double>(get_value(document().dag(), Camera.crop_window().crop_bottom()));
 
 		if(crop_left >= crop_right || crop_top >= crop_bottom)
-			k3d::user_interface().message("Current crop window settings will produce an empty image", "RenderMan:");
+			k3d::user_interface().message("Current crop window settings will produce an empty image");
 
 		engine.RiCropWindow(crop_left, crop_right, crop_top, crop_bottom);
 
@@ -538,7 +566,7 @@ private:
 			motion_blur_camera_orientation_samples.push_back(orientation);
 
 			// Setup render state ...
-			k3d::ri::render_state state(Frame, engine, Camera.projection(), k3d::ri::FINAL_FRAME, samples, sample_index, transform_matrix);
+			k3d::ri::render_state state(Frame, engine, Shaders, Camera.projection(), k3d::ri::FINAL_FRAME, samples, sample_index, transform_matrix);
 
 			if(k3d::ri::last_sample(state))
 			{
@@ -658,6 +686,9 @@ private:
 			// Render objects ...
 			std::for_each(document().nodes().collection().begin(), document().nodes().collection().end(), detail::render(state));
 
+			// Give nodes a chance to cleanup ...
+			std::for_each(document().nodes().collection().begin(), document().nodes().collection().end(), detail::render_complete(state));
+
 			if(k3d::ri::last_sample(state))
 			{
 				// Finish the world ...
@@ -671,27 +702,24 @@ private:
 		// Reset the time back to the beginning of the frame ...
 		writable_time_property->property_set_value(frame_time);
 
-		// Synchronize shaders ...
-		const k3d::ri::render_engine::shaders_t shaders = engine.shaders();
-		for(k3d::ri::render_engine::shaders_t::const_iterator shader = shaders.begin(); shader != shaders.end(); ++shader)
-		{
-			// If this shader has already been synchronized, we're done ...
-			if(Shaders.count(*shader))
-				continue;
+		return true;
+	}
 
+	void synchronize_shaders(const k3d::ri::shader_collection& Shaders)
+	{
+		// For each shader in the collection ...
+		const k3d::ri::shader_collection::shaders_t& shaders = Shaders.shaders();
+		for(k3d::ri::shader_collection::shaders_t::const_iterator shader = shaders.begin(); shader != shaders.end(); ++shader)
+		{
 			// Compile that bad-boy!
 			if(!k3d::compile_shader(*shader, "ri", m_render_engine.value()))
-				k3d::log() << error << k3d::string_cast(boost::format(_("Error compiling shader %1%")) % shader->native_file_string()) << std::endl;
-
-			// Keep track of this shader ...
-			Shaders.insert(*shader);
+				k3d::log() << error << k3d::string_cast(boost::format(_("Error compiling shader %1%")) % shader->native_utf8_string().raw()) << std::endl;
 		}
-
-		return true;
 	}
 
 	k3d_data(std::string, immutable_name, change_signal, with_undo, local_storage, no_constraint, enumeration_property, with_serialization) m_resolution;
 	k3d_data(std::string, immutable_name, change_signal, with_undo, local_storage, no_constraint, list_property, with_serialization) m_render_engine;
+	k3d_data(std::string, immutable_name, change_signal, with_undo, local_storage, no_constraint, writable_property, with_serialization) m_hider;
 	k3d_data(long, immutable_name, change_signal, with_undo, local_storage, with_constraint, measurement_property, with_serialization) m_pixel_width;
 	k3d_data(long, immutable_name, change_signal, with_undo, local_storage, with_constraint, measurement_property, with_serialization) m_pixel_height;
 	k3d_data(double, immutable_name, change_signal, with_undo, local_storage, with_constraint, measurement_property, with_serialization) m_pixel_aspect_ratio;
