@@ -48,25 +48,24 @@ public:
 	{
 		set_script(DEFAULT_SCRIPT);
 
-		m_input.changed_signal().connect(m_output.make_reset_slot());
-		connect_script_changed_signal(m_output.make_reset_slot());
+		connect_script_changed_signal(make_reset_bitmap_slot());
 	}
 
-	void on_create_bitmap(k3d::bitmap& Bitmap)
+	void on_create_bitmap(const k3d::bitmap& Input, k3d::bitmap& Output)
 	{
-		k3d::bitmap* const input_bitmap = m_input.value();
-		if(!input_bitmap)
-			return;
-
 		k3d::iscript_engine::context_t context;
 		context["Document"] = static_cast<k3d::iunknown*>(&document());
 		context["Node"] = static_cast<k3d::iunknown*>(this);
-		context["Input"] = input_bitmap;
-		context["Output"] = &Bitmap;
+		context["Input"] = &Input;
+		context["Output"] = &Output;
 
 		execute_script(context);
 	}
 
+	void on_update_bitmap(const k3d::bitmap& Input, k3d::bitmap& Output)
+	{
+	}
+
 	k3d::iplugin_factory& factory()
 	{
 		return get_factory();
