@@ -46,12 +46,12 @@ class select_cube :
 	public:
 	select_cube(k3d::idocument& Document) :
 		base(Document),
-		m_x1(init_owner(*this) + init_name("x1") + init_label(_("X1")) + init_description(_("X coordinate of cube's min corner")) + init_value(-10.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
-		m_y1(init_owner(*this) + init_name("y1") + init_label(_("Y1")) + init_description(_("Y coordinate of cube's min corner")) + init_value(-10.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
-		m_z1(init_owner(*this) + init_name("z1") + init_label(_("Z1")) + init_description(_("Z coordinate of cube's min corner")) + init_value(-10.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
-		m_x2(init_owner(*this) + init_name("x2") + init_label(_("X2")) + init_description(_("X coordinate of cube's max corner")) + init_value(10.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
-		m_y2(init_owner(*this) + init_name("y2") + init_label(_("Y2")) + init_description(_("Y coordinate of cube's max corner")) + init_value(10.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
-		m_z2(init_owner(*this) + init_name("z2") + init_label(_("Z2")) + init_description(_("Z coordinate of cube's max corner")) + init_value(10.0) + init_precision(2) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance)))
+		m_x1(init_owner(*this) + init_name("x1") + init_label(_("X1")) + init_description(_("X coordinate of cube's min corner")) + init_value(-10.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
+		m_y1(init_owner(*this) + init_name("y1") + init_label(_("Y1")) + init_description(_("Y coordinate of cube's min corner")) + init_value(-10.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
+		m_z1(init_owner(*this) + init_name("z1") + init_label(_("Z1")) + init_description(_("Z coordinate of cube's min corner")) + init_value(-10.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
+		m_x2(init_owner(*this) + init_name("x2") + init_label(_("X2")) + init_description(_("X coordinate of cube's max corner")) + init_value(10.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
+		m_y2(init_owner(*this) + init_name("y2") + init_label(_("Y2")) + init_description(_("Y coordinate of cube's max corner")) + init_value(10.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance))),
+		m_z2(init_owner(*this) + init_name("z2") + init_label(_("Z2")) + init_description(_("Z coordinate of cube's max corner")) + init_value(10.0) + init_step_increment(0.1) + init_units(typeid(k3d::measurement::distance)))
 	{
 		m_x1.changed_signal().connect(make_update_mesh_slot());
 		m_y1.changed_signal().connect(make_update_mesh_slot());
