@@ -1,5 +1,5 @@
 // K-3D
-// Copyright (c) 1995-2004, Timothy M. Shead
+// Copyright (c) 1995-2006, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -22,16 +22,15 @@
 		\author Timothy M. Shead
 */
 
+#include <k3dsdk/classes.h>
 #include <k3dsdk/i18n.h>
 #include <k3dsdk/ibitmap_write_format.h>
 #include <k3dsdk/ideletable.h>
 #include <k3dsdk/ifile_format.h>
-#include <k3dsdk/classes.h>
 #include <k3dsdk/module.h>
+#include <k3dsdk/path.h>
 #include <k3dsdk/string_modifiers.h>
 
-#include <boost/filesystem/path.hpp>
-
 #include <tiffio.h>
 
 namespace libk3dtiff
@@ -55,19 +54,17 @@ public:
 		return 128;
 	}
 
-	bool query_can_handle(const boost::filesystem::path& File)
+	bool query_can_handle(const k3d::filesystem::path& File)
 	{
-		return_val_if_fail(!File.empty(), false);
-		return "tiff" == k3d::file_extension(File) ||
-			"tif" == k3d::file_extension(File);
+		return k3d::filesystem::extension(File).lowercase().raw() == ".tiff" || k3d::filesystem::extension(File).lowercase().raw() == ".tif";
 	}
 
-	bool write_file(const boost::filesystem::path& File, const k3d::bitmap& Bitmap)
+	bool write_file(const k3d::filesystem::path& File, const k3d::bitmap& Bitmap)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!File.empty(), false);
 
-		k3d::log() << info << "Write " << File.native_file_string() << " using TIFFWriter" << std::endl;
+		k3d::log() << info << "Write " << File.native_console_string() << " using TIFFWriter" << std::endl;
 
 		// Convert the input bitmap to 8-bit-integer samples (would prefer to store images as floating-point, but we have to establish the lowest common denominator of what various render engines will read)
 		typedef k3d::basic_rgba<boost::uint8_t> integer_pixel_t;
@@ -79,12 +76,12 @@ public:
 		const k3d::pixel_size_t width = bitmap.width();
 		const k3d::pixel_size_t height = bitmap.height();
 
-		TIFF* const file = TIFFOpen(File.native_file_string().c_str(), "w");
+		TIFF* const file = TIFFOpen(File.native_filesystem_string().c_str(), "w");
 		if(!file)
-			{
-				k3d::log() << error << "Error opening [" << File.native_file_string() << "] for TIFF output" << std::endl;
-				return false;
-			}
+		{
+			k3d::log() << error << "Error opening [" << File.native_console_string() << "] for TIFF output" << std::endl;
+			return false;
+		}
 
 		TIFFSetField(file, TIFFTAG_IMAGEWIDTH, width);
 		TIFFSetField(file, TIFFTAG_IMAGELENGTH, height);
@@ -97,20 +94,20 @@ public:
 		TIFFSetField(file, TIFFTAG_IMAGEDESCRIPTION, "Created with K-3D, http://www.k-3d.org");
 
 		for(k3d::pixel_size_t row = 0; row != height; ++row)
+		{
+			if(TIFFWriteScanline(file, const_cast<integer_pixel_t*>(data), row, 0) < 0)
 			{
-				if(TIFFWriteScanline(file, const_cast<integer_pixel_t*>(data), row, 0) < 0)
-					{
-						TIFFClose(file);
-						k3d::log() << error << "Error writing data to [" << File.native_file_string() << "] for TIFF output" << std::endl;
-						return false;
-					}
-				data += width;
+				TIFFClose(file);
+				k3d::log() << error << "Error writing data to [" << File.native_console_string() << "] for TIFF output" << std::endl;
+				return false;
 			}
-		
+
+			data += width;
+		}
+
 		TIFFClose(file);
 
 		return true;
-
 	}
 
 	k3d::iplugin_factory& factory()
@@ -123,16 +120,13 @@ public:
 		static k3d::plugin_factory<
 			k3d::application_plugin<tiff_writer>,
 			k3d::interface_list<k3d::ibitmap_write_format> > factory(
-			k3d::classes::TIFFWriter(),
-			"TIFFWriter",
-			_("TIFF (*.tiff)"),
-			"Bitmap BitmapWriter");
+				k3d::classes::TIFFWriter(),
+				"TIFFWriter",
+				_("TIFF (*.tiff)"),
+				"Bitmap BitmapWriter");
 
 		return factory;
 	}
-
-private:
-
 };
 
 /////////////////////////////////////////////////////////////////////////////
@@ -145,4 +139,3 @@ k3d::iplugin_factory& tiff_writer_factory()
 
 } // namespace libk3dtiff
 
-
