@@ -23,6 +23,7 @@
 */
 
 #include <k3dsdk/module.h>
+#include <k3dsdk/types.h>
 
 /// Namespace reserved for the yafray plugin module, to protect public symbols from name clashes with other modules
 namespace libk3dyafray
@@ -56,9 +57,5 @@ K3D_MODULE_START(libk3dyafray, k3d::uuid(0xeb84cce7, 0x9a4a42b2, 0xb813f65e, 0x6
 	Registry.register_factory(libk3dyafray::soft_light_factory());
 	Registry.register_factory(libk3dyafray::spot_light_factory());
 	Registry.register_factory(libk3dyafray::sun_light_factory());
-#ifndef K3D_PLATFORM_WIN32
-	Registry.register_factory(libk3dyafray::yafray_reader_factory());
-#endif // !K3D_PLATFORM_WIN32
 K3D_MODULE_END
 
-
