@@ -26,7 +26,7 @@
 
 #include <k3dsdk/algebra.h>
 #include <k3dsdk/classes.h>
-#include <k3dsdk/frames.h>
+#include <k3dsdk/file_range.h>
 #include <k3dsdk/fstream.h>
 #include <k3dsdk/gl.h>
 #include <k3dsdk/i18n.h>
@@ -53,8 +53,6 @@
 #include <k3dsdk/time_source.h>
 #include <k3dsdk/transform.h>
 
-#include <boost/filesystem/path.hpp>
-
 #include <iomanip>
 #include <iterator>
 #include <map>
@@ -77,13 +75,13 @@ public:
 	render_engine(k3d::idocument& Document) :
 		base(Document),
 		m_resolution(init_owner(*this) + init_name("resolution") + init_label(_("Resolution")) + init_description(_("Choose a predefined image resolution")) + init_enumeration(k3d::resolution_values()) + init_value(std::string(""))),
-		m_pixel_width(init_owner(*this) + init_name("pixel_width") + init_label(_("pixel_width")) + init_description(_("Output pixel width")) + init_value(320) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(1L))),
-		m_pixel_height(init_owner(*this) + init_name("pixel_height") + init_label(_("pixel_height")) + init_description(_("Output pixel height")) + init_value(240) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(1L))),
-		m_AA_passes(init_owner(*this) + init_name("AA_passes") + init_label(_("AA_passes")) + init_description(_("AA passes")) + init_value(3) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
-		m_AA_minsamples(init_owner(*this) + init_name("AA_minsamples") + init_label(_("AA_minsamples")) + init_description(_("AA min samples")) + init_value(2) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
+		m_pixel_width(init_owner(*this) + init_name("pixel_width") + init_label(_("pixel_width")) + init_description(_("Output pixel width")) + init_value(320) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(1L))),
+		m_pixel_height(init_owner(*this) + init_name("pixel_height") + init_label(_("pixel_height")) + init_description(_("Output pixel height")) + init_value(240) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(1L))),
+		m_AA_passes(init_owner(*this) + init_name("AA_passes") + init_label(_("AA_passes")) + init_description(_("AA passes")) + init_value(3) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
+		m_AA_minsamples(init_owner(*this) + init_name("AA_minsamples") + init_label(_("AA_minsamples")) + init_description(_("AA min samples")) + init_value(2) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
 		m_AA_pixelwidth(init_owner(*this) + init_name("AA_pixelwidth") + init_label(_("AA_pixelwidth")) + init_description(_("AA pixelwidth")) + init_value(1.5)),
 		m_AA_threshold(init_owner(*this) + init_name("AA_threshold") + init_label(_("AA_threshold")) + init_description(_("AA threshold")) + init_value(0.05)),
-		m_raydepth(init_owner(*this) + init_name("raydepth") + init_label(_("raydepth")) + init_description(_("raydepth")) + init_value(3) + init_precision(0) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
+		m_raydepth(init_owner(*this) + init_name("raydepth") + init_label(_("raydepth")) + init_description(_("raydepth")) + init_value(3) + init_step_increment(1) + init_units(typeid(k3d::measurement::scalar)) + init_constraint(constraint::minimum(0L))),
 		m_bias(init_owner(*this) + init_name("bias") + init_label(_("bias")) + init_description(_("bias")) + init_value(0.1)),
 		m_save_alpha(init_owner(*this) + init_name("save_alpha") + init_label(_("save_alpha")) + init_description(_("Save alpha")) + init_value(false)),
 		m_exposure(init_owner(*this) + init_name("exposure") + init_label(_("exposure")) + init_description(_("exposure")) + init_value(0.0)),
@@ -122,7 +120,7 @@ public:
 		k3d::irender_frame& frame = job.create_frame("frame");
 
 		// Create an output image path ...
-		const boost::filesystem::path outputimagepath = frame.add_output_file("salida.tga");
+		const k3d::filesystem::path outputimagepath = frame.add_output_file("salida.tga");
 		return_val_if_fail(!outputimagepath.empty(), false);
 
 		// View the output image when it's done ...
@@ -137,7 +135,7 @@ public:
 		return true;
 	}
 
-	bool render_camera_frame(k3d::icamera& Camera, const boost::filesystem::path& OutputImage, const bool ViewImage)
+	bool render_camera_frame(k3d::icamera& Camera, const k3d::filesystem::path& OutputImage, const bool ViewImage)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!OutputImage.empty(), false);
@@ -149,7 +147,7 @@ public:
 		k3d::irender_frame& frame = job.create_frame("frame");
 
 		// Create an output image path ...
-		const boost::filesystem::path outputimagepath = frame.add_output_file("salida.tga");
+		const k3d::filesystem::path outputimagepath = frame.add_output_file("salida.tga");
 		return_val_if_fail(!outputimagepath.empty(), false);
 
 		// Copy the output image to its requested destination ...
@@ -168,11 +166,8 @@ public:
 		return true;
 	}
 
-	bool render_camera_animation(k3d::icamera& Camera, const boost::filesystem::path& OutputImages, const bool ViewCompletedImages)
+	bool render_camera_animation(k3d::icamera& Camera, const k3d::file_range& Files, const bool ViewCompletedImages)
 	{
-		// Sanity checks ...
-		return_val_if_fail(!OutputImages.empty(), false);
-
 		// Ensure that the document has animation capabilities, first ...
 		k3d::iproperty* const start_time_property = k3d::get_start_time(document());
 		k3d::iproperty* const end_time_property = k3d::get_end_time(document());
@@ -185,17 +180,16 @@ public:
 		const double end_time = boost::any_cast<double>(k3d::get_value(document().dag(), *end_time_property));
 		const double frame_rate = boost::any_cast<double>(k3d::get_value(document().dag(), *frame_rate_property));
 
-		const long start_frame = static_cast<long>(k3d::round(frame_rate * start_time));
-		const long end_frame = static_cast<long>(k3d::round(frame_rate * end_time));
+		const size_t start_frame = static_cast<size_t>(k3d::round(frame_rate * start_time));
+		const size_t end_frame = static_cast<size_t>(k3d::round(frame_rate * end_time));
 
-		k3d::frames frames(OutputImages, start_frame, end_frame);
-		return_val_if_fail(frames.max_frame() >= end_frame, false);
+		return_val_if_fail(Files.max_file_count() > end_frame, false);
 
 		// Start a new render job ...
 		k3d::irender_job& job = k3d::render_farm().create_job("k3d-render-animation");
 
 		// For each frame to be rendered ...
-		for(long view_frame = start_frame; view_frame < end_frame; ++view_frame)
+		for(size_t view_frame = start_frame; view_frame < end_frame; ++view_frame)
 		{
 			// Set the frame time ...
 			time_property->property_set_value(view_frame / frame_rate);
@@ -205,16 +199,15 @@ public:
 
 			// Add a render frame to the job ...
 			std::stringstream buffer;
-			buffer << "frame-" << std::setw(frames.frame_digits()) << std::setfill('0') << view_frame;
+			buffer << "frame-" << std::setw(Files.digits) << std::setfill('0') << view_frame;
 			k3d::irender_frame& frame = job.create_frame(buffer.str());
 
 			// Create an output image path ...
-			const boost::filesystem::path outputimagepath = frame.add_output_file("salida.tga");
+			const k3d::filesystem::path outputimagepath = frame.add_output_file("salida.tga");
 			return_val_if_fail(!outputimagepath.empty(), false);
 
 			// Copy the output image to its requested destination ...
-			boost::filesystem::path destination;
-			frames.frame(view_frame, destination);
+			const k3d::filesystem::path destination = Files.file(view_frame);
 			frame.add_copy_operation(outputimagepath, destination);
 
 			// View the output image when it's done ...
@@ -278,13 +271,13 @@ private:
 		return "default_shader";
 	}
 
-	bool render(k3d::icamera& Camera, k3d::irender_frame& Frame, const boost::filesystem::path& OutputImagePath, const bool VisibleRender)
+	bool render(k3d::icamera& Camera, k3d::irender_frame& Frame, const k3d::filesystem::path& OutputImagePath, const bool VisibleRender)
 	{
 		// Sanity checks ...
 		return_val_if_fail(!OutputImagePath.empty(), false);
 
 		// Start our YafRay XML file ...
-		const boost::filesystem::path filepath = Frame.add_input_file("world.xml");
+		const k3d::filesystem::path filepath = Frame.add_input_file("world.xml");
 		return_val_if_fail(!filepath.empty(), false);
 
 		// Open the RIB file stream ...
@@ -407,8 +400,6 @@ private:
 				for(k3d::mesh::polyhedra_t::const_iterator polyhedron = out_mesh.polyhedra.begin(); polyhedron != out_mesh.polyhedra.end(); ++polyhedron)
 					k3d::triangulate((*polyhedron)->faces, new_faces, new_points);
 
-				k3d::log() << debug << new_faces.size() << std::endl;
-
 				typedef std::multimap<k3d::imaterial*, k3d::face*> sorted_faces_t;
 				sorted_faces_t sorted_faces;
 				for(k3d::polyhedron::faces_t::iterator face = new_faces.begin(); face != new_faces.end(); ++face)
@@ -564,7 +555,7 @@ private:
 		const k3d::color fog_color = m_fog_color.value();
 
 		stream << "<render camera_name=\"camera\" AA_passes=\"" << m_AA_passes.value() << "\"" << " AA_minsamples=\"" << m_AA_minsamples.value() << "\" AA_pixelwidth=\"" << m_AA_pixelwidth.value() << "\" AA_threshold=\"" << m_AA_threshold.value() << "\" raydepth=\"" << m_raydepth.value() << "\" bias=\"" << m_bias.value() << "\">" << std::endl;
-		stream << "	<outfile value=\"" << OutputImagePath.native_file_string() << "\"/>" << std::endl;
+		stream << "	<outfile value=\"" << OutputImagePath.native_filesystem_string() << "\"/>" << std::endl;
 		stream << "	<save_alpha value=\"" << (m_save_alpha.value() ? "on" : "off") << "\"/>" << std::endl;
 		stream << "	<exposure value=\"" << m_exposure.value() << "\"/>" << std::endl;
 		stream << "	<gamma value=\"" << m_gamma.value() << "\"/>" << std::endl;
