@@ -28,6 +28,7 @@
 #include "widget_manip.h"
 
 #include <k3dsdk/i18n.h>
+#include <k3dsdk/path.h>
 #include <k3dsdk/version.h>
 
 #include <gtkmm/box.h>
@@ -37,8 +38,6 @@
 #include <gtkmm/label.h>
 #include <gtkmm/stock.h>
 
-#include <boost/filesystem/path.hpp>
-
 namespace libk3dngui
 {
 
@@ -66,9 +65,9 @@ public:
 
 		Gtk::VBox* const box1 = new Gtk::VBox(false, 10);
 		box1->set_border_width(10);
-		box1->pack_start(*Gtk::manage(new Gtk::Image(load_pixbuf("about.xpm"))), Gtk::PACK_EXPAND_WIDGET);
+		box1->pack_start(*Gtk::manage(new Gtk::Image(load_pixbuf(k3d::filesystem::native_path(k3d::ustring::from_utf8("about.xpm"))))), Gtk::PACK_EXPAND_WIDGET);
 		box1->pack_start(*Gtk::manage(new Gtk::Label() << line_wrap() << center_justify() << set_markup("<big><b>K-3D Version " K3D_VERSION "</b></big>")));
-		box1->pack_start(*Gtk::manage(new Gtk::Label("Copyright (c) 1995-2006, Timothy M. Shead.") << line_wrap() << center_justify()));
+		box1->pack_start(*Gtk::manage(new Gtk::Label(K3D_COPYRIGHT) << line_wrap() << center_justify()));
 		box1->pack_start(*Gtk::manage(new Gtk::Label("Portions copyright (c) 2002, Industrial Light & Magic, a division of Lucas Digital Ltd. LLC") << line_wrap() << center_justify()));
 		box1->pack_start(*Gtk::manage(new Gtk::Label("See the AUTHORS file for contributors.") << line_wrap() << center_justify()));
 		box1->pack_start(*Gtk::manage(new Gtk::Label("This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License.  See the COPYING file for details.") << line_wrap() << center_justify()));
