@@ -46,13 +46,20 @@ public:
 	/// Attempts to safely close the application, saving unsaved documents and giving the user a chance to cancel.  Returns true iff the application will close.
 	bool safe_close(Gtk::Window& Parent);
 
-	/// Set to true when batch (no user intervention) mode is enabled for the UI
-	bool& batch_mode();
+	/// Enables / disables batch (no user intervention) mode
+	void enable_batch_mode(const bool Enabled = true);
+	/// Returns true if batch (no user intervention) mode is enabled
+	const bool batch_mode();
 
-	/// Defines storage for the current global assign hotkeys mode
-	typedef k3d_data(bool, immutable_name, change_signal, no_undo, local_storage, no_constraint, no_property, no_serialization) assign_hotkeys_t;
-	/// Set to true while dynamic hotkey assignment is enabled
-	assign_hotkeys_t& assign_hotkeys();
+	/// Enables / disables use of user-customized UI layouts
+	void enable_custom_layouts(const bool Enabled = true);
+	/// Returns true if user-customized UI layouts are enabled
+	const bool custom_layouts();
+
+	/// Enables / disables interactive hotkey assignment
+	void enable_hotkey_assignment(const bool Enabled = true);
+	/// Returns true if dynamic hotkey assignment is enabled
+	const bool assign_hotkeys();
 
 private:
 	application_state();
