@@ -28,12 +28,12 @@
 #include "ui_component.h"
 
 #include <k3dsdk/bitmap.h>
-#include <k3dsdk/iproperty.h>
 
 #include <gtkmm/buttonbox.h>
 
-// Forward declarations
 namespace Gtk { class Image; }
+namespace k3d { class idag; }
+namespace k3d { class iproperty; }
 
 namespace libk3dngui
 {
@@ -119,36 +119,6 @@ private:
 	data_t& m_data;
 };
 
-/// Specialization of bitmap_preview::data_proxy for use with iproperty objects
-template<>
-class data_proxy<k3d::iproperty> :
-	public idata_proxy
-{
-public:
-	typedef k3d::iproperty data_t;
-
-	data_proxy(data_t& Data) :
-		m_readable_data(Data)
-	{
-	}
-
-	k3d::bitmap* value()
-	{
-		return boost::any_cast<k3d::bitmap*>(m_readable_data.property_value());
-	}
-
-	changed_signal_t& changed_signal()
-	{
-		return m_readable_data.property_changed_signal();
-	}
-
-private:
-	data_proxy(const data_proxy& RHS);
-	data_proxy& operator=(const data_proxy& RHS);
-
-	data_t& m_readable_data;
-};
-
 /// Convenience factory function for creating bitmap_preview::idata_proxy objects
 template<typename data_t>
 std::auto_ptr<idata_proxy> proxy(data_t& Data)
@@ -156,6 +126,9 @@ std::auto_ptr<idata_proxy> proxy(data_t& Data)
 	return std::auto_ptr<idata_proxy>(new data_proxy<data_t>(Data));
 }
 
+/// Specialization of proxy() for use with properties
+std::auto_ptr<idata_proxy> proxy(k3d::idag& Graph, k3d::iproperty& Data);
+
 } // namespace bitmap_preview
 
 } // namespace libk3dngui
