@@ -1,5 +1,5 @@
 // K-3D
-// Copyright (c) 1995-2006, Timothy M. Shead
+// Copyright (c) 1995-2007, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -18,9 +18,9 @@
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 /** \file
-		\brief Implements the context menu
-		\author Timothy M. Shead (tshead@k-3d.com)
-		\author Romain Behar (romainbehar@yahoo.com)
+	\brief Implements the context menu
+	\author Timothy M. Shead (tshead@k-3d.com)
+	\author Romain Behar (romainbehar@yahoo.com)
 */
 
 #include <gtkmm/image.h>
@@ -44,7 +44,6 @@
 
 #include <k3dsdk/classes.h>
 #include <k3dsdk/dependencies.h>
-#include <k3dsdk/frames.h>
 #include <k3dsdk/fstream.h>
 #include <k3dsdk/i18n.h>
 #include <k3dsdk/ianimation_render_engine.h>
@@ -92,10 +91,6 @@ public:
 			set_markup(_("<b><i>Viewport:</i></b>"))));
 		append(*Gtk::manage(m_viewport1));
 
-		items().push_back(*Gtk::manage(
-			new menu_item::control(Parent, "set_viewport_camera", _("Set Camera ...")) <<
-			connect_menu_item(sigc::mem_fun(*this, &node_context_menu::on_set_viewport_camera))));
-
 		// Render-related functionality ...
 		Gtk::Menu* const render_submenu = new Gtk::Menu();
 
@@ -119,26 +114,30 @@ public:
 
 		items().push_back(Gtk::Menu_Helpers::MenuElem(_("Render"), *Gtk::manage(render_submenu)));
 
+		items().push_back(*Gtk::manage(
+			new menu_item::control(Parent, "set_viewport_camera", _("Set Camera ...")) <<
+			connect_menu_item(sigc::mem_fun(*this, &node_context_menu::on_set_viewport_camera))));
+
 		// Set render engines
 		Gtk::Menu* const engines_submenu = new Gtk::Menu();
 
 		engines_submenu->items().push_back(*Gtk::manage(
-			new menu_item::control(Parent, "set_viewport_preview_engine", _("Set preview engine ...")) <<
+			new menu_item::control(Parent, "set_viewport_preview_engine", _("Set Preview Engine ...")) <<
 			connect_menu_item(sigc::mem_fun(*this, &node_context_menu::on_set_viewport_preview_engine))));
 
 		engines_submenu->items().push_back(*Gtk::manage(
-			new menu_item::control(Parent, "set_viewport_still_engine", _("Set still engine ...")) <<
+			new menu_item::control(Parent, "set_viewport_still_engine", _("Set Still Engine ...")) <<
 			connect_menu_item(sigc::mem_fun(*this, &node_context_menu::on_set_viewport_still_engine))));
 
 		engines_submenu->items().push_back(*Gtk::manage(
-			new menu_item::control(Parent, "set_viewport_animation_engine", _("Set animation engine ...")) <<
+			new menu_item::control(Parent, "set_viewport_animation_engine", _("Set Animation Engine ...")) <<
 			connect_menu_item(sigc::mem_fun(*this, &node_context_menu::on_set_viewport_animation_engine))));
 
 		engines_submenu->items().push_back(*Gtk::manage(
 			new menu_item::control(Parent, "set_viewport_gl_engine", _("Set OpenGL Engine ...")) <<
 			connect_menu_item(sigc::mem_fun(*this, &node_context_menu::on_set_viewport_gl_engine))));
 
-		items().push_back(Gtk::Menu_Helpers::MenuElem(_("Set render engine"), *Gtk::manage(engines_submenu)));
+		items().push_back(Gtk::Menu_Helpers::MenuElem(_("Render Engine"), *Gtk::manage(engines_submenu)));
 
 		// Viewport section end
 		items().push_back(Gtk::Menu_Helpers::SeparatorElem());
@@ -400,19 +399,19 @@ private:
 		k3d::ipersistent* const persistent = dynamic_cast<k3d::ipersistent*>(&m_node);
 		return_if_fail(persistent);
 
-		boost::filesystem::path path;
-		if(!get_file_path(k3d::ipath_property::WRITE, m_node.factory().name(), _("Save Object Properties:"), boost::filesystem::path(), path))
+		k3d::filesystem::path path;
+		if(!get_file_path(k3d::ipath_property::WRITE, m_node.factory().name(), _("Save Object Properties:"), k3d::filesystem::path(), path))
 			return;
 
-		k3d::log() << info << "Writing .k3d file: " << path.native_file_string() << std::endl;
+		k3d::log() << info << "Writing .k3d file: " << path.native_string() << std::endl;
 		k3d::filesystem::ofstream file(path);
 		if(!file)
 			{
-				k3d::log() << error << k3d_file_reference << ": error opening [" << path.native_file_string() << "]" << std::endl;
+				k3d::log() << error << k3d_file_reference << ": error opening [" << path.native_string() << "]" << std::endl;
 				return;
 			}
 
-		const boost::filesystem::path root_path = path.branch_path();
+		const k3d::filesystem::path root_path = path.branch_path();
 		k3d::dependencies dependencies;
 		k3d::persistent_lookup lookup;
 		k3d::ipersistent::save_context context(root_path, dependencies, lookup);
@@ -428,15 +427,15 @@ private:
 		k3d::ipersistent* const persistent = dynamic_cast<k3d::ipersistent*>(&m_node);
 		return_if_fail(persistent);
 
-		boost::filesystem::path path;
-		if(!get_file_path(k3d::ipath_property::READ, m_node.factory().name(), _("Load Object Properties:"), boost::filesystem::path(), path))
+		k3d::filesystem::path path;
+		if(!get_file_path(k3d::ipath_property::READ, m_node.factory().name(), _("Load Object Properties:"), k3d::filesystem::path(), path))
 			return;
 
-		k3d::log() << info << "Reading .k3d file: " << path.native_file_string() << std::endl;
+		k3d::log() << info << "Reading .k3d file: " << path.native_string() << std::endl;
 		k3d::filesystem::ifstream file(path);
 		if(!file)
 		{
-			k3d::log() << error << k3d_file_reference << ": error opening [" << path.native_file_string() << "]" << std::endl;
+			k3d::log() << error << k3d_file_reference << ": error opening [" << path.native_string() << "]" << std::endl;
 			return;
 		}
 
@@ -444,7 +443,7 @@ private:
 		try
 		{
 			k3d::xml::hide_progress progress;
-			k3d::xml::parse(xml, file, path.native_file_string(), progress);
+			k3d::xml::parse(xml, file, path.native_string(), progress);
 		}
 		catch(std::exception& e)
 		{
@@ -464,9 +463,9 @@ private:
 			return;
 		}
 
-		k3d::record_state_change_set changeset(m_document_state.document(), k3d::string_cast(boost::format(_("Load %1%")) % path.native_file_string()));
+		k3d::record_state_change_set changeset(m_document_state.document(), k3d::string_cast(boost::format(_("Load %1%")) % path.native_string()));
 
-		const boost::filesystem::path root_path = path.branch_path();
+		const k3d::filesystem::path root_path = path.branch_path();
 		k3d::persistent_lookup lookup;
 		k3d::ipersistent::load_context context(root_path, lookup);
 
@@ -476,7 +475,7 @@ private:
 
 	void on_delete()
 	{
-		k3d::record_state_change_set changeset(m_document_state.document(), _("Delete nodes"));
+		k3d::record_state_change_set changeset(m_document_state.document(), _("Delete nodes"), __PRETTY_FUNCTION__);
 
 		k3d::nodes_t nodes = m_document_state.selected_nodes();
 
@@ -540,25 +539,25 @@ private:
 
 	void on_hide_selection()
 	{
-		k3d::record_state_change_set change_set(m_document_state.document(), _("Hide selection"));
+		k3d::record_state_change_set change_set(m_document_state.document(), _("Hide selection"), __PRETTY_FUNCTION__);
 		m_document_state.hide_selection();
 	}
 
 	void on_show_selection()
 	{
-		k3d::record_state_change_set change_set(m_document_state.document(), _("Show selection"));
+		k3d::record_state_change_set change_set(m_document_state.document(), _("Show selection"), __PRETTY_FUNCTION__);
 		m_document_state.show_selection();
 	}
 
 	void on_hide_unselected()
 	{
-		k3d::record_state_change_set change_set(m_document_state.document(), _("Hide unselected"));
+		k3d::record_state_change_set change_set(m_document_state.document(), _("Hide unselected"), __PRETTY_FUNCTION__);
 		m_document_state.hide_unselected();
 	}
 
 	void on_show_all()
 	{
-		k3d::record_state_change_set change_set(m_document_state.document(), _("Show all"));
+		k3d::record_state_change_set change_set(m_document_state.document(), _("Show all"), __PRETTY_FUNCTION__);
 		m_document_state.show_all_nodes();
 	}
 
