@@ -159,14 +159,14 @@ void control::set_value()
 
 	// Turn this into an undo/redo -able event ...
 	if(m_data->state_recorder)
-		m_data->state_recorder->start_recording(k3d::create_state_change_set());
+		m_data->state_recorder->start_recording(k3d::create_state_change_set(__PRETTY_FUNCTION__), __PRETTY_FUNCTION__);
 
 	// Update everything with the new value ...
 	m_data->set_value(new_value);
 
 	// Turn this into an undo/redo -able event ...
 	if(m_data->state_recorder)
-		m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(), m_data->change_message + " " + new_value);
+		m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(__PRETTY_FUNCTION__), m_data->change_message + " " + new_value, __PRETTY_FUNCTION__);
 }
 
 void control::data_changed(k3d::iunknown*)
