@@ -31,18 +31,8 @@ namespace libk3dngui
 
 class document_state;
 
-/// Opaque handle for the main per-document user interface window
-class main_document_window
-{
-public:
-	main_document_window(document_state& DocumentState);
-	~main_document_window();
-	
-private:
-	class implementation;
-	implementation* const m_implementation;
-};
-
+/// Create a new main document window, attaching it to the given document
+void create_main_document_window(document_state& DocumentState);
 /// Adds objects to a newly-created document to give the user a better out-of-box experience
 void populate_new_document(k3d::idocument& Document);
 
