@@ -22,7 +22,6 @@
 		\author Tim Shead (tshead@k-3d.com)
 */
 
-#include "black_box_recorder.h"
 #include "file_chooser_dialog.h"
 
 #include <k3dsdk/data.h>
@@ -41,7 +40,6 @@
 #include <k3dsdk/xml.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/path.hpp>
 
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
@@ -202,26 +200,24 @@ private:
 
 void merge_nodes(k3d::idocument& Document)
 {
-	boost::filesystem::path document_path;
+	k3d::filesystem::path document_path;
 
 	{
 		file_chooser_dialog dialog(_("Merge K-3D Document:"), k3d::options::path::documents(), Gtk::FILE_CHOOSER_ACTION_OPEN);
-		dialog.add_pattern_filter(_("K-3D document (*.k3d)"), "*.k3d");
+		dialog.add_pattern_filter(_("K-3D Document (*.k3d)"), "*.k3d");
 		dialog.add_all_files_filter();
 
 		if(!dialog.get_file_path(document_path))
 			return;
 	}
 
-	black_box_recorder::process_file process_file(document_path);
-	
 	// Check for a K-3D document
 	k3d::xml::element xml("k3dml");
 	try
 	{
 		k3d::filesystem::ifstream stream(document_path);
 		k3d::xml::hide_progress progress;
-		parse(xml, stream, document_path.native_file_string(), progress);
+		parse(xml, stream, document_path.native_utf8_string().raw(), progress);
 	}
 	catch(std::exception& e)
 	{
@@ -235,7 +231,7 @@ void merge_nodes(k3d::idocument& Document)
 	k3d::upgrade_document(xml);
 
 	// Setup context
-	const boost::filesystem::path root_path = document_path.branch_path();
+	const k3d::filesystem::path root_path = document_path.branch_path();
 	k3d::persistent_lookup persistent_lookup;
 	k3d::ipersistent::load_context context(root_path, persistent_lookup);
 
