@@ -34,7 +34,6 @@
 #include "keyboard.h"
 #include "move_tool.h"
 #include "transform_tool.h"
-#include "tutorial_message.h"
 #include "utility.h"
 #include "viewport.h"
 
@@ -156,7 +155,7 @@ public:
 		// Load parameters from configuration file
 		try
 		{
-			k3d::filesystem::ifstream layout_stream(k3d::share_path() / "ngui/tool_layout.k3d");
+			k3d::filesystem::ifstream layout_stream(k3d::share_path() / k3d::filesystem::generic_path("ngui/tool_layout.k3d"));
 			k3d::xml::element layout_xml;
 			layout_stream >> layout_xml;
 			k3d::xml::element& xml_move = layout_xml.safe_element("application").safe_element("user_interface").safe_element("tools").safe_element("move");
@@ -643,7 +642,7 @@ move_tool::move_tool(document_state& DocumentState, const std::string& Name) :
 	m_world_position(init_owner(*this) + init_name("world_position") + init_label(_("World position")) + init_description(_("Manipulators' world position")) + init_slot(sigc::mem_fun(*this, &move_tool::get_world_position)))
 {
 	//navigation_model().connect_command_signal(sigc::mem_fun(*this, &move_tool::record_command));
-	m_move.explicit_change_signal().connect(sigc::mem_fun(*this, &move_tool::on_move));
+	m_move.connect_explicit_change_signal(sigc::mem_fun(*this, &move_tool::on_move));
 
 	m_input_model.connect_lbutton_down(sigc::mem_fun(*this, &move_tool::on_lbutton_down));
 	m_input_model.connect_lbutton_click(sigc::mem_fun(*this, &move_tool::on_lbutton_click));
@@ -671,7 +670,6 @@ const k3d::icommand_node::result move_tool::execute_command(const std::string& C
 	try
 	{
 		command_arguments arguments(Arguments);
-		//tutorial_mouse_message("Move tool click", k3d::iuser_interface::LMB_CLICK, k3d::key_modifiers());
 
 		if(Command == "mouse_move")
 		{
