@@ -218,7 +218,7 @@ private:
 
 	// Move value
 	bool m_mutex;
-	k3d_data(k3d::point3, immutable_name, detail::custom_change_signal, with_undo, local_storage, no_constraint, writable_property, no_serialization) m_move;
+	k3d_data(k3d::point3, immutable_name, explicit_change_signal, with_undo, local_storage, no_constraint, writable_property, no_serialization) m_move;
 	k3d_data(k3d::point3, immutable_name, change_signal, no_undo, computed_storage, no_constraint, read_only_property, no_serialization) m_world_position;
 };
 
