@@ -251,10 +251,10 @@ public:
 	{
 		try
 		{
-			command_arguments arguments(Arguments);
-
 			if(Command == "rename")
 			{
+				command_arguments arguments(Arguments);
+
 				k3d::inode* const node = arguments.get_node(m_document_state.document(), "node");
 				return_val_if_fail(node, RESULT_ERROR);
 				const std::string new_name = arguments.get_string("newname");
@@ -268,6 +268,8 @@ public:
 
 			if(Command == "select")
 			{
+				command_arguments arguments(Arguments);
+
 				std::istringstream buffer(arguments.get_string("selection"));
 				k3d::inode* const context_menu_node = arguments.get_node(m_document_state.document(), "context_menu");
 
@@ -494,7 +496,7 @@ public:
 		arguments.append("newname", NewText);
 		m_command_signal.emit("rename", arguments);
 
-		k3d::record_state_change_set change_set(m_document_state.document(), k3d::string_cast(boost::format(_("Rename node %1%")) % NewText));
+		k3d::record_state_change_set change_set(m_document_state.document(), k3d::string_cast(boost::format(_("Rename node %1%")) % NewText), __PRETTY_FUNCTION__);
 		node->set_name(NewText);
 	}
 
@@ -579,15 +581,18 @@ public:
 				deselected_records.push_back(k3d::selection::make_record(get_node(selection->first)));
 		}
 
-		m_document_selection_change_mutex = true;
+		if(selected_records.size() || deselected_records.size())
 		{
-			k3d::record_state_change_set change_set(m_document_state.document(), _("Select nodes"));
+			m_document_selection_change_mutex = true;
+
+			k3d::record_state_change_set change_set(m_document_state.document(), _("Select nodes"), __PRETTY_FUNCTION__);
 
 			m_document_state.set_selection_mode(SELECT_NODES);
 			m_document_state.deselect(deselected_records);
 			m_document_state.select(selected_records);
+
+			m_document_selection_change_mutex = false;
 		}
-		m_document_selection_change_mutex = false;
 
 		// If a single node was selected, display its properties / history
 		if(m_selection_paths.size() == 1 && m_selection_paths.begin()->second)
