@@ -35,6 +35,7 @@
 #include "messages.h"
 #include "node_chooser.h"
 #include "node_properties.h"
+#include "open_uri.h"
 #include "path_chooser.h"
 #include "point_control.h"
 #include "property_button.h"
@@ -50,7 +51,6 @@
 #include "utility.h"
 #include "widget_manip.h"
 
-#include <k3dsdk/frames.h>
 #include <k3dsdk/i18n.h>
 #include <k3dsdk/ianimation_render_engine.h>
 #include <k3dsdk/iaqsis.h>
@@ -63,6 +63,7 @@
 #include <k3dsdk/ienumeration_property.h>
 #include <k3dsdk/ilist_property.h>
 #include <k3dsdk/imeasurement_property.h>
+#include <k3dsdk/imesh_storage.h>
 #include <k3dsdk/inode.h>
 #include <k3dsdk/iplugin_factory.h>
 #include <k3dsdk/ipreview_render_engine.h>
@@ -79,6 +80,8 @@
 #include <k3dsdk/string_cast.h>
 #include <k3dsdk/string_modifiers.h>
 #include <k3dsdk/system.h>
+#include <k3dsdk/types.h>
+#include <k3dsdk/user_properties.h>
 #include <k3dsdk/utility.h>
 
 // Not strictly required to compile, but this #include ensures that we have a std::typeinfo for k3d::mesh that matches the SDK (i.e. we don't break the ODR)
@@ -94,7 +97,6 @@
 #include <gtkmm/table.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/operations.hpp>
 #include <boost/format.hpp>
 
 namespace libk3dngui
@@ -113,11 +115,14 @@ public:
 	implementation(document_state& DocumentState, k3d::icommand_node& Parent) :
 		m_document_state(DocumentState),
 		m_node(0),
-		m_parent(Parent)
+		m_parent(Parent),
+		m_help_button(m_parent, "onlin_help", Gtk::Stock::HELP)
 	{
 		m_label.set_alignment(Gtk::ALIGN_LEFT);
 		m_label.set_padding(5, 5);
 
+		&m_help_button << connect_button(sigc::mem_fun(*this, &implementation::on_online_help));
+
 		m_scrolled_window.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
 		m_scrolled_window.add(m_vbox);
 
@@ -155,7 +160,7 @@ public:
 				m_node_name_change_connection = m_node->name_changed_signal().connect(sigc::mem_fun(*this, &implementation::update_label));
 				k3d::iproperty_collection* const property_collection = dynamic_cast<k3d::iproperty_collection*>(m_node);
 				if(property_collection)
-					m_node_properties_changed_connection = property_collection->properties_changed_signal().connect(sigc::hide(sigc::mem_fun(*this, &implementation::on_node_properties_changed)));
+					m_node_properties_changed_connection = property_collection->connect_properties_changed_signal(sigc::hide(sigc::mem_fun(*this, &implementation::on_node_properties_changed)));
 
 			}
 
@@ -179,9 +184,15 @@ public:
 	void update_label()
 	{
 		if(m_node)
-			m_label.set_text(k3d::string_cast(boost::format(_("%1% Properties")) % m_node->name()));
+		{
+			m_label.set_text(m_node->name());
+			m_help_button.set_sensitive(true);
+		}
 		else
+		{
 			m_label.set_text("");
+			m_help_button.set_sensitive(false);
+		}
 	}
 
 	void reset()
@@ -264,6 +275,17 @@ public:
 			toolbar_control->row(0).pack_start(*Gtk::manage(control), Gtk::PACK_SHRINK);
 		}
 
+		// Add a "reset" button for nodes that implement k3d::imesh_storage (FrozenMesh, external file readers, etc) ...
+		if(dynamic_cast<k3d::imesh_storage*>(m_node))
+		{
+			button::control* const control =
+				new button::control(m_parent, "reset_mesh", _("Reset Mesh"))
+					<< connect_button(sigc::mem_fun(*this, &implementation::on_reset_mesh))
+					<< set_tooltip(_("Reset / Reload Mesh"));
+
+			toolbar_control->row(0).pack_start(*Gtk::manage(control), Gtk::PACK_SHRINK);
+		}
+
 		// Get the node properties, grouped together ...
 		k3d::iproperty_collection* const property_collection = dynamic_cast<k3d::iproperty_collection*>(m_node);
 		k3d::iproperty_group_collection::groups_t property_groups;
@@ -342,10 +364,8 @@ public:
 				else if(property_type == typeid(double) || property_type == typeid(float) || property_type == typeid(long) || property_type == typeid(unsigned long) || property_type == typeid(int) || property_type == typeid(unsigned int))
 				{
 					spin_button::control* const control = new spin_button::control(m_parent, property_name, spin_button::proxy(property, state_recorder, property_name));
-					k3d::imeasurement_property* const measurement_property = dynamic_cast<k3d::imeasurement_property*>(&property);
-					if(measurement_property)
+					if(k3d::imeasurement_property* const measurement_property = dynamic_cast<k3d::imeasurement_property*>(&property))
 					{
-						control->set_precision(measurement_property->property_precision());
 						control->set_step_increment(measurement_property->property_step_increment());
 						control->set_units(measurement_property->property_units());
 					}
@@ -411,15 +431,15 @@ public:
 					entry_list.push_back(control);
 				}
 				// Bitmap properties ...
-				else if(property_type == typeid(k3d::bitmap*))
+				else if(property_type == k3d::type_id_k3d_bitmap_ptr())
 				{
-					bitmap_preview::control* const control = new bitmap_preview::control(m_parent, property_name, bitmap_preview::proxy(property));
+					bitmap_preview::control* const control = new bitmap_preview::control(m_parent, property_name, bitmap_preview::proxy(m_document_state.document().dag(), property));
 					table->attach(*manage(control), prop_control_begin, prop_control_end, row, row + 1, Gtk::FILL | Gtk::SHRINK, Gtk::FILL | Gtk::SHRINK);
 
 					entry_list.push_back(control);
 				}
 				// Filesystem-path properties ...
-				else if(property_type == typeid(boost::filesystem::path))
+				else if(property_type == typeid(k3d::filesystem::path))
 				{
 					path_chooser::control* const control = new path_chooser::control(m_parent, property_name, path_chooser::proxy(property, state_recorder, property_name));
 					table->attach(*manage(control), prop_control_begin, prop_control_end, row, row + 1, Gtk::FILL | Gtk::SHRINK, Gtk::FILL | Gtk::SHRINK);
@@ -499,6 +519,14 @@ public:
 		m_vbox.show_all();
 	}
 
+	void on_online_help()
+	{
+		if(m_node)
+		{
+			open_uri("http://www.k-3d.org/wiki/" + m_node->factory().name());
+		}
+	}
+
 	void on_render_camera_preview()
 	{
 		k3d::icamera* camera = dynamic_cast<k3d::icamera*>(m_node);
@@ -574,22 +602,37 @@ public:
 		render_animation(m_document_state, *render_engine);
 	}
 
+    void on_reset_mesh()
+    {
+            k3d::imesh_storage* const mesh_storage = dynamic_cast<k3d::imesh_storage*>(m_node);
+            return_if_fail(mesh_storage);
+
+            mesh_storage->reset_mesh(0);
+    }
+
 	void on_delete_user_property(k3d::iproperty_collection* Collection, k3d::iproperty* Property)
 	{
 		return_if_fail(Collection);
 		return_if_fail(Property);
 		return_if_fail(dynamic_cast<k3d::iuser_property*>(Property));
 
+		k3d::record_state_change_set change_set(m_document_state.document(), "Delete user property", __PRETTY_FUNCTION__);
+
+		if(m_document_state.document().state_recorder().current_change_set())
+			m_document_state.document().state_recorder().current_change_set()->record_old_state(new k3d::user::property_container(*Collection));
+
+		Collection->unregister_property(*Property);
 		if(k3d::ipersistent* const persistent = dynamic_cast<k3d::ipersistent*>(Property))
 		{
 			if(k3d::ipersistent_container* const persistent_container = dynamic_cast<k3d::ipersistent_container*>(Collection))
-			{
 				persistent_container->disable_serialization(*persistent);
-			}
 		}
 
-		Collection->unregister_property(*Property);
-		delete dynamic_cast<k3d::ideletable*>(Property);
+		if(k3d::ideletable* const deletable = dynamic_cast<k3d::ideletable*>(Property))
+			undoable_delete(deletable, m_document_state.document());
+
+		if(m_document_state.document().state_recorder().current_change_set())
+			m_document_state.document().state_recorder().current_change_set()->record_new_state(new k3d::user::property_container(*Collection));
 	}
 
 	void on_add_user_property()
@@ -612,6 +655,8 @@ public:
 	sigc::connection m_node_properties_changed_connection;
 	/// Displays the current node name
 	Gtk::Label m_label;
+	/// Online help button
+	button::control m_help_button;
 	/// Contains the set of node properties
 	Gtk::ScrolledWindow m_scrolled_window;
 	/// Parent widget for the rest of the implementation
@@ -635,8 +680,12 @@ control::control(document_state& DocumentState, k3d::icommand_node& Parent) :
 	m_implementation->m_command_signal.connect(sigc::mem_fun(*this, &control::record_command));
 
 	m_implementation->m_scrolled_window.signal_button_press_event().connect(sigc::bind_return(sigc::hide(m_implementation->m_panel_grab_signal.make_slot()), false), false);
-	
-	pack_start(m_implementation->m_label, Gtk::PACK_SHRINK);
+
+	Gtk::HBox* const hbox = new Gtk::HBox();
+	hbox->pack_start(m_implementation->m_label, Gtk::PACK_EXPAND_WIDGET);
+	hbox->pack_start(m_implementation->m_help_button, Gtk::PACK_SHRINK);
+
+	pack_start(*Gtk::manage(hbox), Gtk::PACK_SHRINK);
 	pack_start(m_implementation->m_scrolled_window, Gtk::PACK_EXPAND_WIDGET);
 	show_all();
 }
