@@ -58,7 +58,7 @@ bool open_uri(const std::string& URI)
 		boost::format command_line(k3d::options::get_command(k3d::options::command::html_viewer()));
 		command_line % URI;
 
-		return_val_if_fail(k3d::system::async_run_process(command_line.str()), false);
+		return_val_if_fail(k3d::system::spawn_async(command_line.str()), false);
 
 		return true;
 	}
