@@ -21,8 +21,8 @@
 		\author Tim Shead (tshead@k-3d.com)
 */
 
-#include "black_box_recorder.h"
 #include "button.h"
+#include "command_arguments.h"
 #include "file_chooser_dialog.h"
 #include "hotkey_entry.h"
 #include "interactive.h"
@@ -30,7 +30,9 @@
 
 #include <k3dsdk/i18n.h>
 #include <k3dsdk/istate_recorder.h>
+#include <k3dsdk/path.h>
 #include <k3dsdk/result.h>
+#include <k3dsdk/share.h>
 #include <k3dsdk/state_change_set.h>
 
 #include <gtkmm/combobox.h>
@@ -85,13 +87,13 @@ public:
 	{
 		return m_path_data ? m_path_data->pattern_filters() : k3d::ipath_property::pattern_filters_t();
 	}
-	
-	const boost::filesystem::path value()
+
+	const k3d::filesystem::path value()
 	{
-		return boost::any_cast<boost::filesystem::path>(m_readable_data.property_value());
+		return boost::any_cast<k3d::filesystem::path>(m_readable_data.property_value());
 	}
 
-	void set_value(const boost::filesystem::path& Value)
+	void set_value(const k3d::filesystem::path& Value)
 	{
 		return_if_fail(m_writable_data);
 		m_writable_data->property_set_value(Value);
@@ -125,7 +127,8 @@ control::control(k3d::icommand_node& Parent, const std::string& Name, std::auto_
 	m_entry(new hotkey_entry),
 	m_button(new Gtk::Button("...")),
 	m_combo(new Gtk::ComboBox()),
-	m_data(Data)
+	m_data(Data),
+	m_disable_set_value(false)
 {
 	m_entry->signal_focus_out_event().connect(sigc::mem_fun(*this, &control::on_focus_out_event));
 	m_entry->signal_activate().connect(sigc::mem_fun(*this, &control::on_activate));
@@ -165,17 +168,46 @@ control::control(k3d::icommand_node& Parent, const std::string& Name, std::auto_
 
 const k3d::icommand_node::result control::execute_command(const std::string& Command, const std::string& Arguments)
 {
-	if(Command == "browse")
+	try
 	{
-		interactive::activate(*m_button);
-		return RESULT_CONTINUE;
+		if(Command == "browse" || Command == "set_value")
+		{
+			command_arguments arguments(Arguments);
+
+			switch(k3d::from_string<k3d::ipath_property::reference_t>(arguments.get_string("reference"), k3d::ipath_property::ABSOLUTE_REFERENCE))
+			{
+				case k3d::ipath_property::RELATIVE_REFERENCE:
+				{
+					std::string root_path_string = arguments.get_string("root");
+					std::string relative_path_string = arguments.get_string("relative_path");
+
+					k3d::filesystem::path root_path;
+					if(root_path_string == "$K3D_SHARE_PATH")
+						root_path = k3d::share_path();
+					else
+						root_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(root_path_string));
+
+					const k3d::filesystem::path path = root_path / k3d::filesystem::native_path(k3d::ustring::from_utf8(arguments.get_string("relative_path")));
+
+					interactive::set_text(*m_entry, path.native_utf8_string().raw());
+					return RESULT_CONTINUE;
+				}
+				case k3d::ipath_property::ABSOLUTE_REFERENCE:
+				{
+					std::string absolute_path = arguments.get_string("absolute_path");
+					interactive::set_text(*m_entry, absolute_path);
+					return RESULT_CONTINUE;
+				}
+				default:
+					k3d::log() << error << "Unknown reference type" << std::endl;
+					return RESULT_ERROR;
+			}
+		}
 	}
-	else if(Command == "set_value")
+	catch(std::exception& e)
 	{
-		interactive::set_text(*m_entry, Arguments);
-		m_entry->select_region(0, 0);
-		set_value();
-		return RESULT_CONTINUE;
+		k3d::log() << error << e.what() << std::endl;
+		return RESULT_ERROR;
 	}
 
 	return ui_component::execute_command(Command, Arguments);
@@ -196,10 +228,7 @@ void control::on_browse()
 {
 	return_if_fail(m_data.get());
 
-	// Record the command for posterity (tutorials) ...
-	record_command("browse");
-
-	boost::filesystem::path new_path;
+	k3d::filesystem::path new_value;
 	{
 		file_chooser_dialog dialog("", m_data->type(), m_data->mode(), m_data->value());
 
@@ -209,20 +238,36 @@ void control::on_browse()
 		if(!filters.empty())
 			dialog.add_all_files_filter();
 
-		if(!dialog.get_file_path(new_path))
+		if(!dialog.get_file_path(new_value))
 			return;
 	}
 
+	// Record the command for posterity (tutorials) ...
+	command_arguments arguments;
+	if(0 == new_value.generic_utf8_string().find(k3d::share_path().generic_utf8_string()))
+	{
+		const k3d::filesystem::path relative_path = k3d::filesystem::make_relative_path(new_value, k3d::share_path());
+		arguments.append("reference", k3d::string_cast(k3d::ipath_property::RELATIVE_REFERENCE));
+		arguments.append("relative_path", relative_path.native_utf8_string().raw());
+		arguments.append("root", "$K3D_SHARE_PATH");
+	}
+	else
+	{
+		arguments.append("reference", k3d::string_cast(k3d::ipath_property::ABSOLUTE_REFERENCE));
+		arguments.append("absolute_path", new_value.native_utf8_string().raw());
+	}
+	record_command("browse", arguments);
+
 	// Turn this into an undo/redo -able event ...
 	if(m_data->state_recorder)
-		m_data->state_recorder->start_recording(k3d::create_state_change_set());
+		m_data->state_recorder->start_recording(k3d::create_state_change_set(__PRETTY_FUNCTION__), __PRETTY_FUNCTION__);
 
 	// Update everything with the new value ...
-	m_data->set_value(new_path);
+	m_data->set_value(new_value);
 
 	// Turn this into an undo/redo -able event ...
 	if(m_data->state_recorder)
-		m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(), m_data->change_message + " " + new_path.native_file_string());
+		m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(__PRETTY_FUNCTION__), m_data->change_message + " " + new_value.native_utf8_string().raw(), __PRETTY_FUNCTION__);
 }
 
 void control::on_pick_reference_type()
@@ -235,37 +280,68 @@ void control::on_pick_reference_type()
 
 void control::set_value()
 {
-	return_if_fail(m_data.get());
-
-	// If the value didn't change, we're done ...
-	const std::string new_value = m_entry->get_text();
-	if(new_value == m_data->value().native_file_string())
+	if(m_disable_set_value)
 		return;
 
-	// For debugging purposes, keep track of the file we're loading ...
-	black_box_recorder::process_file process_file(boost::filesystem::path(new_value, boost::filesystem::native));
-	
+	return_if_fail(m_data.get());
+
+	m_disable_set_value = true;
+
+	k3d::filesystem::path new_value;
+	try
+	{
+		new_value = k3d::filesystem::native_path(k3d::ustring::from_utf8(m_entry->get_text()));
+	}
+	catch(std::exception& e)
+	{
+		k3d::log() << error << e.what() << std::endl;
+		m_disable_set_value = false;
+		return;
+	}
+
+	// If the value didn't change, we're done ...
+	if(m_data->value().generic_utf8_string() == new_value.generic_utf8_string())
+	{
+		m_disable_set_value = false;
+		return;
+	}
+
 	// Record the command for posterity (tutorials) ...
-	record_command("set_value", new_value);
+	command_arguments arguments;
+	if(0 == new_value.generic_utf8_string().find(k3d::share_path().generic_utf8_string()))
+	{
+		const k3d::filesystem::path relative_path = k3d::filesystem::make_relative_path(new_value, k3d::share_path());
+		arguments.append("reference", k3d::string_cast(k3d::ipath_property::RELATIVE_REFERENCE));
+		arguments.append("relative_path", relative_path.native_utf8_string().raw());
+		arguments.append("root", "$K3D_SHARE_PATH");
+	}
+	else
+	{
+		arguments.append("reference", k3d::string_cast(k3d::ipath_property::ABSOLUTE_REFERENCE));
+		arguments.append("absolute_path", new_value.native_utf8_string().raw());
+	}
+	record_command("set_value", arguments);
 
 	// Turn this into an undo/redo -able event ...
 	if(m_data->state_recorder)
-		m_data->state_recorder->start_recording(k3d::create_state_change_set());
+		m_data->state_recorder->start_recording(k3d::create_state_change_set(__PRETTY_FUNCTION__), __PRETTY_FUNCTION__);
 
 	// Update everything with the new value ...
-	m_data->set_value(boost::filesystem::path(new_value, boost::filesystem::native));
+	m_data->set_value(new_value);
 
 	// Turn this into an undo/redo -able event ...
 	if(m_data->state_recorder)
-		m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(), m_data->change_message + " " + new_value);
+		m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(__PRETTY_FUNCTION__), m_data->change_message + " " + new_value.native_utf8_string().raw(), __PRETTY_FUNCTION__);
+
+	m_disable_set_value = false;
 }
 
 void control::data_changed(k3d::iunknown*)
 {
 	return_if_fail(m_data.get());
 
-	m_entry->set_text(m_data->value().leaf());
-	tooltips().set_tip(*m_entry, m_data->value().native_file_string());
+	m_entry->set_text(m_data->value().leaf().raw());
+	tooltips().set_tip(*m_entry, m_data->value().native_utf8_string().raw());
 
 	m_combo->set_active(m_data->reference());
 }
