@@ -34,7 +34,6 @@
 #include "keyboard.h"
 #include "scale_tool.h"
 #include "transform_tool.h"
-#include "tutorial_message.h"
 #include "utility.h"
 #include "viewport.h"
 
@@ -193,7 +192,7 @@ public:
 		// Load parameters from configuration file
 		try
 		{
-			k3d::filesystem::ifstream layout_stream(k3d::share_path() / "ngui/tool_layout.k3d");
+			k3d::filesystem::ifstream layout_stream(k3d::share_path() / k3d::filesystem::generic_path("ngui/tool_layout.k3d"));
 			k3d::xml::element layout_xml;
 			layout_stream >> layout_xml;
 			k3d::xml::element& xml_scale = layout_xml.safe_element("application").safe_element("user_interface").safe_element("tools").safe_element("scale");
@@ -652,7 +651,7 @@ scale_tool::scale_tool(document_state& DocumentState, const std::string& Name) :
 	m_center(init_owner(*this) + init_name("center") + init_label(_("Center")) + init_description(_("Center")) + init_value(k3d::point3(0, 0, 0)))
 {
 	//navigation_model().connect_command_signal(sigc::mem_fun(*this, &scale_tool::record_command));
-	m_scaling.explicit_change_signal().connect(sigc::mem_fun(*this, &scale_tool::on_scale));
+	m_scaling.connect_explicit_change_signal(sigc::mem_fun(*this, &scale_tool::on_scale));
 
 	m_input_model.connect_lbutton_down(sigc::mem_fun(*this, &scale_tool::on_lbutton_down));
 	m_input_model.connect_lbutton_click(sigc::mem_fun(*this, &scale_tool::on_lbutton_click));
@@ -680,7 +679,6 @@ const k3d::icommand_node::result scale_tool::execute_command(const std::string&
 	try
 	{
 		command_arguments arguments(Arguments);
-		//tutorial_mouse_message("Move tool click", k3d::iuser_interface::LMB_CLICK, k3d::key_modifiers());
 
 		if(Command == "mouse_move")
 		{
