@@ -216,9 +216,9 @@ private:
 
 	// Scaling value
 	k3d::point3 m_original_scaling;
-	k3d_data(k3d::point3, immutable_name, detail::custom_change_signal, with_undo, local_storage, no_constraint, writable_property, no_serialization) m_scaling;
+	k3d_data(k3d::point3, immutable_name, explicit_change_signal, with_undo, local_storage, no_constraint, writable_property, no_serialization) m_scaling;
 	// Scaling center
-	k3d_data(k3d::point3, immutable_name, detail::custom_change_signal, with_undo, local_storage, no_constraint, writable_property, no_serialization) m_center;
+	k3d_data(k3d::point3, immutable_name, explicit_change_signal, with_undo, local_storage, no_constraint, writable_property, no_serialization) m_center;
 };
 
 } // namespace libk3dngui
