@@ -40,8 +40,6 @@
 #include <gtkmm/tooltips.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/path.hpp>
 #include <boost/format.hpp>
 
 #include <sstream>
@@ -137,7 +135,7 @@ void control::on_load()
 {
 	return_if_fail(m_data.get());
 
-	boost::filesystem::path input_path;
+	k3d::filesystem::path input_path;
 
 	{
 		file_chooser_dialog dialog(_("Load Script:"), k3d::options::path::scripts(), Gtk::FILE_CHOOSER_ACTION_OPEN);
@@ -153,12 +151,12 @@ void control::on_load()
 	if(buffer.str() != m_data->value())
 	{
 		if(m_data->state_recorder)
-			m_data->state_recorder->start_recording(k3d::create_state_change_set());
+			m_data->state_recorder->start_recording(k3d::create_state_change_set(__PRETTY_FUNCTION__), __PRETTY_FUNCTION__);
 
 		m_data->set_value(buffer.str());
 
 		if(m_data->state_recorder)
-			m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(), m_data->change_message);
+			m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(__PRETTY_FUNCTION__), m_data->change_message, __PRETTY_FUNCTION__);
 	}
 }
 
@@ -166,7 +164,7 @@ void control::on_save()
 {
 	return_if_fail(m_data.get());
 
-	boost::filesystem::path output_path;
+	k3d::filesystem::path output_path;
 
 	{
 		file_chooser_dialog dialog(_("Save Script:"), k3d::options::path::scripts(), Gtk::FILE_CHOOSER_ACTION_SAVE);
@@ -184,27 +182,27 @@ void control::on_edit()
 
 	try
 	{
-		boost::filesystem::path temp_path = k3d::system::generate_temp_file();
+		k3d::filesystem::path temp_path = k3d::system::generate_temp_file();
 		return_if_fail(!temp_path.empty());
 
 		const k3d::script::code original_value(m_data->value());
 
 		k3d::iplugin_factory* const language = k3d::script::language(original_value).factory();
 		if(language && language->class_id() == k3d::classes::PythonEngine())
-			temp_path = boost::filesystem::path(temp_path.native_file_string() + ".py", boost::filesystem::native);
+			temp_path = temp_path + ".py";
 		else if(language && language->class_id() == k3d::classes::K3DScriptEngine())
-			temp_path = boost::filesystem::path(temp_path.native_file_string() + ".k3dscript", boost::filesystem::native);
+			temp_path = temp_path + ".k3dscript";
 		else
 			k3d::log() << warning << "unknown script language" << std::endl;
 
-		
+
 		k3d::filesystem::ofstream output_stream(temp_path);
 		output_stream << original_value.source();
 		output_stream.close();
 
 		boost::format command_line(k3d::options::get_command(k3d::options::command::text_editor()));
-		command_line % temp_path.native_file_string();
-		k3d::system::run_process(command_line.str());
+		command_line % temp_path.native_utf8_string().raw();
+		k3d::system::spawn_sync(command_line.str());
 
 		std::stringstream buffer;
 		k3d::filesystem::ifstream input_stream(temp_path);
@@ -214,15 +212,15 @@ void control::on_edit()
 		if(buffer.str() != original_value.source())
 		{
 			if(m_data->state_recorder)
-				m_data->state_recorder->start_recording(k3d::create_state_change_set());
+				m_data->state_recorder->start_recording(k3d::create_state_change_set(__PRETTY_FUNCTION__), __PRETTY_FUNCTION__);
 
 			m_data->set_value(buffer.str());
 
 			if(m_data->state_recorder)
-				m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(), m_data->change_message);
+				m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(__PRETTY_FUNCTION__), m_data->change_message, __PRETTY_FUNCTION__);
 		}
 
-		boost::filesystem::remove(temp_path);
+		k3d::filesystem::remove(temp_path);
 	}
 	catch(std::exception& e)
 	{
