@@ -34,8 +34,6 @@
 #include "keyboard.h"
 #include "snap_tool.h"
 #include "snap_tool_detail.h"
-#include "tutorial_message.h"
-#include "utility.h"
 #include "viewport.h"
 
 #include <k3dsdk/color.h>
@@ -157,7 +155,7 @@ struct snap_tool::implementation :
 		m_snap_orientation(init_owner(*this) + init_name("snap_orientation") + init_label(_("Snap Orientation")) + init_description(_("Snap Orientation")) + init_value(true)),
 		m_match_groups(init_owner(*this) + init_name("match_groups") + init_label(_("Match Groups")) + init_description(_("Match Groups")) + init_value(true))
 	{
-		m_transformation.explicit_change_signal().connect(sigc::mem_fun(*this, &implementation::on_move));
+		m_transformation.connect_explicit_change_signal(sigc::mem_fun(*this, &implementation::on_move));
 
 		m_input_model.connect_lbutton_down(sigc::mem_fun(*this, &implementation::on_lbutton_down));
 		m_input_model.connect_lbutton_click(sigc::mem_fun(*this, &implementation::on_lbutton_click));
@@ -203,7 +201,7 @@ struct snap_tool::implementation :
 		// Load parameters from configuration file
 		try
 		{
-			k3d::filesystem::ifstream layout_stream(k3d::share_path() / "ngui/tool_layout.k3d");
+			k3d::filesystem::ifstream layout_stream(k3d::share_path() / k3d::filesystem::generic_path("ngui/tool_layout.k3d"));
 			k3d::xml::element layout_xml;
 			layout_stream >> layout_xml;
 			k3d::xml::element& xml_move = layout_xml.safe_element("application").safe_element("user_interface").safe_element("tools").safe_element("move");
@@ -553,7 +551,6 @@ struct snap_tool::implementation :
 		try
 		{
 			command_arguments arguments(Arguments);
-			//tutorial_mouse_message("Move tool click", k3d::iuser_interface::LMB_CLICK, k3d::key_modifiers());
 
 			if(Command == "mouse_move")
 			{
@@ -1060,7 +1057,7 @@ private:
 	double m_axis_arrow_length;
 	unsigned long m_axis_arrow_slices;
 
-	k3d_data(k3d::matrix4, immutable_name, detail::custom_change_signal, with_undo, local_storage, no_constraint, writable_property, no_serialization) m_transformation;
+	k3d_data(k3d::matrix4, immutable_name, explicit_change_signal, with_undo, local_storage, no_constraint, writable_property, no_serialization) m_transformation;
 	k3d_data(k3d::isnappable*, immutable_name, change_signal, no_undo, node_storage, no_constraint, node_property, no_serialization) m_target;
 	k3d_data(std::string, immutable_name, change_signal, no_undo, local_storage, no_constraint, enumeration_property, no_serialization) m_snap_target;
 	k3d_data(double, immutable_name, change_signal, no_undo, local_storage, no_constraint, writable_property, no_serialization) m_snap_distance;
