@@ -157,7 +157,6 @@ control::control(k3d::icommand_node& Parent, const std::string& Name, std::auto_
 	m_down_button(new Gtk::Button()),
 	m_data(Data),
 	m_step_increment(0.01),
-	m_precision(2),
 	m_units(&typeid(scalar)),
 	m_dragging(false),
 	m_tap_started(false)
@@ -201,12 +200,6 @@ control::control(k3d::icommand_node& Parent, const std::string& Name, std::auto_
 		m_data->changed_signal().connect(sigc::mem_fun(*this, &control::on_data_changed));
 }
 
-void control::set_precision(const unsigned long Precision)
-{
-	m_precision = Precision;
-	on_data_changed(0);
-}
-
 void control::set_step_increment(const double StepIncrement)
 {
 	m_step_increment = StepIncrement;
@@ -268,7 +261,7 @@ const k3d::icommand_node::result control::execute_command(const std::string& Com
 			}
 
 			if(m_data->state_recorder)
-				m_data->state_recorder->start_recording(k3d::create_state_change_set());
+				m_data->state_recorder->start_recording(k3d::create_state_change_set(__PRETTY_FUNCTION__), __PRETTY_FUNCTION__);
 
 			m_timer.restart();
 
@@ -304,7 +297,7 @@ const k3d::icommand_node::result control::execute_command(const std::string& Com
 			{
 				std::stringstream buffer;
 				buffer << std::setprecision(3) << m_data->value();
-				m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(), m_data->change_message + ' ' + buffer.str());
+				m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(__PRETTY_FUNCTION__), m_data->change_message + ' ' + buffer.str(), __PRETTY_FUNCTION__);
 			}
 
 			return RESULT_CONTINUE;
@@ -345,8 +338,27 @@ void control::on_data_changed(k3d::iunknown*)
 void control::display_value(const double Value)
 {
 	std::ostringstream buffer;
-	buffer << std::fixed << std::setprecision(m_precision);
-	k3d::measurement::format(buffer, Value, *m_units);
+
+	if(*m_units == typeid(k3d::measurement::angle)) // Display angles in degrees, even though the internal unit is radians
+		buffer << k3d::string_cast(boost::format("%g") % k3d::measurement::convert(k3d::measurement::quantity<k3d::measurement::angle>(Value, k3d::measurement::angle_units("rad")), k3d::measurement::angle_units("deg")).value()) << " deg";
+	else if(*m_units == typeid(k3d::measurement::area))
+		buffer << k3d::string_cast(boost::format("%g") % Value) << " m^2";
+	else if(*m_units == typeid(k3d::measurement::distance))
+		buffer << k3d::string_cast(boost::format("%g") % Value) << " m";
+	else if(*m_units == typeid(k3d::measurement::force))
+		buffer << k3d::string_cast(boost::format("%g") % Value) << " N";
+	else if(*m_units == typeid(k3d::measurement::mass))
+		buffer << k3d::string_cast(boost::format("%g") % Value) << " Kg";
+	else if(*m_units == typeid(k3d::measurement::pressure))
+		buffer << k3d::string_cast(boost::format("%g") % Value) << " Pa";
+	else if(*m_units == typeid(k3d::measurement::time))
+		buffer << k3d::string_cast(boost::format("%g") % Value) << " s";
+	else if(*m_units == typeid(k3d::measurement::volume))
+		buffer << k3d::string_cast(boost::format("%g") % Value) << " m^3";
+	else if(*m_units == typeid(scalar))
+		buffer << k3d::string_cast(boost::format("%g") % Value);
+	else
+		k3d::log() << error << "Unknown physical unit - " << m_units->name() << std::endl;
 
 	m_entry->set_text(buffer.str());
 }
@@ -395,13 +407,13 @@ void control::on_manual_value()
 
 		// Turn this into an undo/redo -able event ...
 		if(m_data->state_recorder)
-			m_data->state_recorder->start_recording(k3d::create_state_change_set());
+			m_data->state_recorder->start_recording(k3d::create_state_change_set(__PRETTY_FUNCTION__), __PRETTY_FUNCTION__);
 
 		m_data->set_value(new_value);
 
 		// Turn this into an undo/redo -able event ...
 		if(m_data->state_recorder)
-			m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(), m_data->change_message + ' ' + new_text);
+			m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(__PRETTY_FUNCTION__), m_data->change_message + ' ' + new_text, __PRETTY_FUNCTION__);
 	}
 	else
 	{
@@ -435,7 +447,7 @@ void control::on_drag_pressed(const bool Up)
 
 	// Turn this into an undo/redo -able event ...
 	if(m_data->state_recorder)
-		m_data->state_recorder->start_recording(k3d::create_state_change_set());
+		m_data->state_recorder->start_recording(k3d::create_state_change_set(__PRETTY_FUNCTION__), __PRETTY_FUNCTION__);
 }
 
 bool control::on_drag_motion_notify_event(GdkEventMotion* Event)
@@ -594,7 +606,7 @@ void control::on_drag_released()
 		// Format a limited-precision version of the new value, so we we don't create unreadably-long undo-node labels ...
 		std::stringstream buffer;
 		buffer << std::setprecision(3) << m_data->value();
-		m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(), m_data->change_message + ' ' + buffer.str());
+		m_data->state_recorder->commit_change_set(m_data->state_recorder->stop_recording(__PRETTY_FUNCTION__), m_data->change_message + ' ' + buffer.str(), __PRETTY_FUNCTION__);
 	}
 
 	m_up_button->unset_flags(Gtk::CAN_FOCUS);
