@@ -27,6 +27,7 @@
 
 #include <k3dsdk/i18n.h>
 #include <k3dsdk/log.h>
+#include <k3dsdk/path.h>
 #include <k3dsdk/version.h>
 
 #include <gtkmm/box.h>
@@ -34,8 +35,6 @@
 #include <gtkmm/image.h>
 #include <gtkmm/label.h>
 
-#include <boost/filesystem/path.hpp>
-
 #include <iostream>
 
 namespace libk3dngui
@@ -44,7 +43,7 @@ namespace libk3dngui
 /////////////////////////////////////////////////////////////////////////////
 // splash_box
 
-splash_box::splash_box(const boost::filesystem::path& SharePath) :
+splash_box::splash_box(const k3d::filesystem::path& SharePath) :
 	base(Gtk::WINDOW_TOPLEVEL),
 	m_startup_message(new Gtk::Label("", Gtk::ALIGN_CENTER, Gtk::ALIGN_CENTER))
 {
@@ -63,7 +62,7 @@ splash_box::splash_box(const boost::filesystem::path& SharePath) :
 		<< set_markup("<big><b>K-3D Version " K3D_VERSION "</b></big>")));
 
 	vbox->pack_start(*Gtk::manage(
-		new Gtk::Label("Copyright (c) 1995-2006, Timothy M. Shead.")
+		new Gtk::Label(K3D_COPYRIGHT)
 		<< line_wrap()
 		<< center_justify()));
 
@@ -84,19 +83,19 @@ splash_box::splash_box(const boost::filesystem::path& SharePath) :
 
 	Gtk::HBox* const hbox = new Gtk::HBox(false, 8);
 
-	const boost::filesystem::path path = SharePath / "splash.xpm";
+	const k3d::filesystem::path path = SharePath / k3d::filesystem::generic_path("splash.xpm");
 	try
 	{
 		Gtk::Frame* const frame = new Gtk::Frame();
 		frame->set_shadow_type(Gtk::SHADOW_OUT);
-		frame->add(*Gtk::manage(new Gtk::Image(Gdk::Pixbuf::create_from_file(path.native_file_string()))));
+		frame->add(*Gtk::manage(new Gtk::Image(Gdk::Pixbuf::create_from_file(path.native_filesystem_string()))));
 
 		// Note: we can't use our convenience load_pixbuf() function here, because k3d::application() isn't initialized, yet ...
 		hbox->pack_start(*Gtk::manage(frame));
 	}
 	catch(...)
 	{
-		k3d::log() << error << "Error loading image [" << path.native_file_string() << "]" << std::endl;
+		k3d::log() << error << "Error loading image [" << path.native_console_string() << "]" << std::endl;
 	}
 
 	hbox->pack_start(*Gtk::manage(vbox));
@@ -104,7 +103,7 @@ splash_box::splash_box(const boost::filesystem::path& SharePath) :
 	Gtk::VBox* const vbox2 = new Gtk::VBox(false, 8);
 	vbox2->pack_start(*Gtk::manage(hbox));
 	vbox2->pack_start(*Gtk::manage(m_startup_message));
-	
+
 	add(*Gtk::manage(vbox2));
 
 	show_all();
