@@ -38,6 +38,7 @@
 #include <k3dsdk/fstream.h>
 #include <k3dsdk/gl.h>
 #include <k3dsdk/i18n.h>
+#include <k3dsdk/ipath_property.h>
 #include <k3dsdk/iselectable.h>
 #include <k3dsdk/plugins.h>
 #include <k3dsdk/result.h>
@@ -219,18 +220,18 @@ struct control::implementation
 
 		Gtk::Notebook* const notebook = new Gtk::Notebook();
 
-		const boost::filesystem::path layout_path = k3d::share_path() / "ngui/toolbar_layout.k3d";
+		const k3d::filesystem::path layout_path = k3d::share_path() / k3d::filesystem::generic_path("ngui/toolbar_layout.k3d");
 		k3d::xml::element xml_layout;
 		try
 		{
-			k3d::log() << info << "Loading toolbar layout from " << layout_path.native_file_string() << std::endl;
+			k3d::log() << info << "Loading toolbar layout from " << layout_path.native_console_string() << std::endl;
 			k3d::filesystem::ifstream layout_stream(layout_path);
 			layout_stream >> xml_layout;
 			assert_warning(xml_layout.name == "k3dml");
 		}
 		catch(...)
 		{
-			k3d::log() << error << "Error loading toolbar layout from " << layout_path.native_file_string() << std::endl;
+			k3d::log() << error << "Error loading toolbar layout from " << layout_path.native_console_string() << std::endl;
 		}
 
 		k3d::xml::element& xml_application = xml_layout.safe_element("application");
@@ -248,11 +249,11 @@ struct control::implementation
 
 			toolbar::control* const toolbar_widget = new toolbar::control(Parent, toolbar_name);
 
-			for(k3d::xml::element::elements_t::const_iterator xml_icon = xml_toolbar->children.begin(); xml_icon != xml_toolbar->children.end(); ++xml_icon)
+			for(k3d::xml::element::elements_t::const_iterator xml_button = xml_toolbar->children.begin(); xml_button != xml_toolbar->children.end(); ++xml_button)
 			{
-				if(xml_icon->name == "node")
+				if(xml_button->name == "node")
 				{
-					const std::string name = k3d::xml::attribute_text(*xml_icon, "name");
+					const std::string name = k3d::xml::attribute_text(*xml_button, "name");
 					const k3d::factories_t factories = k3d::plugins(name);
 					if(1 != factories.size())
 						continue;
@@ -270,38 +271,86 @@ struct control::implementation
 
 					toolbar_widget->row(0).pack_start(*Gtk::manage(button), Gtk::PACK_SHRINK);
 				}
-				else if(xml_icon->name == "script")
+				else if(xml_button->name == "script")
 				{
-					const std::string name = k3d::xml::attribute_text(*xml_icon, "name");
-					const std::string label = k3d::xml::attribute_text(*xml_icon, "label");
-					const std::string tooltip = k3d::xml::attribute_text(*xml_icon, "tooltip");
-					const boost::filesystem::path path = k3d::xml::attribute_text(*xml_icon, "path");
-					const std::string script = xml_icon->text;
+					const std::string name = k3d::xml::attribute_text(*xml_button, "name");
+					const std::string label = k3d::xml::attribute_text(*xml_button, "label");
+					const std::string description = k3d::xml::attribute_text(*xml_button, "description");
 
-					if(path.empty())
+					const k3d::ipath_property::reference_t reference = k3d::xml::attribute_value<k3d::ipath_property::reference_t>(*xml_button, "reference", k3d::ipath_property::RELATIVE_REFERENCE);
+					switch(reference)
 					{
-						button::control* const button =
-							new button::control(*toolbar_widget, name, label)
-							<< set_tooltip(tooltip)
-							<< connect_button(sigc::bind(sigc::mem_fun(*this, &implementation::on_run_inline_script), script))
-							<< make_toolbar_button()
-							<< enable_dynamic_accelerators();
+						case k3d::ipath_property::ABSOLUTE_REFERENCE:
+							try
+							{
+								const k3d::filesystem::path absolute_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(k3d::xml::attribute_text(*xml_button, "absolute_path")));
 
-						toolbar_widget->row(0).pack_start(*Gtk::manage(button), Gtk::PACK_SHRINK);
-					}
-					else
-					{
-						button::control* const button =
-							new button::control(*toolbar_widget, name, label)
-							<< set_tooltip(tooltip)
-							<< connect_button(sigc::bind(sigc::mem_fun(*this, &implementation::on_run_external_script), path))
-							<< make_toolbar_button()
-							<< enable_dynamic_accelerators();
+								button::control* const button =
+									new button::control(*toolbar_widget, name, label)
+									<< set_tooltip(description)
+									<< connect_button(sigc::bind(sigc::mem_fun(*this, &implementation::on_run_external_script), absolute_path))
+									<< make_toolbar_button()
+									<< enable_dynamic_accelerators();
 
-						toolbar_widget->row(0).pack_start(*Gtk::manage(button), Gtk::PACK_SHRINK);
+								toolbar_widget->row(0).pack_start(*Gtk::manage(button), Gtk::PACK_SHRINK);
+							}
+							catch(std::exception& e)
+							{
+								k3d::log() << error << e.what() << std::endl;
+							}
+							break;
+						case k3d::ipath_property::RELATIVE_REFERENCE:
+							try
+							{
+								k3d::filesystem::path root_path = k3d::share_path() / k3d::filesystem::generic_path("ngui");
+								if(const k3d::xml::element* const xml_root = k3d::xml::find_element(*xml_button, "root"))
+								{
+									if(xml_root->text == "$K3D_SHARE_PATH")
+										root_path = k3d::share_path();
+									else
+										root_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(xml_root->text));
+								}
+
+								const k3d::filesystem::path absolute_path = root_path / k3d::filesystem::native_path(k3d::ustring::from_utf8(k3d::xml::attribute_text(*xml_button, "relative_path")));
+
+								button::control* const button =
+									new button::control(*toolbar_widget, name, label)
+									<< set_tooltip(description)
+									<< connect_button(sigc::bind(sigc::mem_fun(*this, &implementation::on_run_external_script), absolute_path))
+									<< make_toolbar_button()
+									<< enable_dynamic_accelerators();
+
+								toolbar_widget->row(0).pack_start(*Gtk::manage(button), Gtk::PACK_SHRINK);
+							}
+							catch(std::exception& e)
+							{
+								k3d::log() << error << e.what() << std::endl;
+							}
+							break;
+						case k3d::ipath_property::INLINE_REFERENCE:
+							try
+							{
+								const std::string encoding = k3d::xml::attribute_text(*xml_button, "encoding");
+								if(encoding != "text/plain")
+									throw std::runtime_error("Toolbar script inline encoding must be text/plain");
+
+								button::control* const button =
+									new button::control(*toolbar_widget, name, label)
+									<< set_tooltip(description)
+									<< connect_button(sigc::bind(sigc::mem_fun(*this, &implementation::on_run_inline_script), xml_button->text))
+									<< make_toolbar_button()
+									<< enable_dynamic_accelerators();
+
+								toolbar_widget->row(0).pack_start(*Gtk::manage(button), Gtk::PACK_SHRINK);
+							}
+							catch(std::exception& e)
+							{
+								k3d::log() << error << e.what() << std::endl;
+							}
+							break;
 					}
 				}
-				else if(xml_icon->name == "separator")
+				else if(xml_button->name == "separator")
 				{
 					toolbar_widget->row(0).pack_start(*Gtk::manage(new Gtk::SeparatorToolItem()), Gtk::PACK_SHRINK);
 				}
@@ -322,7 +371,7 @@ struct control::implementation
 	/// Unparents all selected nodes
 	void on_unparent()
 	{
-		k3d::record_state_change_set change_set(m_document_state.document(), _("Unparent selected"));
+		k3d::record_state_change_set change_set(m_document_state.document(), _("Unparent selected"), __PRETTY_FUNCTION__);
 
 		// Note: we're making a copy of the current set of nodes here, because unparenting changes the contents of the collection
 		const k3d::inode_collection::nodes_t nodes = m_document_state.document().nodes().collection();
@@ -371,7 +420,7 @@ struct control::implementation
 		execute_script(script, "Inline Script", context);
 	}
 
-	void on_run_external_script(const boost::filesystem::path Script)
+	void on_run_external_script(const k3d::filesystem::path Script)
 	{
 		k3d::iscript_engine::context_t context;
 		context["Document"] = static_cast<k3d::iunknown*>(&m_document_state.document());
