@@ -51,7 +51,6 @@
 #include "widget_manip.h"
 
 #include <k3dsdk/command_tree.h>
-#include <k3dsdk/frames.h>
 #include <k3dsdk/i18n.h>
 #include <k3dsdk/ianimation_render_engine.h>
 #include <k3dsdk/iaqsis.h>
@@ -131,7 +130,7 @@ public:
 		k3d::iproperty_collection* const property_collection = dynamic_cast<k3d::iproperty_collection*>(&active_tool);
 		if(property_collection)
 		{
-			m_tool_properties_changed_connection = property_collection->properties_changed_signal().connect(sigc::hide(sigc::mem_fun(*this, &implementation::schedule_update)));
+			m_tool_properties_changed_connection = property_collection->connect_properties_changed_signal(sigc::hide(sigc::mem_fun(*this, &implementation::schedule_update)));
 
 			return true;
 		}
@@ -242,7 +241,6 @@ public:
 					k3d::imeasurement_property* const measurement_property = dynamic_cast<k3d::imeasurement_property*>(&property);
 					if(measurement_property)
 					{
-						control->set_precision(measurement_property->property_precision());
 						control->set_step_increment(measurement_property->property_step_increment());
 						control->set_units(measurement_property->property_units());
 					}
@@ -318,7 +316,7 @@ public:
 				}
 */
 				// Filesystem-path properties ...
-				else if(property_type == typeid(boost::filesystem::path))
+				else if(property_type == typeid(k3d::filesystem::path))
 				{
 					path_chooser::control* const control = new path_chooser::control(m_parent, property_name, path_chooser::proxy(property, state_recorder, property_name));
 					table->attach(*manage(control), prop_control_begin, prop_control_end, row, row + 1, Gtk::FILL | Gtk::SHRINK, Gtk::FILL | Gtk::SHRINK);
