@@ -63,53 +63,6 @@ typedef std::list<component_point_t> component_points_t;
 /// Lists selected points in a mesh and returns average component position
 k3d::point3 get_selected_points(selection_mode_t SelectionMode, const k3d::mesh& Mesh, component_points_t& PointList);
 
-/// Signal policy with explicit signal that isn't emitted on undo/redo
-template<typename value_t>
-class custom_change_signal
-{
-public:
-	/// Defines a signal emitted when the underlying data changes
-	typedef sigc::signal1<void, k3d::iunknown*> changed_signal_t;
-
-	/// Returns a reference to the signal that is emitted whenever the underlying data changes
-	changed_signal_t& changed_signal()
-	{
-		return m_changed_signal;
-	}
-
-	/// Returns a reference to the signal that isn't emitted on undo/redo
-	changed_signal_t& explicit_change_signal()
-	{
-		return m_explicit_change_signal;
-	}
-
-protected:
-	template<typename init_t>
-	custom_change_signal(const init_t& Init)
-	{
-	}
-
-	void start_recording(k3d::istate_recorder& StateRecorder)
-	{
-	}
-
-	void set_value(k3d::iunknown* const Hint)
-	{
-		m_changed_signal.emit(Hint);
-		m_explicit_change_signal.emit(Hint);
-	}
-
-	void finish_recording(k3d::istate_recorder& StateRecorder)
-	{
-		StateRecorder.current_change_set()->undo_signal().connect(sigc::bind(m_changed_signal.make_slot(), static_cast<k3d::iunknown*>(0)));
-		StateRecorder.current_change_set()->redo_signal().connect(sigc::bind(m_changed_signal.make_slot(), static_cast<k3d::iunknown*>(0)));
-	}
-
-private:
-	changed_signal_t m_changed_signal;
-	changed_signal_t m_explicit_change_signal;
-};
-
 template<typename Type>
 class imanipulators
 {
@@ -521,7 +474,7 @@ protected:
 		return Stream;
 	}
 
-	const k3d::ienumeration_property::enumeration_values_t& coordinate_system_values()
+	static const k3d::ienumeration_property::enumeration_values_t& coordinate_system_values()
 	{
 		static k3d::ienumeration_property::enumeration_values_t values;
 		if(values.empty())
