@@ -48,9 +48,6 @@
 #include <gtkmm/stock.h>
 #include <gtkmm/treeview.h>
 
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/path.hpp>
-
 namespace libk3dngui
 {
 
@@ -92,7 +89,7 @@ public:
 
 		m_show_tutorials.set_active(options::nag("show_tutorials"));
 		m_show_tutorials.signal_toggled().connect(sigc::mem_fun(*this, &tutorial_menu::on_show_tutorials));
-		
+
 		Gtk::VBox* const box1 = Gtk::manage(new Gtk::VBox(false, 10));
 		box1->pack_start(*Gtk::manage(new Gtk::Label(_("Welcome to K-3D!"))), Gtk::PACK_SHRINK);
 		box1->pack_start(*Gtk::manage(new Gtk::Label(_("Below is a list of interactive tutorials you can\nrun to become familiar with K-3D.  If this is the\nfirst time you've used the program, we recommend\nyou begin with the \"Getting Started\" tutorial."))), Gtk::PACK_SHRINK);
@@ -114,15 +111,15 @@ private:
 	{
 		m_tutorial_store = Gtk::ListStore::create(m_tutorial_columns);
 
-		const boost::filesystem::path tutorials_path = k3d::share_path() / "tutorials";
-		const boost::filesystem::path index_path = tutorials_path / "index.k3d";
+		const k3d::filesystem::path tutorials_path = k3d::share_path() / k3d::filesystem::generic_path("tutorials");
+		const k3d::filesystem::path index_path = tutorials_path / k3d::filesystem::generic_path("index.k3d");
 
-		if(!boost::filesystem::exists(index_path))
+		if(!k3d::filesystem::exists(index_path))
 		{
-			k3d::log() << error << "Couldn't find tutorial index file [" << index_path.native_file_string() << "]" << std::endl;
+			k3d::log() << error << "Couldn't find tutorial index file [" << index_path.native_console_string() << "]" << std::endl;
 			return;
 		}
-		
+
 		// Load the index file as XML ...
 		k3d::xml::element index("k3dml");
 		k3d::filesystem::ifstream stream(index_path);
@@ -157,10 +154,10 @@ private:
 				continue;
 			}
 
-			const boost::filesystem::path tutorial_path = tutorials_path / boost::filesystem::path(xml_path, boost::filesystem::native);
-			if(!boost::filesystem::exists(tutorial_path))
+			const k3d::filesystem::path tutorial_path = tutorials_path / k3d::filesystem::native_path(k3d::ustring::from_utf8(xml_path));
+			if(!k3d::filesystem::exists(tutorial_path))
 			{
-				k3d::log() << error << "Couldn't locate tutorial [" << tutorial_path.native_file_string() << "]" << std::endl;
+				k3d::log() << error << "Couldn't locate tutorial [" << tutorial_path.native_console_string() << "]" << std::endl;
 				continue;
 			}
 
@@ -178,15 +175,14 @@ private:
 		Gtk::TreeRow row = *m_tutorial_store->get_iter(Path);
 
 		// Look-up the path to the actual tutorial implementation ...
-		const boost::filesystem::path tutorial_path = row[m_tutorial_columns.path];
+		const k3d::filesystem::path tutorial_path = row[m_tutorial_columns.path];
 
 		// Make sure it exists!
-		if(!boost::filesystem::exists(tutorial_path))
+		if(!k3d::filesystem::exists(tutorial_path))
 		{
 			error_message(
 				_("Could not find the tutorial implementation file.  This may be caused by a partial- or incorrect-installation.\n"
-				"If you built the application from CVS source, make sure you re-run bootstrap and configure after every update."),
-				k3d::string_cast(boost::format(_("Play %1%:")) % tutorial_path.native_file_string()));
+				"If you built the application from CVS source, make sure you re-run bootstrap and configure after every update."));
 			return;
 		}
 
@@ -198,12 +194,12 @@ private:
 
 		const bool tutorial_playing = m_tutorial_playing;
 		m_tutorial_playing = true;
-		
+
 		k3d::iscript_engine::context_t context;
-		execute_script(file, tutorial_path.native_file_string(), context);
+		execute_script(file, tutorial_path.native_utf8_string().raw(), context);
 
 		m_tutorial_playing = tutorial_playing;
-		
+
 		tutorial_message::instance().hide_messages();
 	}
 
@@ -212,7 +208,7 @@ private:
 		options::enable_nag("show_tutorials", m_show_tutorials.get_active());
 		k3d::options::commit();
 	}
-	
+
 	class columns :
 		public Gtk::TreeModelColumnRecord
 	{
@@ -224,7 +220,7 @@ private:
 		}
 
 		Gtk::TreeModelColumn<Glib::ustring> name;
-		Gtk::TreeModelColumn<boost::filesystem::path> path;
+		Gtk::TreeModelColumn<k3d::filesystem::path> path;
 	};
 
 	columns m_tutorial_columns;
