@@ -31,6 +31,9 @@ namespace libk3dngui
 /// Displays a tutorial menu dialog
 void create_tutorial_menu();
 
+/// Returns true iff tutorial playback is in progress
+const bool tutorial_playing();
+
 } // namespace libk3dngui
 
 #endif // NGUI_TUTORIAL_MENU_H
