@@ -54,12 +54,11 @@
 #include <k3dsdk/iscript_engine.h>
 #include <k3dsdk/iuser_interface.h>
 #include <k3dsdk/options.h>
+#include <k3dsdk/plugins.h>
 #include <k3dsdk/scripting.h>
 #include <k3dsdk/string_cast.h>
 #include <k3dsdk/user_interface.h>
 
-#include <boost/filesystem/path.hpp>
-
 #include <gtkmm/box.h>
 #include <gtkmm/paned.h>
 #include <gtkmm/scrolledwindow.h>
@@ -80,7 +79,7 @@ class tutorial_recorder :
 public:
 	tutorial_recorder() :
 		base("tutorial_recorder", 0),
-		m_script_engine(dynamic_cast<k3d::iscript_engine*>(k3d::create_plugin(k3d::classes::K3DScriptEngine()))),
+		m_script_engine(k3d::create_plugin<k3d::iscript_engine>(k3d::classes::K3DScriptEngine())),
 		m_compression(true),
 		m_unsaved_changes(false),
 		m_recording(init_name("recording") + init_label(_("Recording")) + init_description(_("Tells whether the tutorial recorder records user actions")) + init_value(true)),
@@ -123,6 +122,16 @@ public:
 			new menu_item::control(*menubar, "edit_play_from_cursor", _("Play From Cursor")) <<
 			connect_menu_item(sigc::mem_fun(*this, &tutorial_recorder::on_edit_play_from_cursor))));
 
+		Gtk::Menu* const language_menu = Gtk::manage(new Gtk::Menu());
+
+		const k3d::factories_t factories = k3d::plugins<k3d::iscript_engine>();
+		for(k3d::factories_t::const_iterator factory = factories.begin(); factory != factories.end(); ++factory)
+		{
+			language_menu->items().push_back(*Gtk::manage(
+				new menu_item::control(*menubar, "script_engine_" + (*factory)->name(), (*factory)->name())
+				<< connect_menu_item(sigc::bind(sigc::mem_fun(*this, &tutorial_recorder::on_tools_language), (*factory)))));
+		}
+
 		Gtk::Menu* const tools_menu = Gtk::manage(new Gtk::Menu());
 
 		tools_menu->items().push_back(*Gtk::manage(
@@ -131,10 +140,11 @@ public:
 		tools_menu->items().push_back(*Gtk::manage(
 			new menu_item::control(*menubar, "tools_event_recorder", _("Event Recorder ...")) <<
 			connect_menu_item(sigc::mem_fun(*this, &tutorial_recorder::on_tools_event_recorder))));
+		tools_menu->items().push_back(Gtk::Menu_Helpers::MenuElem(_("Script Language"), *language_menu));
 
-		menubar->items().push_back(Gtk::Menu_Helpers::MenuElem(_("_File"), *manage(file_menu)));
-		menubar->items().push_back(Gtk::Menu_Helpers::MenuElem(_("_Edit"), *manage(edit_menu)));
-		menubar->items().push_back(Gtk::Menu_Helpers::MenuElem(_("_Tools"), *manage(tools_menu)));
+		menubar->items().push_back(Gtk::Menu_Helpers::MenuElem(_("_File"), *file_menu));
+		menubar->items().push_back(Gtk::Menu_Helpers::MenuElem(_("_Edit"), *edit_menu));
+		menubar->items().push_back(Gtk::Menu_Helpers::MenuElem(_("_Tools"), *tools_menu));
 
 		toolbar::control* const toolbar = new toolbar::control(*this, "toolbar");
 		toolbar->row(0).pack_start(*Gtk::manage(
@@ -171,15 +181,22 @@ public:
 		hbox1->pack_start(*Gtk::manage(menubar), Gtk::PACK_SHRINK);
 		hbox1->pack_start(*Gtk::manage(toolbar), Gtk::PACK_SHRINK);
 
-		m_script.set_wrap_mode(Gtk::WRAP_CHAR);
+		m_script.set_wrap_mode(Gtk::WRAP_WORD_CHAR);
 
-		Gtk::ScrolledWindow* const scrolled_window = new Gtk::ScrolledWindow();
-		scrolled_window->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
-		scrolled_window->add(m_script);
+		m_script_window.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
+		m_script_window.add(m_script);
 
+		m_recording_message.set_markup("<span foreground=\"red\" size=\"x-large\" weight=\"bold\">Recording in\nProgress</span>");
+		m_recording_message.set_justify(Gtk::JUSTIFY_CENTER);
+		
+		Gtk::VBox* const vbox2 = new Gtk::VBox(false);
+		vbox2->pack_start(m_script_window, Gtk::PACK_EXPAND_WIDGET);
+		vbox2->pack_start(m_recording_message, Gtk::PACK_EXPAND_WIDGET);
+		
 		Gtk::VPaned* const vpaned = new Gtk::VPaned();
 		vpaned->pack1(m_message);
-		vpaned->pack2(*Gtk::manage(scrolled_window));
+		vpaned->pack2(*Gtk::manage(vbox2));
+		vpaned->set_position(30);
 
 		Gtk::VBox* const vbox1 = new Gtk::VBox(false);
 		vbox1->pack_start(*Gtk::manage(hbox1), Gtk::PACK_SHRINK);
@@ -193,6 +210,8 @@ public:
 		show_all();
 
 		m_script.get_buffer()->signal_changed().connect(sigc::mem_fun(*this, &tutorial_recorder::on_script_changed));
+
+		on_edit_recording();
 	}
 
 	static unsigned long m_recording_count;
@@ -217,11 +236,12 @@ private:
 		if(!save_changes())
 			return;
 
-		boost::filesystem::path filepath;
+		k3d::filesystem::path filepath;
 
 		{
 			file_chooser_dialog dialog(_("Open Tutorial:"), k3d::options::path::tutorials(), Gtk::FILE_CHOOSER_ACTION_OPEN);
 			dialog.add_pattern_filter(_("K-3D Script (*.k3dscript)"), "*.k3dscript");
+			dialog.add_pattern_filter(_("Python Script (*.py)"), "*.py");
 			dialog.add_all_files_filter();
 
 			if(!dialog.get_file_path(filepath))
@@ -252,8 +272,29 @@ private:
 			file_open(m_path);
 	}
 
-	void on_edit_recording(k3d::iunknown*)
+	void on_edit_recording(k3d::iunknown* = 0)
 	{
+		if(m_recording.value())
+		{
+			m_script_window.hide();
+			m_recording_message.show();
+		}
+		else
+		{
+			if(!m_buffer.empty())
+			{
+				m_script.get_buffer()->insert(m_script.get_buffer()->end(), m_buffer);
+				Gtk::TextBuffer::iterator end = m_script.get_buffer()->end();
+				m_script.scroll_to(end, 0.0);
+
+				m_unsaved_changes = true;
+				m_buffer.clear();
+			}
+
+			m_script_window.show();
+			m_recording_message.hide();
+		}
+
 		update_title();
 	}
 
@@ -310,6 +351,19 @@ private:
 		update_title();
 	}
 
+	void on_tools_language(k3d::iplugin_factory* Factory)
+	{
+		return_if_fail(Factory);
+
+		if(!save_changes())
+			return;
+
+		delete dynamic_cast<k3d::ideletable*>(m_script_engine);
+		m_script_engine = k3d::create_plugin<k3d::iscript_engine>(*Factory);
+
+		file_new();
+	}
+	
 	void on_tools_command_node_inspector()
 	{
 		create_command_node_inspector();
@@ -336,12 +390,12 @@ private:
 		m_script_engine->bless_script(script);
 		m_script.get_buffer()->set_text(script.str());
 
-		m_path = boost::filesystem::path();
+		m_path = k3d::filesystem::path();
 		m_unsaved_changes = false;
 		update_title();
 	}
 
-	void file_open(const boost::filesystem::path& Path)
+	void file_open(const k3d::filesystem::path& Path)
 	{
 		k3d::filesystem::igzstream stream(Path);
 
@@ -379,9 +433,17 @@ private:
 	{
 		{
 			file_chooser_dialog dialog(_("Save Tutorial As:"), k3d::options::path::tutorials(), Gtk::FILE_CHOOSER_ACTION_SAVE);
-			dialog.add_pattern_filter(_("K-3D Script (*.k3dscript"), "*.k3dscript");
+			if(m_script_engine->factory().class_id() == k3d::classes::K3DScriptEngine())
+			{
+				dialog.add_pattern_filter(_("K-3D Script (*.k3dscript)"), "*.k3dscript");
+				dialog.append_extension(".k3dscript");
+			}
+			else if(m_script_engine->factory().class_id() == k3d::classes::PythonEngine())
+			{
+				dialog.add_pattern_filter(_("Python Script (*.py)"), "*.py");
+				dialog.append_extension(".py");
+			}
 			dialog.add_all_files_filter();
-			dialog.append_extension(".k3dscript");
 			dialog.enable_compression();
 
 			if(!dialog.get_file_path(m_path, m_compression))
@@ -426,17 +488,21 @@ private:
 		m_script_engine->append_command(buffer, CommandNode, Command, Arguments);
 		m_buffer += buffer.str();
 
+/** \todo Restore this code once we figure-out why updates during recording cause an X server crash
 		schedule_update();
+*/
 	}
 
 	void on_update()
 	{
+/** \todo Restore this code once we figure-out why updates during recording cause an X server crash
 		m_script.get_buffer()->insert(m_script.get_buffer()->end(), m_buffer);
 		Gtk::TextBuffer::iterator end = m_script.get_buffer()->end();
 		m_script.scroll_to(end, 0.0);
 
 		m_unsaved_changes = true;
 		m_buffer.clear();
+*/
 	}
 
 	const bool unsaved_changes()
@@ -456,7 +522,7 @@ private:
 	
 	std::string get_script_title()
 	{
-		return m_path.empty() ? _("Untitled Tutorial") : m_path.leaf();
+		return m_path.empty() ? _("Untitled Tutorial") : m_path.leaf().raw();
 	}
 
 	void update_title()
@@ -473,9 +539,9 @@ private:
 	}
 
 	/// Script engine for the script being recorded
-	k3d::iscript_engine* const m_script_engine;
+	k3d::iscript_engine* m_script_engine;
 	/// Stores the file path (could be empty)
-	boost::filesystem::path m_path;
+	k3d::filesystem::path m_path;
 	bool m_compression;
 	/// Set to true iff there are unsaved changes
 	bool m_unsaved_changes;
@@ -487,6 +553,10 @@ private:
 	Gtk::TextView m_message;
 	/// Stores the script being recorded
 	Gtk::TextView m_script;
+	/// Scroll window that contains the script
+	Gtk::ScrolledWindow m_script_window;
+	/// Displays a message while recording is in progress
+	Gtk::Label m_recording_message;
 	/// Buffers incoming command text so we can maintain responsiveness while recording
 	std::string m_buffer;
 };
