@@ -107,9 +107,9 @@ public:
 
 		m_view.append_column(*manage(column));
 
-		m_document_state.document().state_recorder().node_added_signal().connect(sigc::mem_fun(*this, &implementation::on_node_added));
-		m_document_state.document().state_recorder().current_node_changed_signal().connect(sigc::mem_fun(*this, &implementation::on_current_node_changed));
-		m_document_state.document().state_recorder().last_saved_node_changed_signal().connect(sigc::mem_fun(*this, &implementation::on_last_saved_node_changed));
+		m_document_state.document().state_recorder().connect_node_added_signal(sigc::mem_fun(*this, &implementation::on_node_added));
+		m_document_state.document().state_recorder().connect_current_node_changed_signal(sigc::mem_fun(*this, &implementation::on_current_node_changed));
+		m_document_state.document().state_recorder().connect_last_saved_node_changed_signal(sigc::mem_fun(*this, &implementation::on_last_saved_node_changed));
 
 		schedule_update();
 	}
