@@ -24,7 +24,6 @@
 
 #include "application_state.h"
 #include "application_window.h"
-#include "black_box_recorder.h"
 #include "button.h"
 #include "document_state.h"
 #include "file_chooser_dialog.h"
@@ -38,7 +37,6 @@
 #include "tutorial_message.h"
 #include "tutorial_recorder.h"
 #include "utility.h"
-#include "widget_manip.h"
 
 #include <k3dsdk/application.h>
 #include <k3dsdk/command_node.h>
@@ -65,13 +63,7 @@
 
 #include <gtkmm/accelkey.h>
 #include <gtkmm/accelmap.h>
-#include <gtkmm/box.h>
-#include <gtkmm/buttonbox.h>
-#include <gtkmm/label.h>
 #include <gtkmm/main.h>
-#include <gtkmm/settings.h>
-#include <gtkmm/stock.h>
-#include <gtkmm/window.h>
 
 #include <gtk/gtkgl.h>
 
@@ -79,9 +71,6 @@
 #include <boost/date_time/posix_time/posix_time.hpp>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/convenience.hpp>
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/path.hpp>
 #include <boost/format.hpp>
 
 #include <iostream>
@@ -100,9 +89,9 @@ void handle_error(const std::string& Message, bool& Quit, bool& Error)
 	Error = true;
 }
 
-const boost::filesystem::path hotkey_path()
+const k3d::filesystem::path hotkey_path()
 {
-	return k3d::system::get_home_directory() / boost::filesystem::path(".k3d/hotkeys", boost::filesystem::native);
+	return k3d::system::get_home_directory() / k3d::filesystem::generic_path(".k3d/hotkeys");
 }
 
 void setup_default_hotkeys()
@@ -168,58 +157,12 @@ void setup_default_hotkeys()
 	Gtk::AccelMap::add_entry("<k3d-document>/actions/view/toggle_projection", Gtk::AccelKey("o").get_key(), Gdk::ModifierType(0));
 }
 
-/////////////////////////////////////////////////////////////////////////////
-// assign_hotkeys_popup
-
-class assign_hotkeys_popup :
-	public application_window
-{
-	typedef application_window base;
-public:
-	assign_hotkeys_popup() :
-		base("assign_hotkeys", 0)
-	{
-		set_title(_("Assign Hotkeys:"));
-		set_role("assign_hotkeys");
-		set_keep_above(true);
-
-		Gtk::HButtonBox* const box2 = new Gtk::HButtonBox(Gtk::BUTTONBOX_END);
-		box2->pack_start(*Gtk::manage(
-			new button::control(*this, "close", Gtk::Stock::CLOSE)
-			<< connect_button(sigc::mem_fun(*this, &assign_hotkeys_popup::close))
-			), Gtk::PACK_SHRINK);
-
-		Gtk::VBox* const box1 = new Gtk::VBox(false, 10);
-		box1->set_border_width(10);
-		box1->pack_start(*Gtk::manage(new Gtk::Label() << line_wrap() << center_justify() << set_markup(_("<big><b>Assign Hotkeys Mode</b></big>"))));
-		box1->pack_start(*Gtk::manage(new Gtk::Label(_("To assign hotkeys, hover the mouse over a menu item, and hit the desired hotkey combination.  Use \"delete\" to remove hotkeys.  Close this window to turn-off Assign Hotkeys Mode.")) << line_wrap() << center_justify()));
-		box1->pack_start(*Gtk::manage(box2));
-
-		add(*Gtk::manage(box1));
-
-		show_all();
-
-		application_state::instance().assign_hotkeys().changed_signal().connect(sigc::mem_fun(*this, &assign_hotkeys_popup::on_assign_hotkeys));
-	}
-
-	void on_assign_hotkeys(k3d::iunknown*)
-	{
-		if(!application_state::instance().assign_hotkeys().value())
-			close();
-	}
-
-	void on_close()
-	{
-		application_state::instance().assign_hotkeys().set_value(false);
-	}
-};
-
 } // namespace detail
 
 /////////////////////////////////////////////////////////////////////////////
-// user_interface_implementation
+// user_interface
 
-class user_interface_implementation :
+class user_interface :
 	public k3d::command_node::implementation,
 	public k3d::iuser_interface,
 	public k3d::iuser_interface_plugin,
@@ -229,7 +172,7 @@ class user_interface_implementation :
 	typedef k3d::command_node::implementation base;
 
 public:
-	user_interface_implementation() :
+	user_interface() :
 		base("ui", 0),
 		m_show_tutorials(options::nag("show_tutorials")),
 		m_record_tutorials(false)
@@ -248,19 +191,14 @@ public:
 		g_log_set_handler("glibmm", static_cast<GLogLevelFlags>(G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION), log_handler, 0);
 		g_log_set_handler("gtkmm", static_cast<GLogLevelFlags>(G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION), log_handler, 0);
 		g_log_set_handler("pangomm", static_cast<GLogLevelFlags>(G_LOG_LEVEL_MASK | G_LOG_FLAG_FATAL | G_LOG_FLAG_RECURSION), log_handler, 0);
-
-		application_state::instance().assign_hotkeys().changed_signal().connect(sigc::mem_fun(*this, &user_interface_implementation::on_assign_hotkeys));
 	}
 
-	~user_interface_implementation()
+	~user_interface()
 	{
-		const boost::filesystem::path hotkey_path = detail::hotkey_path();
-		boost::filesystem::create_directories(hotkey_path.branch_path());
-		k3d::log() << info << "Saving hotkeys to " << hotkey_path.native_file_string() << std::endl;
-		Gtk::AccelMap::save(hotkey_path.native_file_string());
-
-		/** \todo Figure out whether to keep the black box recorder or dump it */
-//		black_box_recorder::instance().stop();
+		const k3d::filesystem::path hotkey_path = detail::hotkey_path();
+		k3d::filesystem::create_directories(hotkey_path.branch_path());
+		k3d::log() << info << "Saving hotkeys to " << hotkey_path.native_console_string() << std::endl;
+		Gtk::AccelMap::save(hotkey_path.native_filesystem_string());
 	}
 
 	static void log_handler(const gchar* LogDomain, GLogLevelFlags LogLevel, const gchar* Message, gpointer UserData)
@@ -299,9 +237,9 @@ public:
 		bool show_splash = true;
 
 		// We want GTK to parse an optional RC file from the user's home directory ...
-		const boost::filesystem::path rc_file = k3d::system::get_home_directory() / boost::filesystem::path(".k3d/gtkrc", boost::filesystem::native);
-		boost::filesystem::create_directories(rc_file.branch_path());
-		if(!boost::filesystem::exists(rc_file))
+		const k3d::filesystem::path rc_file = k3d::system::get_home_directory() / k3d::filesystem::generic_path(".k3d/gtkrc");
+		k3d::filesystem::create_directories(rc_file.branch_path());
+		if(!k3d::filesystem::exists(rc_file))
 		{
 			k3d::filesystem::ofstream stream(rc_file);
 			stream << "# You can add your own K-3D-specific GTK styles here.\n\n";
@@ -317,13 +255,13 @@ public:
 
 			stream << "class \"*\" style \"k3d-style\"\n";
 		}
-		if(boost::filesystem::exists(rc_file))
+		if(k3d::filesystem::exists(rc_file))
 		{
-			Gtk::RC::add_default_file(rc_file.native_file_string());
+			Gtk::RC::add_default_file(rc_file.native_filesystem_string());
 		}
 		else
 		{
-			k3d::log() << warning << "Could not locate or create " << rc_file.native_file_string() << " resource file" << std::endl;
+			k3d::log() << warning << "Could not locate or create " << rc_file.native_console_string() << " resource file" << std::endl;
 		}
 
 		try
@@ -364,7 +302,11 @@ public:
 		{
 			if((*argument) == "--batch")
 			{
-				application_state::instance().batch_mode() = true;
+				application_state::instance().enable_batch_mode();
+			}
+			else if((*argument) == "--no-custom-layouts")
+			{
+				application_state::instance().enable_custom_layouts(false);
 			}
 			else if((*argument) == "--no-splash")
 			{
@@ -379,7 +321,7 @@ public:
 					return arguments_t();
 				}
 
-				m_tutorials_path = boost::filesystem::path(*argument, boost::filesystem::native);
+				m_tutorials_path = k3d::filesystem::native_path(k3d::ustring::from_utf8(*argument));
 			}
 			else if((*argument) == "--show-tutorials")
 			{
@@ -395,10 +337,10 @@ public:
 			}
 		}
 
-		Gtk::Window::set_default_icon(load_pixbuf(k3d::share_path() / "ngui/pixmap", "default_icon.png"));
+		Gtk::Window::set_default_icon(load_pixbuf(k3d::share_path() / k3d::filesystem::generic_path("ngui/pixmap"), k3d::filesystem::generic_path("default_icon.png")));
 
 		if(show_splash)
-			m_splash_box.reset(new splash_box(k3d::share_path() / "ngui/pixmap"));
+			m_splash_box.reset(new splash_box(k3d::share_path() / k3d::filesystem::generic_path("ngui/pixmap")));
 
 		return unused;
 	}
@@ -413,9 +355,9 @@ public:
 	{
 		detail::setup_default_hotkeys();
 
-		const boost::filesystem::path hotkey_path = detail::hotkey_path();
-		k3d::log() << info << "Loading hotkeys from " << hotkey_path.native_file_string() << std::endl;
-		Gtk::AccelMap::load(hotkey_path.native_file_string());
+		const k3d::filesystem::path hotkey_path = detail::hotkey_path();
+		k3d::log() << info << "Loading hotkeys from " << hotkey_path.native_console_string() << std::endl;
+		Gtk::AccelMap::load(hotkey_path.native_filesystem_string());
 
 		k3d::idocument* const document = k3d::application().create_document();
 		return_if_fail(document);
@@ -423,7 +365,7 @@ public:
 		populate_new_document(*document);
 
 		document_state* const state = new document_state(*document);
-		new main_document_window(*state);
+		create_main_document_window(*state);
 
 		if(m_show_tutorials)
 			create_tutorial_menu();
@@ -431,9 +373,6 @@ public:
 		if(m_record_tutorials)
 			create_tutorial_recorder();
 
-		/** \todo Figure out whether to keep the black box recorder or dump it */
-//		black_box_recorder::instance().start();
-
 		m_splash_box.reset();
 	}
 
@@ -457,19 +396,24 @@ public:
 		return_if_fail(libk3dngui::open_uri(URL));
 	}
 
-	void message(const std::string& Message, const std::string& Title)
+	void message(const std::string& Message)
 	{
-		libk3dngui::message(Message, Title);
+		libk3dngui::message(Message);
 	}
 
-	void error_message(const std::string& Message, const std::string& Title)
+	void warning_message(const std::string& Message)
 	{
-		libk3dngui::error_message(Message, Title);
+		libk3dngui::warning_message(Message);
 	}
 
-	unsigned int query_message(const std::string& Message, const std::string& Title, const unsigned int DefaultButton, const std::vector<std::string> Buttons)
+	void error_message(const std::string& Message)
 	{
-		return libk3dngui::query_message(Message, Title, DefaultButton, Buttons);
+		libk3dngui::error_message(Message);
+	}
+
+	unsigned int query_message(const std::string& Message, const unsigned int DefaultOption, const std::vector<std::string>& Options)
+	{
+		return libk3dngui::query_message(Message, DefaultOption, Options);
 	}
 
 	bool tutorial_message(const std::string& Message)
@@ -478,7 +422,7 @@ public:
 		return tutorial_message::instance().show_message(Message);
 	}
 
-	bool get_file_path(const k3d::ipath_property::mode_t Mode, const std::string& Type, const std::string& Prompt, const boost::filesystem::path& OldPath, boost::filesystem::path& Result)
+	bool get_file_path(const k3d::ipath_property::mode_t Mode, const std::string& Type, const std::string& Prompt, const k3d::filesystem::path& OldPath, k3d::filesystem::path& Result)
 	{
 		file_chooser_dialog dialog(Prompt, Type, Mode);
 		return dialog.get_file_path(Result);
@@ -514,7 +458,7 @@ public:
 	static k3d::iplugin_factory& get_factory()
 	{
 		static k3d::plugin_factory<
-			k3d::application_plugin<user_interface_implementation>,
+			k3d::application_plugin<user_interface>,
 			k3d::interface_list<k3d::iuser_interface_plugin> > factory(
 				get_class_id(),
 				"NextGenerationUI",
@@ -525,25 +469,12 @@ public:
 	}
 
 private:
-	void on_assign_hotkeys(k3d::iunknown*)
-	{
-		if(application_state::instance().assign_hotkeys().value())
-		{
-			new detail::assign_hotkeys_popup();
-			Gtk::Settings::get_default()->property_gtk_can_change_accels() = true;
-		}
-		else
-		{
-			Gtk::Settings::get_default()->property_gtk_can_change_accels() = false;
-		}
-	}
-
 	/// Set to true iff we should display the tutorial menu at startup
 	bool m_show_tutorials;
 	/// Set to true iff we should begin recording a tutorial immediately at startup
 	bool m_record_tutorials;
 	/// Stores the path where tutorials should be displayed
-	boost::filesystem::path m_tutorials_path;
+	k3d::filesystem::path m_tutorials_path;
 	/// Stores the main loop
 	std::auto_ptr<Gtk::Main> m_main;
 	/// Stores the (optional) splash screen
@@ -555,7 +486,7 @@ private:
 
 k3d::iplugin_factory& user_interface_factory()
 {
-	return user_interface_implementation::get_factory();
+	return user_interface::get_factory();
 }
 
 } // namespace libk3dngui
