@@ -1,5 +1,5 @@
 // K-3D
-// Copyright (c) 1995-2005, Timothy M. Shead
+// Copyright (c) 1995-2006, Timothy M. Shead
 //
 // Contact: tshead@k-3d.com
 //
@@ -24,15 +24,15 @@
 #include <gtkmm/widget.h>
 
 #include "document_state.h"
-#include "modifiers.h"
 #include "iuser_input_model.h"
+#include "modifiers.h"
 #include "tool.h"
 #include "utility.h"
 #include "viewport.h"
 
 #include <k3dsdk/basic_math.h>
 #include <k3dsdk/classes.h>
-#include <k3dsdk/frames.h>
+#include <k3dsdk/file_range.h>
 #include <k3dsdk/high_res_timer.h>
 #include <k3dsdk/i18n.h>
 #include <k3dsdk/icamera.h>
@@ -50,8 +50,6 @@
 #include <gtk/gtkmain.h>
 
 #include <k3dsdk/fstream.h>
-#include <boost/filesystem/path.hpp>
-
 #include <cassert>
 #include <iomanip>
 #include <sstream>
@@ -74,6 +72,7 @@ const k3d::gl::select_state select_points()
 {
 	k3d::gl::select_state result;
 
+	result.exclude_unselected_nodes = true;
 	result.select_points = true;
 	result.select_point_groups = true;
 
@@ -83,7 +82,8 @@ const k3d::gl::select_state select_points()
 const k3d::gl::select_state select_lines()
 {
 	k3d::gl::select_state result;
-	
+
+	result.exclude_unselected_nodes = true;
 	result.select_edges = true;
 	result.select_linear_curves = true;
 	result.select_cubic_curves = true;
@@ -95,7 +95,8 @@ const k3d::gl::select_state select_lines()
 const k3d::gl::select_state select_faces()
 {
 	k3d::gl::select_state result;
-	
+
+	result.exclude_unselected_nodes = true;
 	result.select_faces = true;
 	result.select_bilinear_patches = true;
 	result.select_bicubic_patches = true;
@@ -256,12 +257,12 @@ private:
 };
 
 /// Convenience function used to choose whichever point is closest to the given window coordinates
-void select_nearest_point(const k3d::point* const Point, const k3d::vector2& Coordinates, const double ScreenHeight, const GLdouble ModelViewMatrix[16], const GLdouble ProjectionMatrix[16], const GLint Viewport[4], const k3d::point*& OutputPoint, double& OutputDistance)
+void select_nearest_point(const k3d::point* const Point, const k3d::point2& Coordinates, const double ScreenHeight, const GLdouble ModelViewMatrix[16], const GLdouble ProjectionMatrix[16], const GLint Viewport[4], const k3d::point*& OutputPoint, double& OutputDistance)
 {
 	if(!Point)
 		return;
 
-	k3d::vector2 coords;
+	k3d::point2 coords;
 	double unused;
 	gluProject(
 		Point->position[0],
@@ -275,7 +276,7 @@ void select_nearest_point(const k3d::point* const Point, const k3d::vector2& Coo
 		&unused);
 	coords[1] = ScreenHeight - coords[1];
 
-	const double distance = (coords - Coordinates).Length2();
+	const double distance = k3d::to_vector(coords - Coordinates).length2();
 	if(distance < OutputDistance)
 	{
 		OutputPoint = Point;
@@ -284,7 +285,7 @@ void select_nearest_point(const k3d::point* const Point, const k3d::vector2& Coo
 }
 
 /// Convenience function used to choose whichever edge is closest to the mouse pointer in window coordinates
-void select_nearest_edge(const k3d::split_edge* const Edge, const k3d::vector2& Coordinates, const double ScreenHeight, const GLdouble ModelViewMatrix[16], const GLdouble ProjectionMatrix[16], const GLint Viewport[4], const k3d::split_edge*& OutputEdge, double& OutputDistance)
+void select_nearest_edge(const k3d::split_edge* const Edge, const k3d::point2& Coordinates, const double ScreenHeight, const GLdouble ModelViewMatrix[16], const GLdouble ProjectionMatrix[16], const GLint Viewport[4], const k3d::split_edge*& OutputEdge, double& OutputDistance)
 {
 	return_if_fail(Edge && Edge->vertex && Edge->face_clockwise && Edge->face_clockwise->vertex);
 
@@ -303,7 +304,7 @@ void select_nearest_edge(const k3d::split_edge* const Edge, const k3d::vector2&
 		&y1,
 		&unused);
 
-	const k3d::vector2 S1(x1, ScreenHeight - y1);
+	const k3d::point2 S1(x1, ScreenHeight - y1);
 
 	// Second edge end : S2
 	gluProject(
@@ -317,27 +318,27 @@ void select_nearest_edge(const k3d::split_edge* const Edge, const k3d::vector2&
 		&y2,
 		&unused);
 
-	const k3d::vector2 S2(x2, ScreenHeight - y2);
+	const k3d::point2 S2(x2, ScreenHeight - y2);
 
 	// Coordinates to segment distance
 	double distance = 0;
 
-	const k3d::vector2 edge = S2 - S1;
-	const k3d::vector2 w = Coordinates - S1;
+	const k3d::point2 edge = S2 - S1;
+	const k3d::point2 w = Coordinates - S1;
 
 	const double c1 = w * edge;
 	if(c1 <= 0)
-		distance = (Coordinates - S1).Length();
+		distance = k3d::distance(Coordinates, S1);
 	else
 	{
 		const double c2 = edge * edge;
 		if(c2 <= c1)
-			distance = (Coordinates - S2).Length();
+			distance = k3d::distance(Coordinates, S2);
 		else
 		{
 			const double b = c1 / c2;
-			const k3d::vector2 middlepoint = S1 + b * edge;
-			distance = (Coordinates - middlepoint).Length();
+			const k3d::point2 middlepoint = S1 + b * edge;
+			distance = k3d::distance(Coordinates, middlepoint);
 		}
 	}
 
@@ -350,27 +351,73 @@ void select_nearest_edge(const k3d::split_edge* const Edge, const k3d::vector2&
 
 } // namespace detail
 
+/////////////////////////////////////////////////////////////////////////////
+// control::implementation
+
+class control::implementation
+{
+public:
+	implementation(document_state& DocumentState) :
+		m_document_state(DocumentState),
+		m_camera(init_value<k3d::icamera*>(0)),
+		m_gl_engine(init_value<k3d::gl::irender_engine*>(0)),
+		m_preview_engine(init_value<k3d::icamera_preview_render_engine*>(0)),
+		m_still_engine(init_value<k3d::icamera_still_render_engine*>(0)),
+		m_animation_engine(init_value<k3d::icamera_animation_render_engine*>(0)),
+		m_font_begin(0),
+		m_font_end(0)
+	{
+	}
+	
+	/// Stores a reference to the owning document
+	document_state& m_document_state;
+	/// Stores a reference to the current camera
+	k3d_data(k3d::icamera*, no_name, change_signal, no_undo, node_storage, no_constraint, no_property, no_serialization) m_camera;
+	/// Stores a reference to the current OpenGL render engine
+	k3d_data(k3d::gl::irender_engine*, no_name, change_signal, no_undo, node_storage, no_constraint, no_property, no_serialization) m_gl_engine;
+	/// Stores a reference to the current preview render engine
+	k3d_data(k3d::icamera_preview_render_engine*, no_name, change_signal, no_undo, node_storage, no_constraint, no_property, no_serialization) m_preview_engine;
+	/// Stores a reference to the current still render engine
+	k3d_data(k3d::icamera_still_render_engine*, no_name, change_signal, no_undo, node_storage, no_constraint, no_property, no_serialization) m_still_engine;
+	/// Stores a reference to the current animation render engine
+	k3d_data(k3d::icamera_animation_render_engine*, no_name, change_signal, no_undo, node_storage, no_constraint, no_property, no_serialization) m_animation_engine;
+
+	/// Stores the current set of OpenGL font glyphs (generated from Pango by gtkglext)
+	unsigned long m_font_begin;
+	/// Stores the current set of OpenGL font glyphs (generated from Pango by gtkglext)
+	unsigned long m_font_end;
+
+	/// Stores a connection to the attached OpenGL render engine redraw request signal
+	sigc::connection m_gl_engine_redraw_request_connection;
+
+	/// Buffers OpenGL hit records
+	typedef std::vector<GLuint> gl_selection_buffer_t;
+	gl_selection_buffer_t m_selection_buffer;
+
+	// Buffers parameters from the most-recent render
+	GLdouble m_gl_view_matrix[16];
+	GLdouble m_gl_projection_matrix[16];
+	GLint m_gl_viewport[4];
+
+	/// Signal that will be emitted whenever this control should grab the panel focus
+	sigc::signal<void> m_panel_grab_signal;
+};
+
 /////////////////////////////////////////////////////////////////////////////
 // control
 
 control::control(document_state& DocumentState, k3d::icommand_node& Parent) :
 	ui_component("viewport", &Parent),
-	property_collection(),
-	m_document_state(DocumentState),
-	m_camera(init_value<k3d::icamera*>(0)),
-	m_gl_engine(init_value<k3d::gl::irender_engine*>(0)),
-	m_preview_engine(init_value<k3d::ipreview_render_engine*>(0)),
-	m_still_engine(init_value<k3d::istill_render_engine*>(0)),
-	m_animation_engine(init_value<k3d::ianimation_render_engine*>(0)),
-	m_font_begin(0),
-	m_font_end(0)
+	m_implementation(new implementation(DocumentState))
 {
-	m_camera.changed_signal().connect(sigc::mem_fun(*this, &control::on_camera_changed));
-	m_gl_engine.changed_signal().connect(sigc::mem_fun(*this, &control::on_gl_engine_changed));
+	m_implementation->m_camera.changed_signal().connect(sigc::mem_fun(*this, &control::on_camera_changed));
+	m_implementation->m_gl_engine.changed_signal().connect(sigc::mem_fun(*this, &control::on_gl_engine_changed));
 
 	set_flags(Gtk::CAN_FOCUS);
 	add_events(Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK | Gdk::KEY_PRESS_MASK | Gdk::POINTER_MOTION_MASK | Gdk::SCROLL_MASK);
 
+	signal_button_press_event().connect(sigc::bind_return(sigc::hide(m_implementation->m_panel_grab_signal.make_slot()), false), false);
+
 	signal_expose_event().connect(sigc::hide(sigc::mem_fun(*this, &control::on_redraw)));
 	set_double_buffered(false);
 
@@ -379,70 +426,75 @@ control::control(document_state& DocumentState, k3d::icommand_node& Parent) :
 	return_if_fail(config);
 
 	return_if_fail(
-		gtk_widget_set_gl_capability(GTK_WIDGET(gobj()), config, m_document_state.gdkgl_share_list(), true, GDK_GL_RGBA_TYPE));
+		gtk_widget_set_gl_capability(GTK_WIDGET(gobj()), config, m_implementation->m_document_state.gdkgl_share_list(), true, GDK_GL_RGBA_TYPE));
 
 	show_all();
 }
 
+sigc::connection control::connect_focus_signal(const sigc::slot<void>& Slot)
+{
+	return m_implementation->m_panel_grab_signal.connect(Slot);
+}
+
 k3d::idocument& control::document()
 {
-	return m_document_state.document();
+	return m_implementation->m_document_state.document();
 }
 
 k3d::icamera* const control::camera()
 {
-	return m_camera.value();
+	return m_implementation->m_camera.value();
 }
 
 k3d::gl::irender_engine* const control::gl_engine()
 {
-	return m_gl_engine.value();
+	return m_implementation->m_gl_engine.value();
 }
 
-k3d::ipreview_render_engine* const control::preview_engine()
+k3d::icamera_preview_render_engine* const control::camera_preview_engine()
 {
-	return m_preview_engine.value();
+	return m_implementation->m_preview_engine.value();
 }
 
-k3d::istill_render_engine* const control::still_engine()
+k3d::icamera_still_render_engine* const control::camera_still_engine()
 {
-	return m_still_engine.value();
+	return m_implementation->m_still_engine.value();
 }
 
-k3d::ianimation_render_engine* const control::animation_engine()
+k3d::icamera_animation_render_engine* const control::camera_animation_engine()
 {
-	return m_animation_engine.value();
+	return m_implementation->m_animation_engine.value();
 }
 
 void control::set_camera(k3d::icamera* const Camera)
 {
-	m_camera.set_value(Camera);
+	m_implementation->m_camera.set_value(Camera);
 }
 
 void control::set_gl_engine(k3d::gl::irender_engine* const Engine)
 {
-	m_gl_engine_redraw_request_connection.disconnect();
+	m_implementation->m_gl_engine_redraw_request_connection.disconnect();
 	if(Engine)
-		m_gl_engine_redraw_request_connection = Engine->redraw_request_signal().connect(sigc::mem_fun(*this, &control::on_redraw_request));
+		m_implementation->m_gl_engine_redraw_request_connection = Engine->redraw_request_signal().connect(sigc::mem_fun(*this, &control::on_redraw_request));
 
-	m_gl_engine.set_value(Engine);
+	m_implementation->m_gl_engine.set_value(Engine);
 
 	on_redraw_request(k3d::gl::irender_engine::SYNCHRONOUS);
 }
 
-void control::set_preview_engine(k3d::ipreview_render_engine* const Engine)
+void control::set_camera_preview_engine(k3d::icamera_preview_render_engine* const Engine)
 {
-	m_preview_engine.set_value(Engine);
+	m_implementation->m_preview_engine.set_value(Engine);
 }
 
-void control::set_still_engine(k3d::istill_render_engine* const Engine)
+void control::set_camera_still_engine(k3d::icamera_still_render_engine* const Engine)
 {
-	m_still_engine.set_value(Engine);
+	m_implementation->m_still_engine.set_value(Engine);
 }
 
-void control::set_animation_engine(k3d::ianimation_render_engine* const Engine)
+void control::set_camera_animation_engine(k3d::icamera_animation_render_engine* const Engine)
 {
-	m_animation_engine.set_value(Engine);
+	m_implementation->m_animation_engine.set_value(Engine);
 }
 
 const k3d::matrix4 control::get_view_matrix()
@@ -457,40 +509,40 @@ void control::set_view_matrix(const k3d::matrix4& Matrix)
 	k3d::set_matrix(camera()->navigation_target(), Matrix);
 }
 
-const k3d::vector3 control::get_target()
+const k3d::point3 control::get_target()
 {
-	return m_target;
+	return boost::any_cast<k3d::point3>(camera()->world_target().property_value());
 }
 
-void control::set_target(const k3d::vector3& Target)
+void control::set_target(const k3d::point3& Target)
 {
-	m_target = Target;
+	k3d::set_value(*camera(), "world_target", Target);
 }
 
-const k3d::normal3 control::get_up_axis()
+const k3d::vector3 control::get_up_axis()
 {
-	return k3d::normal3(0, 0, 1);
+	return k3d::vector3(0, 0, 1);
 }
 
 void control::get_gl_viewport(GLdouble ViewMatrix[16], GLdouble ProjectionMatrix[16], GLint Viewport[4])
 {
-	std::copy(m_gl_view_matrix, m_gl_view_matrix + 16, ViewMatrix);
-	std::copy(m_gl_projection_matrix, m_gl_projection_matrix + 16, ProjectionMatrix);
-	std::copy(m_gl_viewport, m_gl_viewport + 4, Viewport);
+	std::copy(m_implementation->m_gl_view_matrix, m_implementation->m_gl_view_matrix + 16, ViewMatrix);
+	std::copy(m_implementation->m_gl_projection_matrix, m_implementation->m_gl_projection_matrix + 16, ProjectionMatrix);
+	std::copy(m_implementation->m_gl_viewport, m_implementation->m_gl_viewport + 4, Viewport);
 }
 
-const k3d::vector2 control::project(const k3d::vector3& WorldCoords)
+const k3d::point2 control::project(const k3d::point3& WorldCoords)
 {
-	k3d::vector2 coords;
+	k3d::point2 coords;
 	double unused;
 
 	gluProject(
 		WorldCoords[0],
 		WorldCoords[1],
 		WorldCoords[2],
-		m_gl_view_matrix,
-		m_gl_projection_matrix,
-		m_gl_viewport,
+		m_implementation->m_gl_view_matrix,
+		m_implementation->m_gl_projection_matrix,
+		m_implementation->m_gl_viewport,
 		&coords[0],
 		&coords[1],
 		&unused);
@@ -499,51 +551,45 @@ const k3d::vector2 control::project(const k3d::vector3& WorldCoords)
 	return coords;
 }
 
-bool control::render_frame(k3d::icamera& Camera, const boost::filesystem::path& OutputImage, const bool ViewCompletedImage)
+bool control::render_camera_frame(k3d::icamera& Camera, const k3d::filesystem::path& OutputImage, const bool ViewCompletedImage)
 {
 	return save_frame(Camera, OutputImage, ViewCompletedImage);
 }
 
-bool control::render_animation(k3d::icamera& Camera, const boost::filesystem::path& OutputImages, const bool ViewCompletedImages)
+bool control::render_camera_animation(k3d::icamera& Camera, const k3d::file_range& Files, const bool ViewCompletedImages)
 {
-	// Sanity checks ...
-	return_val_if_fail(!OutputImages.empty(), false);
-
 	// Ensure that the document has animation capabilities, first ...
-	k3d::iproperty* const start_time_property = k3d::get_start_time(m_document_state.document());
-	k3d::iproperty* const end_time_property = k3d::get_end_time(m_document_state.document());
-	k3d::iproperty* const frame_rate_property = k3d::get_frame_rate(m_document_state.document());
-	k3d::iwritable_property* const time_property = dynamic_cast<k3d::iwritable_property*>(k3d::get_time(m_document_state.document()));
+	k3d::iproperty* const start_time_property = k3d::get_start_time(m_implementation->m_document_state.document());
+	k3d::iproperty* const end_time_property = k3d::get_end_time(m_implementation->m_document_state.document());
+	k3d::iproperty* const frame_rate_property = k3d::get_frame_rate(m_implementation->m_document_state.document());
+	k3d::iwritable_property* const time_property = dynamic_cast<k3d::iwritable_property*>(k3d::get_time(m_implementation->m_document_state.document()));
 	return_val_if_fail(start_time_property && end_time_property && frame_rate_property && time_property, false);
 
 	// Test the output images filepath to make sure it can hold all the frames we're going to generate ...
-	const double start_time = boost::any_cast<double>(k3d::get_value(m_document_state.document().dag(), *start_time_property));
-	const double end_time = boost::any_cast<double>(k3d::get_value(m_document_state.document().dag(), *end_time_property));
-	const double frame_rate = boost::any_cast<double>(k3d::get_value(m_document_state.document().dag(), *frame_rate_property));
+	const double start_time = boost::any_cast<double>(k3d::get_value(m_implementation->m_document_state.document().dag(), *start_time_property));
+	const double end_time = boost::any_cast<double>(k3d::get_value(m_implementation->m_document_state.document().dag(), *end_time_property));
+	const double frame_rate = boost::any_cast<double>(k3d::get_value(m_implementation->m_document_state.document().dag(), *frame_rate_property));
 
-	const long start_frame = static_cast<long>(k3d::round(frame_rate * start_time));
-	const long end_frame = static_cast<long>(k3d::round(frame_rate * end_time));
+	const size_t start_frame = static_cast<size_t>(k3d::round(frame_rate * start_time));
+	const size_t end_frame = static_cast<size_t>(k3d::round(frame_rate * end_time));
 
-	k3d::frames frames(OutputImages, start_frame, end_frame);
-	return_val_if_fail(frames.max_frame() >= end_frame, false);
+	return_val_if_fail(Files.max_file_count() > end_frame, false);
 
 	// For each frame to be rendered ...
-	for(long view_frame = start_frame; view_frame < end_frame; ++view_frame)
+	for(size_t view_frame = start_frame; view_frame < end_frame; ++view_frame)
 	{
 		// Set the frame time ...
 		time_property->property_set_value(view_frame / frame_rate);
 
 		// Save that baby ...
-		boost::filesystem::path destination;
-		frames.frame(view_frame, destination);
-
+		const k3d::filesystem::path destination = Files.file(view_frame);
 		return_val_if_fail(save_frame(Camera, destination, ViewCompletedImages), false);
 	}
 
 	return true;
 }
 
-bool control::save_frame(k3d::icamera& Camera, const boost::filesystem::path& OutputImage, const bool ViewCompletedImage)
+bool control::save_frame(k3d::icamera& Camera, const k3d::filesystem::path& OutputImage, const bool ViewCompletedImage)
 {
 	// Draw the image as we normally would ...
 	const unsigned long width = get_width();
@@ -560,9 +606,9 @@ bool control::save_frame(k3d::icamera& Camera, const boost::filesystem::path& Ou
 
 	create_font();
 	glViewport(0, 0, width, height);
-	if(m_gl_engine.value())
+	if(m_implementation->m_gl_engine.value())
 	{
-		m_gl_engine.value()->redraw(Camera, width, height, m_font_begin, m_gl_view_matrix, m_gl_projection_matrix, m_gl_viewport);
+		m_implementation->m_gl_engine.value()->redraw(Camera, width, height, m_implementation->m_font_begin, m_implementation->m_gl_view_matrix, m_implementation->m_gl_projection_matrix, m_implementation->m_gl_viewport);
 	}
 	else
 	{
@@ -604,12 +650,12 @@ bool control::save_frame(k3d::icamera& Camera, const boost::filesystem::path& Ou
 	return true;
 }
 
-void control::on_camera_changed()
+void control::on_camera_changed(k3d::iunknown*)
 {
 	on_redraw_request(k3d::gl::irender_engine::SYNCHRONOUS);
 }
 
-void control::on_gl_engine_changed()
+void control::on_gl_engine_changed(k3d::iunknown*)
 {
 	on_redraw_request(k3d::gl::irender_engine::SYNCHRONOUS);
 }
@@ -628,58 +674,64 @@ void control::on_redraw_request(k3d::gl::irender_engine::redraw_type_t RedrawTyp
 void control::on_style_changed(const Glib::RefPtr<Gtk::Style>& previous_style)
 {
 	base::on_style_changed(previous_style);
-	glDeleteLists(m_font_begin, m_font_end - m_font_begin);
+	if (m_implementation->m_font_begin != m_implementation->m_font_end)
+		glDeleteLists(m_implementation->m_font_begin, m_implementation->m_font_end - m_implementation->m_font_begin);
 }
 
 void control::create_font()
 {
-	if(m_font_begin != m_font_end)
+	if(m_implementation->m_font_begin != m_implementation->m_font_end)
 		return;
 
 	const unsigned long begin_glyph = 0;
 	const unsigned long end_glyph = 256;
-	m_font_begin = glGenLists(end_glyph - begin_glyph);
-	return_if_fail(m_font_begin);
-	m_font_end = m_font_begin + end_glyph - begin_glyph;
+	m_implementation->m_font_begin = glGenLists(end_glyph - begin_glyph);
+	return_if_fail(m_implementation->m_font_begin);
+	m_implementation->m_font_end = m_implementation->m_font_begin + end_glyph - begin_glyph;
 
-	gdk_gl_font_use_pango_font(get_pango_context()->get_font_description().gobj(), begin_glyph, end_glyph, m_font_begin);
+	// Initialize font
+	return_if_fail(get_pango_context());
+	const Pango::FontDescription& font_description = get_pango_context()->get_font_description();
+	return_if_fail(get_pango_context()->get_font_description().gobj());
+	Glib::RefPtr<Pango::Font> font = Glib::wrap(gdk_gl_font_use_pango_font(font_description.gobj(), begin_glyph, end_glyph, m_implementation->m_font_begin));
+
+	if(font)
+		font->reference();
 }
 
 bool control::on_button_press_event(GdkEventButton* Event)
 {
-	m_document_state.active_tool().input_model().button_press_event(*this, Event);
-
-	// For viewport panel to get focus on mouse click
-	return false;
+	m_implementation->m_document_state.active_tool().input_model().button_press_event(*this, Event);
+	return true;
 }
 
 bool control::on_button_release_event(GdkEventButton* Event)
 {
-	m_document_state.active_tool().input_model().button_release_event(*this, Event);
+	m_implementation->m_document_state.active_tool().input_model().button_release_event(*this, Event);
 	return true;
 }
 
 bool control::on_motion_notify_event(GdkEventMotion* Event)
 {
-	m_document_state.active_tool().input_model().motion_notify_event(*this, Event);
+	m_implementation->m_document_state.active_tool().input_model().motion_notify_event(*this, Event);
 	return true;
 }
 
 bool control::on_scroll_event(GdkEventScroll* Event)
 {
-	m_document_state.active_tool().input_model().scroll_event(*this, Event);
+	m_implementation->m_document_state.active_tool().input_model().scroll_event(*this, Event);
 	return true;
 }
 
 bool control::on_key_press_event(GdkEventKey* Event)
 {
-	m_document_state.active_tool().input_model().key_press_event(*this, Event);
+	m_implementation->m_document_state.active_tool().input_model().key_press_event(*this, Event);
 	return true;
 }
 
 bool control::on_key_release_event(GdkEventKey* Event)
 {
-	m_document_state.active_tool().input_model().key_release_event(*this, Event);
+	m_implementation->m_document_state.active_tool().input_model().key_release_event(*this, Event);
 	return true;
 }
 
@@ -705,7 +757,7 @@ k3d::selection::records control::get_selectable_nodes(const k3d::rectangle& Sele
 
 k3d::selection::records control::get_selectable_objects(const k3d::rectangle& SelectionRegion)
 {
-	switch(m_document_state.selection_mode().value())
+	switch(m_implementation->m_document_state.selection_mode().value())
 	{
 		case SELECT_NODES:
 			return get_selectable_nodes(SelectionRegion);
@@ -725,40 +777,41 @@ k3d::selection::records control::get_selectable_objects(const k3d::rectangle& Se
 	return k3d::selection::records();
 }
 
-k3d::selection::record control::pick_point(const k3d::vector2& Coordinates)
+k3d::selection::record control::pick_point(const k3d::point2& Coordinates)
 {
 	k3d::selection::records records;
 	return pick_point(Coordinates, records);
 }
 
-k3d::selection::record control::pick_line(const k3d::vector2& Coordinates)
+k3d::selection::record control::pick_line(const k3d::point2& Coordinates)
 {
 	k3d::selection::records records;
 	return pick_line(Coordinates, records);
 }
 
-k3d::selection::record control::pick_face(const k3d::vector2& Coordinates)
+k3d::selection::record control::pick_face(const k3d::point2& Coordinates)
 {
 	k3d::selection::records records;
 	return pick_face(Coordinates, records);
 }
 
-k3d::selection::record control::pick_node(const k3d::vector2& Coordinates)
+k3d::selection::record control::pick_node(const k3d::point2& Coordinates)
 {
 	k3d::selection::records records;
 	return pick_node(Coordinates, records);
 }
 
-k3d::selection::record control::pick_object(const k3d::vector2& Coordinates)
+k3d::selection::record control::pick_object(const k3d::point2& Coordinates)
 {
 	k3d::selection::records records;
 	return pick_object(Coordinates, records);
 }
 
-k3d::selection::record control::pick_point(const k3d::vector2& Coordinates, k3d::selection::records& Records)
+k3d::selection::record control::pick_point(const k3d::point2& Coordinates, k3d::selection::records& Records)
 {
 	// Draw everything (will find nearest point if another component is picked)
 	k3d::gl::select_state selection_state;
+	selection_state.exclude_unselected_nodes = true;
 	selection_state.select_points = true;
 	selection_state.select_point_groups = true;
 	selection_state.select_edges = true;
@@ -809,13 +862,13 @@ k3d::selection::record control::pick_point(const k3d::vector2& Coordinates, k3d:
 	{
 		return record;
 	}
-	
+
 	if(tokens.count(POLYHEDRON) && tokens.count(FACE) && tokens.count(SPLIT_EDGE))
 	{
 		k3d::split_edge* edge = mesh->polyhedra[tokens[POLYHEDRON]]->faces[tokens[FACE]]->first_edge;
 		for(unsigned long i = 0; edge && (i != tokens[SPLIT_EDGE]); ++i)
 			edge = edge->face_clockwise;
-		
+
 		k3d::point* const v1 = edge ? edge->vertex : 0;
 		k3d::point* const v2 = edge->face_clockwise ? edge->face_clockwise->vertex : 0;
 
@@ -884,14 +937,15 @@ k3d::selection::record control::pick_point(const k3d::vector2& Coordinates, k3d:
 			return record;
 		}
 	}
-	
+
 	return k3d::selection::record::empty_record();
 }
 
-k3d::selection::record control::pick_line(const k3d::vector2& Coordinates, k3d::selection::records& Records)
+k3d::selection::record control::pick_line(const k3d::point2& Coordinates, k3d::selection::records& Records)
 {
 	// Draw everything (will find nearest point if another component is picked)
 	k3d::gl::select_state selection_state;
+	selection_state.exclude_unselected_nodes = true;
 	selection_state.select_edges = true;
 	selection_state.select_faces = true;
 	selection_state.select_linear_curves = true;
@@ -997,7 +1051,7 @@ k3d::selection::record control::pick_line(const k3d::vector2& Coordinates, k3d::
 						record.tokens.push_back(k3d::selection::token(ABSOLUTE_SPLIT_EDGE, absolute_edge_id));
 						return record;
 					}
-					
+
 					++edge_id;
 					++absolute_edge_id;
 
@@ -1039,7 +1093,7 @@ k3d::selection::record control::pick_line(const k3d::vector2& Coordinates, k3d::
 }
 
 /// Retrieves the face (if any) under the given widget coordinates
-k3d::selection::record control::pick_face(const k3d::vector2& Coordinates, k3d::selection::records& Records)
+k3d::selection::record control::pick_face(const k3d::point2& Coordinates, k3d::selection::records& Records)
 {
 	const double sensitivity = 3;
 	const k3d::rectangle selection_region(
@@ -1063,7 +1117,7 @@ k3d::selection::record control::pick_face(const k3d::vector2& Coordinates, k3d::
 	return k3d::selection::record::empty_record();
 }
 
-k3d::selection::record control::pick_node(const k3d::vector2& Coordinates, k3d::selection::records& Records)
+k3d::selection::record control::pick_node(const k3d::point2& Coordinates, k3d::selection::records& Records)
 {
 	const double sensitivity = 3;
 
@@ -1085,9 +1139,9 @@ k3d::selection::record control::pick_node(const k3d::vector2& Coordinates, k3d::
 	return k3d::selection::record::empty_record();
 }
 
-k3d::selection::record control::pick_object(const k3d::vector2& Coordinates, k3d::selection::records& Records)
+k3d::selection::record control::pick_object(const k3d::point2& Coordinates, k3d::selection::records& Records)
 {
-	switch(m_document_state.selection_mode().value())
+	switch(m_implementation->m_document_state.selection_mode().value())
 	{
 		case SELECT_NODES:
 			return pick_node(Coordinates, Records);
@@ -1122,12 +1176,12 @@ const k3d::selection::records control::get_selection(const k3d::gl::select_state
 
 	const unsigned int hit_count = select(SelectionState, SelectionRegion, ViewMatrix, ProjectionMatrix, Viewport);
 
-	for(detail::hit_iterator hit(m_selection_buffer, hit_count); hit != detail::hit_iterator(); ++hit)
+	for(detail::hit_iterator hit(m_implementation->m_selection_buffer, hit_count); hit != detail::hit_iterator(); ++hit)
 	{
 		k3d::selection::record record;
 		record.zmin = (*hit).zmin();
 		record.zmax = (*hit).zmax();
-		
+
 		for(detail::hit_record::const_name_iterator name = (*hit).name_begin(); name != (*hit).name_end(); )
 		{
 			k3d::selection::type type = k3d::selection::type(*name++);
@@ -1150,7 +1204,6 @@ bool control::on_redraw()
 	if(!width || !height)
 		return true;
 
-
 	if(!is_realized())
 		return true;
 
@@ -1164,12 +1217,13 @@ bool control::on_redraw()
 
 	create_font();
 	glViewport(0, 0, width, height);
-	if(m_gl_engine.value() && m_camera.value())
+	if(m_implementation->m_gl_engine.value() && m_implementation->m_camera.value())
 	{
 		k3d::timer timer;
 
-		m_gl_engine.value()->redraw(*m_camera.value(), width, height, m_font_begin, m_gl_view_matrix, m_gl_projection_matrix, m_gl_viewport);
-		m_document_state.active_tool().redraw(*this);
+		m_implementation->m_gl_engine.value()->redraw(*m_implementation->m_camera.value(), width, height, m_implementation->m_font_begin, m_implementation->m_gl_view_matrix, m_implementation->m_gl_projection_matrix, m_implementation->m_gl_viewport);
+		if(m_implementation->m_document_state.get_focus_viewport() == this)
+			m_implementation->m_document_state.active_tool().redraw(*this);
 
 		const double elapsed = timer.elapsed();
 		if(elapsed)
@@ -1192,7 +1246,7 @@ bool control::on_redraw()
 			glColor3d(0, 0, 0);
 
 			glRasterPos3d(-0.95, -0.95, 0);
-			glListBase(m_font_begin);
+			glListBase(m_implementation->m_font_begin);
 			glCallLists(buffer.str().size(), GL_UNSIGNED_BYTE, buffer.str().data());
 		}
 	}
@@ -1217,7 +1271,7 @@ bool control::on_redraw()
 
 		glRasterPos3d(-0.95, -0.95, 0);
 		const std::string buffer(_("Unattached"));
-		glListBase(m_font_begin);
+		glListBase(m_implementation->m_font_begin);
 		glCallLists(buffer.size(), GL_UNSIGNED_BYTE, buffer.data());
 	}
 	glFlush();
@@ -1242,11 +1296,14 @@ const GLint control::select(const k3d::gl::select_state& SelectState, const k3d:
 const GLint control::select(const k3d::gl::select_state& SelectState, const k3d::rectangle& SelectionRegion, GLdouble ViewMatrix[16], GLdouble ProjectionMatrix[16], GLint Viewport[4])
 {
 	// If we don't have a camera, we're done ...
-	if(!m_camera.value())
+	if(!m_implementation->m_camera.value())
+		return 0;
+
+	if(!is_realized())
 		return 0;
 
 	// Viewport doesn't support selection, so we're done ...
-	k3d::gl::iselection_engine* const selection_engine = dynamic_cast<k3d::gl::iselection_engine*>(m_gl_engine.value());
+	k3d::gl::iselection_engine* const selection_engine = dynamic_cast<k3d::gl::iselection_engine*>(m_implementation->m_gl_engine.value());
 	if(!selection_engine)
 		return 0;
 
@@ -1257,11 +1314,11 @@ const GLint control::select(const k3d::gl::select_state& SelectState, const k3d:
 		return 0;
 
 	// Set our selection buffer to a sensible minimum size ...
-	if(m_selection_buffer.size() < 8096)
-		m_selection_buffer.resize(8096);
+	if(m_implementation->m_selection_buffer.size() < 8096)
+		m_implementation->m_selection_buffer.resize(8096);
 
 	// Set an (arbitrary) upper-limit on how large we let the buffer grow ...
-	while(m_selection_buffer.size() < 10000000)
+	while(m_implementation->m_selection_buffer.size() < 10000000)
 	{
 		// Draw the scene, recording hits ...
 		GdkGLDrawable* const drawable = gtk_widget_get_gl_drawable(GTK_WIDGET(gobj()));
@@ -1275,15 +1332,18 @@ const GLint control::select(const k3d::gl::select_state& SelectState, const k3d:
 		create_font();
 		glViewport(0, 0, width, height);
 
-		glSelectBuffer(m_selection_buffer.size(), &m_selection_buffer[0]);
+		glSelectBuffer(m_implementation->m_selection_buffer.size(), &m_implementation->m_selection_buffer[0]);
 		glRenderMode(GL_SELECT);
 		glInitNames();
-		selection_engine->select(SelectState, *m_camera.value(), width, height, m_font_begin, k3d::normalize(SelectionRegion), m_gl_view_matrix, m_gl_projection_matrix, m_gl_viewport);
-		std::copy(m_gl_view_matrix, m_gl_view_matrix + 16, ViewMatrix);
-		std::copy(m_gl_projection_matrix, m_gl_projection_matrix + 16, ProjectionMatrix);
-		std::copy(m_gl_viewport, m_gl_viewport + 4, Viewport);
 
-		m_document_state.active_tool().select(*this);
+		GLdouble projection_matrix[16];
+		selection_engine->select(SelectState, *m_implementation->m_camera.value(), width, height, m_implementation->m_font_begin, k3d::normalize(SelectionRegion), m_implementation->m_gl_view_matrix, projection_matrix, m_implementation->m_gl_viewport);
+		std::copy(m_implementation->m_gl_view_matrix, m_implementation->m_gl_view_matrix + 16, ViewMatrix);
+		std::copy(projection_matrix, projection_matrix + 16, ProjectionMatrix);
+		std::copy(m_implementation->m_gl_viewport, m_implementation->m_gl_viewport + 4, Viewport);
+
+		if(m_implementation->m_document_state.get_focus_viewport() == this)
+			m_implementation->m_document_state.active_tool().select(*this);
 		const GLint hits = glRenderMode(GL_RENDER);
 		glFlush();
 
@@ -1294,7 +1354,7 @@ const GLint control::select(const k3d::gl::select_state& SelectState, const k3d:
 			return hits;
 
 		// A negative number means there was buffer overflow, so try again ...
-		m_selection_buffer.resize(m_selection_buffer.size() * 2);
+		m_implementation->m_selection_buffer.resize(m_implementation->m_selection_buffer.size() * 2);
 	}
 
 	// Ran out of buffer space!
@@ -1308,10 +1368,10 @@ const GLint control::select(const k3d::gl::select_state& SelectState, const k3d:
 /////////////////////////////////////////////////////////////////////////////
 // widget_to_ndc
 
-const k3d::vector2 widget_to_ndc(viewport::control& Viewport, const k3d::vector2& WidgetCoords)
+const k3d::point2 widget_to_ndc(viewport::control& Viewport, const k3d::point2& WidgetCoords)
 {
-	return_val_if_fail(Viewport.gl_engine(), k3d::vector2());
-	return_val_if_fail(Viewport.camera(), k3d::vector2());
+	return_val_if_fail(Viewport.gl_engine(), k3d::point2());
+	return_val_if_fail(Viewport.camera(), k3d::point2());
 
 	const unsigned long width = Viewport.get_width();
 	const unsigned long height = Viewport.get_height();
@@ -1325,16 +1385,16 @@ const k3d::vector2 widget_to_ndc(viewport::control& Viewport, const k3d::vector2
 	const double x = (window_x - host_rect.left) / (host_rect.right - host_rect.left);
 	const double y = (window_y - host_rect.top) / (host_rect.bottom - host_rect.top);
 
-	return k3d::vector2(x, y);
+	return k3d::point2(x, y);
 }
 
 /////////////////////////////////////////////////////////////////////////////
 // ndc_to_widget
 
-const k3d::vector2 ndc_to_widget(viewport::control& Viewport, const k3d::vector2& NDC)
+const k3d::point2 ndc_to_widget(viewport::control& Viewport, const k3d::point2& NDC)
 {
-	return_val_if_fail(Viewport.gl_engine(), k3d::vector2());
-	return_val_if_fail(Viewport.camera(), k3d::vector2());
+	return_val_if_fail(Viewport.gl_engine(), k3d::point2());
+	return_val_if_fail(Viewport.camera(), k3d::point2());
 
 	const unsigned long width = Viewport.get_width();
 	const unsigned long height = Viewport.get_height();
@@ -1348,30 +1408,29 @@ const k3d::vector2 ndc_to_widget(viewport::control& Viewport, const k3d::vector2
 	const double x = (host_x - window_rect.left) / (window_rect.right - window_rect.left);
 	const double y = (host_y - window_rect.top) / (window_rect.bottom - window_rect.top);
 
-	return k3d::vector2(width * x, height * y);
+	return k3d::point2(width * x, height * y);
 }
 
 /////////////////////////////////////////////////////////////////////////////
 // mouse_to_world
 
-const k3d::line3 mouse_to_world(viewport::control& Viewport, const k3d::vector2& WidgetCoords)
+const k3d::line3 mouse_to_world(viewport::control& Viewport, const k3d::point2& WidgetCoords)
 {
-	return_val_if_fail(Viewport.gl_engine(), k3d::line3(k3d::normal3(), k3d::vector3()));
+	return_val_if_fail(Viewport.gl_engine(), k3d::line3(k3d::vector3(), k3d::point3()));
 
 	GLdouble gl_view_matrix[16];
 	GLdouble gl_projection_matrix[16];
 	GLint gl_viewport[4];
 	Viewport.get_gl_viewport(gl_view_matrix, gl_projection_matrix, gl_viewport);
 
-	k3d::vector3 near_plane;
+	k3d::point3 near_plane;
 	gluUnProject(WidgetCoords[0], Viewport.get_height() - WidgetCoords[1], 0.0, gl_view_matrix, gl_projection_matrix, gl_viewport, &near_plane[0], &near_plane[1], &near_plane[2]);
 
-	k3d::vector3 far_plane;
+	k3d::point3 far_plane;
 	gluUnProject(WidgetCoords[0], Viewport.get_height() - WidgetCoords[1], 1.0, gl_view_matrix, gl_projection_matrix, gl_viewport, &far_plane[0], &far_plane[1], &far_plane[2]);
 
-	return k3d::line3(to_normal(far_plane - near_plane), near_plane);
+	return k3d::line3(to_vector(far_plane - near_plane), near_plane);
 }
 
 } // namespace libk3dngui
 
-
