@@ -56,7 +56,7 @@ bool dynamic_accelerator_on_enter_notify_event(GdkEventCrossing*, Gtk::Widget* W
 	return_val_if_fail(Widget, false);
 
 	// Unless assign hotkeys mode is enabled, we're done ...
-	if(!application_state::instance().assign_hotkeys().value())
+	if(!application_state::instance().assign_hotkeys())
 		return false;
 
 	// If the widget doesn't have an accelerator path, we're done ...
@@ -72,7 +72,7 @@ bool dynamic_accelerator_on_key_press_event(GdkEventKey*, Gtk::Widget* Widget)
 	return_val_if_fail(Widget, false);
 
 	// Unless assign hotkeys mode is enabled, we're done ...
-	if(!application_state::instance().assign_hotkeys().value())
+	if(!application_state::instance().assign_hotkeys())
 		return false;
 
 	// If the widget doesn't have an accelerator path, we're done ...
