@@ -67,30 +67,34 @@ public:
 	{
 		return true;
 	}
-	
+
 	void browser_navigate(const std::string& URL)
 	{
 	}
-	
-	void message(const std::string& Message, const std::string& Title)
+
+	void message(const std::string& Message)
 	{
 	}
-	
-	void error_message(const std::string& Message, const std::string& Title)
+
+	void warning_message(const std::string& Message)
 	{
 	}
-	
-	unsigned int query_message(const std::string& Message, const std::string& Title, const unsigned int DefaultButton, const std::vector<std::string> Buttons)
+
+	void error_message(const std::string& Message)
+	{
+	}
+
+	unsigned int query_message(const std::string& Message, const unsigned int DefaultOption, const std::vector<std::string>& Options)
 	{
 		return 0;
 	}
-	
+
 	bool tutorial_message(const std::string& Message)
 	{
 		return false;
 	}
-	
-	bool get_file_path(const k3d::ipath_property::mode_t Mode, const std::string& Type, const std::string& Prompt, const boost::filesystem::path& OldPath, boost::filesystem::path& Result)
+
+	bool get_file_path(const k3d::ipath_property::mode_t Mode, const std::string& Type, const std::string& Prompt, const k3d::filesystem::path& OldPath, k3d::filesystem::path& Result)
 	{
 		return false;
 	}
