@@ -1,20 +1,18 @@
 #python
 
-import k3d
-
-doc = k3d.Document
+doc = Document
 doc.start_change_set()
 try:
-	material = doc.new_object("RenderManMaterial")
+	material = doc.new_node("RenderManMaterial")
 	material.name = "Patch Material"
 	material.color = (1, 1, 1)
 
-	frozen_mesh = doc.new_object("FrozenMesh")
+	frozen_mesh = doc.new_node("FrozenMesh")
 	frozen_mesh.name = "Bilinear Patch"
 
 	mesh = frozen_mesh.new_mesh()
 
-	points = ((0, 5, 5), (5, 5, -5), (-5, -5, 0), (5, -5, 0))
+	points = ((-5, 0, 5), (5, 0, 5), (0, -5, -5), (0, 5, -5))
 	for position in points:
 		mesh.new_point(position)
 
@@ -33,7 +31,7 @@ try:
 	patch.varying_data[2].set_color("Cs", (0, 0, 1))
 	patch.varying_data[3].set_color("Cs", (1, 1, 1))
 
-	mesh_instance = doc.new_object("MeshInstance")
+	mesh_instance = doc.new_node("MeshInstance")
 	mesh_instance.name = "Bilinear Patch Instance"
 	doc.set_dependency(mesh_instance.get_property("input_mesh"), frozen_mesh.get_property("output_mesh"))
 
