@@ -1,20 +1,18 @@
 #python
 
-import k3d
-
-doc = k3d.Document
+doc = Document
 doc.start_change_set()
 try:
-	material = doc.new_object("RenderManMaterial")
+	material = doc.new_node("RenderManMaterial")
 	material.name = "Square Material"
 	material.color = (1, 1, 1)
-	frozen_mesh = doc.new_object("FrozenMesh")
+	frozen_mesh = doc.new_node("FrozenMesh")
 
 	frozen_mesh.name = "Square"
 
 	mesh = frozen_mesh.new_mesh()
 
-	positions = ((-5, 5, 0), (5, 5, 0), (5, -5, 0), (-5, -5, 0))
+	positions = ((-5, 0, 5), (5, 0, 5), (5, 0, -5), (-5, 0, -5))
 	points = []
 	for position in positions:
 		points.append(mesh.new_point(position))
@@ -37,7 +35,7 @@ try:
 	points[2].vertex_data.set_color("Cs", (0, 0, 1))
 	points[3].vertex_data.set_color("Cs", (1, 1, 1))
 
-	mesh_instance = doc.new_object("MeshInstance")
+	mesh_instance = doc.new_node("MeshInstance")
 	mesh_instance.name = "Square Instance"
 	doc.set_dependency(mesh_instance.get_property("input_mesh"), frozen_mesh.get_property("output_mesh"))
 
