@@ -873,7 +873,7 @@ public:
 			}
 			catch (cache_invalid_exception& E)
 			{
-				k3d::log() << debug << "Invalidating cache during update" << std::endl;
+//				k3d::log() << debug << "Invalidating cache during update" << std::endl;
 				m_valid = false;
 				set_input(m_first_level_cache_mesh);
 				update();
@@ -882,7 +882,7 @@ public:
 		else // invalid cache
 		{
 			delete m_higher_level_cache;
-			k3d::log() << debug << "cache reset" << std::endl;
+//			k3d::log() << debug << "cache reset" << std::endl;
 			m_higher_level_cache = new higher_level_cache(m_levels, m_use_nurbs, m_first_level_cache->face_vertices());
 			update_detail(true);
 			m_valid = true;
@@ -896,7 +896,7 @@ public:
 		if (m_valid && m_first_level_cache && m_first_level_cache->set_input(Input))
 			return;
 		delete m_first_level_cache;
-		k3d::log() << debug << "input reset" << std::endl;
+//		k3d::log() << debug << "input reset" << std::endl;
 		m_first_level_cache = create_cache_input(Input);
 		m_valid = false;
 	}
